#! /bin/false

# Copyright (C) 2019 Guido Flohr <guido.flohr@cantanea.com>,
# all rights reserved.

# This program is free software. It comes without any warranty, to
# the extent permitted by applicable law. You can redistribute it
# and/or modify it under the terms of the Do What the Fuck You Want
# to Public License, Version 2, as published by Sam Hocevar. See
# http://www.wtfpl.net/ for more details.

# Make Dist::Zilla happy.
# ABSTRACT: Read chess opening books in polyglot format

package Chess::Opening::ECO;
$Chess::Opening::ECO::VERSION = '0.6';
use common::sense;

use Locale::TextDomain 'com.cantanea.Chess-Opening';

sub positions {
	return {
		'rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR w KQkq' => {
			eco => 'A00a',
			# TRANSLATORS: A00a:
			variation => N__('Start'),
			moves => {
				'a2a3' => 1,
				'a2a4' => 1,
				'b1a3' => 1,
				'b1c3' => 1,
				'b2b3' => 1,
				'b2b4' => 1,
				'c2c3' => 1,
				'c2c4' => 1,
				'd2d3' => 1,
				'd2d4' => 1,
				'e2e3' => 1,
				'e2e4' => 1,
				'f2f3' => 1,
				'f2f4' => 1,
				'g1f3' => 1,
				'g1h3' => 1,
				'g2g3' => 1,
				'g2g4' => 1,
				'h2h3' => 1,
				'h2h4' => 1,
			},
		},
		'rnbqkbnr/pppppppp/8/8/8/5P2/PPPPP1PP/RNBQKBNR b KQkq' => {
			eco => 'A00b',
			# TRANSLATORS: A00b: 1. f3
			variation => N__('Barnes Opening'),
			moves => {
				'e7e5' => 1,
			},
		},
		'rnbqkbnr/pppp1ppp/8/4p3/8/5P2/PPPPP1PP/RNBQKBNR w KQkq' => {
			eco => 'A00b',
			# TRANSLATORS: A00b: 1. f3 e5
			variation => N__('Barnes Opening'),
			moves => {
				'e1f2' => 1,
			},
		},
		'rnbqkbnr/pppp1ppp/8/4p3/8/5P2/PPPPPKPP/RNBQ1BNR b kq' => {
			eco => 'A00b',
			# TRANSLATORS: A00b: 1. f3 e5 2. Kf2
			variation => N__('Fried fox'),
			moves => {
			},
		},
		'rnbqkbnr/pppppppp/8/8/7P/8/PPPPPPP1/RNBQKBNR b KQkq' => {
			eco => 'A00c',
			# TRANSLATORS: A00c: 1. h4
			variation => N__('Kadas Opening'),
			moves => {
			},
		},
		'rnbqkbnr/pppppppp/8/8/8/7P/PPPPPPP1/RNBQKBNR b KQkq' => {
			eco => 'A00d',
			# TRANSLATORS: A00d: 1. h3
			variation => N__('Clemenz Opening'),
			moves => {
			},
		},
		'rnbqkbnr/pppppppp/8/8/P7/8/1PPPPPPP/RNBQKBNR b KQkq' => {
			eco => 'A00e',
			# TRANSLATORS: A00e: 1. a4
			variation => N__('Ware Opening'),
			moves => {
			},
		},
		'rnbqkbnr/pppppppp/8/8/8/P7/1PPPPPPP/RNBQKBNR b KQkq' => {
			eco => 'A00f',
			# TRANSLATORS: A00f: 1. a3
			variation => N__('Anderssen Opening'),
			moves => {
				'e7e5' => 1,
			},
		},
		'rnbqkbnr/pppp1ppp/8/4p3/8/P7/1PPPPPPP/RNBQKBNR w KQkq' => {
			eco => 'A00f',
			# TRANSLATORS: A00f: 1. a3 e5
			variation => N__('Anderssen Opening'),
			moves => {
				'h2h3' => 1,
			},
		},
		'rnbqkbnr/pppp1ppp/8/4p3/8/P6P/1PPPPPP1/RNBQKBNR b KQkq' => {
			eco => 'A00f',
			# TRANSLATORS: A00f: 1. a3 e5 2. h3
			variation => N__('Anderssen Opening'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/8/3pp3/8/P6P/1PPPPPP1/RNBQKBNR w KQkq' => {
			eco => 'A00f',
			# TRANSLATORS: A00f: 1. a3 e5 2. h3 d5
			variation => N__('Creepy Crawly Opening (Basman)'),
			moves => {
			},
		},
		'rnbqkbnr/pppppppp/8/8/8/7N/PPPPPPPP/RNBQKB1R b KQkq' => {
			eco => 'A00g',
			# TRANSLATORS: A00g: 1. Nh3
			variation => N__('Amar/Paris Opening'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/8/7N/PPPPPPPP/RNBQKB1R w KQkq' => {
			eco => 'A00g',
			# TRANSLATORS: A00g: 1. Nh3 d5
			variation => N__('Amar/Paris Opening'),
			moves => {
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/8/6PN/PPPPPP1P/RNBQKB1R b KQkq' => {
			eco => 'A00g',
			# TRANSLATORS: A00g: 1. Nh3 d5 2. g3
			variation => N__('Amar/Paris Opening'),
			moves => {
				'e7e5' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/8/3pp3/8/6PN/PPPPPP1P/RNBQKB1R w KQkq' => {
			eco => 'A00g',
			# TRANSLATORS: A00g: 1. Nh3 d5 2. g3 e5
			variation => N__('Amar/Paris Opening'),
			moves => {
				'f2f4' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/8/3pp3/5P2/6PN/PPPPP2P/RNBQKB1R b KQkq' => {
			eco => 'A00g',
			# TRANSLATORS: A00g: 1. Nh3 d5 2. g3 e5 3. f4
			variation => N__('Amar: Paris Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pppppppp/8/8/8/N7/PPPPPPPP/R1BQKBNR b KQkq' => {
			eco => 'A00h',
			# TRANSLATORS: A00h: 1. Na3
			variation => N__('Durkin'),
			moves => {
			},
		},
		'rnbqkbnr/pppppppp/8/8/8/2P5/PP1PPPPP/RNBQKBNR b KQkq' => {
			eco => 'A00i',
			# TRANSLATORS: A00i: 1. c3
			variation => N__('Saragossa'),
			moves => {
			},
		},
		'rnbqkbnr/pppppppp/8/8/8/3P4/PPP1PPPP/RNBQKBNR b KQkq' => {
			eco => 'A00j',
			# TRANSLATORS: A00j: 1. d3
			variation => N__('Mieses'),
			moves => {
				'd7d5' => 1,
				'e7e5' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/8/3P4/PPP1PPPP/RNBQKBNR w KQkq' => {
			eco => 'A00j',
			# TRANSLATORS: A00j: 1. d3 d5
			variation => N__('Mieses: 1... d5'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/4p3/8/3P4/PPP1PPPP/RNBQKBNR w KQkq' => {
			eco => 'A00j',
			# TRANSLATORS: A00j: 1. d3 e5
			variation => N__('Mieses: 1... e5'),
			moves => {
			},
		},
		'rnbqkbnr/pppppp1p/6p1/8/8/3P4/PPP1PPPP/RNBQKBNR w KQkq' => {
			eco => 'A00j',
			# TRANSLATORS: A00j: 1. d3 g6
			variation => N__('Mieses'),
			moves => {
				'g2g4' => 1,
			},
		},
		'rnbqkbnr/pppppp1p/6p1/8/6P1/3P4/PPP1PP1P/RNBQKBNR b KQkq' => {
			eco => 'A00j',
			# TRANSLATORS: A00j: 1. d3 g6 2. g4
			variation => N__('Spike Deferred'),
			moves => {
			},
		},
		'rnbqkbnr/pppppppp/8/8/8/4P3/PPPP1PPP/RNBQKBNR b KQkq' => {
			eco => 'A00k',
			# TRANSLATORS: A00k: 1. e3
			variation => N__('Van Kruijs'),
			moves => {
			},
		},
		'rnbqkbnr/pppppppp/8/8/8/2N5/PPPPPPPP/R1BQKBNR b KQkq' => {
			eco => 'A00l',
			# TRANSLATORS: A00l: 1. Nc3
			variation => N__('Van Geet (Dunst) Opening'),
			moves => {
				'c7c5' => 1,
				'd7d5' => 1,
				'e7e5' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/pp1ppppp/8/2p5/8/2N5/PPPPPPPP/R1BQKBNR w KQkq' => {
			eco => 'A00l',
			# TRANSLATORS: A00l: 1. Nc3 c5
			variation => N__('Van Geet: Sicilian Variation'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pp1ppppp/8/2p5/8/2N2N2/PPPPPPPP/R1BQKB1R b KQkq' => {
			eco => 'A00l',
			# TRANSLATORS: A00l: 1. Nc3 c5 2. Nf3
			variation => N__('Van Geet: Sicilian Variation, 2. Nf3'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/2p5/8/2N2N2/PPPPPPPP/R1BQKB1R w KQkq' => {
			eco => 'A00l',
			# TRANSLATORS: A00l: 1. Nc3 c5 2. Nf3 Nc6
			variation => N__('Van Geet: Sicilian Variation, 2. Nf3 Nc6'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/4p3/8/2N5/PPPPPPPP/R1BQKBNR w KQkq' => {
			eco => 'A00l',
			# TRANSLATORS: A00l: 1. Nc3 e5
			variation => N__('Van Geet: 1... e5'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pppp1ppp/8/4p3/8/2N2N2/PPPPPPPP/R1BQKB1R b KQkq' => {
			eco => 'A00l',
			# TRANSLATORS: A00l: 1. Nc3 e5 2. Nf3
			variation => N__('Van Geet: 1... e5 2. Nf3'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/8/2N5/PPPPPPPP/R1BQKBNR w KQkq' => {
			eco => 'A00l',
			# TRANSLATORS: A00l: 1. Nc3 Nf6
			variation => N__('Van Geet: 1... Nf6'),
			moves => {
				'g1f3' => 1,
				'g2g4' => 1,
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/8/2N2N2/PPPPPPPP/R1BQKB1R b KQkq' => {
			eco => 'A00l',
			# TRANSLATORS: A00l: 1. Nc3 Nf6 2. Nf3
			variation => N__('Van Geet: 1... Nf6 2. Nf3'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/6P1/2N5/PPPPPP1P/R1BQKBNR b KQkq' => {
			eco => 'A00l',
			# TRANSLATORS: A00l: 1. Nc3 Nf6 2. g4
			variation => N__('Van Geet: Tübingen Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/8/2N5/PPPPPPPP/R1BQKBNR w KQkq' => {
			eco => 'A00m',
			# TRANSLATORS: A00m: 1. Nc3 d5
			variation => N__('Van Geet: 1... d5'),
			moves => {
				'e2e4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/4P3/2N5/PPPP1PPP/R1BQKBNR b KQkq' => {
			eco => 'A00m',
			# TRANSLATORS: A00m: 1. Nc3 d5 2. e4
			variation => N__('Van Geet: 1... d5 2. e4'),
			moves => {
				'd5d4' => 1,
				'd5e4' => 1,
			},
		},
		'rnbqkbnr/ppp1pppp/8/8/3pP3/2N5/PPPP1PPP/R1BQKBNR w KQkq' => {
			eco => 'A00m',
			# TRANSLATORS: A00m: 1. Nc3 d5 2. e4 d4
			variation => N__('Van Geet: 1... d5 2. e4 d4'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/8/4p3/2N5/PPPP1PPP/R1BQKBNR w KQkq' => {
			eco => 'A00m',
			# TRANSLATORS: A00m: 1. Nc3 d5 2. e4 dxe4
			variation => N__('Van Geet: 1... d5 2. e4 dxe4'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnbqkbnr/ppp1pppp/8/8/2B1p3/2N5/PPPP1PPP/R1BQK1NR b KQkq' => {
			eco => 'A00m',
			# TRANSLATORS: A00m: 1. Nc3 d5 2. e4 dxe4 3. Bc4
			variation => N__('Van Geet: Hector Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/8/2N2N2/PPPPPPPP/R1BQKB1R b KQkq' => {
			eco => 'A00m',
			# TRANSLATORS: A00m: 1. Nc3 d5 2. Nf3
			variation => N__('Van Geet: 1... d5 2. Nf3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/8/2N2N2/PPPPPPPP/R1BQKB1R w KQkq' => {
			eco => 'A00m',
			# TRANSLATORS: A00m: 1. Nc3 d5 2. Nf3 Nf6
			variation => N__('Van Geet: 1... d5 2. Nf3 Nf6'),
			moves => {
			},
		},
		'rnbqkbnr/pppppppp/8/8/6P1/8/PPPPPP1P/RNBQKBNR b KQkq' => {
			eco => 'A00n',
			# TRANSLATORS: A00n: 1. g4
			variation => N__('Grob'),
			moves => {
				'd7d5' => 1,
				'e7e5' => 1,
				'f7f5' => 1,
				'g7g5' => 1,
			},
		},
		'rnbqkbnr/pppp1ppp/8/4p3/6P1/8/PPPPPP1P/RNBQKBNR w KQkq' => {
			eco => 'A00n',
			# TRANSLATORS: A00n: 1. g4 e5
			variation => N__('Grob: 1... e5'),
			moves => {
			},
		},
		'rnbqkbnr/ppppp1pp/8/5p2/6P1/8/PPPPPP1P/RNBQKBNR w KQkq' => {
			eco => 'A00n',
			# TRANSLATORS: A00n: 1. g4 f5
			variation => N__('Grob: Alessi Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pppppp1p/8/6p1/6P1/8/PPPPPP1P/RNBQKBNR w KQkq' => {
			eco => 'A00n',
			# TRANSLATORS: A00n: 1. g4 g5
			variation => N__('Grob: Double Grob'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/6P1/8/PPPPPP1P/RNBQKBNR w KQkq' => {
			eco => 'A00o',
			# TRANSLATORS: A00o: 1. g4 d5
			variation => N__('Grob: 1... d5'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/6P1/8/PPPPPPBP/RNBQK1NR b KQkq' => {
			eco => 'A00o',
			# TRANSLATORS: A00o: 1. g4 d5 2. Bg2
			variation => N__('Grob Gambit'),
			moves => {
				'c7c6' => 1,
				'c8g4' => 1,
				'e7e5' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3p4/6P1/8/PPPPPPBP/RNBQK1NR w KQkq' => {
			eco => 'A00o',
			# TRANSLATORS: A00o: 1. g4 d5 2. Bg2 c6
			variation => N__('Grob Gambit: 2... c6'),
			moves => {
				'g4g5' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3p2P1/8/8/PPPPPPBP/RNBQK1NR b KQkq' => {
			eco => 'A00o',
			# TRANSLATORS: A00o: 1. g4 d5 2. Bg2 c6 3. g5
			variation => N__('Grob Gambit: Spike Attack'),
			moves => {
			},
		},
		'rn1qkbnr/ppp1pppp/8/3p4/6b1/8/PPPPPPBP/RNBQK1NR w KQkq' => {
			eco => 'A00o',
			# TRANSLATORS: A00o: 1. g4 d5 2. Bg2 Bxg4
			variation => N__('Grob Gambit Accepted'),
			moves => {
				'c2c4' => 1,
			},
		},
		'rn1qkbnr/ppp1pppp/8/3p4/2P3b1/8/PP1PPPBP/RNBQK1NR b KQkq' => {
			eco => 'A00o',
			# TRANSLATORS: A00o: 1. g4 d5 2. Bg2 Bxg4 3. c4
			variation => N__('Grob Gambit Accepted: Fritz Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/8/3pp3/6P1/8/PPPPPPBP/RNBQK1NR w KQkq' => {
			eco => 'A00o',
			# TRANSLATORS: A00o: 1. g4 d5 2. Bg2 e5
			variation => N__('Grob Gambit: e5'),
			moves => {
				'c2c4' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/8/3pp3/2P3P1/8/PP1PPPBP/RNBQK1NR b KQkq' => {
			eco => 'A00o',
			# TRANSLATORS: A00o: 1. g4 d5 2. Bg2 e5 3. c4
			variation => N__('Grob Gambit: Hurst Attack'),
			moves => {
			},
		},
		'rnbqkbnr/pppppppp/8/8/1P6/8/P1PPPPPP/RNBQKBNR b KQkq' => {
			eco => 'A00p',
			# TRANSLATORS: A00p: 1. b4
			variation => N__('Polish (Sokolsky; Orang-Utan)'),
			moves => {
				'c7c5' => 1,
				'c7c6' => 1,
				'd7d5' => 1,
				'e7e5' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/pp1ppppp/8/2p5/1P6/8/P1PPPPPP/RNBQKBNR w KQkq' => {
			eco => 'A00p',
			# TRANSLATORS: A00p: 1. b4 c5
			variation => N__('Polish: Birmingham Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/2p5/8/1P6/8/P1PPPPPP/RNBQKBNR w KQkq' => {
			eco => 'A00p',
			# TRANSLATORS: A00p: 1. b4 c6
			variation => N__('Polish: 1... c6'),
			moves => {
				'c1b2' => 1,
			},
		},
		'rnbqkbnr/pp1ppppp/2p5/8/1P6/8/PBPPPPPP/RN1QKBNR b KQkq' => {
			eco => 'A00p',
			# TRANSLATORS: A00p: 1. b4 c6 2. Bb2
			variation => N__('Polish: 1... c6'),
			moves => {
				'a7a5' => 1,
			},
		},
		'rnbqkbnr/1p1ppppp/2p5/p7/1P6/8/PBPPPPPP/RN1QKBNR w KQkq' => {
			eco => 'A00p',
			# TRANSLATORS: A00p: 1. b4 c6 2. Bb2 a5
			variation => N__('Polish: 1... c6'),
			moves => {
				'b4b5' => 1,
			},
		},
		'rnbqkbnr/1p1ppppp/2p5/pP6/8/8/PBPPPPPP/RN1QKBNR b KQkq' => {
			eco => 'A00p',
			# TRANSLATORS: A00p: 1. b4 c6 2. Bb2 a5 3. b5
			variation => N__('Polish: Schühler Gambit'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/1P6/8/P1PPPPPP/RNBQKBNR w KQkq' => {
			eco => 'A00p',
			# TRANSLATORS: A00p: 1. b4 Nf6
			variation => N__('Polish: 1... Nf6'),
			moves => {
				'c1b2' => 1,
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/1P6/8/PBPPPPPP/RN1QKBNR b KQkq' => {
			eco => 'A00p',
			# TRANSLATORS: A00p: 1. b4 Nf6 2. Bb2
			variation => N__('Polish: 1... Nf6 2. Bb2'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/4pn2/8/1P6/8/PBPPPPPP/RN1QKBNR w KQkq' => {
			eco => 'A00p',
			# TRANSLATORS: A00p: 1. b4 Nf6 2. Bb2 e6
			variation => N__('Polish: 1... Nf6 2. Bb2 e6'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/1P6/8/P1PPPPPP/RNBQKBNR w KQkq' => {
			eco => 'A00q',
			# TRANSLATORS: A00q: 1. b4 d5
			variation => N__('Polish: 1... d5'),
			moves => {
				'c1b2' => 1,
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/1P6/8/PBPPPPPP/RN1QKBNR b KQkq' => {
			eco => 'A00q',
			# TRANSLATORS: A00q: 1. b4 d5 2. Bb2
			variation => N__('Polish: 1... d5 2. Bb2'),
			moves => {
				'c8f5' => 1,
				'g8f6' => 1,
			},
		},
		'rn1qkbnr/ppp1pppp/8/3p1b2/1P6/8/PBPPPPPP/RN1QKBNR w KQkq' => {
			eco => 'A00q',
			# TRANSLATORS: A00q: 1. b4 d5 2. Bb2 Bf5
			variation => N__('Polish: 1... d5 2. Bb2 Bf5'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/1P6/8/PBPPPPPP/RN1QKBNR w KQkq' => {
			eco => 'A00q',
			# TRANSLATORS: A00q: 1. b4 d5 2. Bb2 Nf6
			variation => N__('Polish: 1... d5 2. Bb2 Nf6'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/1P6/4P3/PBPP1PPP/RN1QKBNR b KQkq' => {
			eco => 'A00q',
			# TRANSLATORS: A00q: 1. b4 d5 2. Bb2 Nf6 3. e3
			variation => N__('Polish: 1... d5 2. Bb2 Nf6 3. e3'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/4p3/1P6/8/P1PPPPPP/RNBQKBNR w KQkq' => {
			eco => 'A00r',
			# TRANSLATORS: A00r: 1. b4 e5
			variation => N__('Polish: 1... e5'),
			moves => {
				'a2a3' => 1,
				'c1b2' => 1,
			},
		},
		'rnbqkbnr/pppp1ppp/8/4p3/1P6/P7/2PPPPPP/RNBQKBNR b KQkq' => {
			eco => 'A00r',
			# TRANSLATORS: A00r: 1. b4 e5 2. a3
			variation => N__('Polish: Bugayev Attack'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/4p3/1P6/8/PBPPPPPP/RN1QKBNR b KQkq' => {
			eco => 'A00r',
			# TRANSLATORS: A00r: 1. b4 e5 2. Bb2
			variation => N__('Polish: 1... e5 2. Bb2'),
			moves => {
				'c7c5' => 1,
				'd7d6' => 1,
				'f7f6' => 1,
				'f8b4' => 1,
			},
		},
		'rnbqkbnr/pp1p1ppp/8/2p1p3/1P6/8/PBPPPPPP/RN1QKBNR w KQkq' => {
			eco => 'A00r',
			# TRANSLATORS: A00r: 1. b4 e5 2. Bb2 c5
			variation => N__('Polish: Wolfertz Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/3p4/4p3/1P6/8/PBPPPPPP/RN1QKBNR w KQkq' => {
			eco => 'A00r',
			# TRANSLATORS: A00r: 1. b4 e5 2. Bb2 d6
			variation => N__('Polish: 1... e5 2. Bb2 d6'),
			moves => {
			},
		},
		'rnbqkbnr/pppp2pp/5p2/4p3/1P6/8/PBPPPPPP/RN1QKBNR w KQkq' => {
			eco => 'A00r',
			# TRANSLATORS: A00r: 1. b4 e5 2. Bb2 f6
			variation => N__('Polish: 1... e5 2. Bb2 f6'),
			moves => {
				'e2e4' => 1,
			},
		},
		'rnbqkbnr/pppp2pp/5p2/4p3/1P2P3/8/PBPP1PPP/RN1QKBNR b KQkq' => {
			eco => 'A00r',
			# TRANSLATORS: A00r: 1. b4 e5 2. Bb2 f6 3. e4
			variation => N__('Polish: 1... e5 2. Bb2 f6'),
			moves => {
				'f8b4' => 1,
			},
		},
		'rnbqk1nr/pppp2pp/5p2/4p3/1b2P3/8/PBPP1PPP/RN1QKBNR w KQkq' => {
			eco => 'A00r',
			# TRANSLATORS: A00r: 1. b4 e5 2. Bb2 f6 3. e4 Bxb4
			variation => N__('Polish: Tartakower Gambit'),
			moves => {
			},
		},
		'rnbqk1nr/pppp1ppp/8/4p3/1b6/8/PBPPPPPP/RN1QKBNR w KQkq' => {
			eco => 'A00s',
			# TRANSLATORS: A00s: 1. b4 e5 2. Bb2 Bxb4
			variation => N__('Polish: 2...Bxb4'),
			moves => {
				'b2e5' => 1,
			},
		},
		'rnbqk1nr/pppp1ppp/8/4B3/1b6/8/P1PPPPPP/RN1QKBNR b KQkq' => {
			eco => 'A00s',
			# TRANSLATORS: A00s: 1. b4 e5 2. Bb2 Bxb4 3. Bxe5
			variation => N__('Polish: 2...Bxb4 3.Bxe5'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqk2r/pppp1ppp/5n2/4B3/1b6/8/P1PPPPPP/RN1QKBNR w KQkq' => {
			eco => 'A00s',
			# TRANSLATORS: A00s: 1. b4 e5 2. Bb2 Bxb4 3. Bxe5 Nf6
			variation => N__('Polish: 2...Bxb4 3.Bxe5 Nf6'),
			moves => {
				'c2c4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqk2r/pppp1ppp/5n2/4B3/1bP5/8/P2PPPPP/RN1QKBNR b KQkq' => {
			eco => 'A00s',
			# TRANSLATORS: A00s: 1. b4 e5 2. Bb2 Bxb4 3. Bxe5 Nf6 4. c4
			variation => N__('Polish: 2...Bxb4 3.Bxe5 Nf6 4. c4'),
			moves => {
			},
		},
		'rnbqk2r/pppp1ppp/5n2/4B3/1b6/5N2/P1PPPPPP/RN1QKB1R b KQkq' => {
			eco => 'A00s',
			# TRANSLATORS: A00s: 1. b4 e5 2. Bb2 Bxb4 3. Bxe5 Nf6 4. Nf3
			variation => N__('Polish: 2...Bxb4 3.Bxe5 Nf6 4. Nf3'),
			moves => {
			},
		},
		'rnbqkbnr/pppppppp/8/8/8/6P1/PPPPPP1P/RNBQKBNR b KQkq' => {
			eco => 'A00t',
			# TRANSLATORS: A00t: 1. g3
			variation => N__('Benko Opening'),
			moves => {
				'd7d5' => 1,
				'e7e5' => 1,
				'g7g6' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/pppppp1p/6p1/8/8/6P1/PPPPPP1P/RNBQKBNR w KQkq' => {
			eco => 'A00t',
			# TRANSLATORS: A00t: 1. g3 g6
			variation => N__('Benko Opening: Symmetrical'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/8/6P1/PPPPPP1P/RNBQKBNR w KQkq' => {
			eco => 'A00t',
			# TRANSLATORS: A00t: 1. g3 Nf6
			variation => N__('Benko Opening'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/4p3/8/6P1/PPPPPP1P/RNBQKBNR w KQkq' => {
			eco => 'A00u',
			# TRANSLATORS: A00u: 1. g3 e5
			variation => N__('Benko Opening'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/8/6P1/PPPPPP1P/RNBQKBNR w KQkq' => {
			eco => 'A00v',
			# TRANSLATORS: A00v: 1. g3 d5
			variation => N__('Benko Opening'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/8/6P1/PPPPPPBP/RNBQK1NR b KQkq' => {
			eco => 'A00v',
			# TRANSLATORS: A00v: 1. g3 d5 2. Bg2
			variation => N__('Benko Opening'),
			moves => {
				'c7c6' => 1,
				'e7e5' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3p4/8/6P1/PPPPPPBP/RNBQK1NR w KQkq' => {
			eco => 'A00v',
			# TRANSLATORS: A00v: 1. g3 d5 2. Bg2 c6
			variation => N__('Benko Opening'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/8/3pp3/8/6P1/PPPPPPBP/RNBQK1NR w KQkq' => {
			eco => 'A00v',
			# TRANSLATORS: A00v: 1. g3 d5 2. Bg2 e5
			variation => N__('Benko Opening'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/8/6P1/PPPPPPBP/RNBQK1NR w KQkq' => {
			eco => 'A00v',
			# TRANSLATORS: A00v: 1. g3 d5 2. Bg2 Nf6
			variation => N__('Benko Opening'),
			moves => {
			},
		},
		'rnbqkbnr/pppppppp/8/8/8/1P6/P1PPPPPP/RNBQKBNR b KQkq' => {
			eco => 'A01',
			# TRANSLATORS: A01: 1. b3
			variation => N__('Nimzowitsch-Larsen Attack'),
			moves => {
				'b7b5' => 1,
				'b7b6' => 1,
				'c7c5' => 1,
				'd7d5' => 1,
				'e7e5' => 1,
				'f7f5' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/p1pppppp/8/1p6/8/1P6/P1PPPPPP/RNBQKBNR w KQkq' => {
			eco => 'A01',
			# TRANSLATORS: A01: 1. b3 b5
			variation => N__('Nimzowitsch-Larsen: Polish Variation'),
			moves => {
			},
		},
		'rnbqkbnr/p1pppppp/1p6/8/8/1P6/P1PPPPPP/RNBQKBNR w KQkq' => {
			eco => 'A01',
			# TRANSLATORS: A01: 1. b3 b6
			variation => N__('Nimzowitsch-Larsen: Symmetrical'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/8/2p5/8/1P6/P1PPPPPP/RNBQKBNR w KQkq' => {
			eco => 'A01',
			# TRANSLATORS: A01: 1. b3 c5
			variation => N__('Nimzowitsch-Larsen: English Variation'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/8/1P6/P1PPPPPP/RNBQKBNR w KQkq' => {
			eco => 'A01',
			# TRANSLATORS: A01: 1. b3 d5
			variation => N__('Nimzowitsch-Larsen: 1... d5'),
			moves => {
				'c1b2' => 1,
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/8/1P6/PBPPPPPP/RN1QKBNR b KQkq' => {
			eco => 'A01',
			# TRANSLATORS: A01: 1. b3 d5 2. Bb2
			variation => N__('Nimzowitsch-Larsen: 1... d5 2. Bb2'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/4p3/8/1P6/P1PPPPPP/RNBQKBNR w KQkq' => {
			eco => 'A01',
			# TRANSLATORS: A01: 1. b3 e5
			variation => N__('Nimzowitsch-Larsen: 1... e5'),
			moves => {
				'c1b2' => 1,
			},
		},
		'rnbqkbnr/pppp1ppp/8/4p3/8/1P6/PBPPPPPP/RN1QKBNR b KQkq' => {
			eco => 'A01',
			# TRANSLATORS: A01: 1. b3 e5 2. Bb2
			variation => N__('Nimzowitsch-Larsen: 1... e5 2. Bb2'),
			moves => {
				'b8c6' => 1,
				'd7d6' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4p3/8/1P6/PBPPPPPP/RN1QKBNR w KQkq' => {
			eco => 'A01',
			# TRANSLATORS: A01: 1. b3 e5 2. Bb2 Nc6
			variation => N__('Nimzowitsch-Larsen: 1... e5 2. Bb2 Nc6'),
			moves => {
				'e2e3' => 1,
				'f2f4' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4p3/8/1P2P3/PBPP1PPP/RN1QKBNR b KQkq' => {
			eco => 'A01',
			# TRANSLATORS: A01: 1. b3 e5 2. Bb2 Nc6 3. e3
			variation => N__('Nimzowitsch-Larsen: 1... e5 2. Bb2 Nc6 3. e3'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4p3/5P2/1P6/PBPPP1PP/RN1QKBNR b KQkq' => {
			eco => 'A01',
			# TRANSLATORS: A01: 1. b3 e5 2. Bb2 Nc6 3. f4
			variation => N__('Nimzowitsch-Larsen: Paschmann Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/3p4/4p3/8/1P6/PBPPPPPP/RN1QKBNR w KQkq' => {
			eco => 'A01',
			# TRANSLATORS: A01: 1. b3 e5 2. Bb2 d6
			variation => N__('Nimzowitsch-Larsen: 1... e5 2. Bb2 d6'),
			moves => {
			},
		},
		'rnbqkbnr/ppppp1pp/8/5p2/8/1P6/P1PPPPPP/RNBQKBNR w KQkq' => {
			eco => 'A01',
			# TRANSLATORS: A01: 1. b3 f5
			variation => N__('Nimzowitsch-Larsen: Dutch Variation'),
			moves => {
				'c1b2' => 1,
			},
		},
		'rnbqkbnr/ppppp1pp/8/5p2/8/1P6/PBPPPPPP/RN1QKBNR b KQkq' => {
			eco => 'A01',
			# TRANSLATORS: A01: 1. b3 f5 2. Bb2
			variation => N__('Nimzowitsch-Larsen: Dutch Variation'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rnbqkbnr/pppp2pp/4p3/5p2/8/1P6/PBPPPPPP/RN1QKBNR w KQkq' => {
			eco => 'A01',
			# TRANSLATORS: A01: 1. b3 f5 2. Bb2 e6
			variation => N__('Nimzowitsch-Larsen: Dutch Variation'),
			moves => {
				'e2e4' => 1,
			},
		},
		'rnbqkbnr/pppp2pp/4p3/5p2/4P3/1P6/PBPP1PPP/RN1QKBNR b KQkq' => {
			eco => 'A01',
			# TRANSLATORS: A01: 1. b3 f5 2. Bb2 e6 3. e4
			variation => N__('Nimzowitsch-Larsen: Ringelbach Gambit'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/8/1P6/P1PPPPPP/RNBQKBNR w KQkq' => {
			eco => 'A01',
			# TRANSLATORS: A01: 1. b3 Nf6
			variation => N__('Nimzowitsch-Larsen: Indian Variation'),
			moves => {
				'c1b2' => 1,
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/8/1P6/PBPPPPPP/RN1QKBNR b KQkq' => {
			eco => 'A01',
			# TRANSLATORS: A01: 1. b3 Nf6 2. Bb2
			variation => N__('Nimzowitsch-Larsen: Indian Variation'),
			moves => {
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/pppppp1p/5np1/8/8/1P6/PBPPPPPP/RN1QKBNR w KQkq' => {
			eco => 'A01',
			# TRANSLATORS: A01: 1. b3 Nf6 2. Bb2 g6
			variation => N__('Nimzowitsch-Larsen: Indian Variation'),
			moves => {
				'g2g4' => 1,
			},
		},
		'rnbqkb1r/pppppp1p/5np1/8/6P1/1P6/PBPPPP1P/RN1QKBNR b KQkq' => {
			eco => 'A01',
			# TRANSLATORS: A01: 1. b3 Nf6 2. Bb2 g6 3. g4
			variation => N__('Nimzowitsch-Larsen: Spike Variation'),
			moves => {
			},
		},
		'rnbqkbnr/pppppppp/8/8/5P2/8/PPPPP1PP/RNBQKBNR b KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4
			variation => N__('Bird'),
			moves => {
				'c7c5' => 1,
				'd7d5' => 1,
				'd7d6' => 1,
				'e7e5' => 1,
				'f7f5' => 1,
				'g7g5' => 1,
				'g7g6' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/pp1ppppp/8/2p5/5P2/8/PPPPP1PP/RNBQKBNR w KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 c5
			variation => N__('Bird: 1..c5'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pp1ppppp/8/2p5/5P2/5N2/PPPPP1PP/RNBQKB1R b KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 c5 2. Nf3
			variation => N__('Bird: 1..c5'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/2p5/5P2/5N2/PPPPP1PP/RNBQKB1R w KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 c5 2. Nf3 Nc6
			variation => N__('Bird: 1..c5 2. Nf3 Nc6'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/3p4/8/5P2/8/PPPPP1PP/RNBQKBNR w KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 d6
			variation => N__('Bird: 1..d6'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/4p3/5P2/8/PPPPP1PP/RNBQKBNR w KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 e5
			variation => N__('Bird: From Gambit'),
			moves => {
				'f4e5' => 1,
			},
		},
		'rnbqkbnr/pppp1ppp/8/4P3/8/8/PPPPP1PP/RNBQKBNR b KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 e5 2. fxe5
			variation => N__('Bird: From Gambit Accepted'),
			moves => {
				'b8c6' => 1,
				'd7d6' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4P3/8/8/PPPPP1PP/RNBQKBNR w KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 e5 2. fxe5 Nc6
			variation => N__('Bird: From Gambit, Schlecter'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/3p4/4P3/8/8/PPPPP1PP/RNBQKBNR w KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 e5 2. fxe5 d6
			variation => N__('Bird: From Gambit, 2... d6'),
			moves => {
				'e5d6' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/3P4/8/8/8/PPPPP1PP/RNBQKBNR b KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 e5 2. fxe5 d6 3. exd6
			variation => N__('Bird: From Gambit, 3.exd6'),
			moves => {
				'f8d6' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqk1nr/ppp2ppp/3b4/8/8/8/PPPPP1PP/RNBQKBNR w KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 e5 2. fxe5 d6 3. exd6 Bxd6
			variation => N__('Bird: From Gambit, 3...Bxd6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqk1nr/ppp2ppp/3b4/8/8/5N2/PPPPP1PP/RNBQKB1R b KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 e5 2. fxe5 d6 3. exd6 Bxd6 4. Nf3
			variation => N__('Bird: From Gambit, 3...Bxd6'),
			moves => {
				'g7g5' => 1,
				'g8h6' => 1,
			},
		},
		'rnbqk1nr/ppp2p1p/3b4/6p1/8/5N2/PPPPP1PP/RNBQKB1R w KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 e5 2. fxe5 d6 3. exd6 Bxd6 4. Nf3 g5
			variation => N__('Bird: From Gambit, Lasker Variation'),
			moves => {
				'd2d4' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqk1nr/ppp2p1p/3b4/6p1/3P4/5N2/PPP1P1PP/RNBQKB1R b KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 e5 2. fxe5 d6 3. exd6 Bxd6 4. Nf3 g5 5. d4
			variation => N__('Bird: From Gambit, Lasker, 5. d4'),
			moves => {
				'g5g4' => 1,
			},
		},
		'rnbqk1nr/ppp2p1p/3b4/8/3P2p1/5N2/PPP1P1PP/RNBQKB1R w KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 e5 2. fxe5 d6 3. exd6 Bxd6 4. Nf3 g5 5. d4 g4
			variation => N__('Bird: From Gambit, Lasker, 5. d4'),
			moves => {
				'f3e5' => 1,
			},
		},
		'rnbqk1nr/ppp2p1p/3b4/4N3/3P2p1/8/PPP1P1PP/RNBQKB1R b KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 e5 2. fxe5 d6 3. exd6 Bxd6 4. Nf3 g5 5. d4 g4 6. Ne5
			variation => N__('Bird: From Gambit, Lasker, 5. d4'),
			moves => {
				'd6e5' => 1,
			},
		},
		'rnbqk1nr/ppp2p1p/8/4b3/3P2p1/8/PPP1P1PP/RNBQKB1R w KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 e5 2. fxe5 d6 3. exd6 Bxd6 4. Nf3 g5 5. d4 g4 6. Ne5 Bxe5
			variation => N__('Bird: From Gambit, Lasker, 5. d4'),
			moves => {
				'd4e5' => 1,
			},
		},
		'rnbqk1nr/ppp2p1p/8/4P3/6p1/8/PPP1P1PP/RNBQKB1R b KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 e5 2. fxe5 d6 3. exd6 Bxd6 4. Nf3 g5 5. d4 g4 6. Ne5 Bxe5 7. dxe5
			variation => N__('Bird: From Gambit, Lasker, 5. d4'),
			moves => {
				'd8d1' => 1,
			},
		},
		'rnb1k1nr/ppp2p1p/8/4P3/6p1/8/PPP1P1PP/RNBqKB1R w KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 e5 2. fxe5 d6 3. exd6 Bxd6 4. Nf3 g5 5. d4 g4 6. Ne5 Bxe5 7. dxe5 Qxd1+
			variation => N__('Bird: From Gambit, Lasker, Queenswap Line'),
			moves => {
			},
		},
		'rnbqk1nr/ppp2p1p/3b4/6p1/8/5NP1/PPPPP2P/RNBQKB1R b KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 e5 2. fxe5 d6 3. exd6 Bxd6 4. Nf3 g5 5. g3
			variation => N__('Bird: From Gambit, Lasker, 5. g3'),
			moves => {
			},
		},
		'rnbqk2r/ppp2ppp/3b3n/8/8/5N2/PPPPP1PP/RNBQKB1R w KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 e5 2. fxe5 d6 3. exd6 Bxd6 4. Nf3 Nh6
			variation => N__('Bird: From Gambit, 3...Bxd6'),
			moves => {
				'd2d4' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/3b3n/8/3P4/5N2/PPP1P1PP/RNBQKB1R b KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 e5 2. fxe5 d6 3. exd6 Bxd6 4. Nf3 Nh6 5. d4
			variation => N__('Bird: From Gambit, Lipke'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/3P1n2/8/8/8/PPPPP1PP/RNBQKBNR w KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 e5 2. fxe5 d6 3. exd6 Nf6
			variation => N__('Bird: From Gambit, Langheld Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/ppppp1pp/8/5p2/5P2/8/PPPPP1PP/RNBQKBNR w KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 f5
			variation => N__('Bird: Symmetrical'),
			moves => {
				'e2e4' => 1,
			},
		},
		'rnbqkbnr/ppppp1pp/8/5p2/4PP2/8/PPPP2PP/RNBQKBNR b KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 f5 2. e4
			variation => N__('Bird: Swiss Gambit'),
			moves => {
				'f5e4' => 1,
			},
		},
		'rnbqkbnr/ppppp1pp/8/8/4pP2/8/PPPP2PP/RNBQKBNR w KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 f5 2. e4 fxe4
			variation => N__('Bird: Swiss Gambit'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkbnr/ppppp1pp/8/8/4pP2/2N5/PPPP2PP/R1BQKBNR b KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 f5 2. e4 fxe4 3. Nc3
			variation => N__('Bird: Swiss Gambit'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/8/4pP2/2N5/PPPP2PP/R1BQKBNR w KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 f5 2. e4 fxe4 3. Nc3 Nf6
			variation => N__('Bird: Swiss Gambit'),
			moves => {
				'g2g4' => 1,
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/8/4pPP1/2N5/PPPP3P/R1BQKBNR b KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 f5 2. e4 fxe4 3. Nc3 Nf6 4. g4
			variation => N__('Bird: Swiss Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pppppp1p/8/6p1/5P2/8/PPPPP1PP/RNBQKBNR w KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 g5
			variation => N__('Bird: Hobbs Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pppppp1p/6p1/8/5P2/8/PPPPP1PP/RNBQKBNR w KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 g6
			variation => N__('Bird: 1..g6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pppppp1p/6p1/8/5P2/5N2/PPPPP1PP/RNBQKB1R b KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 g6 2. Nf3
			variation => N__('Bird: 1..g6'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk1nr/ppppppbp/6p1/8/5P2/5N2/PPPPP1PP/RNBQKB1R w KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 g6 2. Nf3 Bg7
			variation => N__('Bird: 1..g6'),
			moves => {
				'e2e3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqk1nr/ppppppbp/6p1/8/5P2/4PN2/PPPP2PP/RNBQKB1R b KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 g6 2. Nf3 Bg7 3. e3
			variation => N__('Bird: 1..g6'),
			moves => {
			},
		},
		'rnbqk1nr/ppppppbp/6p1/8/5P2/5NP1/PPPPP2P/RNBQKB1R b KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 g6 2. Nf3 Bg7 3. g3
			variation => N__('Bird: 1..g6'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/5P2/8/PPPPP1PP/RNBQKBNR w KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 Nf6
			variation => N__('Bird: 1..Nf6'),
			moves => {
				'b2b3' => 1,
				'e2e3' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/5P2/1P6/P1PPP1PP/RNBQKBNR b KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 Nf6 2. b3
			variation => N__('Bird: 1..Nf6 2. b3'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/5P2/4P3/PPPP2PP/RNBQKBNR b KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 Nf6 2. e3
			variation => N__('Bird: 1..Nf6 2. e3'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/5P2/5N2/PPPPP1PP/RNBQKB1R b KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 Nf6 2. Nf3
			variation => N__('Bird: 1..Nf6 2. Nf3'),
			moves => {
				'c7c5' => 1,
				'd7d6' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/2p5/5P2/5N2/PPPPP1PP/RNBQKB1R w KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 Nf6 2. Nf3 c5
			variation => N__('Bird: 1..Nf6 2. Nf3 c5'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/3p1n2/8/5P2/5N2/PPPPP1PP/RNBQKB1R w KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 Nf6 2. Nf3 d6
			variation => N__('Bird: 1..Nf6 2. Nf3 d6'),
			moves => {
			},
		},
		'rnbqkb1r/pppppp1p/5np1/8/5P2/5N2/PPPPP1PP/RNBQKB1R w KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 Nf6 2. Nf3 g6
			variation => N__('Bird: 1..Nf6 2. Nf3 g6'),
			moves => {
				'b2b4' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/pppppp1p/5np1/8/1P3P2/5N2/P1PPP1PP/RNBQKB1R b KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 Nf6 2. Nf3 g6 3. b4
			variation => N__('Bird: Batavo Polish Attack'),
			moves => {
			},
		},
		'rnbqkb1r/pppppp1p/5np1/8/5P2/5NP1/PPPPP2P/RNBQKB1R b KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 Nf6 2. Nf3 g6 3. g3
			variation => N__('Bird: 1..Nf6 2. Nf3 g6 3. g3'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppppppbp/5np1/8/5P2/5NP1/PPPPP2P/RNBQKB1R w KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 Nf6 2. Nf3 g6 3. g3 Bg7
			variation => N__('Bird: 1..Nf6 2. Nf3 g6 3. g3'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqk2r/ppppppbp/5np1/8/5P2/5NP1/PPPPP1BP/RNBQK2R b KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 Nf6 2. Nf3 g6 3. g3 Bg7 4. Bg2
			variation => N__('Bird: 1..Nf6 2. Nf3 g6 3. g3'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/5P2/5NP1/PPPPP1BP/RNBQK2R w KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 Nf6 2. Nf3 g6 3. g3 Bg7 4. Bg2 d6
			variation => N__('Bird: 1..Nf6 2. Nf3 g6 3. g3'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/5P2/6P1/PPPPP2P/RNBQKBNR b KQkq' => {
			eco => 'A02',
			# TRANSLATORS: A02: 1. f4 Nf6 2. g3
			variation => N__('Bird: 1..Nf6 2. g3'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/5P2/8/PPPPP1PP/RNBQKBNR w KQkq' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5
			variation => N__('Bird: 1... d5'),
			moves => {
				'b2b3' => 1,
				'c2c4' => 1,
				'e2e3' => 1,
				'e2e4' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
				'g2g4' => 1,
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/5P2/1P6/P1PPP1PP/RNBQKBNR b KQkq' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. b3
			variation => N__('Bird: 1... d5 2. b3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/5P2/1P6/P1PPP1PP/RNBQKBNR w KQkq' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. b3 Nf6
			variation => N__('Bird: 1... d5 2. b3'),
			moves => {
				'c1b2' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/5P2/1P6/PBPPP1PP/RN1QKBNR b KQkq' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. b3 Nf6 3. Bb2
			variation => N__('Bird: 1... d5 2. b3'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/2P2P2/8/PP1PP1PP/RNBQKBNR b KQkq' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. c4
			variation => N__('Bird: Sturm Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/5P2/4P3/PPPP2PP/RNBQKBNR b KQkq' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. e3
			variation => N__('Bird: Lasker Variation'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/5P2/4P3/PPPP2PP/RNBQKBNR w KQkq' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. e3 Nf6
			variation => N__('Bird: Lasker Variation'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/4PP2/8/PPPP2PP/RNBQKBNR b KQkq' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. e4
			variation => N__('Bird: Williams Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/5P2/5N2/PPPPP1PP/RNBQKB1R b KQkq' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. Nf3
			variation => N__('Bird: 1... d5 2. Nf3'),
			moves => {
				'c7c5' => 1,
				'g7g6' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/8/2pp4/5P2/5N2/PPPPP1PP/RNBQKB1R w KQkq' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. Nf3 c5
			variation => N__('Bird: 1... d5 2. Nf3 c5'),
			moves => {
				'e2e3' => 1,
				'e2e4' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/8/2pp4/5P2/4PN2/PPPP2PP/RNBQKB1R b KQkq' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. Nf3 c5 3. e3
			variation => N__('Bird: 1... d5 2. Nf3 c5 3. e3'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/8/2pp4/4PP2/5N2/PPPP2PP/RNBQKB1R b KQkq' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. Nf3 c5 3. e4
			variation => N__('Bird: Batavo Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pp1p/6p1/3p4/5P2/5N2/PPPPP1PP/RNBQKB1R w KQkq' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. Nf3 g6
			variation => N__('Bird: 1... d5 2. Nf3 g6'),
			moves => {
				'e2e3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/ppp1pp1p/6p1/3p4/5P2/4PN2/PPPP2PP/RNBQKB1R b KQkq' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. Nf3 g6 3. e3
			variation => N__('Bird: 1... d5 2. Nf3 g6 3. e3'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pp1p/6p1/3p4/5P2/5NP1/PPPPP2P/RNBQKB1R b KQkq' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. Nf3 g6 3. g3
			variation => N__('Bird: 1... d5 2. Nf3 g6 3. g3'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk1nr/ppp1ppbp/6p1/3p4/5P2/5NP1/PPPPP2P/RNBQKB1R w KQkq' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. Nf3 g6 3. g3 Bg7
			variation => N__('Bird: 1... d5 2. Nf3 g6 3. g3'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqk1nr/ppp1ppbp/6p1/3p4/5P2/5NP1/PPPPP1BP/RNBQK2R b KQkq' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. Nf3 g6 3. g3 Bg7 4. Bg2
			variation => N__('Bird: 1... d5 2. Nf3 g6 3. g3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/5P2/5N2/PPPPP1PP/RNBQKB1R w KQkq' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. Nf3 Nf6
			variation => N__('Bird: 1... d5 2. Nf3 Nf6'),
			moves => {
				'b2b3' => 1,
				'e2e3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/5P2/1P3N2/P1PPP1PP/RNBQKB1R b KQkq' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. Nf3 Nf6 3. b3
			variation => N__('Bird: 1... d5 2. Nf3 Nf6 3. b3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/5P2/4PN2/PPPP2PP/RNBQKB1R b KQkq' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. Nf3 Nf6 3. e3
			variation => N__('Bird: Lasker Variation'),
			moves => {
				'c7c5' => 1,
				'c8g4' => 1,
				'e7e6' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/5n2/2pp4/5P2/4PN2/PPPP2PP/RNBQKB1R w KQkq' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. Nf3 Nf6 3. e3 c5
			variation => N__('Bird: Lasker, 3... c5'),
			moves => {
				'b2b3' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/5n2/2pp4/5P2/1P2PN2/P1PP2PP/RNBQKB1R b KQkq' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. Nf3 Nf6 3. e3 c5 4. b3
			variation => N__('Bird: Lasker, 3... c5 4. b3'),
			moves => {
			},
		},
		'rn1qkb1r/ppp1pppp/5n2/3p4/5Pb1/4PN2/PPPP2PP/RNBQKB1R w KQkq' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. Nf3 Nf6 3. e3 Bg4
			variation => N__('Bird: Lasker, 3... Bg4'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p4/5P2/4PN2/PPPP2PP/RNBQKB1R w KQkq' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. Nf3 Nf6 3. e3 e6
			variation => N__('Bird: Lasker, 3... e6'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/3p4/5P2/4PN2/PPPP2PP/RNBQKB1R w KQkq' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. Nf3 Nf6 3. e3 g6
			variation => N__('Bird: Lasker, 3... g6'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/5P2/5NP1/PPPPP2P/RNBQKB1R b KQkq' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. Nf3 Nf6 3. g3
			variation => N__('Bird: 1... d5 2. Nf3 Nf6 3. g3'),
			moves => {
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/3p4/5P2/5NP1/PPPPP2P/RNBQKB1R w KQkq' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. Nf3 Nf6 3. g3 g6
			variation => N__('Bird: 1... d5 2. Nf3 Nf6 3. g3 g6'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/3p4/5P2/5NP1/PPPPP1BP/RNBQK2R b KQkq' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. Nf3 Nf6 3. g3 g6 4. Bg2
			variation => N__('Bird: 1... d5 2. Nf3 Nf6 3. g3 g6'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/3p4/5P2/5NP1/PPPPP1BP/RNBQK2R w KQkq' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. Nf3 Nf6 3. g3 g6 4. Bg2 Bg7
			variation => N__('Bird: 1... d5 2. Nf3 Nf6 3. g3 g6'),
			moves => {
				'd2d3' => 1,
				'e1g1' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/3p4/5P2/3P1NP1/PPP1P1BP/RNBQK2R b KQkq' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. Nf3 Nf6 3. g3 g6 4. Bg2 Bg7 5. d3
			variation => N__('Bird: 1... d5 2. Nf3 Nf6 3. g3 g6: 5. d3'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/3p4/5P2/5NP1/PPPPP1BP/RNBQ1RK1 b kq' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. Nf3 Nf6 3. g3 g6 4. Bg2 Bg7 5. O-O
			variation => N__('Bird: 1... d5 2. Nf3 Nf6 3. g3 g6: 5.O-O'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/3p4/5P2/5NP1/PPPPP1BP/RNBQ1RK1 w -' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. Nf3 Nf6 3. g3 g6 4. Bg2 Bg7 5. O-O O-O
			variation => N__('Bird: 1... d5 2. Nf3 Nf6 3. g3 g6: 5.O-O O-O'),
			moves => {
				'd2d3' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/3p4/5P2/3P1NP1/PPP1P1BP/RNBQ1RK1 b -' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. Nf3 Nf6 3. g3 g6 4. Bg2 Bg7 5. O-O O-O 6. d3
			variation => N__('Bird: 1... d5 2. Nf3 Nf6 3. g3 g6: 5.O-O O-O 6. d3'),
			moves => {
				'c7c5' => 1,
				'c7c6' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/5np1/2pp4/5P2/3P1NP1/PPP1P1BP/RNBQ1RK1 w -' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. Nf3 Nf6 3. g3 g6 4. Bg2 Bg7 5. O-O O-O 6. d3 c5
			variation => N__('Bird: 1... d5 2. Nf3 Nf6 3. g3 g6: 6. d3 c5'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/2p2np1/3p4/5P2/3P1NP1/PPP1P1BP/RNBQ1RK1 w -' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. Nf3 Nf6 3. g3 g6 4. Bg2 Bg7 5. O-O O-O 6. d3 c6
			variation => N__('Bird: 1... d5 2. Nf3 Nf6 3. g3 g6: 6. d3 c6'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/5P2/6P1/PPPPP2P/RNBQKBNR b KQkq' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. g3
			variation => N__('Bird: 1... d5 2. g3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/5P2/6P1/PPPPP2P/RNBQKBNR w KQkq' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. g3 Nf6
			variation => N__('Bird: 1... d5 2. g3'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/5P2/6P1/PPPPP1BP/RNBQK1NR b KQkq' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. g3 Nf6 3. Bg2
			variation => N__('Bird: 1... d5 2. g3'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/5PP1/8/PPPPP2P/RNBQKBNR b KQkq' => {
			eco => 'A03',
			# TRANSLATORS: A03: 1. f4 d5 2. g4
			variation => N__('Bird: Dudweiler Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pppppppp/8/8/8/5N2/PPPPPPPP/RNBQKB1R b KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3
			variation => N__('Reti'),
			moves => {
				'b7b5' => 1,
				'b7b6' => 1,
				'b8c6' => 1,
				'c7c5' => 1,
				'd7d5' => 1,
				'd7d6' => 1,
				'e7e6' => 1,
				'f7f5' => 1,
				'g7g5' => 1,
				'g7g6' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/p1pppppp/8/1p6/8/5N2/PPPPPPPP/RNBQKB1R w KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 b5
			variation => N__('Reti: 1... b5'),
			moves => {
			},
		},
		'rnbqkbnr/p1pppppp/1p6/8/8/5N2/PPPPPPPP/RNBQKB1R w KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 b6
			variation => N__('Reti: 1... b6'),
			moves => {
			},
		},
		'r1bqkbnr/pppppppp/2n5/8/8/5N2/PPPPPPPP/RNBQKB1R w KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 Nc6
			variation => N__('Reti: 1... Nc6'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/8/2p5/8/5N2/PPPPPPPP/RNBQKB1R w KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 c5
			variation => N__('Reti: 1... c5'),
			moves => {
				'b2b3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/pp1ppppp/8/2p5/8/1P3N2/P1PPPPPP/RNBQKB1R b KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 c5 2. b3
			variation => N__('Reti: 1... c5, Nimzowitsch-Larsen'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/8/2p5/8/5NP1/PPPPPP1P/RNBQKB1R b KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 c5 2. g3
			variation => N__('Reti: 1... c5'),
			moves => {
				'b7b6' => 1,
				'b8c6' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkbnr/p2ppppp/1p6/2p5/8/5NP1/PPPPPP1P/RNBQKB1R w KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 c5 2. g3 b6
			variation => N__('Reti: 1... c5'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkbnr/p2ppppp/1p6/2p5/8/5NP1/PPPPPPBP/RNBQK2R b KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 c5 2. g3 b6 3. Bg2
			variation => N__('Reti: 1... c5'),
			moves => {
				'c8b7' => 1,
			},
		},
		'rn1qkbnr/pb1ppppp/1p6/2p5/8/5NP1/PPPPPPBP/RNBQK2R w KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 c5 2. g3 b6 3. Bg2 Bb7
			variation => N__('Reti: 1... c5'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/2p5/8/5NP1/PPPPPP1P/RNBQKB1R w KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 c5 2. g3 Nc6
			variation => N__('Reti: 1... c5'),
			moves => {
				'f1g2' => 1,
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/2p5/8/5NP1/PPPPPPBP/RNBQK2R b KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 c5 2. g3 Nc6 3. Bg2
			variation => N__('Reti: 1... c5'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppp1p/6p1/2p5/8/5NP1/PPPPPP1P/RNBQKB1R w KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 c5 2. g3 g6
			variation => N__('Reti: 1... c5'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkbnr/pp1ppp1p/6p1/2p5/8/5NP1/PPPPPPBP/RNBQK2R b KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 c5 2. g3 g6 3. Bg2
			variation => N__('Reti: 1... c5'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk1nr/pp1pppbp/6p1/2p5/8/5NP1/PPPPPPBP/RNBQK2R w KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 c5 2. g3 g6 3. Bg2 Bg7
			variation => N__('Reti: 1... c5'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbqk1nr/pp1pppbp/6p1/2p5/8/5NP1/PPPPPPBP/RNBQ1RK1 b kq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 c5 2. g3 g6 3. Bg2 Bg7 4. O-O
			variation => N__('Reti: 1... c5'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqk1nr/pp1pppbp/2n3p1/2p5/8/5NP1/PPPPPPBP/RNBQ1RK1 w kq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 c5 2. g3 g6 3. Bg2 Bg7 4. O-O Nc6
			variation => N__('Reti: 1... c5'),
			moves => {
				'd2d3' => 1,
			},
		},
		'r1bqk1nr/pp1pppbp/2n3p1/2p5/8/3P1NP1/PPP1PPBP/RNBQ1RK1 b kq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 c5 2. g3 g6 3. Bg2 Bg7 4. O-O Nc6 5. d3
			variation => N__('Reti: 1... c5'),
			moves => {
				'd7d6' => 1,
				'e7e6' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqk1nr/pp2ppbp/2np2p1/2p5/8/3P1NP1/PPP1PPBP/RNBQ1RK1 w kq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 c5 2. g3 g6 3. Bg2 Bg7 4. O-O Nc6 5. d3 d6
			variation => N__('Reti: 1... c5'),
			moves => {
				'e2e4' => 1,
			},
		},
		'r1bqk1nr/pp2ppbp/2np2p1/2p5/4P3/3P1NP1/PPP2PBP/RNBQ1RK1 b kq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 c5 2. g3 g6 3. Bg2 Bg7 4. O-O Nc6 5. d3 d6 6. e4
			variation => N__('Reti: 1... c5'),
			moves => {
			},
		},
		'r1bqk1nr/pp1p1pbp/2n1p1p1/2p5/8/3P1NP1/PPP1PPBP/RNBQ1RK1 w kq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 c5 2. g3 g6 3. Bg2 Bg7 4. O-O Nc6 5. d3 e6
			variation => N__('Reti: 1... c5'),
			moves => {
				'e2e4' => 1,
			},
		},
		'r1bqk1nr/pp1p1pbp/2n1p1p1/2p5/4P3/3P1NP1/PPP2PBP/RNBQ1RK1 b kq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 c5 2. g3 g6 3. Bg2 Bg7 4. O-O Nc6 5. d3 e6 6. e4
			variation => N__('Reti: 1... c5'),
			moves => {
			},
		},
		'r1bqk2r/pp1pppbp/2n2np1/2p5/8/3P1NP1/PPP1PPBP/RNBQ1RK1 w kq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 c5 2. g3 g6 3. Bg2 Bg7 4. O-O Nc6 5. d3 Nf6
			variation => N__('Reti: 1... c5'),
			moves => {
				'e2e4' => 1,
			},
		},
		'r1bqk2r/pp1pppbp/2n2np1/2p5/4P3/3P1NP1/PPP2PBP/RNBQ1RK1 b kq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 c5 2. g3 g6 3. Bg2 Bg7 4. O-O Nc6 5. d3 Nf6 6. e4
			variation => N__('Reti: 1... c5'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/3p4/8/8/5N2/PPPPPPPP/RNBQKB1R w KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 d6
			variation => N__('Reti: 1... d6'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/4p3/8/8/5N2/PPPPPPPP/RNBQKB1R w KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 e6
			variation => N__('Reti: 1... e6'),
			moves => {
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/pppp1ppp/4p3/8/8/5NP1/PPPPPP1P/RNBQKB1R b KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 e6 2. g3
			variation => N__('Reti: 1... e6'),
			moves => {
			},
		},
		'rnbqkbnr/ppppp1pp/8/5p2/8/5N2/PPPPPPPP/RNBQKB1R w KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 f5
			variation => N__('Reti: 1... f5'),
			moves => {
				'd2d3' => 1,
				'e2e4' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/ppppp1pp/8/5p2/8/3P1N2/PPP1PPPP/RNBQKB1R b KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 f5 2. d3
			variation => N__('Reti: 1... f5 2. d3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/5p2/8/3P1N2/PPP1PPPP/RNBQKB1R w KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 f5 2. d3 Nf6
			variation => N__('Reti: 1... f5 2. d3 Nf6'),
			moves => {
				'e2e4' => 1,
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/5p2/4P3/3P1N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 f5 2. d3 Nf6 3. e4
			variation => N__('Reti: Lisitsin Deferred'),
			moves => {
			},
		},
		'rnbqkbnr/ppppp1pp/8/5p2/4P3/5N2/PPPP1PPP/RNBQKB1R b KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 f5 2. e4
			variation => N__('Reti: Lisitsin'),
			moves => {
				'f5e4' => 1,
			},
		},
		'rnbqkbnr/ppppp1pp/8/8/4p3/5N2/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 f5 2. e4 fxe4
			variation => N__('Reti: Lisitsin'),
			moves => {
				'f3g5' => 1,
			},
		},
		'rnbqkbnr/ppppp1pp/8/6N1/4p3/8/PPPP1PPP/RNBQKB1R b KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 f5 2. e4 fxe4 3. Ng5
			variation => N__('Reti: Lisitsin'),
			moves => {
				'd7d5' => 1,
				'e7e5' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/ppp1p1pp/8/3p2N1/4p3/8/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 f5 2. e4 fxe4 3. Ng5 d5
			variation => N__('Reti: Lisitsin: 3. Ng5 d5'),
			moves => {
			},
		},
		'rnbqkbnr/pppp2pp/8/4p1N1/4p3/8/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 f5 2. e4 fxe4 3. Ng5 e5
			variation => N__('Reti: Lisitsin: 3. Ng5 e5'),
			moves => {
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/6N1/4p3/8/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 f5 2. e4 fxe4 3. Ng5 Nf6
			variation => N__('Reti: Lisitsin: 3. Ng5 Nf6'),
			moves => {
				'd2d3' => 1,
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/6N1/4p3/3P4/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 f5 2. e4 fxe4 3. Ng5 Nf6 4. d3
			variation => N__('Reti: Lisitsin: 3. Ng5 Nf6'),
			moves => {
				'e4e3' => 1,
				'e7e5' => 1,
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/6N1/8/3Pp3/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 f5 2. e4 fxe4 3. Ng5 Nf6 4. d3 e3
			variation => N__('Reti: Lisitsin: 3. Ng5 Nf6'),
			moves => {
			},
		},
		'rnbqkb1r/pppp2pp/5n2/4p1N1/4p3/3P4/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 f5 2. e4 fxe4 3. Ng5 Nf6 4. d3 e5
			variation => N__('Reti: Lisitsin: 3. Ng5 Nf6'),
			moves => {
			},
		},
		'rnbqkbnr/ppppp1pp/8/5p2/8/5NP1/PPPPPP1P/RNBQKB1R b KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 f5 2. g3
			variation => N__('Reti: 1... f5 2. g3'),
			moves => {
			},
		},
		'rnbqkbnr/pppppp1p/8/6p1/8/5N2/PPPPPPPP/RNBQKB1R w KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 g5
			variation => N__('Reti: Herrström Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pppppp1p/6p1/8/8/5N2/PPPPPPPP/RNBQKB1R w KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 g6
			variation => N__('Reti: 1... g6'),
			moves => {
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/pppppp1p/6p1/8/8/5NP1/PPPPPP1P/RNBQKB1R b KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 g6 2. g3
			variation => N__('Reti: 1... g6'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk1nr/ppppppbp/6p1/8/8/5NP1/PPPPPP1P/RNBQKB1R w KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 g6 2. g3 Bg7
			variation => N__('Reti: 1... g6'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqk1nr/ppppppbp/6p1/8/8/5NP1/PPPPPPBP/RNBQK2R b KQkq' => {
			eco => 'A04',
			# TRANSLATORS: A04: 1. Nf3 g6 2. g3 Bg7 3. Bg2
			variation => N__('Reti: 1... g6'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/8/5N2/PPPPPPPP/RNBQKB1R w KQkq' => {
			eco => 'A05',
			# TRANSLATORS: A05: 1. Nf3 Nf6
			variation => N__('Reti: 1... Nf6'),
			moves => {
				'b2b3' => 1,
				'b2b4' => 1,
				'e2e3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/8/1P3N2/P1PPPPPP/RNBQKB1R b KQkq' => {
			eco => 'A05',
			# TRANSLATORS: A05: 1. Nf3 Nf6 2. b3
			variation => N__('Reti: 1... Nf6 2. b3'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/1P6/5N2/P1PPPPPP/RNBQKB1R b KQkq' => {
			eco => 'A05',
			# TRANSLATORS: A05: 1. Nf3 Nf6 2. b4
			variation => N__('Reti: Santasiere\'s folly'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/8/4PN2/PPPP1PPP/RNBQKB1R b KQkq' => {
			eco => 'A05',
			# TRANSLATORS: A05: 1. Nf3 Nf6 2. e3
			variation => N__('Reti: 1... Nf6 2. e3'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/8/5NP1/PPPPPP1P/RNBQKB1R b KQkq' => {
			eco => 'A05',
			# TRANSLATORS: A05: 1. Nf3 Nf6 2. g3
			variation => N__('Reti: KIA'),
			moves => {
				'b7b5' => 1,
				'b7b6' => 1,
				'c7c5' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/p1pppppp/5n2/1p6/8/5NP1/PPPPPP1P/RNBQKB1R w KQkq' => {
			eco => 'A05',
			# TRANSLATORS: A05: 1. Nf3 Nf6 2. g3 b5
			variation => N__('Reti: KIA, Spassky'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkb1r/p1pppppp/5n2/1p6/8/5NP1/PPPPPPBP/RNBQK2R b KQkq' => {
			eco => 'A05',
			# TRANSLATORS: A05: 1. Nf3 Nf6 2. g3 b5 3. Bg2
			variation => N__('Reti: KIA, Spassky'),
			moves => {
			},
		},
		'rnbqkb1r/p1pppppp/1p3n2/8/8/5NP1/PPPPPP1P/RNBQKB1R w KQkq' => {
			eco => 'A05',
			# TRANSLATORS: A05: 1. Nf3 Nf6 2. g3 b6
			variation => N__('Reti: KIA'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkb1r/p1pppppp/1p3n2/8/8/5NP1/PPPPPPBP/RNBQK2R b KQkq' => {
			eco => 'A05',
			# TRANSLATORS: A05: 1. Nf3 Nf6 2. g3 b6 3. Bg2
			variation => N__('Reti: KIA'),
			moves => {
				'c8b7' => 1,
			},
		},
		'rn1qkb1r/pbpppppp/1p3n2/8/8/5NP1/PPPPPPBP/RNBQK2R w KQkq' => {
			eco => 'A05',
			# TRANSLATORS: A05: 1. Nf3 Nf6 2. g3 b6 3. Bg2 Bb7
			variation => N__('Reti: KIA'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/2p5/8/5NP1/PPPPPP1P/RNBQKB1R w KQkq' => {
			eco => 'A05',
			# TRANSLATORS: A05: 1. Nf3 Nf6 2. g3 c5
			variation => N__('Reti: KIA'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/2p5/8/5NP1/PPPPPPBP/RNBQK2R b KQkq' => {
			eco => 'A05',
			# TRANSLATORS: A05: 1. Nf3 Nf6 2. g3 c5 3. Bg2
			variation => N__('Reti: KIA'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkb1r/pp1ppppp/2n2n2/2p5/8/5NP1/PPPPPPBP/RNBQK2R w KQkq' => {
			eco => 'A05',
			# TRANSLATORS: A05: 1. Nf3 Nf6 2. g3 c5 3. Bg2 Nc6
			variation => N__('Reti: KIA'),
			moves => {
			},
		},
		'rnbqkb1r/pppppp1p/5np1/8/8/5NP1/PPPPPP1P/RNBQKB1R w KQkq' => {
			eco => 'A05',
			# TRANSLATORS: A05: 1. Nf3 Nf6 2. g3 g6
			variation => N__('Reti: KIA'),
			moves => {
				'b2b4' => 1,
				'f1g2' => 1,
			},
		},
		'rnbqkb1r/pppppp1p/5np1/8/1P6/5NP1/P1PPPP1P/RNBQKB1R b KQkq' => {
			eco => 'A05',
			# TRANSLATORS: A05: 1. Nf3 Nf6 2. g3 g6 3. b4
			variation => N__('Reti: KIA, Reti-Smyslov Variation'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppppppbp/5np1/8/1P6/5NP1/P1PPPP1P/RNBQKB1R w KQkq' => {
			eco => 'A05',
			# TRANSLATORS: A05: 1. Nf3 Nf6 2. g3 g6 3. b4 Bg7
			variation => N__('Reti: KIA, Reti-Smyslov Variation'),
			moves => {
				'c1b2' => 1,
			},
		},
		'rnbqk2r/ppppppbp/5np1/8/1P6/5NP1/PBPPPP1P/RN1QKB1R b KQkq' => {
			eco => 'A05',
			# TRANSLATORS: A05: 1. Nf3 Nf6 2. g3 g6 3. b4 Bg7 4. Bb2
			variation => N__('Reti: KIA, Reti-Smyslov Variation'),
			moves => {
			},
		},
		'rnbqkb1r/pppppp1p/5np1/8/8/5NP1/PPPPPPBP/RNBQK2R b KQkq' => {
			eco => 'A05',
			# TRANSLATORS: A05: 1. Nf3 Nf6 2. g3 g6 3. Bg2
			variation => N__('Reti: KIA'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppppppbp/5np1/8/8/5NP1/PPPPPPBP/RNBQK2R w KQkq' => {
			eco => 'A05',
			# TRANSLATORS: A05: 1. Nf3 Nf6 2. g3 g6 3. Bg2 Bg7
			variation => N__('Reti: KIA'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbqk2r/ppppppbp/5np1/8/8/5NP1/PPPPPPBP/RNBQ1RK1 b kq' => {
			eco => 'A05',
			# TRANSLATORS: A05: 1. Nf3 Nf6 2. g3 g6 3. Bg2 Bg7 4. O-O
			variation => N__('Reti: KIA'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppppppbp/5np1/8/8/5NP1/PPPPPPBP/RNBQ1RK1 w -' => {
			eco => 'A05',
			# TRANSLATORS: A05: 1. Nf3 Nf6 2. g3 g6 3. Bg2 Bg7 4. O-O O-O
			variation => N__('Reti: KIA'),
			moves => {
				'd2d3' => 1,
			},
		},
		'rnbq1rk1/ppppppbp/5np1/8/8/3P1NP1/PPP1PPBP/RNBQ1RK1 b -' => {
			eco => 'A05',
			# TRANSLATORS: A05: 1. Nf3 Nf6 2. g3 g6 3. Bg2 Bg7 4. O-O O-O 5. d3
			variation => N__('Reti: KIA'),
			moves => {
				'c7c5' => 1,
				'd7d6' => 1,
			},
		},
		'rnbq1rk1/pp1pppbp/5np1/2p5/8/3P1NP1/PPP1PPBP/RNBQ1RK1 w -' => {
			eco => 'A05',
			# TRANSLATORS: A05: 1. Nf3 Nf6 2. g3 g6 3. Bg2 Bg7 4. O-O O-O 5. d3 c5
			variation => N__('Reti: KIA'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/8/3P1NP1/PPP1PPBP/RNBQ1RK1 w -' => {
			eco => 'A05',
			# TRANSLATORS: A05: 1. Nf3 Nf6 2. g3 g6 3. Bg2 Bg7 4. O-O O-O 5. d3 d6
			variation => N__('Reti: KIA'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/8/5N2/PPPPPPPP/RNBQKB1R w KQkq' => {
			eco => 'A06',
			# TRANSLATORS: A06: 1. Nf3 d5
			variation => N__('Reti: 1... d5'),
			moves => {
				'b2b3' => 1,
				'b2b4' => 1,
				'c2c4' => 1,
				'd2d3' => 1,
				'e2e3' => 1,
				'e2e4' => 1,
				'g2g3' => 1,
				'h1g1' => 1,
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/8/1P3N2/P1PPPPPP/RNBQKB1R b KQkq' => {
			eco => 'A06',
			# TRANSLATORS: A06: 1. Nf3 d5 2. b3
			variation => N__('Reti: Nimzowitsch-Larsen'),
			moves => {
				'c7c5' => 1,
				'c8g4' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/8/2pp4/8/1P3N2/P1PPPPPP/RNBQKB1R w KQkq' => {
			eco => 'A06',
			# TRANSLATORS: A06: 1. Nf3 d5 2. b3 c5
			variation => N__('Reti: Nimzowitsch-Larsen, 2... c5'),
			moves => {
			},
		},
		'rn1qkbnr/ppp1pppp/8/3p4/6b1/1P3N2/P1PPPPPP/RNBQKB1R w KQkq' => {
			eco => 'A06',
			# TRANSLATORS: A06: 1. Nf3 d5 2. b3 Bg4
			variation => N__('Reti: Nimzowitsch-Larsen, 2... Bg4'),
			moves => {
				'c1b2' => 1,
			},
		},
		'rn1qkbnr/ppp1pppp/8/3p4/6b1/1P3N2/PBPPPPPP/RN1QKB1R b KQkq' => {
			eco => 'A06',
			# TRANSLATORS: A06: 1. Nf3 d5 2. b3 Bg4 3. Bb2
			variation => N__('Reti: Nimzowitsch-Larsen, 2... Bg4'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r2qkbnr/pppnpppp/8/3p4/6b1/1P3N2/PBPPPPPP/RN1QKB1R w KQkq' => {
			eco => 'A06',
			# TRANSLATORS: A06: 1. Nf3 d5 2. b3 Bg4 3. Bb2 Nd7
			variation => N__('Reti: Nimzowitsch-Larsen, 2... Bg4'),
			moves => {
				'e2e3' => 1,
			},
		},
		'r2qkbnr/pppnpppp/8/3p4/6b1/1P2PN2/PBPP1PPP/RN1QKB1R b KQkq' => {
			eco => 'A06',
			# TRANSLATORS: A06: 1. Nf3 d5 2. b3 Bg4 3. Bb2 Nd7 4. e3
			variation => N__('Reti: Nimzowitsch-Larsen, 2... Bg4'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/8/1P3N2/P1PPPPPP/RNBQKB1R w KQkq' => {
			eco => 'A06',
			# TRANSLATORS: A06: 1. Nf3 d5 2. b3 Nf6
			variation => N__('Reti: Nimzowitsch-Larsen, 2... Nf6'),
			moves => {
				'c1b2' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/8/1P3N2/PBPPPPPP/RN1QKB1R b KQkq' => {
			eco => 'A06',
			# TRANSLATORS: A06: 1. Nf3 d5 2. b3 Nf6 3. Bb2
			variation => N__('Reti: Nimzowitsch-Larsen, 2... Nf6'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p4/8/1P3N2/PBPPPPPP/RN1QKB1R w KQkq' => {
			eco => 'A06',
			# TRANSLATORS: A06: 1. Nf3 d5 2. b3 Nf6 3. Bb2 e6
			variation => N__('Reti: Nimzowitsch-Larsen, 2... Nf6'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p4/8/1P2PN2/PBPP1PPP/RN1QKB1R b KQkq' => {
			eco => 'A06',
			# TRANSLATORS: A06: 1. Nf3 d5 2. b3 Nf6 3. Bb2 e6 4. e3
			variation => N__('Reti: Nimzowitsch-Larsen, 2... Nf6'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/1P6/5N2/P1PPPPPP/RNBQKB1R b KQkq' => {
			eco => 'A06',
			# TRANSLATORS: A06: 1. Nf3 d5 2. b4
			variation => N__('Reti: Santasiere\'s folly'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/1P6/5N2/P1PPPPPP/RNBQKB1R w KQkq' => {
			eco => 'A06',
			# TRANSLATORS: A06: 1. Nf3 d5 2. b4 Nf6
			variation => N__('Reti: Santasiere\'s folly'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/8/3P1N2/PPP1PPPP/RNBQKB1R b KQkq' => {
			eco => 'A06',
			# TRANSLATORS: A06: 1. Nf3 d5 2. d3
			variation => N__('Reti: Old Indian Attack'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/8/3P1N2/PPP1PPPP/RNBQKB1R w KQkq' => {
			eco => 'A06',
			# TRANSLATORS: A06: 1. Nf3 d5 2. d3 Nf6
			variation => N__('Reti: Old Indian Attack'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/8/4PN2/PPPP1PPP/RNBQKB1R b KQkq' => {
			eco => 'A06',
			# TRANSLATORS: A06: 1. Nf3 d5 2. e3
			variation => N__('Reti: 1... d5 2. e3'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/4P3/5N2/PPPP1PPP/RNBQKB1R b KQkq' => {
			eco => 'A06',
			# TRANSLATORS: A06: 1. Nf3 d5 2. e4
			variation => N__('Reti: Tennison/Zukertort Gambit'),
			moves => {
				'd5e4' => 1,
			},
		},
		'rnbqkbnr/ppp1pppp/8/8/4p3/5N2/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'A06',
			# TRANSLATORS: A06: 1. Nf3 d5 2. e4 dxe4
			variation => N__('Reti: Tennison Gambit Accepted'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/8/5N2/PPPPPPPP/RNBQKBR1 b Qkq' => {
			eco => 'A06',
			# TRANSLATORS: A06: 1. Nf3 d5 2. Rg1
			variation => N__('Reti: Ampel Variation'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/8/5NP1/PPPPPP1P/RNBQKB1R b KQkq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3
			variation => N__('Reti: KIA'),
			moves => {
				'b8c6' => 1,
				'c7c5' => 1,
				'c7c6' => 1,
				'c8g4' => 1,
				'g7g6' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkbnr/ppp1pppp/2n5/3p4/8/5NP1/PPPPPP1P/RNBQKB1R w KQkq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 Nc6
			variation => N__('Reti: KIA'),
			moves => {
				'f1g2' => 1,
			},
		},
		'r1bqkbnr/ppp1pppp/2n5/3p4/8/5NP1/PPPPPPBP/RNBQK2R b KQkq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 Nc6 3. Bg2
			variation => N__('Reti: KIA'),
			moves => {
				'e7e5' => 1,
			},
		},
		'r1bqkbnr/ppp2ppp/2n5/3pp3/8/5NP1/PPPPPPBP/RNBQK2R w KQkq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 Nc6 3. Bg2 e5
			variation => N__('Reti: KIA'),
			moves => {
				'd2d3' => 1,
			},
		},
		'r1bqkbnr/ppp2ppp/2n5/3pp3/8/3P1NP1/PPP1PPBP/RNBQK2R b KQkq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 Nc6 3. Bg2 e5 4. d3
			variation => N__('Reti: KIA'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2n2n2/3pp3/8/3P1NP1/PPP1PPBP/RNBQK2R w KQkq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 Nc6 3. Bg2 e5 4. d3 Nf6
			variation => N__('Reti: KIA'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2n2n2/3pp3/8/3P1NP1/PPP1PPBP/RNBQ1RK1 b kq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 Nc6 3. Bg2 e5 4. d3 Nf6 5. O-O
			variation => N__('Reti: KIA'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r1bqk2r/ppp1bppp/2n2n2/3pp3/8/3P1NP1/PPP1PPBP/RNBQ1RK1 w kq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 Nc6 3. Bg2 e5 4. d3 Nf6 5. O-O Be7
			variation => N__('Reti: KIA'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3p4/8/5NP1/PPPPPP1P/RNBQKB1R w KQkq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 c6
			variation => N__('Reti: KIA'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3p4/8/5NP1/PPPPPPBP/RNBQK2R b KQkq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 c6 3. Bg2
			variation => N__('Reti: KIA'),
			moves => {
				'c8g4' => 1,
			},
		},
		'rn1qkbnr/pp2pppp/2p5/3p4/6b1/5NP1/PPPPPPBP/RNBQK2R w KQkq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 c6 3. Bg2 Bg4
			variation => N__('Reti: KIA, Yugoslav'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rn1qkbnr/pp2pppp/2p5/3p4/6b1/5NP1/PPPPPPBP/RNBQ1RK1 b kq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 c6 3. Bg2 Bg4 4. O-O
			variation => N__('Reti: KIA, Yugoslav'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r2qkbnr/pp1npppp/2p5/3p4/6b1/5NP1/PPPPPPBP/RNBQ1RK1 w kq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 c6 3. Bg2 Bg4 4. O-O Nd7
			variation => N__('Reti: KIA, Yugoslav'),
			moves => {
				'd2d3' => 1,
			},
		},
		'r2qkbnr/pp1npppp/2p5/3p4/6b1/3P1NP1/PPP1PPBP/RNBQ1RK1 b kq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 c6 3. Bg2 Bg4 4. O-O Nd7 5. d3
			variation => N__('Reti: KIA, Yugoslav'),
			moves => {
			},
		},
		'rn1qkbnr/ppp1pppp/8/3p4/6b1/5NP1/PPPPPP1P/RNBQKB1R w KQkq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 Bg4
			variation => N__('Reti: KIA'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rn1qkbnr/ppp1pppp/8/3p4/6b1/5NP1/PPPPPPBP/RNBQK2R b KQkq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 Bg4 3. Bg2
			variation => N__('Reti: KIA'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r2qkbnr/pppnpppp/8/3p4/6b1/5NP1/PPPPPPBP/RNBQK2R w KQkq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 Bg4 3. Bg2 Nd7
			variation => N__('Reti: KIA, Keres Variation'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pp1p/6p1/3p4/8/5NP1/PPPPPP1P/RNBQKB1R w KQkq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 g6
			variation => N__('Reti: KIA'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkbnr/ppp1pp1p/6p1/3p4/8/5NP1/PPPPPPBP/RNBQK2R b KQkq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 g6 3. Bg2
			variation => N__('Reti: KIA'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk1nr/ppp1ppbp/6p1/3p4/8/5NP1/PPPPPPBP/RNBQK2R w KQkq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 g6 3. Bg2 Bg7
			variation => N__('Reti: KIA'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbqk1nr/ppp1ppbp/6p1/3p4/8/5NP1/PPPPPPBP/RNBQ1RK1 b kq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 g6 3. Bg2 Bg7 4. O-O
			variation => N__('Reti: KIA'),
			moves => {
				'e7e5' => 1,
			},
		},
		'rnbqk1nr/ppp2pbp/6p1/3pp3/8/5NP1/PPPPPPBP/RNBQ1RK1 w kq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 g6 3. Bg2 Bg7 4. O-O e5
			variation => N__('Reti: KIA'),
			moves => {
				'd2d3' => 1,
			},
		},
		'rnbqk1nr/ppp2pbp/6p1/3pp3/8/3P1NP1/PPP1PPBP/RNBQ1RK1 b kq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 g6 3. Bg2 Bg7 4. O-O e5 5. d3
			variation => N__('Reti: KIA'),
			moves => {
				'g8e7' => 1,
			},
		},
		'rnbqk2r/ppp1npbp/6p1/3pp3/8/3P1NP1/PPP1PPBP/RNBQ1RK1 w kq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 g6 3. Bg2 Bg7 4. O-O e5 5. d3 Ne7
			variation => N__('Reti: KIA, Pachman'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/8/5NP1/PPPPPP1P/RNBQKB1R w KQkq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 Nf6
			variation => N__('Reti: KIA'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/8/5NP1/PPPPPPBP/RNBQK2R b KQkq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 Nf6 3. Bg2
			variation => N__('Reti: KIA'),
			moves => {
				'c7c6' => 1,
				'c8f5' => 1,
				'e7e6' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/3p4/8/5NP1/PPPPPPBP/RNBQK2R w KQkq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 Nf6 3. Bg2 c6
			variation => N__('Reti: KIA'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/3p4/8/5NP1/PPPPPPBP/RNBQ1RK1 b kq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 Nf6 3. Bg2 c6 4. O-O
			variation => N__('Reti: KIA'),
			moves => {
				'c8f5' => 1,
				'c8g4' => 1,
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/3p1b2/8/5NP1/PPPPPPBP/RNBQ1RK1 w kq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 Nf6 3. Bg2 c6 4. O-O Bf5
			variation => N__('Reti: KIA'),
			moves => {
				'd2d3' => 1,
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/3p1b2/8/3P1NP1/PPP1PPBP/RNBQ1RK1 b kq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 Nf6 3. Bg2 c6 4. O-O Bf5 5. d3
			variation => N__('Reti: KIA'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rn1qkb1r/pp3ppp/2p1pn2/3p1b2/8/3P1NP1/PPP1PPBP/RNBQ1RK1 w kq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 Nf6 3. Bg2 c6 4. O-O Bf5 5. d3 e6
			variation => N__('Reti: KIA'),
			moves => {
				'b1d2' => 1,
			},
		},
		'rn1qkb1r/pp3ppp/2p1pn2/3p1b2/8/3P1NP1/PPPNPPBP/R1BQ1RK1 b kq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 Nf6 3. Bg2 c6 4. O-O Bf5 5. d3 e6 6. Nbd2
			variation => N__('Reti: KIA, Petrosian Variation'),
			moves => {
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/3p4/6b1/5NP1/PPPPPPBP/RNBQ1RK1 w kq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 Nf6 3. Bg2 c6 4. O-O Bg4
			variation => N__('Reti: KIA, Yugoslav'),
			moves => {
				'd2d3' => 1,
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/3p4/6b1/3P1NP1/PPP1PPBP/RNBQ1RK1 b kq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 Nf6 3. Bg2 c6 4. O-O Bg4 5. d3
			variation => N__('Reti: KIA, Yugoslav'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r2qkb1r/pp1npppp/2p2n2/3p4/6b1/3P1NP1/PPP1PPBP/RNBQ1RK1 w kq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 Nf6 3. Bg2 c6 4. O-O Bg4 5. d3 Nbd7
			variation => N__('Reti: KIA, Yugoslav, Main Line'),
			moves => {
				'b1d2' => 1,
			},
		},
		'r2qkb1r/pp1npppp/2p2n2/3p4/6b1/3P1NP1/PPPNPPBP/R1BQ1RK1 b kq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 Nf6 3. Bg2 c6 4. O-O Bg4 5. d3 Nbd7 6. Nbd2
			variation => N__('Reti: KIA, Yugoslav, Main Line, 6.Nbd2'),
			moves => {
				'e7e5' => 1,
				'e7e6' => 1,
			},
		},
		'r2qkb1r/pp1n1ppp/2p2n2/3pp3/6b1/3P1NP1/PPPNPPBP/R1BQ1RK1 w kq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 Nf6 3. Bg2 c6 4. O-O Bg4 5. d3 Nbd7 6. Nbd2 e5
			variation => N__('Reti: KIA, Yugoslav, Main Line, 6.Nbd2 e5'),
			moves => {
			},
		},
		'r2qkb1r/pp1n1ppp/2p1pn2/3p4/6b1/3P1NP1/PPPNPPBP/R1BQ1RK1 w kq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 Nf6 3. Bg2 c6 4. O-O Bg4 5. d3 Nbd7 6. Nbd2 e6
			variation => N__('Reti: KIA, Yugoslav, Main Line, 6.Nbd2 e6'),
			moves => {
			},
		},
		'rn1qkb1r/ppp1pppp/5n2/3p1b2/8/5NP1/PPPPPPBP/RNBQK2R w KQkq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 Nf6 3. Bg2 Bf5
			variation => N__('Reti: KIA'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p4/8/5NP1/PPPPPPBP/RNBQK2R w KQkq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 Nf6 3. Bg2 e6
			variation => N__('Reti: KIA'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/3p4/8/5NP1/PPPPPPBP/RNBQK2R w KQkq' => {
			eco => 'A07',
			# TRANSLATORS: A07: 1. Nf3 d5 2. g3 Nf6 3. Bg2 g6
			variation => N__('Reti: KIA, Neo-Grünfeld'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/8/2pp4/8/5NP1/PPPPPP1P/RNBQKB1R w KQkq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5
			variation => N__('Reti: KIA, 2... c5'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/8/2pp4/8/5NP1/PPPPPPBP/RNBQK2R b KQkq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2
			variation => N__('Reti: KIA, 2... c5'),
			moves => {
				'b8c6' => 1,
				'g7g6' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkbnr/pp2pppp/2n5/2pp4/8/5NP1/PPPPPPBP/RNBQK2R w KQkq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 Nc6
			variation => N__('Reti: KIA, 2... c5  3. Bg2 Nc6'),
			moves => {
				'd2d4' => 1,
				'e1g1' => 1,
			},
		},
		'r1bqkbnr/pp2pppp/2n5/2pp4/3P4/5NP1/PPP1PPBP/RNBQK2R b KQkq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 Nc6 4. d4
			variation => N__('Reti: KIA, 2... c5, 3. Bg2 Nc6 4. d4'),
			moves => {
			},
		},
		'r1bqkbnr/pp2pppp/2n5/2pp4/8/5NP1/PPPPPPBP/RNBQ1RK1 b kq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 Nc6 4. O-O
			variation => N__('Reti: KIA, 2... c5, 3. Bg2 Nc6 4.O-O'),
			moves => {
				'e7e6' => 1,
			},
		},
		'r1bqkbnr/pp3ppp/2n1p3/2pp4/8/5NP1/PPPPPPBP/RNBQ1RK1 w kq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 Nc6 4. O-O e6
			variation => N__('Reti: KIA, 2... c5, 3. Bg2 Nc6 4.O-O'),
			moves => {
				'd2d3' => 1,
			},
		},
		'r1bqkbnr/pp3ppp/2n1p3/2pp4/8/3P1NP1/PPP1PPBP/RNBQ1RK1 b kq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 Nc6 4. O-O e6 5. d3
			variation => N__('Reti: KIA, 2... c5, 3. Bg2 Nc6 4.O-O'),
			moves => {
				'f8d6' => 1,
				'g8e7' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqk1nr/pp3ppp/2nbp3/2pp4/8/3P1NP1/PPP1PPBP/RNBQ1RK1 w kq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 Nc6 4. O-O e6 5. d3 Bd6
			variation => N__('Reti: KIA, 2... c5, 3. Bg2 Nc6 4.O-O'),
			moves => {
				'b1d2' => 1,
			},
		},
		'r1bqk1nr/pp3ppp/2nbp3/2pp4/8/3P1NP1/PPPNPPBP/R1BQ1RK1 b kq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 Nc6 4. O-O e6 5. d3 Bd6 6. Nbd2
			variation => N__('Reti: KIA, 2... c5, 3. Bg2 Nc6 4.O-O'),
			moves => {
				'g8e7' => 1,
			},
		},
		'r1bqk2r/pp2nppp/2nbp3/2pp4/8/3P1NP1/PPPNPPBP/R1BQ1RK1 w kq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 Nc6 4. O-O e6 5. d3 Bd6 6. Nbd2 Nge7
			variation => N__('Reti: KIA, 2... c5, 3. Bg2 Nc6 4.O-O'),
			moves => {
				'e2e4' => 1,
			},
		},
		'r1bqk2r/pp2nppp/2nbp3/2pp4/4P3/3P1NP1/PPPN1PBP/R1BQ1RK1 b kq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 Nc6 4. O-O e6 5. d3 Bd6 6. Nbd2 Nge7 7. e4
			variation => N__('Reti: KIA, French Variation'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp2nppp/2nbp3/2pp4/4P3/3P1NP1/PPPN1PBP/R1BQ1RK1 w -' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 Nc6 4. O-O e6 5. d3 Bd6 6. Nbd2 Nge7 7. e4 O-O
			variation => N__('Reti: KIA, French Variation'),
			moves => {
				'f1e1' => 1,
			},
		},
		'r1bq1rk1/pp2nppp/2nbp3/2pp4/4P3/3P1NP1/PPPN1PBP/R1BQR1K1 b -' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 Nc6 4. O-O e6 5. d3 Bd6 6. Nbd2 Nge7 7. e4 O-O 8. Re1
			variation => N__('Reti: KIA, French Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pp2nppp/2n1p3/2pp4/8/3P1NP1/PPP1PPBP/RNBQ1RK1 w kq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 Nc6 4. O-O e6 5. d3 Nge7
			variation => N__('Reti: KIA, 2... c5, 3. Bg2 Nc6 4.O-O'),
			moves => {
				'b1d2' => 1,
			},
		},
		'r1bqkb1r/pp2nppp/2n1p3/2pp4/8/3P1NP1/PPPNPPBP/R1BQ1RK1 b kq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 Nc6 4. O-O e6 5. d3 Nge7 6. Nbd2
			variation => N__('Reti: KIA, 2... c5, 3. Bg2 Nc6 4.O-O'),
			moves => {
				'b7b6' => 1,
				'g7g6' => 1,
			},
		},
		'r1bqkb1r/p3nppp/1pn1p3/2pp4/8/3P1NP1/PPPNPPBP/R1BQ1RK1 w kq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 Nc6 4. O-O e6 5. d3 Nge7 6. Nbd2 b6
			variation => N__('Reti: KIA, 2... c5, 3. Bg2 Nc6 4.O-O'),
			moves => {
				'e2e4' => 1,
			},
		},
		'r1bqkb1r/p3nppp/1pn1p3/2pp4/4P3/3P1NP1/PPPN1PBP/R1BQ1RK1 b kq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 Nc6 4. O-O e6 5. d3 Nge7 6. Nbd2 b6 7. e4
			variation => N__('Reti: KIA, French Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pp2np1p/2n1p1p1/2pp4/8/3P1NP1/PPPNPPBP/R1BQ1RK1 w kq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 Nc6 4. O-O e6 5. d3 Nge7 6. Nbd2 g6
			variation => N__('Reti: KIA, 2... c5, 3. Bg2 Nc6 4.O-O'),
			moves => {
				'e2e4' => 1,
			},
		},
		'r1bqkb1r/pp2np1p/2n1p1p1/2pp4/4P3/3P1NP1/PPPN1PBP/R1BQ1RK1 b kq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 Nc6 4. O-O e6 5. d3 Nge7 6. Nbd2 g6 7. e4
			variation => N__('Reti: KIA, 2... c5, 3. Bg2 Nc6 4.O-O'),
			moves => {
				'f8g7' => 1,
			},
		},
		'r1bqk2r/pp2npbp/2n1p1p1/2pp4/4P3/3P1NP1/PPPN1PBP/R1BQ1RK1 w kq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 Nc6 4. O-O e6 5. d3 Nge7 6. Nbd2 g6 7. e4 Bg7
			variation => N__('Reti: KIA, French Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2n1pn2/2pp4/8/3P1NP1/PPP1PPBP/RNBQ1RK1 w kq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 Nc6 4. O-O e6 5. d3 Nf6
			variation => N__('Reti: KIA, 2... c5, 3. Bg2 Nc6 4.O-O'),
			moves => {
				'b1d2' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2n1pn2/2pp4/8/3P1NP1/PPPNPPBP/R1BQ1RK1 b kq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 Nc6 4. O-O e6 5. d3 Nf6 6. Nbd2
			variation => N__('Reti: KIA, 2... c5, 3. Bg2 Nc6 4.O-O'),
			moves => {
				'b7b6' => 1,
				'f8e7' => 1,
				'g7g6' => 1,
			},
		},
		'r1bqkb1r/p4ppp/1pn1pn2/2pp4/8/3P1NP1/PPPNPPBP/R1BQ1RK1 w kq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 Nc6 4. O-O e6 5. d3 Nf6 6. Nbd2 b6
			variation => N__('Reti: KIA, 2... c5, 3. Bg2 Nc6 4.O-O'),
			moves => {
				'e2e4' => 1,
			},
		},
		'r1bqkb1r/p4ppp/1pn1pn2/2pp4/4P3/3P1NP1/PPPN1PBP/R1BQ1RK1 b kq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 Nc6 4. O-O e6 5. d3 Nf6 6. Nbd2 b6 7. e4
			variation => N__('Reti: KIA, French Variation'),
			moves => {
			},
		},
		'r1bqk2r/pp2bppp/2n1pn2/2pp4/8/3P1NP1/PPPNPPBP/R1BQ1RK1 w kq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 Nc6 4. O-O e6 5. d3 Nf6 6. Nbd2 Be7
			variation => N__('Reti: KIA, 2... c5, 3. Bg2 Nc6 4.O-O'),
			moves => {
				'e2e4' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2n1pn2/2pp4/4P3/3P1NP1/PPPN1PBP/R1BQ1RK1 b kq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 Nc6 4. O-O e6 5. d3 Nf6 6. Nbd2 Be7 7. e4
			variation => N__('Reti: KIA, French Variation'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2n1pn2/2pp4/4P3/3P1NP1/PPPN1PBP/R1BQ1RK1 w -' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 Nc6 4. O-O e6 5. d3 Nf6 6. Nbd2 Be7 7. e4 O-O
			variation => N__('Reti: KIA, French Variation'),
			moves => {
				'f1e1' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2n1pn2/2pp4/4P3/3P1NP1/PPPN1PBP/R1BQR1K1 b -' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 Nc6 4. O-O e6 5. d3 Nf6 6. Nbd2 Be7 7. e4 O-O 8. Re1
			variation => N__('Reti: KIA, French Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pp3p1p/2n1pnp1/2pp4/8/3P1NP1/PPPNPPBP/R1BQ1RK1 w kq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 Nc6 4. O-O e6 5. d3 Nf6 6. Nbd2 g6
			variation => N__('Reti: KIA, 2... c5, 3. Bg2 Nc6 4.O-O'),
			moves => {
				'e2e4' => 1,
			},
		},
		'r1bqkb1r/pp3p1p/2n1pnp1/2pp4/4P3/3P1NP1/PPPN1PBP/R1BQ1RK1 b kq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 Nc6 4. O-O e6 5. d3 Nf6 6. Nbd2 g6 7. e4
			variation => N__('Reti: KIA, 2... c5, 3. Bg2 Nc6 4.O-O'),
			moves => {
				'f8g7' => 1,
			},
		},
		'r1bqk2r/pp3pbp/2n1pnp1/2pp4/4P3/3P1NP1/PPPN1PBP/R1BQ1RK1 w kq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 Nc6 4. O-O e6 5. d3 Nf6 6. Nbd2 g6 7. e4 Bg7
			variation => N__('Reti: KIA, French Variation'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pp1p/6p1/2pp4/8/5NP1/PPPPPPBP/RNBQK2R w KQkq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 g6
			variation => N__('Reti: KIA, 2... c5'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbqkbnr/pp2pp1p/6p1/2pp4/8/5NP1/PPPPPPBP/RNBQ1RK1 b kq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 g6 4. O-O
			variation => N__('Reti: KIA, 2... c5'),
			moves => {
				'b8c6' => 1,
				'f8g7' => 1,
			},
		},
		'r1bqkbnr/pp2pp1p/2n3p1/2pp4/8/5NP1/PPPPPPBP/RNBQ1RK1 w kq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 g6 4. O-O Nc6
			variation => N__('Reti: KIA, 2... c5'),
			moves => {
				'd2d3' => 1,
			},
		},
		'r1bqkbnr/pp2pp1p/2n3p1/2pp4/8/3P1NP1/PPP1PPBP/RNBQ1RK1 b kq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 g6 4. O-O Nc6 5. d3
			variation => N__('Reti: KIA, 2... c5'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r1bqkb1r/pp2pp1p/2n2np1/2pp4/8/3P1NP1/PPP1PPBP/RNBQ1RK1 w kq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 g6 4. O-O Nc6 5. d3 Nf6
			variation => N__('Reti: KIA, 2... c5 + 3... g6'),
			moves => {
			},
		},
		'rnbqk1nr/pp2ppbp/6p1/2pp4/8/5NP1/PPPPPPBP/RNBQ1RK1 w kq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 g6 4. O-O Bg7
			variation => N__('Reti: KIA, 2... c5 + 3... g6'),
			moves => {
				'd2d3' => 1,
			},
		},
		'rnbqk1nr/pp2ppbp/6p1/2pp4/8/3P1NP1/PPP1PPBP/RNBQ1RK1 b kq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 g6 4. O-O Bg7 5. d3
			variation => N__('Reti: KIA, 2... c5 + 3... g6'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/5np1/2pp4/8/3P1NP1/PPP1PPBP/RNBQ1RK1 w kq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 g6 4. O-O Bg7 5. d3 Nf6
			variation => N__('Reti: KIA, 2... c5 + 3... g6'),
			moves => {
				'b1d2' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/5np1/2pp4/8/3P1NP1/PPPNPPBP/R1BQ1RK1 b kq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 g6 4. O-O Bg7 5. d3 Nf6 6. Nbd2
			variation => N__('Reti: KIA, 2... c5 + 3... g6'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/5np1/2pp4/8/3P1NP1/PPPNPPBP/R1BQ1RK1 w -' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 g6 4. O-O Bg7 5. d3 Nf6 6. Nbd2 O-O
			variation => N__('Reti: KIA, 2... c5 + 3... g6'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/5n2/2pp4/8/5NP1/PPPPPPBP/RNBQK2R w KQkq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 Nf6
			variation => N__('Reti: KIA, 2... c5 3. Bg2 Nf6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/5n2/2pp4/8/5NP1/PPPPPPBP/RNBQ1RK1 b kq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 Nf6 4. O-O
			variation => N__('Reti: KIA, 2... c5 3. Bg2 Nf6 4.O-O'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkb1r/pp2pppp/2n2n2/2pp4/8/5NP1/PPPPPPBP/RNBQ1RK1 w kq' => {
			eco => 'A08',
			# TRANSLATORS: A08: 1. Nf3 d5 2. g3 c5 3. Bg2 Nf6 4. O-O Nc6
			variation => N__('Reti: KIA, 2... c5 3. Bg2 Nf6 4.O-O Nc6'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/2P5/5N2/PP1PPPPP/RNBQKB1R b KQkq' => {
			eco => 'A09a',
			# TRANSLATORS: A09a: 1. Nf3 d5 2. c4
			variation => N__('Reti: 2. c4'),
			moves => {
				'd5c4' => 1,
				'd5d4' => 1,
			},
		},
		'rnbqkbnr/ppp1pppp/8/8/2Pp4/5N2/PP1PPPPP/RNBQKB1R w KQkq' => {
			eco => 'A09b',
			# TRANSLATORS: A09b: 1. Nf3 d5 2. c4 d4
			variation => N__('Reti: Advance Variation'),
			moves => {
				'b2b4' => 1,
				'e2e3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/ppp1pppp/8/8/1PPp4/5N2/P2PPPPP/RNBQKB1R b KQkq' => {
			eco => 'A09c',
			# TRANSLATORS: A09c: 1. Nf3 d5 2. c4 d4 3. b4
			variation => N__('Reti: Advance, Anglo-Polish Attack'),
			moves => {
				'g7g6' => 1,
			},
		},
		'rnbqkbnr/ppp1pp1p/6p1/8/1PPp4/5N2/P2PPPPP/RNBQKB1R w KQkq' => {
			eco => 'A09c',
			# TRANSLATORS: A09c: 1. Nf3 d5 2. c4 d4 3. b4 g6
			variation => N__('Reti: Advance, Anglo-Polish, 3... g6'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/8/2Pp4/4PN2/PP1P1PPP/RNBQKB1R b KQkq' => {
			eco => 'A09d',
			# TRANSLATORS: A09d: 1. Nf3 d5 2. c4 d4 3. e3
			variation => N__('Reti: Advance, 3. e3'),
			moves => {
				'b8c6' => 1,
				'c7c5' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/8/2p5/2Pp4/4PN2/PP1P1PPP/RNBQKB1R w KQkq' => {
			eco => 'A09e',
			# TRANSLATORS: A09e: 1. Nf3 d5 2. c4 d4 3. e3 c5
			variation => N__('Reti: Advance, 3. e3 c5'),
			moves => {
			},
		},
		'r1bqkbnr/ppp1pppp/2n5/8/2Pp4/4PN2/PP1P1PPP/RNBQKB1R w KQkq' => {
			eco => 'A09f',
			# TRANSLATORS: A09f: 1. Nf3 d5 2. c4 d4 3. e3 Nc6
			variation => N__('Reti: Advance, 3. e3 Nc6'),
			moves => {
				'e3d4' => 1,
			},
		},
		'r1bqkbnr/ppp1pppp/2n5/8/2PP4/5N2/PP1P1PPP/RNBQKB1R b KQkq' => {
			eco => 'A09f',
			# TRANSLATORS: A09f: 1. Nf3 d5 2. c4 d4 3. e3 Nc6 4. exd4
			variation => N__('Reti: Advance, 3. e3 Nc6'),
			moves => {
				'c6d4' => 1,
			},
		},
		'r1bqkbnr/ppp1pppp/8/8/2Pn4/5N2/PP1P1PPP/RNBQKB1R w KQkq' => {
			eco => 'A09f',
			# TRANSLATORS: A09f: 1. Nf3 d5 2. c4 d4 3. e3 Nc6 4. exd4 Nxd4
			variation => N__('Reti: Advance, 3. e3 Nc6 4.exd4 Nxd4'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/8/2Pp4/5NP1/PP1PPP1P/RNBQKB1R b KQkq' => {
			eco => 'A09g',
			# TRANSLATORS: A09g: 1. Nf3 d5 2. c4 d4 3. g3
			variation => N__('Reti: Advance, 3. g3'),
			moves => {
				'b8c6' => 1,
				'c7c5' => 1,
				'g7g6' => 1,
			},
		},
		'r1bqkbnr/ppp1pppp/2n5/8/2Pp4/5NP1/PP1PPP1P/RNBQKB1R w KQkq' => {
			eco => 'A09h',
			# TRANSLATORS: A09h: 1. Nf3 d5 2. c4 d4 3. g3 Nc6
			variation => N__('Reti: Advance, 3. g3 Nc6'),
			moves => {
				'f1g2' => 1,
			},
		},
		'r1bqkbnr/ppp1pppp/2n5/8/2Pp4/5NP1/PP1PPPBP/RNBQK2R b KQkq' => {
			eco => 'A09h',
			# TRANSLATORS: A09h: 1. Nf3 d5 2. c4 d4 3. g3 Nc6 4. Bg2
			variation => N__('Reti: Advance, 3. g3 Nc6'),
			moves => {
				'e7e5' => 1,
			},
		},
		'r1bqkbnr/ppp2ppp/2n5/4p3/2Pp4/5NP1/PP1PPPBP/RNBQK2R w KQkq' => {
			eco => 'A09h',
			# TRANSLATORS: A09h: 1. Nf3 d5 2. c4 d4 3. g3 Nc6 4. Bg2 e5
			variation => N__('Reti: Advance, 3. g3 Nc6 4. Bg2 e5'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pp1p/6p1/8/2Pp4/5NP1/PP1PPP1P/RNBQKB1R w KQkq' => {
			eco => 'A09i',
			# TRANSLATORS: A09i: 1. Nf3 d5 2. c4 d4 3. g3 g6
			variation => N__('Reti: Advance, 3. g3 g6'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkbnr/ppp1pp1p/6p1/8/2Pp4/5NP1/PP1PPPBP/RNBQK2R b KQkq' => {
			eco => 'A09i',
			# TRANSLATORS: A09i: 1. Nf3 d5 2. c4 d4 3. g3 g6 4. Bg2
			variation => N__('Reti: Advance, 3. g3 g6'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk1nr/ppp1ppbp/6p1/8/2Pp4/5NP1/PP1PPPBP/RNBQK2R w KQkq' => {
			eco => 'A09i',
			# TRANSLATORS: A09i: 1. Nf3 d5 2. c4 d4 3. g3 g6 4. Bg2 Bg7
			variation => N__('Reti: Advance, 3. g3 g6 4. Bg2 Bg7'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/8/2p5/2Pp4/5NP1/PP1PPP1P/RNBQKB1R w KQkq' => {
			eco => 'A09j',
			# TRANSLATORS: A09j: 1. Nf3 d5 2. c4 d4 3. g3 c5
			variation => N__('Reti: Advance, 3. g3 c5'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/8/2p5/2Pp4/5NP1/PP1PPPBP/RNBQK2R b KQkq' => {
			eco => 'A09j',
			# TRANSLATORS: A09j: 1. Nf3 d5 2. c4 d4 3. g3 c5 4. Bg2
			variation => N__('Reti: Advance, 3. g3 c5'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkbnr/pp2pppp/2n5/2p5/2Pp4/5NP1/PP1PPPBP/RNBQK2R w KQkq' => {
			eco => 'A09j',
			# TRANSLATORS: A09j: 1. Nf3 d5 2. c4 d4 3. g3 c5 4. Bg2 Nc6
			variation => N__('Reti: Advance, 3. g3 c5 4. Bg2 Nc6'),
			moves => {
				'd2d3' => 1,
			},
		},
		'r1bqkbnr/pp2pppp/2n5/2p5/2Pp4/3P1NP1/PP2PPBP/RNBQK2R b KQkq' => {
			eco => 'A09j',
			# TRANSLATORS: A09j: 1. Nf3 d5 2. c4 d4 3. g3 c5 4. Bg2 Nc6 5. d3
			variation => N__('Reti: Advance, 3. g3 c5 4. Bg2 Nc6'),
			moves => {
				'e7e5' => 1,
			},
		},
		'r1bqkbnr/pp3ppp/2n5/2p1p3/2Pp4/3P1NP1/PP2PPBP/RNBQK2R w KQkq' => {
			eco => 'A09j',
			# TRANSLATORS: A09j: 1. Nf3 d5 2. c4 d4 3. g3 c5 4. Bg2 Nc6 5. d3 e5
			variation => N__('Reti: Advance, 3. g3 c5 4. Bg2 Nc6 5. d3 e5'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/8/2p5/5N2/PP1PPPPP/RNBQKB1R w KQkq' => {
			eco => 'A09k',
			# TRANSLATORS: A09k: 1. Nf3 d5 2. c4 dxc4
			variation => N__('Reti: Accepted'),
			moves => {
				'b1a3' => 1,
				'd1a4' => 1,
				'e2e3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/ppp1pppp/8/8/2p5/5NP1/PP1PPP1P/RNBQKB1R b KQkq' => {
			eco => 'A09l',
			# TRANSLATORS: A09l: 1. Nf3 d5 2. c4 dxc4 3. g3
			variation => N__('Reti: Accepted, 3. g3'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/8/2p5/5NP1/PP1PPP1P/RNBQKB1R w KQkq' => {
			eco => 'A09m',
			# TRANSLATORS: A09m: 1. Nf3 d5 2. c4 dxc4 3. g3 e6
			variation => N__('Reti: Accepted, 3. g3 e6'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/8/Q1p5/5N2/PP1PPPPP/RNB1KB1R b KQkq' => {
			eco => 'A09n',
			# TRANSLATORS: A09n: 1. Nf3 d5 2. c4 dxc4 3. Qa4+
			variation => N__('Reti: Accepted, 3. Qa4+'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/8/2p5/N4N2/PP1PPPPP/R1BQKB1R b KQkq' => {
			eco => 'A09o',
			# TRANSLATORS: A09o: 1. Nf3 d5 2. c4 dxc4 3. Na3
			variation => N__('Reti: Accepted, 3. Na3'),
			moves => {
				'a7a6' => 1,
				'c7c5' => 1,
			},
		},
		'rnbqkbnr/1pp1pppp/p7/8/2p5/N4N2/PP1PPPPP/R1BQKB1R w KQkq' => {
			eco => 'A09p',
			# TRANSLATORS: A09p: 1. Nf3 d5 2. c4 dxc4 3. Na3 a6
			variation => N__('Reti: Accepted, 3. Na3 a6'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/8/2p5/2p5/N4N2/PP1PPPPP/R1BQKB1R w KQkq' => {
			eco => 'A09q',
			# TRANSLATORS: A09q: 1. Nf3 d5 2. c4 dxc4 3. Na3 c5
			variation => N__('Reti: Accepted, 3. Na3 c5'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/8/2p5/4PN2/PP1P1PPP/RNBQKB1R b KQkq' => {
			eco => 'A09r',
			# TRANSLATORS: A09r: 1. Nf3 d5 2. c4 dxc4 3. e3
			variation => N__('Reti: Accepted, 3. e3'),
			moves => {
				'c8e6' => 1,
				'g8f6' => 1,
			},
		},
		'rn1qkbnr/ppp1pppp/4b3/8/2p5/4PN2/PP1P1PPP/RNBQKB1R w KQkq' => {
			eco => 'A09s',
			# TRANSLATORS: A09s: 1. Nf3 d5 2. c4 dxc4 3. e3 Be6
			variation => N__('Reti: Accepted, Keres Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/8/2p5/4PN2/PP1P1PPP/RNBQKB1R w KQkq' => {
			eco => 'A09t',
			# TRANSLATORS: A09t: 1. Nf3 d5 2. c4 dxc4 3. e3 Nf6
			variation => N__('Reti: Accepted, 3. e3 Nf6'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/8/2B5/4PN2/PP1P1PPP/RNBQK2R b KQkq' => {
			eco => 'A09t',
			# TRANSLATORS: A09t: 1. Nf3 d5 2. c4 dxc4 3. e3 Nf6 4. Bxc4
			variation => N__('Reti: Accepted, 3. e3 Nf6'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/8/2B5/4PN2/PP1P1PPP/RNBQK2R w KQkq' => {
			eco => 'A09u',
			# TRANSLATORS: A09u: 1. Nf3 d5 2. c4 dxc4 3. e3 Nf6 4. Bxc4 e6
			variation => N__('Reti: Accepted, 3. e3 Nf6 4.Bxc4 e6'),
			moves => {
			},
		},
		'rnbqkbnr/pppppppp/8/8/2P5/8/PP1PPPPP/RNBQKBNR b KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4
			variation => N__('English'),
			moves => {
				'b7b5' => 1,
				'b7b6' => 1,
				'b8c6' => 1,
				'c7c5' => 1,
				'c7c6' => 1,
				'd7d5' => 1,
				'd7d6' => 1,
				'e7e5' => 1,
				'e7e6' => 1,
				'f7f5' => 1,
				'g7g5' => 1,
				'g7g6' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/p1pppppp/8/1p6/2P5/8/PP1PPPPP/RNBQKBNR w KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 b5
			variation => N__('English: Jänisch Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/p1pppppp/1p6/8/2P5/8/PP1PPPPP/RNBQKBNR w KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 b6
			variation => N__('English: 1... b6'),
			moves => {
				'b1c3' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/p1pppppp/1p6/8/2P5/2N5/PP1PPPPP/R1BQKBNR b KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 b6 2. Nc3
			variation => N__('English: 1... b6 2. Nc3'),
			moves => {
				'c8b7' => 1,
				'e7e6' => 1,
			},
		},
		'rn1qkbnr/pbpppppp/1p6/8/2P5/2N5/PP1PPPPP/R1BQKBNR w KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 b6 2. Nc3 Bb7
			variation => N__('English: 1... b6 2. Nc3 Bb7'),
			moves => {
				'e2e4' => 1,
			},
		},
		'rn1qkbnr/pbpppppp/1p6/8/2P1P3/2N5/PP1P1PPP/R1BQKBNR b KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 b6 2. Nc3 Bb7 3. e4
			variation => N__('English: 1... b6 2. Nc3 Bb7 3. e4'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rn1qkbnr/pbpp1ppp/1p2p3/8/2P1P3/2N5/PP1P1PPP/R1BQKBNR w KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 b6 2. Nc3 Bb7 3. e4 e6
			variation => N__('English: 1... b6 2. Nc3 Bb7 3. e4 e6'),
			moves => {
			},
		},
		'rnbqkbnr/p1pp1ppp/1p2p3/8/2P5/2N5/PP1PPPPP/R1BQKBNR w KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 b6 2. Nc3 e6
			variation => N__('English: 1... b6 2. Nc3 e6'),
			moves => {
				'e2e4' => 1,
			},
		},
		'rnbqkbnr/p1pp1ppp/1p2p3/8/2P1P3/2N5/PP1P1PPP/R1BQKBNR b KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 b6 2. Nc3 e6 3. e4
			variation => N__('English: 1... b6 2. Nc3 e6 3. e4'),
			moves => {
			},
		},
		'rnbqkbnr/p1pppppp/1p6/8/2P5/5N2/PP1PPPPP/RNBQKB1R b KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 b6 2. Nf3
			variation => N__('English: 1... b6 2. Nf3'),
			moves => {
				'c8b7' => 1,
			},
		},
		'rn1qkbnr/pbpppppp/1p6/8/2P5/5N2/PP1PPPPP/RNBQKB1R w KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 b6 2. Nf3 Bb7
			variation => N__('English: 1... b6 2. Nf3 Bb7'),
			moves => {
			},
		},
		'r1bqkbnr/pppppppp/2n5/8/2P5/8/PP1PPPPP/RNBQKBNR w KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 Nc6
			variation => N__('English: 1... Nc6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r1bqkbnr/pppppppp/2n5/8/2P5/2N5/PP1PPPPP/R1BQKBNR b KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 Nc6 2. Nc3
			variation => N__('English: 1... Nc6 2. Nc3'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/2P5/8/PP1PPPPP/RNBQKBNR w KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 d5
			variation => N__('English: Vector'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/3p4/8/2P5/8/PP1PPPPP/RNBQKBNR w KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 d6
			variation => N__('English: 1... d6'),
			moves => {
				'b1c3' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/ppp1pppp/3p4/8/2P5/2N5/PP1PPPPP/R1BQKBNR b KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 d6 2. Nc3
			variation => N__('English: 1... d6'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/3p4/8/2P5/5N2/PP1PPPPP/RNBQKB1R b KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 d6 2. Nf3
			variation => N__('English: 1... d6'),
			moves => {
			},
		},
		'rnbqkbnr/ppppp1pp/8/5p2/2P5/8/PP1PPPPP/RNBQKBNR w KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 f5
			variation => N__('English: Anglo-Dutch'),
			moves => {
				'b1c3' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
				'g2g4' => 1,
			},
		},
		'rnbqkbnr/ppppp1pp/8/5p2/2P5/2N5/PP1PPPPP/R1BQKBNR b KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 f5 2. Nc3
			variation => N__('English: Anglo-Dutch'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/5p2/2P5/2N5/PP1PPPPP/R1BQKBNR w KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 f5 2. Nc3 Nf6
			variation => N__('English: Anglo-Dutch'),
			moves => {
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/5p2/2P5/2N3P1/PP1PPP1P/R1BQKBNR b KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 f5 2. Nc3 Nf6 3. g3
			variation => N__('English: Anglo-Dutch'),
			moves => {
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/ppppp2p/5np1/5p2/2P5/2N3P1/PP1PPP1P/R1BQKBNR w KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 f5 2. Nc3 Nf6 3. g3 g6
			variation => N__('English: Anglo-Dutch'),
			moves => {
			},
		},
		'rnbqkbnr/ppppp1pp/8/5p2/2P5/5N2/PP1PPPPP/RNBQKB1R b KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 f5 2. Nf3
			variation => N__('English: Anglo-Dutch'),
			moves => {
				'e7e6' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/pppp2pp/4p3/5p2/2P5/5N2/PP1PPPPP/RNBQKB1R w KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 f5 2. Nf3 e6
			variation => N__('English: Anglo-Dutch'),
			moves => {
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/5p2/2P5/5N2/PP1PPPPP/RNBQKB1R w KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 f5 2. Nf3 Nf6
			variation => N__('English: Anglo-Dutch'),
			moves => {
				'b1c3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/5p2/2P5/2N2N2/PP1PPPPP/R1BQKB1R b KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 f5 2. Nf3 Nf6 3. Nc3
			variation => N__('English: Anglo-Dutch'),
			moves => {
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/5p2/2P5/5NP1/PP1PPP1P/RNBQKB1R b KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 f5 2. Nf3 Nf6 3. g3
			variation => N__('English: Anglo-Dutch'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rnbqkb1r/pppp2pp/4pn2/5p2/2P5/5NP1/PP1PPP1P/RNBQKB1R w KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 f5 2. Nf3 Nf6 3. g3 e6
			variation => N__('English: Anglo-Dutch'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkb1r/pppp2pp/4pn2/5p2/2P5/5NP1/PP1PPPBP/RNBQK2R b KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 f5 2. Nf3 Nf6 3. g3 e6 4. Bg2
			variation => N__('English: Anglo-Dutch'),
			moves => {
				'c7c6' => 1,
				'f8e7' => 1,
			},
		},
		'rnbqkb1r/pp1p2pp/2p1pn2/5p2/2P5/5NP1/PP1PPPBP/RNBQK2R w KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 f5 2. Nf3 Nf6 3. g3 e6 4. Bg2 c6
			variation => N__('English: Anglo-Dutch'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbqkb1r/pp1p2pp/2p1pn2/5p2/2P5/5NP1/PP1PPPBP/RNBQ1RK1 b kq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 f5 2. Nf3 Nf6 3. g3 e6 4. Bg2 c6 5. O-O
			variation => N__('English: Anglo-Dutch'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqkb1r/pp4pp/2p1pn2/3p1p2/2P5/5NP1/PP1PPPBP/RNBQ1RK1 w kq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 f5 2. Nf3 Nf6 3. g3 e6 4. Bg2 c6 5. O-O d5
			variation => N__('English: Anglo-Dutch'),
			moves => {
			},
		},
		'rnbqk2r/ppppb1pp/4pn2/5p2/2P5/5NP1/PP1PPPBP/RNBQK2R w KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 f5 2. Nf3 Nf6 3. g3 e6 4. Bg2 Be7
			variation => N__('English: Anglo-Dutch'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbqk2r/ppppb1pp/4pn2/5p2/2P5/5NP1/PP1PPPBP/RNBQ1RK1 b kq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 f5 2. Nf3 Nf6 3. g3 e6 4. Bg2 Be7 5. O-O
			variation => N__('English: Anglo-Dutch'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppppb1pp/4pn2/5p2/2P5/5NP1/PP1PPPBP/RNBQ1RK1 w -' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 f5 2. Nf3 Nf6 3. g3 e6 4. Bg2 Be7 5. O-O O-O
			variation => N__('English: Anglo-Dutch'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbq1rk1/ppppb1pp/4pn2/5p2/2P5/2N2NP1/PP1PPPBP/R1BQ1RK1 b -' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 f5 2. Nf3 Nf6 3. g3 e6 4. Bg2 Be7 5. O-O O-O 6. Nc3
			variation => N__('English: Anglo-Dutch'),
			moves => {
			},
		},
		'rnbqkbnr/ppppp1pp/8/5p2/2P5/6P1/PP1PPP1P/RNBQKBNR b KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 f5 2. g3
			variation => N__('English: Anglo-Dutch'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/5p2/2P5/6P1/PP1PPP1P/RNBQKBNR w KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 f5 2. g3 Nf6
			variation => N__('English: Anglo-Dutch'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/5p2/2P5/6P1/PP1PPPBP/RNBQK1NR b KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 f5 2. g3 Nf6 3. Bg2
			variation => N__('English: Anglo-Dutch'),
			moves => {
			},
		},
		'rnbqkbnr/ppppp1pp/8/5p2/2P3P1/8/PP1PPP1P/RNBQKBNR b KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 f5 2. g4
			variation => N__('English: Wade Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pppppp1p/8/6p1/2P5/8/PP1PPPPP/RNBQKBNR w KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 g5
			variation => N__('English: 1... g5'),
			moves => {
				'd2d4' => 1,
			},
		},
		'rnbqkbnr/pppppp1p/8/6p1/2PP4/8/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 g5 2. d4
			variation => N__('English: 1... g5 2. d4'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk1nr/ppppppbp/8/6p1/2PP4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 g5 2. d4 Bg7
			variation => N__('English: Myers Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pppppp1p/6p1/8/2P5/8/PP1PPPPP/RNBQKBNR w KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 g6
			variation => N__('English: 1... g6'),
			moves => {
				'b1c3' => 1,
				'e2e4' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/pppppp1p/6p1/8/2P5/2N5/PP1PPPPP/R1BQKBNR b KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 g6 2. Nc3
			variation => N__('English: 1... g6 2. Nc3'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk1nr/ppppppbp/6p1/8/2P5/2N5/PP1PPPPP/R1BQKBNR w KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 g6 2. Nc3 Bg7
			variation => N__('English: 1... g6 2. Nc3 Bg7'),
			moves => {
				'g2g3' => 1,
			},
		},
		'rnbqk1nr/ppppppbp/6p1/8/2P5/2N3P1/PP1PPP1P/R1BQKBNR b KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 g6 2. Nc3 Bg7 3. g3
			variation => N__('English: 1... g6 2. Nc3 Bg7 3. g3'),
			moves => {
			},
		},
		'rnbqkbnr/pppppp1p/6p1/8/2P1P3/8/PP1P1PPP/RNBQKBNR b KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 g6 2. e4
			variation => N__('English: 1... g6 2. e4'),
			moves => {
				'e7e5' => 1,
			},
		},
		'rnbqkbnr/pppp1p1p/6p1/4p3/2P1P3/8/PP1P1PPP/RNBQKBNR w KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 g6 2. e4 e5
			variation => N__('English: Adorjan Defence'),
			moves => {
			},
		},
		'rnbqkbnr/pppppp1p/6p1/8/2P5/5N2/PP1PPPPP/RNBQKB1R b KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 g6 2. Nf3
			variation => N__('English: 1... g6'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk1nr/ppppppbp/6p1/8/2P5/5N2/PP1PPPPP/RNBQKB1R w KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 g6 2. Nf3 Bg7
			variation => N__('English: 1... g6'),
			moves => {
			},
		},
		'rnbqkbnr/pppppp1p/6p1/8/2P5/6P1/PP1PPP1P/RNBQKBNR b KQkq' => {
			eco => 'A10',
			# TRANSLATORS: A10: 1. c4 g6 2. g3
			variation => N__('English: 1... g6 2. g3'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/2p5/8/2P5/8/PP1PPPPP/RNBQKBNR w KQkq' => {
			eco => 'A11',
			# TRANSLATORS: A11: 1. c4 c6
			variation => N__('English: Caro-Kann Defence'),
			moves => {
				'b1c3' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/pp1ppppp/2p5/8/2P5/2N5/PP1PPPPP/R1BQKBNR b KQkq' => {
			eco => 'A11',
			# TRANSLATORS: A11: 1. c4 c6 2. Nc3
			variation => N__('English: Caro-Kann Defence'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3p4/2P5/2N5/PP1PPPPP/R1BQKBNR w KQkq' => {
			eco => 'A11',
			# TRANSLATORS: A11: 1. c4 c6 2. Nc3 d5
			variation => N__('English: Caro-Kann Defence'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/2p5/8/2P5/5N2/PP1PPPPP/RNBQKB1R b KQkq' => {
			eco => 'A11',
			# TRANSLATORS: A11: 1. c4 c6 2. Nf3
			variation => N__('English: Caro-Kann Defence'),
			moves => {
				'd7d5' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3p4/2P5/5N2/PP1PPPPP/RNBQKB1R w KQkq' => {
			eco => 'A11',
			# TRANSLATORS: A11: 1. c4 c6 2. Nf3 d5
			variation => N__('English: Caro-Kann Defence'),
			moves => {
				'b2b3' => 1,
				'e2e3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3p4/2P5/4PN2/PP1P1PPP/RNBQKB1R b KQkq' => {
			eco => 'A11',
			# TRANSLATORS: A11: 1. c4 c6 2. Nf3 d5 3. e3
			variation => N__('English: Caro-Kann Defence, 3. e3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/3p4/2P5/4PN2/PP1P1PPP/RNBQKB1R w KQkq' => {
			eco => 'A11',
			# TRANSLATORS: A11: 1. c4 c6 2. Nf3 d5 3. e3 Nf6
			variation => N__('English: Caro-Kann Defence, 3. e3 Nf6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/3p4/2P5/2N1PN2/PP1P1PPP/R1BQKB1R b KQkq' => {
			eco => 'A11',
			# TRANSLATORS: A11: 1. c4 c6 2. Nf3 d5 3. e3 Nf6 4. Nc3
			variation => N__('English: Caro-Kann Defence, 3. e3 Nf6 4. Nc3'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3p4/2P5/5NP1/PP1PPP1P/RNBQKB1R b KQkq' => {
			eco => 'A11',
			# TRANSLATORS: A11: 1. c4 c6 2. Nf3 d5 3. g3
			variation => N__('English: Caro-Kann Defence, 3. g3'),
			moves => {
				'c8g4' => 1,
			},
		},
		'rn1qkbnr/pp2pppp/2p5/3p4/2P3b1/5NP1/PP1PPP1P/RNBQKB1R w KQkq' => {
			eco => 'A11',
			# TRANSLATORS: A11: 1. c4 c6 2. Nf3 d5 3. g3 Bg4
			variation => N__('English: Caro-Kann Defence, 3. g3 Bg4'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rn1qkbnr/pp2pppp/2p5/3p4/2P3b1/5NP1/PP1PPPBP/RNBQK2R b KQkq' => {
			eco => 'A11',
			# TRANSLATORS: A11: 1. c4 c6 2. Nf3 d5 3. g3 Bg4 4. Bg2
			variation => N__('English: Caro-Kann Defence, 3. g3 Bg4'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/2p2n2/8/2P5/5N2/PP1PPPPP/RNBQKB1R w KQkq' => {
			eco => 'A11',
			# TRANSLATORS: A11: 1. c4 c6 2. Nf3 Nf6
			variation => N__('English: Caro-Kann Defence'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/2p5/8/2P5/6P1/PP1PPP1P/RNBQKBNR b KQkq' => {
			eco => 'A11',
			# TRANSLATORS: A11: 1. c4 c6 2. g3
			variation => N__('English: Caro-Kann Defence'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/pp1ppppp/2p2n2/8/2P5/6P1/PP1PPP1P/RNBQKBNR w KQkq' => {
			eco => 'A11',
			# TRANSLATORS: A11: 1. c4 c6 2. g3 Nf6
			variation => N__('English: Caro-Kann Defence'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkb1r/pp1ppppp/2p2n2/8/2P5/6P1/PP1PPPBP/RNBQK1NR b KQkq' => {
			eco => 'A11',
			# TRANSLATORS: A11: 1. c4 c6 2. g3 Nf6 3. Bg2
			variation => N__('English: Caro-Kann Defence'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/3p4/2P5/6P1/PP1PPPBP/RNBQK1NR w KQkq' => {
			eco => 'A11',
			# TRANSLATORS: A11: 1. c4 c6 2. g3 Nf6 3. Bg2 d5
			variation => N__('English: Caro-Kann Defence'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/3p4/2P5/5NP1/PP1PPPBP/RNBQK2R b KQkq' => {
			eco => 'A11',
			# TRANSLATORS: A11: 1. c4 c6 2. g3 Nf6 3. Bg2 d5 4. Nf3
			variation => N__('English: Caro-Kann Defence'),
			moves => {
				'c8f5' => 1,
				'c8g4' => 1,
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/3p1b2/2P5/5NP1/PP1PPPBP/RNBQK2R w KQkq' => {
			eco => 'A11',
			# TRANSLATORS: A11: 1. c4 c6 2. g3 Nf6 3. Bg2 d5 4. Nf3 Bf5
			variation => N__('English: Caro-Kann Defence'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/3p1b2/2P5/5NP1/PP1PPPBP/RNBQ1RK1 b kq' => {
			eco => 'A11',
			# TRANSLATORS: A11: 1. c4 c6 2. g3 Nf6 3. Bg2 d5 4. Nf3 Bf5 5. O-O
			variation => N__('English: Caro-Kann Defence'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rn1qkb1r/pp3ppp/2p1pn2/3p1b2/2P5/5NP1/PP1PPPBP/RNBQ1RK1 w kq' => {
			eco => 'A11',
			# TRANSLATORS: A11: 1. c4 c6 2. g3 Nf6 3. Bg2 d5 4. Nf3 Bf5 5. O-O e6
			variation => N__('English: Caro-Kann Defence'),
			moves => {
				'd2d3' => 1,
			},
		},
		'rn1qkb1r/pp3ppp/2p1pn2/3p1b2/2P5/3P1NP1/PP2PPBP/RNBQ1RK1 b kq' => {
			eco => 'A11',
			# TRANSLATORS: A11: 1. c4 c6 2. g3 Nf6 3. Bg2 d5 4. Nf3 Bf5 5. O-O e6 6. d3
			variation => N__('English: Caro-Kann Defence'),
			moves => {
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/3p4/2P3b1/5NP1/PP1PPPBP/RNBQK2R w KQkq' => {
			eco => 'A11',
			# TRANSLATORS: A11: 1. c4 c6 2. g3 Nf6 3. Bg2 d5 4. Nf3 Bg4
			variation => N__('English: Caro-Kann Defence'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/3p4/2P3b1/5NP1/PP1PPPBP/RNBQ1RK1 b kq' => {
			eco => 'A11',
			# TRANSLATORS: A11: 1. c4 c6 2. g3 Nf6 3. Bg2 d5 4. Nf3 Bg4 5. O-O
			variation => N__('English: Caro-Kann Defence'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3p4/2P5/1P3N2/P2PPPPP/RNBQKB1R b KQkq' => {
			eco => 'A12',
			# TRANSLATORS: A12: 1. c4 c6 2. Nf3 d5 3. b3
			variation => N__('English: Caro-Kann Defence, 3. b3'),
			moves => {
				'c8g4' => 1,
				'g8f6' => 1,
			},
		},
		'rn1qkbnr/pp2pppp/2p5/3p4/2P3b1/1P3N2/P2PPPPP/RNBQKB1R w KQkq' => {
			eco => 'A12',
			# TRANSLATORS: A12: 1. c4 c6 2. Nf3 d5 3. b3 Bg4
			variation => N__('English: Bogoljubow Variation'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/3p4/2P5/1P3N2/P2PPPPP/RNBQKB1R w KQkq' => {
			eco => 'A12',
			# TRANSLATORS: A12: 1. c4 c6 2. Nf3 d5 3. b3 Nf6
			variation => N__('English: Caro-Kann Defence, 3. b3'),
			moves => {
				'c1b2' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/3p4/2P5/1P3N2/PB1PPPPP/RN1QKB1R b KQkq' => {
			eco => 'A12',
			# TRANSLATORS: A12: 1. c4 c6 2. Nf3 d5 3. b3 Nf6 4. Bb2
			variation => N__('English: Caro-Kann Defence, 3. b3'),
			moves => {
				'c8f5' => 1,
				'c8g4' => 1,
				'g7g6' => 1,
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/3p1b2/2P5/1P3N2/PB1PPPPP/RN1QKB1R w KQkq' => {
			eco => 'A12',
			# TRANSLATORS: A12: 1. c4 c6 2. Nf3 d5 3. b3 Nf6 4. Bb2 Bf5
			variation => N__('English: New York/London Defence'),
			moves => {
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/3p4/2P3b1/1P3N2/PB1PPPPP/RN1QKB1R w KQkq' => {
			eco => 'A12',
			# TRANSLATORS: A12: 1. c4 c6 2. Nf3 d5 3. b3 Nf6 4. Bb2 Bg4
			variation => N__('English: Capablanca'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pp1p/2p2np1/3p4/2P5/1P3N2/PB1PPPPP/RN1QKB1R w KQkq' => {
			eco => 'A12',
			# TRANSLATORS: A12: 1. c4 c6 2. Nf3 d5 3. b3 Nf6 4. Bb2 g6
			variation => N__('English: Bled Variation'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbqkb1r/pp2pp1p/2p2np1/3p4/2P5/1P2PN2/PB1P1PPP/RN1QKB1R b KQkq' => {
			eco => 'A12',
			# TRANSLATORS: A12: 1. c4 c6 2. Nf3 d5 3. b3 Nf6 4. Bb2 g6 5. e3
			variation => N__('English: Bled Variation'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/2p2np1/3p4/2P5/1P2PN2/PB1P1PPP/RN1QKB1R w KQkq' => {
			eco => 'A12',
			# TRANSLATORS: A12: 1. c4 c6 2. Nf3 d5 3. b3 Nf6 4. Bb2 g6 5. e3 Bg7
			variation => N__('English: Bled Variation'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/3p4/2P5/1P3NP1/P2PPP1P/RNBQKB1R b KQkq' => {
			eco => 'A12',
			# TRANSLATORS: A12: 1. c4 c6 2. Nf3 d5 3. b3 Nf6 4. g3
			variation => N__('English: Caro-Kann Defence, 3. b3'),
			moves => {
				'c8f5' => 1,
				'c8g4' => 1,
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/3p1b2/2P5/1P3NP1/P2PPP1P/RNBQKB1R w KQkq' => {
			eco => 'A12',
			# TRANSLATORS: A12: 1. c4 c6 2. Nf3 d5 3. b3 Nf6 4. g3 Bf5
			variation => N__('English: London Defence'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/3p1b2/2P5/1P3NP1/P2PPPBP/RNBQK2R b KQkq' => {
			eco => 'A12',
			# TRANSLATORS: A12: 1. c4 c6 2. Nf3 d5 3. b3 Nf6 4. g3 Bf5 5. Bg2
			variation => N__('English: London Defence'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rn1qkb1r/pp3ppp/2p1pn2/3p1b2/2P5/1P3NP1/P2PPPBP/RNBQK2R w KQkq' => {
			eco => 'A12',
			# TRANSLATORS: A12: 1. c4 c6 2. Nf3 d5 3. b3 Nf6 4. g3 Bf5 5. Bg2 e6
			variation => N__('English: London Defence'),
			moves => {
				'c1b2' => 1,
			},
		},
		'rn1qkb1r/pp3ppp/2p1pn2/3p1b2/2P5/1P3NP1/PB1PPPBP/RN1QK2R b KQkq' => {
			eco => 'A12',
			# TRANSLATORS: A12: 1. c4 c6 2. Nf3 d5 3. b3 Nf6 4. g3 Bf5 5. Bg2 e6 6. Bb2
			variation => N__('English: London Defence'),
			moves => {
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/3p4/2P3b1/1P3NP1/P2PPP1P/RNBQKB1R w KQkq' => {
			eco => 'A12',
			# TRANSLATORS: A12: 1. c4 c6 2. Nf3 d5 3. b3 Nf6 4. g3 Bg4
			variation => N__('English: Torre Defence'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/3p4/2P3b1/1P3NP1/P2PPPBP/RNBQK2R b KQkq' => {
			eco => 'A12',
			# TRANSLATORS: A12: 1. c4 c6 2. Nf3 d5 3. b3 Nf6 4. g3 Bg4 5. Bg2
			variation => N__('English: Torre Defence'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rn1qkb1r/pp3ppp/2p1pn2/3p4/2P3b1/1P3NP1/P2PPPBP/RNBQK2R w KQkq' => {
			eco => 'A12',
			# TRANSLATORS: A12: 1. c4 c6 2. Nf3 d5 3. b3 Nf6 4. g3 Bg4 5. Bg2 e6
			variation => N__('English: Torre Defence'),
			moves => {
				'c1b2' => 1,
			},
		},
		'rn1qkb1r/pp3ppp/2p1pn2/3p4/2P3b1/1P3NP1/PB1PPPBP/RN1QK2R b KQkq' => {
			eco => 'A12',
			# TRANSLATORS: A12: 1. c4 c6 2. Nf3 d5 3. b3 Nf6 4. g3 Bg4 5. Bg2 e6 6. Bb2
			variation => N__('English: Torre Defence'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/4p3/8/2P5/8/PP1PPPPP/RNBQKBNR w KQkq' => {
			eco => 'A13a',
			# TRANSLATORS: A13a: 1. c4 e6
			variation => N__('English: 1... e6'),
			moves => {
				'b1c3' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/pppp1ppp/4p3/8/2P5/6P1/PP1PPP1P/RNBQKBNR b KQkq' => {
			eco => 'A13b',
			# TRANSLATORS: A13b: 1. c4 e6 2. g3
			variation => N__('English: 1... e6 2. g3'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/3p4/2P5/6P1/PP1PPP1P/RNBQKBNR w KQkq' => {
			eco => 'A13c',
			# TRANSLATORS: A13c: 1. c4 e6 2. g3 d5
			variation => N__('English: 1... e6 2. g3 d5'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/3p4/2P5/6P1/PP1PPPBP/RNBQK1NR b KQkq' => {
			eco => 'A13d',
			# TRANSLATORS: A13d: 1. c4 e6 2. g3 d5 3. Bg2
			variation => N__('English: 1... e6 2. g3 d5'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/4p3/8/2P5/2N5/PP1PPPPP/R1BQKBNR b KQkq' => {
			eco => 'A13e',
			# TRANSLATORS: A13e: 1. c4 e6 2. Nc3
			variation => N__('English: 1... e6 2. Nc3'),
			moves => {
				'd7d5' => 1,
				'f8b4' => 1,
			},
		},
		'rnbqk1nr/pppp1ppp/4p3/8/1bP5/2N5/PP1PPPPP/R1BQKBNR w KQkq' => {
			eco => 'A13f',
			# TRANSLATORS: A13f: 1. c4 e6 2. Nc3 Bb4
			variation => N__('English: 1... e6 2. Nc3 Bb4'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/3p4/2P5/2N5/PP1PPPPP/R1BQKBNR w KQkq' => {
			eco => 'A13g',
			# TRANSLATORS: A13g: 1. c4 e6 2. Nc3 d5
			variation => N__('English: 1... e6 2. Nc3 d5'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/4p3/8/2P5/5N2/PP1PPPPP/RNBQKB1R b KQkq' => {
			eco => 'A13h',
			# TRANSLATORS: A13h: 1. c4 e6 2. Nf3
			variation => N__('English: 1... e6 2. Nf3'),
			moves => {
				'd7d5' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/4pn2/8/2P5/5N2/PP1PPPPP/RNBQKB1R w KQkq' => {
			eco => 'A13i',
			# TRANSLATORS: A13i: 1. c4 e6 2. Nf3 Nf6
			variation => N__('English: 1... e6 2. Nf3 Nf6'),
			moves => {
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/4pn2/8/2P5/5NP1/PP1PPP1P/RNBQKB1R b KQkq' => {
			eco => 'A13j',
			# TRANSLATORS: A13j: 1. c4 e6 2. Nf3 Nf6 3. g3
			variation => N__('English: 1... e6 2. Nf3 Nf6 3. g3'),
			moves => {
				'a7a6' => 1,
			},
		},
		'rnbqkb1r/1ppp1ppp/p3pn2/8/2P5/5NP1/PP1PPP1P/RNBQKB1R w KQkq' => {
			eco => 'A13j',
			# TRANSLATORS: A13j: 1. c4 e6 2. Nf3 Nf6 3. g3 a6
			variation => N__('English: 1... e6 2. Nf3 Nf6 3. g3'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkb1r/1ppp1ppp/p3pn2/8/2P5/5NP1/PP1PPPBP/RNBQK2R b KQkq' => {
			eco => 'A13j',
			# TRANSLATORS: A13j: 1. c4 e6 2. Nf3 Nf6 3. g3 a6 4. Bg2
			variation => N__('English: 1... e6 2. Nf3 Nf6 3. g3'),
			moves => {
				'b7b5' => 1,
			},
		},
		'rnbqkb1r/2pp1ppp/p3pn2/1p6/2P5/5NP1/PP1PPPBP/RNBQK2R w KQkq' => {
			eco => 'A13k',
			# TRANSLATORS: A13k: 1. c4 e6 2. Nf3 Nf6 3. g3 a6 4. Bg2 b5
			variation => N__('English: Romanishin Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/3p4/2P5/5N2/PP1PPPPP/RNBQKB1R w KQkq' => {
			eco => 'A13l',
			# TRANSLATORS: A13l: 1. c4 e6 2. Nf3 d5
			variation => N__('English: 1... e6 2. Nf3 d5'),
			moves => {
				'b2b3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/3p4/2P5/1P3N2/P2PPPPP/RNBQKB1R b KQkq' => {
			eco => 'A13m',
			# TRANSLATORS: A13m: 1. c4 e6 2. Nf3 d5 3. b3
			variation => N__('English: Agincourt Variation'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p4/2P5/1P3N2/P2PPPPP/RNBQKB1R w KQkq' => {
			eco => 'A13m',
			# TRANSLATORS: A13m: 1. c4 e6 2. Nf3 d5 3. b3 Nf6
			variation => N__('English: Agincourt Variation'),
			moves => {
				'c1b2' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p4/2P5/1P3N2/PB1PPPPP/RN1QKB1R b KQkq' => {
			eco => 'A13m',
			# TRANSLATORS: A13m: 1. c4 e6 2. Nf3 d5 3. b3 Nf6 4. Bb2
			variation => N__('English: Agincourt Variation'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2pp4/2P5/1P3N2/PB1PPPPP/RN1QKB1R w KQkq' => {
			eco => 'A13m',
			# TRANSLATORS: A13m: 1. c4 e6 2. Nf3 d5 3. b3 Nf6 4. Bb2 c5
			variation => N__('English: Agincourt Variation'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2pp4/2P5/1P2PN2/PB1P1PPP/RN1QKB1R b KQkq' => {
			eco => 'A13n',
			# TRANSLATORS: A13n: 1. c4 e6 2. Nf3 d5 3. b3 Nf6 4. Bb2 c5 5. e3
			variation => N__('English: Wimpey System'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2n1pn2/2pp4/2P5/1P2PN2/PB1P1PPP/RN1QKB1R w KQkq' => {
			eco => 'A13n',
			# TRANSLATORS: A13n: 1. c4 e6 2. Nf3 d5 3. b3 Nf6 4. Bb2 c5 5. e3 Nc6
			variation => N__('English: Wimpey System'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/3p4/2P5/5NP1/PP1PPP1P/RNBQKB1R b KQkq' => {
			eco => 'A13o',
			# TRANSLATORS: A13o: 1. c4 e6 2. Nf3 d5 3. g3
			variation => N__('English: Agincourt Variation'),
			moves => {
				'c7c6' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/2p1p3/3p4/2P5/5NP1/PP1PPP1P/RNBQKB1R w KQkq' => {
			eco => 'A13p',
			# TRANSLATORS: A13p: 1. c4 e6 2. Nf3 d5 3. g3 c6
			variation => N__('English: Kurajica Defence'),
			moves => {
				'd1c2' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/2p1p3/3p4/2P5/5NP1/PPQPPP1P/RNB1KB1R b KQkq' => {
			eco => 'A13q',
			# TRANSLATORS: A13q: 1. c4 e6 2. Nf3 d5 3. g3 c6 4. Qc2
			variation => N__('English: Kurajica Defence'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p4/2P5/5NP1/PP1PPP1P/RNBQKB1R w KQkq' => {
			eco => 'A13r',
			# TRANSLATORS: A13r: 1. c4 e6 2. Nf3 d5 3. g3 Nf6
			variation => N__('English: Neo-Catalan'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p4/2P5/5NP1/PP1PPPBP/RNBQK2R b KQkq' => {
			eco => 'A13s',
			# TRANSLATORS: A13s: 1. c4 e6 2. Nf3 d5 3. g3 Nf6 4. Bg2
			variation => N__('English: Neo-Catalan'),
			moves => {
				'c7c5' => 1,
				'c7c6' => 1,
				'd5c4' => 1,
				'f8e7' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/2p1pn2/3p4/2P5/5NP1/PP1PPPBP/RNBQK2R w KQkq' => {
			eco => 'A13s',
			# TRANSLATORS: A13s: 1. c4 e6 2. Nf3 d5 3. g3 Nf6 4. Bg2 c6
			variation => N__('English: Neo-Catalan, 4... c6'),
			moves => {
				'b2b3' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/2p1pn2/3p4/2P5/1P3NP1/P2PPPBP/RNBQK2R b KQkq' => {
			eco => 'A13s',
			# TRANSLATORS: A13s: 1. c4 e6 2. Nf3 d5 3. g3 Nf6 4. Bg2 c6 5. b3
			variation => N__('English: Neo-Catalan, 4... c6 5. b3'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2pp4/2P5/5NP1/PP1PPPBP/RNBQK2R w KQkq' => {
			eco => 'A13t',
			# TRANSLATORS: A13t: 1. c4 e6 2. Nf3 d5 3. g3 Nf6 4. Bg2 c5
			variation => N__('English: Neo-Catalan, 4... c5'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2pp4/2P5/5NP1/PP1PPPBP/RNBQ1RK1 b kq' => {
			eco => 'A13t',
			# TRANSLATORS: A13t: 1. c4 e6 2. Nf3 d5 3. g3 Nf6 4. Bg2 c5 5. O-O
			variation => N__('English: Neo-Catalan, 4... c5 5.O-O'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/8/2p5/5NP1/PP1PPPBP/RNBQK2R w KQkq' => {
			eco => 'A13u',
			# TRANSLATORS: A13u: 1. c4 e6 2. Nf3 d5 3. g3 Nf6 4. Bg2 dxc4
			variation => N__('English: Neo-Catalan Accepted'),
			moves => {
				'd1a4' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/8/Q1p5/5NP1/PP1PPPBP/RNB1K2R b KQkq' => {
			eco => 'A13v',
			# TRANSLATORS: A13v: 1. c4 e6 2. Nf3 d5 3. g3 Nf6 4. Bg2 dxc4 5. Qa4+
			variation => N__('English: Neo-Catalan Accepted, 5. Qa4+'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r1bqkb1r/pppn1ppp/4pn2/8/Q1p5/5NP1/PP1PPPBP/RNB1K2R w KQkq' => {
			eco => 'A13v',
			# TRANSLATORS: A13v: 1. c4 e6 2. Nf3 d5 3. g3 Nf6 4. Bg2 dxc4 5. Qa4+ Nbd7
			variation => N__('English: Neo-Catalan Accepted, 5. Qa4+ Nbd7'),
			moves => {
				'a4c4' => 1,
				'e1g1' => 1,
			},
		},
		'r1bqkb1r/pppn1ppp/4pn2/8/Q1p5/5NP1/PP1PPPBP/RNB2RK1 b kq' => {
			eco => 'A13v',
			# TRANSLATORS: A13v: 1. c4 e6 2. Nf3 d5 3. g3 Nf6 4. Bg2 dxc4 5. Qa4+ Nbd7 6. O-O
			variation => N__('English: Neo-Catalan Accepted, 5. Qa4+ Nbd7 6.O-O'),
			moves => {
			},
		},
		'r1bqkb1r/pppn1ppp/4pn2/8/2Q5/5NP1/PP1PPPBP/RNB1K2R b KQkq' => {
			eco => 'A13w',
			# TRANSLATORS: A13w: 1. c4 e6 2. Nf3 d5 3. g3 Nf6 4. Bg2 dxc4 5. Qa4+ Nbd7 6. Qxc4
			variation => N__('English: Neo-Catalan Accepted, 5. Qa4+ Nbd7 6.Qxc4'),
			moves => {
				'a7a6' => 1,
				'c7c5' => 1,
			},
		},
		'r1bqkb1r/1ppn1ppp/p3pn2/8/2Q5/5NP1/PP1PPPBP/RNB1K2R w KQkq' => {
			eco => 'A13w',
			# TRANSLATORS: A13w: 1. c4 e6 2. Nf3 d5 3. g3 Nf6 4. Bg2 dxc4 5. Qa4+ Nbd7 6. Qxc4 a6
			variation => N__('English: Neo-Catalan Accepted, 5. Qa4+ Nbd7 6.Qxc4 a6'),
			moves => {
			},
		},
		'r1bqkb1r/pp1n1ppp/4pn2/2p5/2Q5/5NP1/PP1PPPBP/RNB1K2R w KQkq' => {
			eco => 'A13w',
			# TRANSLATORS: A13w: 1. c4 e6 2. Nf3 d5 3. g3 Nf6 4. Bg2 dxc4 5. Qa4+ Nbd7 6. Qxc4 c5
			variation => N__('English: Neo-Catalan Accepted, 5. Qa4+ Nbd7 6.Qxc4 c5'),
			moves => {
			},
		},
		'rnbqk2r/ppp1bppp/4pn2/3p4/2P5/5NP1/PP1PPPBP/RNBQK2R w KQkq' => {
			eco => 'A14',
			# TRANSLATORS: A14: 1. c4 e6 2. Nf3 d5 3. g3 Nf6 4. Bg2 Be7
			variation => N__('English: Neo-Catalan Declined'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbqk2r/ppp1bppp/4pn2/3p4/2P5/5NP1/PP1PPPBP/RNBQ1RK1 b kq' => {
			eco => 'A14',
			# TRANSLATORS: A14: 1. c4 e6 2. Nf3 d5 3. g3 Nf6 4. Bg2 Be7 5. O-O
			variation => N__('English: Neo-Catalan Declined'),
			moves => {
				'c7c5' => 1,
				'c7c6' => 1,
				'e8g8' => 1,
			},
		},
		'rnbqk2r/pp2bppp/4pn2/2pp4/2P5/5NP1/PP1PPPBP/RNBQ1RK1 w kq' => {
			eco => 'A14',
			# TRANSLATORS: A14: 1. c4 e6 2. Nf3 d5 3. g3 Nf6 4. Bg2 Be7 5. O-O c5
			variation => N__('English: Neo-Catalan Declined, 5... c5'),
			moves => {
			},
		},
		'rnbqk2r/pp2bppp/2p1pn2/3p4/2P5/5NP1/PP1PPPBP/RNBQ1RK1 w kq' => {
			eco => 'A14',
			# TRANSLATORS: A14: 1. c4 e6 2. Nf3 d5 3. g3 Nf6 4. Bg2 Be7 5. O-O c6
			variation => N__('English: Neo-Catalan Declined, 5... c6'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1bppp/4pn2/3p4/2P5/5NP1/PP1PPPBP/RNBQ1RK1 w -' => {
			eco => 'A14',
			# TRANSLATORS: A14: 1. c4 e6 2. Nf3 d5 3. g3 Nf6 4. Bg2 Be7 5. O-O O-O
			variation => N__('English: Neo-Catalan Declined, 5...O-O'),
			moves => {
				'b2b3' => 1,
			},
		},
		'rnbq1rk1/ppp1bppp/4pn2/3p4/2P5/1P3NP1/P2PPPBP/RNBQ1RK1 b -' => {
			eco => 'A14',
			# TRANSLATORS: A14: 1. c4 e6 2. Nf3 d5 3. g3 Nf6 4. Bg2 Be7 5. O-O O-O 6. b3
			variation => N__('English: Neo-Catalan Declined, 5...O-O 6. b3'),
			moves => {
				'b7b6' => 1,
				'c7c5' => 1,
			},
		},
		'rnbq1rk1/p1p1bppp/1p2pn2/3p4/2P5/1P3NP1/P2PPPBP/RNBQ1RK1 w -' => {
			eco => 'A14',
			# TRANSLATORS: A14: 1. c4 e6 2. Nf3 d5 3. g3 Nf6 4. Bg2 Be7 5. O-O O-O 6. b3 b6
			variation => N__('English: Neo-Catalan Declined, 5...O-O 6. b3 b6'),
			moves => {
				'c1b2' => 1,
			},
		},
		'rnbq1rk1/p1p1bppp/1p2pn2/3p4/2P5/1P3NP1/PB1PPPBP/RN1Q1RK1 b -' => {
			eco => 'A14',
			# TRANSLATORS: A14: 1. c4 e6 2. Nf3 d5 3. g3 Nf6 4. Bg2 Be7 5. O-O O-O 6. b3 b6 7. Bb2
			variation => N__('English: Neo-Catalan Declined, 5...O-O 6. b3 b6'),
			moves => {
				'c8b7' => 1,
			},
		},
		'rn1q1rk1/pbp1bppp/1p2pn2/3p4/2P5/1P3NP1/PB1PPPBP/RN1Q1RK1 w -' => {
			eco => 'A14',
			# TRANSLATORS: A14: 1. c4 e6 2. Nf3 d5 3. g3 Nf6 4. Bg2 Be7 5. O-O O-O 6. b3 b6 7. Bb2 Bb7
			variation => N__('English: Neo-Catalan Declined, 5...O-O 6. b3 b6 7. Bb2 Bb7'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rn1q1rk1/pbp1bppp/1p2pn2/3p4/2P5/1P2PNP1/PB1P1PBP/RN1Q1RK1 b -' => {
			eco => 'A14',
			# TRANSLATORS: A14: 1. c4 e6 2. Nf3 d5 3. g3 Nf6 4. Bg2 Be7 5. O-O O-O 6. b3 b6 7. Bb2 Bb7 8. e3
			variation => N__('English: Neo-Catalan Declined, 5...O-O 6. b3 b6 7. Bb2 Bb7 8. e3'),
			moves => {
			},
		},
		'rnbq1rk1/pp2bppp/4pn2/2pp4/2P5/1P3NP1/P2PPPBP/RNBQ1RK1 w -' => {
			eco => 'A14',
			# TRANSLATORS: A14: 1. c4 e6 2. Nf3 d5 3. g3 Nf6 4. Bg2 Be7 5. O-O O-O 6. b3 c5
			variation => N__('English: Neo-Catalan Declined, 5...O-O 6. b3 c5'),
			moves => {
				'c1b2' => 1,
			},
		},
		'rnbq1rk1/pp2bppp/4pn2/2pp4/2P5/1P3NP1/PB1PPPBP/RN1Q1RK1 b -' => {
			eco => 'A14',
			# TRANSLATORS: A14: 1. c4 e6 2. Nf3 d5 3. g3 Nf6 4. Bg2 Be7 5. O-O O-O 6. b3 c5 7. Bb2
			variation => N__('English: Neo-Catalan Declined, 5...O-O 6. b3 c5 7. Bb2'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2n1pn2/2pp4/2P5/1P3NP1/PB1PPPBP/RN1Q1RK1 w -' => {
			eco => 'A14',
			# TRANSLATORS: A14: 1. c4 e6 2. Nf3 d5 3. g3 Nf6 4. Bg2 Be7 5. O-O O-O 6. b3 c5 7. Bb2 Nc6
			variation => N__('English: Neo-Catalan Declined, 5...O-O 6. b3 c5 7. Bb2 Nc6'),
			moves => {
				'e2e3' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2n1pn2/2pp4/2P5/1P2PNP1/PB1P1PBP/RN1Q1RK1 b -' => {
			eco => 'A14',
			# TRANSLATORS: A14: 1. c4 e6 2. Nf3 d5 3. g3 Nf6 4. Bg2 Be7 5. O-O O-O 6. b3 c5 7. Bb2 Nc6 8. e3
			variation => N__('English: Neo-Catalan Declined, 5...O-O 6. b3 c5 7. Bb2 Nc6 8. e3'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/2P5/8/PP1PPPPP/RNBQKBNR w KQkq' => {
			eco => 'A15',
			# TRANSLATORS: A15: 1. c4 Nf6
			variation => N__('English: Anglo-Indian'),
			moves => {
				'b1c3' => 1,
				'b2b4' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/1PP5/8/P2PPPPP/RNBQKBNR b KQkq' => {
			eco => 'A15',
			# TRANSLATORS: A15: 1. c4 Nf6 2. b4
			variation => N__('English: Anglo-Indian, Polish'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/2P5/5N2/PP1PPPPP/RNBQKB1R b KQkq' => {
			eco => 'A15',
			# TRANSLATORS: A15: 1. c4 Nf6 2. Nf3
			variation => N__('English: Anglo-Indian, 2. Nf3'),
			moves => {
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/pppppp1p/5np1/8/2P5/5N2/PP1PPPPP/RNBQKB1R w KQkq' => {
			eco => 'A15',
			# TRANSLATORS: A15: 1. c4 Nf6 2. Nf3 g6
			variation => N__('English: Anglo-Indian, 2. Nf3 g6'),
			moves => {
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/pppppp1p/5np1/8/2P5/5NP1/PP1PPP1P/RNBQKB1R b KQkq' => {
			eco => 'A15',
			# TRANSLATORS: A15: 1. c4 Nf6 2. Nf3 g6 3. g3
			variation => N__('English: Anglo-Indian, 2. Nf3 g6'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppppppbp/5np1/8/2P5/5NP1/PP1PPP1P/RNBQKB1R w KQkq' => {
			eco => 'A15',
			# TRANSLATORS: A15: 1. c4 Nf6 2. Nf3 g6 3. g3 Bg7
			variation => N__('English: Anglo-Indian, 2. Nf3 g6'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqk2r/ppppppbp/5np1/8/2P5/5NP1/PP1PPPBP/RNBQK2R b KQkq' => {
			eco => 'A15',
			# TRANSLATORS: A15: 1. c4 Nf6 2. Nf3 g6 3. g3 Bg7 4. Bg2
			variation => N__('English: Anglo-Indian, 2. Nf3 g6'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppppppbp/5np1/8/2P5/5NP1/PP1PPPBP/RNBQK2R w KQ' => {
			eco => 'A15',
			# TRANSLATORS: A15: 1. c4 Nf6 2. Nf3 g6 3. g3 Bg7 4. Bg2 O-O
			variation => N__('English: Anglo-Indian, 2. Nf3 g6'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/2P5/6P1/PP1PPP1P/RNBQKBNR b KQkq' => {
			eco => 'A15',
			# TRANSLATORS: A15: 1. c4 Nf6 2. g3
			variation => N__('English: Anglo-Indian, 2. g3'),
			moves => {
				'e7e6' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/4pn2/8/2P5/6P1/PP1PPP1P/RNBQKBNR w KQkq' => {
			eco => 'A15',
			# TRANSLATORS: A15: 1. c4 Nf6 2. g3 e6
			variation => N__('English: Anglo-Indian, 2. g3 e6'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/4pn2/8/2P5/6P1/PP1PPPBP/RNBQK1NR b KQkq' => {
			eco => 'A15',
			# TRANSLATORS: A15: 1. c4 Nf6 2. g3 e6 3. Bg2
			variation => N__('English: Anglo-Indian, 2. g3 e6'),
			moves => {
			},
		},
		'rnbqkb1r/pppppp1p/5np1/8/2P5/6P1/PP1PPP1P/RNBQKBNR w KQkq' => {
			eco => 'A15',
			# TRANSLATORS: A15: 1. c4 Nf6 2. g3 g6
			variation => N__('English: Anglo-Indian, 2. g3 g6'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkb1r/pppppp1p/5np1/8/2P5/6P1/PP1PPPBP/RNBQK1NR b KQkq' => {
			eco => 'A15',
			# TRANSLATORS: A15: 1. c4 Nf6 2. g3 g6 3. Bg2
			variation => N__('English: Anglo-Indian, 2. g3 g6'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppppppbp/5np1/8/2P5/6P1/PP1PPPBP/RNBQK1NR w KQkq' => {
			eco => 'A15',
			# TRANSLATORS: A15: 1. c4 Nf6 2. g3 g6 3. Bg2 Bg7
			variation => N__('English: Anglo-Indian, 2. g3 g6'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/2P5/2N5/PP1PPPPP/R1BQKBNR b KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3
			variation => N__('English: Anglo-Indian, 2. Nc3'),
			moves => {
				'b8c6' => 1,
				'c7c6' => 1,
				'd7d5' => 1,
				'd7d6' => 1,
				'e7e6' => 1,
				'g7g6' => 1,
			},
		},
		'r1bqkb1r/pppppppp/2n2n2/8/2P5/2N5/PP1PPPPP/R1BQKBNR w KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 Nc6
			variation => N__('English: Anglo-Indian, 2. Nc3 Nc6'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/2p2n2/8/2P5/2N5/PP1PPPPP/R1BQKBNR w KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 c6
			variation => N__('English: Anglo-Indian, 2. Nc3 c6'),
			moves => {
				'e2e4' => 1,
			},
		},
		'rnbqkb1r/pp1ppppp/2p2n2/8/2P1P3/2N5/PP1P1PPP/R1BQKBNR b KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 c6 3. e4
			variation => N__('English: Anglo-Indian, 2. Nc3 c6 3. e4'),
			moves => {
				'd7d5' => 1,
				'e7e5' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/3p4/2P1P3/2N5/PP1P1PPP/R1BQKBNR w KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 c6 3. e4 d5
			variation => N__('English: Anglo-Indian, 2. Nc3 c6 3. e4 d5'),
			moves => {
			},
		},
		'rnbqkb1r/pp1p1ppp/2p2n2/4p3/2P1P3/2N5/PP1P1PPP/R1BQKBNR w KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 c6 3. e4 e5
			variation => N__('English: Anglo-Indian, 2. Nc3 c6 3. e4 e5'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/2P5/2N5/PP1PPPPP/R1BQKBNR w KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 d5
			variation => N__('English: Anglo-Grünfeld'),
			moves => {
				'c4d5' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3P4/8/2N5/PP1PPPPP/R1BQKBNR b KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 d5 3. cxd5
			variation => N__('English: Anglo-Grünfeld, 3.cxd5'),
			moves => {
				'f6d5' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/8/3n4/8/2N5/PP1PPPPP/R1BQKBNR w KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 d5 3. cxd5 Nxd5
			variation => N__('English: Anglo-Grünfeld, 3.cxd5'),
			moves => {
				'g1f3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/8/3n4/8/2N2N2/PP1PPPPP/R1BQKB1R b KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 d5 3. cxd5 Nxd5 4. Nf3
			variation => N__('English: Anglo-Grünfeld, 4. Nf3'),
			moves => {
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/6p1/3n4/8/2N2N2/PP1PPPPP/R1BQKB1R w KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 d5 3. cxd5 Nxd5 4. Nf3 g6
			variation => N__('English: Anglo-Grünfeld, 4. Nf3 g6'),
			moves => {
				'd1a4' => 1,
				'e2e4' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/6p1/3n4/Q7/2N2N2/PP1PPPPP/R1B1KB1R b KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 d5 3. cxd5 Nxd5 4. Nf3 g6 5. Qa4+
			variation => N__('English: Anglo-Grünfeld, 4. Nf3 g6 5. Qa4+'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/6p1/3n4/4P3/2N2N2/PP1P1PPP/R1BQKB1R b KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 d5 3. cxd5 Nxd5 4. Nf3 g6 5. e4
			variation => N__('English: Anglo-Grünfeld, Andersson-Böök Variation'),
			moves => {
				'd5c3' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/6p1/8/4P3/2n2N2/PP1P1PPP/R1BQKB1R w KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 d5 3. cxd5 Nxd5 4. Nf3 g6 5. e4 Nxc3
			variation => N__('English: Anglo-Grünfeld, Andersson-Böök Variation'),
			moves => {
				'd2c3' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/6p1/8/4P3/2P2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 d5 3. cxd5 Nxd5 4. Nf3 g6 5. e4 Nxc3 6. dxc3
			variation => N__('English: Anglo-Grünfeld, Andersson-Böök Variation'),
			moves => {
				'd8d1' => 1,
			},
		},
		'rnb1kb1r/ppp1pp1p/6p1/8/4P3/2P2N2/PP3PPP/R1BqKB1R w KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 d5 3. cxd5 Nxd5 4. Nf3 g6 5. e4 Nxc3 6. dxc3 Qxd1+
			variation => N__('English: Anglo-Grünfeld, Andersson-Böök Variation'),
			moves => {
				'e1d1' => 1,
			},
		},
		'rnb1kb1r/ppp1pp1p/6p1/8/4P3/2P2N2/PP3PPP/R1BK1B1R b kq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 d5 3. cxd5 Nxd5 4. Nf3 g6 5. e4 Nxc3 6. dxc3 Qxd1+ 7. Kxd1
			variation => N__('English: Anglo-Grünfeld, Andersson-Böök, Queenswap'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/6p1/3n4/8/2N2NP1/PP1PPP1P/R1BQKB1R b KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 d5 3. cxd5 Nxd5 4. Nf3 g6 5. g3
			variation => N__('English: Anglo-Grünfeld, 4. Nf3 g6 5. g3'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/6p1/3n4/8/2N2NP1/PP1PPP1P/R1BQKB1R w KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 d5 3. cxd5 Nxd5 4. Nf3 g6 5. g3 Bg7
			variation => N__('English: Anglo-Grünfeld, 4. Nf3 g6 5. g3'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/6p1/3n4/8/2N2NP1/PP1PPPBP/R1BQK2R b KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 d5 3. cxd5 Nxd5 4. Nf3 g6 5. g3 Bg7 6. Bg2
			variation => N__('English: Anglo-Grünfeld, 4. Nf3 g6 5. g3'),
			moves => {
				'e7e5' => 1,
			},
		},
		'rnbqk2r/ppp2pbp/6p1/3np3/8/2N2NP1/PP1PPPBP/R1BQK2R w KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 d5 3. cxd5 Nxd5 4. Nf3 g6 5. g3 Bg7 6. Bg2 e5
			variation => N__('English: Anglo-Grünfeld, Korchnoi Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/8/3n4/8/2N3P1/PP1PPP1P/R1BQKBNR b KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 d5 3. cxd5 Nxd5 4. g3
			variation => N__('English: Anglo-Grünfeld, 3.cxd5'),
			moves => {
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/6p1/3n4/8/2N3P1/PP1PPP1P/R1BQKBNR w KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 d5 3. cxd5 Nxd5 4. g3 g6
			variation => N__('English: Anglo-Grünfeld, 3.cxd5'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/6p1/3n4/8/2N3P1/PP1PPPBP/R1BQK1NR b KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 d5 3. cxd5 Nxd5 4. g3 g6 5. Bg2
			variation => N__('English: Anglo-Grünfeld, 3.cxd5'),
			moves => {
				'd5b6' => 1,
				'd5c3' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/1n4p1/8/8/2N3P1/PP1PPPBP/R1BQK1NR w KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 d5 3. cxd5 Nxd5 4. g3 g6 5. Bg2 Nb6
			variation => N__('English: Anglo-Grünfeld, Czech Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/6p1/8/8/2n3P1/PP1PPPBP/R1BQK1NR w KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 d5 3. cxd5 Nxd5 4. g3 g6 5. Bg2 Nxc3
			variation => N__('English: Anglo-Grünfeld, Smyslov Variation'),
			moves => {
				'b2c3' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/6p1/8/8/2P3P1/P2PPPBP/R1BQK1NR b KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 d5 3. cxd5 Nxd5 4. g3 g6 5. Bg2 Nxc3 6. bxc3
			variation => N__('English: Anglo-Grünfeld, Smyslov Variation'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/6p1/8/8/2P3P1/P2PPPBP/R1BQK1NR w KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 d5 3. cxd5 Nxd5 4. g3 g6 5. Bg2 Nxc3 6. bxc3 Bg7
			variation => N__('English: Anglo-Grünfeld, Smyslov Variation'),
			moves => {
				'a1b1' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/6p1/8/8/2P3P1/P2PPPBP/1RBQK1NR b Kkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 d5 3. cxd5 Nxd5 4. g3 g6 5. Bg2 Nxc3 6. bxc3 Bg7 7. Rb1
			variation => N__('English: Anglo-Grünfeld, Smyslov, 7. Rb1'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/2P5/2N2N2/PP1PPPPP/R1BQKB1R b KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 d5 3. Nf3
			variation => N__('English: Anglo-Grünfeld'),
			moves => {
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/3p4/2P5/2N2N2/PP1PPPPP/R1BQKB1R w KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 d5 3. Nf3 g6
			variation => N__('English: Anglo-Grünfeld'),
			moves => {
				'd1a4' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/3p4/Q1P5/2N2N2/PP1PPPPP/R1B1KB1R b KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 d5 3. Nf3 g6 4. Qa4+
			variation => N__('English: Anglo-Grünfeld'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/3p4/2P5/2N2NP1/PP1PPP1P/R1BQKB1R b KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 d5 3. Nf3 g6 4. g3
			variation => N__('English: Anglo-Grünfeld'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/3p1n2/8/2P5/2N5/PP1PPPPP/R1BQKBNR w KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 d6
			variation => N__('English: Anglo-Indian, 2. Nc3 d6'),
			moves => {
			},
		},
		'rnbqkb1r/pppppp1p/5np1/8/2P5/2N5/PP1PPPPP/R1BQKBNR w KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 g6
			variation => N__('English: Anglo-Indian, 2. Nc3 g6'),
			moves => {
				'e2e4' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/pppppp1p/5np1/8/2P1P3/2N5/PP1P1PPP/R1BQKBNR b KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 g6 3. e4
			variation => N__('English: Anglo-Indian, 2. Nc3 g6 3. e4'),
			moves => {
			},
		},
		'rnbqkb1r/pppppp1p/5np1/8/2P5/2N3P1/PP1PPP1P/R1BQKBNR b KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 g6 3. g3
			variation => N__('English: Anglo-Indian, 2. Nc3 g6 3. g3'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppppppbp/5np1/8/2P5/2N3P1/PP1PPP1P/R1BQKBNR w KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 g6 3. g3 Bg7
			variation => N__('English: Anglo-Indian, 2. Nc3 g6 3. g3'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqk2r/ppppppbp/5np1/8/2P5/2N3P1/PP1PPPBP/R1BQK1NR b KQkq' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 g6 3. g3 Bg7 4. Bg2
			variation => N__('English: Anglo-Indian, 2. Nc3 g6 3. g3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppppppbp/5np1/8/2P5/2N3P1/PP1PPPBP/R1BQK1NR w KQ' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 g6 3. g3 Bg7 4. Bg2 O-O
			variation => N__('English: Anglo-Indian, 2. Nc3 g6 3. g3'),
			moves => {
				'e2e4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbq1rk1/ppppppbp/5np1/8/2P1P3/2N3P1/PP1P1PBP/R1BQK1NR b KQ' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 g6 3. g3 Bg7 4. Bg2 O-O 5. e4
			variation => N__('English: Anglo-Indian, 2. Nc3 g6 3. g3'),
			moves => {
			},
		},
		'rnbq1rk1/ppppppbp/5np1/8/2P5/2N2NP1/PP1PPPBP/R1BQK2R b KQ' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 g6 3. g3 Bg7 4. Bg2 O-O 5. Nf3
			variation => N__('English: Anglo-Indian, 2. Nc3 g6 3. g3'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2P5/2N2NP1/PP1PPPBP/R1BQK2R w KQ' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 g6 3. g3 Bg7 4. Bg2 O-O 5. Nf3 d6
			variation => N__('English: Anglo-Indian, 2. Nc3 g6 3. g3'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2P5/2N2NP1/PP1PPPBP/R1BQ1RK1 b -' => {
			eco => 'A16',
			# TRANSLATORS: A16: 1. c4 Nf6 2. Nc3 g6 3. g3 Bg7 4. Bg2 O-O 5. Nf3 d6 6. O-O
			variation => N__('English: Anglo-Indian, 2. Nc3 g6 3. g3'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/4pn2/8/2P5/2N5/PP1PPPPP/R1BQKBNR w KQkq' => {
			eco => 'A17',
			# TRANSLATORS: A17: 1. c4 Nf6 2. Nc3 e6
			variation => N__('English: Anglo-Indian, 2. Nc3 e6'),
			moves => {
				'e2e4' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/4pn2/8/2P5/2N2N2/PP1PPPPP/R1BQKB1R b KQkq' => {
			eco => 'A17',
			# TRANSLATORS: A17: 1. c4 Nf6 2. Nc3 e6 3. Nf3
			variation => N__('English: Anglo-Indian, 2. Nc3 e6 3. Nf3'),
			moves => {
				'b7b6' => 1,
				'd7d5' => 1,
				'f8b4' => 1,
			},
		},
		'rnbqkb1r/p1pp1ppp/1p2pn2/8/2P5/2N2N2/PP1PPPPP/R1BQKB1R w KQkq' => {
			eco => 'A17',
			# TRANSLATORS: A17: 1. c4 Nf6 2. Nc3 e6 3. Nf3 b6
			variation => N__('English: Anglo-Queen\'s Indian'),
			moves => {
				'e2e4' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/p1pp1ppp/1p2pn2/8/2P1P3/2N2N2/PP1P1PPP/R1BQKB1R b KQkq' => {
			eco => 'A17',
			# TRANSLATORS: A17: 1. c4 Nf6 2. Nc3 e6 3. Nf3 b6 4. e4
			variation => N__('English: Anglo-Queen\'s Indian, 4. e4'),
			moves => {
				'c8b7' => 1,
			},
		},
		'rn1qkb1r/pbpp1ppp/1p2pn2/8/2P1P3/2N2N2/PP1P1PPP/R1BQKB1R w KQkq' => {
			eco => 'A17',
			# TRANSLATORS: A17: 1. c4 Nf6 2. Nc3 e6 3. Nf3 b6 4. e4 Bb7
			variation => N__('English: Anglo-Queen\'s Indian, 4. e4'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rn1qkb1r/pbpp1ppp/1p2pn2/8/2P1P3/2NB1N2/PP1P1PPP/R1BQK2R b KQkq' => {
			eco => 'A17',
			# TRANSLATORS: A17: 1. c4 Nf6 2. Nc3 e6 3. Nf3 b6 4. e4 Bb7 5. Bd3
			variation => N__('English: Anglo-Queen\'s Indian, Romanishin'),
			moves => {
			},
		},
		'rnbqkb1r/p1pp1ppp/1p2pn2/8/2P5/2N2NP1/PP1PPP1P/R1BQKB1R b KQkq' => {
			eco => 'A17',
			# TRANSLATORS: A17: 1. c4 Nf6 2. Nc3 e6 3. Nf3 b6 4. g3
			variation => N__('English: Anglo-Queen\'s Indian, 4. g3'),
			moves => {
				'c8b7' => 1,
			},
		},
		'rn1qkb1r/pbpp1ppp/1p2pn2/8/2P5/2N2NP1/PP1PPP1P/R1BQKB1R w KQkq' => {
			eco => 'A17',
			# TRANSLATORS: A17: 1. c4 Nf6 2. Nc3 e6 3. Nf3 b6 4. g3 Bb7
			variation => N__('English: Anglo-Queen\'s Indian, 4. g3'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rn1qkb1r/pbpp1ppp/1p2pn2/8/2P5/2N2NP1/PP1PPPBP/R1BQK2R b KQkq' => {
			eco => 'A17',
			# TRANSLATORS: A17: 1. c4 Nf6 2. Nc3 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2
			variation => N__('English: Anglo-Queen\'s Indian, 4. g3'),
			moves => {
				'f8e7' => 1,
			},
		},
		'rn1qk2r/pbppbppp/1p2pn2/8/2P5/2N2NP1/PP1PPPBP/R1BQK2R w KQkq' => {
			eco => 'A17',
			# TRANSLATORS: A17: 1. c4 Nf6 2. Nc3 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7
			variation => N__('English: Anglo-Queen\'s Indian, 4. g3'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rn1qk2r/pbppbppp/1p2pn2/8/2P5/2N2NP1/PP1PPPBP/R1BQ1RK1 b kq' => {
			eco => 'A17',
			# TRANSLATORS: A17: 1. c4 Nf6 2. Nc3 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O
			variation => N__('English: Anglo-Queen\'s Indian, 4. g3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rn1q1rk1/pbppbppp/1p2pn2/8/2P5/2N2NP1/PP1PPPBP/R1BQ1RK1 w -' => {
			eco => 'A17',
			# TRANSLATORS: A17: 1. c4 Nf6 2. Nc3 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O
			variation => N__('English: Anglo-Queen\'s Indian, 4. g3'),
			moves => {
				'f1e1' => 1,
			},
		},
		'rn1q1rk1/pbppbppp/1p2pn2/8/2P5/2N2NP1/PP1PPPBP/R1BQR1K1 b -' => {
			eco => 'A17',
			# TRANSLATORS: A17: 1. c4 Nf6 2. Nc3 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Re1
			variation => N__('English: Anglo-Queen\'s Indian, 4. g3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p4/2P5/2N2N2/PP1PPPPP/R1BQKB1R w KQkq' => {
			eco => 'A17',
			# TRANSLATORS: A17: 1. c4 Nf6 2. Nc3 e6 3. Nf3 d5
			variation => N__('English: Anglo-Indian, 2. Nc3 e6 3. Nf3 d5'),
			moves => {
			},
		},
		'rnbqk2r/pppp1ppp/4pn2/8/1bP5/2N2N2/PP1PPPPP/R1BQKB1R w KQkq' => {
			eco => 'A17',
			# TRANSLATORS: A17: 1. c4 Nf6 2. Nc3 e6 3. Nf3 Bb4
			variation => N__('English: Nimzo-English'),
			moves => {
				'd1c2' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqk2r/pppp1ppp/4pn2/8/1bP5/2N2N2/PPQPPPPP/R1B1KB1R b KQkq' => {
			eco => 'A17',
			# TRANSLATORS: A17: 1. c4 Nf6 2. Nc3 e6 3. Nf3 Bb4 4. Qc2
			variation => N__('English: Nimzo-English, 4. Qc2'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/pppp1ppp/4pn2/8/1bP5/2N2N2/PPQPPPPP/R1B1KB1R w KQ' => {
			eco => 'A17',
			# TRANSLATORS: A17: 1. c4 Nf6 2. Nc3 e6 3. Nf3 Bb4 4. Qc2 O-O
			variation => N__('English: Nimzo-English, 4. Qc2 O-O'),
			moves => {
			},
		},
		'rnbqk2r/pppp1ppp/4pn2/8/1bP5/2N2NP1/PP1PPP1P/R1BQKB1R b KQkq' => {
			eco => 'A17',
			# TRANSLATORS: A17: 1. c4 Nf6 2. Nc3 e6 3. Nf3 Bb4 4. g3
			variation => N__('English: Nimzo-English, 4. g3'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/4pn2/8/2P5/2N3P1/PP1PPP1P/R1BQKBNR b KQkq' => {
			eco => 'A17',
			# TRANSLATORS: A17: 1. c4 Nf6 2. Nc3 e6 3. g3
			variation => N__('English: Anglo-Indian, 2. Nc3 e6 3. g3'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/4pn2/8/2P1P3/2N5/PP1P1PPP/R1BQKBNR b KQkq' => {
			eco => 'A18',
			# TRANSLATORS: A18: 1. c4 Nf6 2. Nc3 e6 3. e4
			variation => N__('English: Mikenas'),
			moves => {
				'b8c6' => 1,
				'c7c5' => 1,
				'd7d5' => 1,
				'd7d6' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n1pn2/8/2P1P3/2N5/PP1P1PPP/R1BQKBNR w KQkq' => {
			eco => 'A18',
			# TRANSLATORS: A18: 1. c4 Nf6 2. Nc3 e6 3. e4 Nc6
			variation => N__('English: Mikenas, Kevitz Defence'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p4/2P1P3/2N5/PP1P1PPP/R1BQKBNR w KQkq' => {
			eco => 'A18',
			# TRANSLATORS: A18: 1. c4 Nf6 2. Nc3 e6 3. e4 d5
			variation => N__('English: Mikenas, French Variation'),
			moves => {
				'c4d5' => 1,
				'e4e5' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3P4/4P3/2N5/PP1P1PPP/R1BQKBNR b KQkq' => {
			eco => 'A18',
			# TRANSLATORS: A18: 1. c4 Nf6 2. Nc3 e6 3. e4 d5 4. cxd5
			variation => N__('English: Mikenas, French, 4.cxd5'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3pP3/2P5/2N5/PP1P1PPP/R1BQKBNR b KQkq' => {
			eco => 'A18',
			# TRANSLATORS: A18: 1. c4 Nf6 2. Nc3 e6 3. e4 d5 4. e5
			variation => N__('English: Mikenas, Flohr Variation'),
			moves => {
				'd5d4' => 1,
				'f6e4' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/4P3/2Pp4/2N5/PP1P1PPP/R1BQKBNR w KQkq' => {
			eco => 'A18',
			# TRANSLATORS: A18: 1. c4 Nf6 2. Nc3 e6 3. e4 d5 4. e5 d4
			variation => N__('English: Mikenas, Flohr, 4... d4'),
			moves => {
				'e5f6' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4pP2/8/2Pp4/2N5/PP1P1PPP/R1BQKBNR b KQkq' => {
			eco => 'A18',
			# TRANSLATORS: A18: 1. c4 Nf6 2. Nc3 e6 3. e4 d5 4. e5 d4 5. exf6
			variation => N__('English: Mikenas, Flohr, 4... d4'),
			moves => {
				'd4c3' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4pP2/8/2P5/2p5/PP1P1PPP/R1BQKBNR w KQkq' => {
			eco => 'A18',
			# TRANSLATORS: A18: 1. c4 Nf6 2. Nc3 e6 3. e4 d5 4. e5 d4 5. exf6 dxc3
			variation => N__('English: Mikenas, Flohr, 4... d4'),
			moves => {
				'b2c3' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4pP2/8/2P5/2P5/P2P1PPP/R1BQKBNR b KQkq' => {
			eco => 'A18',
			# TRANSLATORS: A18: 1. c4 Nf6 2. Nc3 e6 3. e4 d5 4. e5 d4 5. exf6 dxc3 6. bxc3
			variation => N__('English: Mikenas, Flohr, 4... d4'),
			moves => {
				'd8f6' => 1,
			},
		},
		'rnb1kb1r/ppp2ppp/4pq2/8/2P5/2P5/P2P1PPP/R1BQKBNR w KQkq' => {
			eco => 'A18',
			# TRANSLATORS: A18: 1. c4 Nf6 2. Nc3 e6 3. e4 d5 4. e5 d4 5. exf6 dxc3 6. bxc3 Qxf6
			variation => N__('English: Mikenas, Flohr, 4... d4'),
			moves => {
				'd2d4' => 1,
				'g1f3' => 1,
			},
		},
		'rnb1kb1r/ppp2ppp/4pq2/8/2PP4/2P5/P4PPP/R1BQKBNR b KQkq' => {
			eco => 'A18',
			# TRANSLATORS: A18: 1. c4 Nf6 2. Nc3 e6 3. e4 d5 4. e5 d4 5. exf6 dxc3 6. bxc3 Qxf6 7. d4
			variation => N__('English: Mikenas, Flohr, 7. d4'),
			moves => {
				'c7c5' => 1,
				'e6e5' => 1,
			},
		},
		'rnb1kb1r/pp3ppp/4pq2/2p5/2PP4/2P5/P4PPP/R1BQKBNR w KQkq' => {
			eco => 'A18',
			# TRANSLATORS: A18: 1. c4 Nf6 2. Nc3 e6 3. e4 d5 4. e5 d4 5. exf6 dxc3 6. bxc3 Qxf6 7. d4 c5
			variation => N__('English: Mikenas, Flohr, 7. d4 c5'),
			moves => {
			},
		},
		'rnb1kb1r/ppp2ppp/5q2/4p3/2PP4/2P5/P4PPP/R1BQKBNR w KQkq' => {
			eco => 'A18',
			# TRANSLATORS: A18: 1. c4 Nf6 2. Nc3 e6 3. e4 d5 4. e5 d4 5. exf6 dxc3 6. bxc3 Qxf6 7. d4 e5
			variation => N__('English: Mikenas, Flohr, 7. d4 e5'),
			moves => {
			},
		},
		'rnb1kb1r/ppp2ppp/4pq2/8/2P5/2P2N2/P2P1PPP/R1BQKB1R b KQkq' => {
			eco => 'A18',
			# TRANSLATORS: A18: 1. c4 Nf6 2. Nc3 e6 3. e4 d5 4. e5 d4 5. exf6 dxc3 6. bxc3 Qxf6 7. Nf3
			variation => N__('English: Mikenas, Flohr, 7. Nf3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4p3/3pP3/2P1n3/2N5/PP1P1PPP/R1BQKBNR w KQkq' => {
			eco => 'A18',
			# TRANSLATORS: A18: 1. c4 Nf6 2. Nc3 e6 3. e4 d5 4. e5 Ne4
			variation => N__('English: Mikenas, Flohr, 4... Ne4'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/3ppn2/8/2P1P3/2N5/PP1P1PPP/R1BQKBNR w KQkq' => {
			eco => 'A18',
			# TRANSLATORS: A18: 1. c4 Nf6 2. Nc3 e6 3. e4 d6
			variation => N__('English: Mikenas, 3... d6'),
			moves => {
				'd2d4' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/3ppn2/8/2PPP3/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'A18',
			# TRANSLATORS: A18: 1. c4 Nf6 2. Nc3 e6 3. e4 d6 4. d4
			variation => N__('English: Mikenas, 3... d6'),
			moves => {
				'f8e7' => 1,
			},
		},
		'rnbqk2r/ppp1bppp/3ppn2/8/2PPP3/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'A18',
			# TRANSLATORS: A18: 1. c4 Nf6 2. Nc3 e6 3. e4 d6 4. d4 Be7
			variation => N__('English: Mikenas, 3... d6 4. d4 Be7'),
			moves => {
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/2p5/2P1P3/2N5/PP1P1PPP/R1BQKBNR w KQkq' => {
			eco => 'A19',
			# TRANSLATORS: A19: 1. c4 Nf6 2. Nc3 e6 3. e4 c5
			variation => N__('English: Mikenas, Sicilian Variation'),
			moves => {
				'e4e5' => 1,
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/2p1P3/2P5/2N5/PP1P1PPP/R1BQKBNR b KQkq' => {
			eco => 'A19',
			# TRANSLATORS: A19: 1. c4 Nf6 2. Nc3 e6 3. e4 c5 4. e5
			variation => N__('English: Mikenas, Sicilian, 4. e5'),
			moves => {
				'f6g8' => 1,
			},
		},
		'rnbqkbnr/pp1p1ppp/4p3/2p1P3/2P5/2N5/PP1P1PPP/R1BQKBNR w KQkq' => {
			eco => 'A19',
			# TRANSLATORS: A19: 1. c4 Nf6 2. Nc3 e6 3. e4 c5 4. e5 Ng8
			variation => N__('English: Mikenas, Sicilian, 4. e5 Ng8'),
			moves => {
				'd2d4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pp1p1ppp/4p3/2p1P3/2PP4/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'A19',
			# TRANSLATORS: A19: 1. c4 Nf6 2. Nc3 e6 3. e4 c5 4. e5 Ng8 5. d4
			variation => N__('English: Mikenas, Nei Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pp1p1ppp/4p3/2p1P3/2P5/2N2N2/PP1P1PPP/R1BQKB1R b KQkq' => {
			eco => 'A19',
			# TRANSLATORS: A19: 1. c4 Nf6 2. Nc3 e6 3. e4 c5 4. e5 Ng8 5. Nf3
			variation => N__('English: Mikenas, 5. Nf3'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkbnr/pp1p1ppp/2n1p3/2p1P3/2P5/2N2N2/PP1P1PPP/R1BQKB1R w KQkq' => {
			eco => 'A19',
			# TRANSLATORS: A19: 1. c4 Nf6 2. Nc3 e6 3. e4 c5 4. e5 Ng8 5. Nf3 Nc6
			variation => N__('English: Mikenas, 5. Nf3 Nc6'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bqkbnr/pp1p1ppp/2n1p3/2p1P3/2PP4/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'A19',
			# TRANSLATORS: A19: 1. c4 Nf6 2. Nc3 e6 3. e4 c5 4. e5 Ng8 5. Nf3 Nc6 6. d4
			variation => N__('English: Mikenas, 5. Nf3 Nc6 6. d4'),
			moves => {
				'c5d4' => 1,
			},
		},
		'r1bqkbnr/pp1p1ppp/2n1p3/4P3/2Pp4/2N2N2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'A19',
			# TRANSLATORS: A19: 1. c4 Nf6 2. Nc3 e6 3. e4 c5 4. e5 Ng8 5. Nf3 Nc6 6. d4 cxd4
			variation => N__('English: Mikenas, 5. Nf3 Nc6 6. d4'),
			moves => {
				'f3d4' => 1,
			},
		},
		'r1bqkbnr/pp1p1ppp/2n1p3/4P3/2PN4/2N5/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'A19',
			# TRANSLATORS: A19: 1. c4 Nf6 2. Nc3 e6 3. e4 c5 4. e5 Ng8 5. Nf3 Nc6 6. d4 cxd4 7. Nxd4
			variation => N__('English: Mikenas, 5. Nf3 Nc6 6. d4'),
			moves => {
				'c6e5' => 1,
			},
		},
		'r1bqkbnr/pp1p1ppp/4p3/4n3/2PN4/2N5/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'A19',
			# TRANSLATORS: A19: 1. c4 Nf6 2. Nc3 e6 3. e4 c5 4. e5 Ng8 5. Nf3 Nc6 6. d4 cxd4 7. Nxd4 Nxe5
			variation => N__('English: Mikenas, 6. d4 cxd4 7.Nxd4 Nxe5'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/4p3/2P5/8/PP1PPPPP/RNBQKBNR w KQkq' => {
			eco => 'A20',
			# TRANSLATORS: A20: 1. c4 e5
			variation => N__('English: King\'s (1... e5)'),
			moves => {
				'b1c3' => 1,
				'd2d3' => 1,
				'e2e3' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/pppp1ppp/8/4p3/2P5/3P4/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'A20',
			# TRANSLATORS: A20: 1. c4 e5 2. d3
			variation => N__('English: King\'s, 2. d3'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/4p3/2P5/4P3/PP1P1PPP/RNBQKBNR b KQkq' => {
			eco => 'A20',
			# TRANSLATORS: A20: 1. c4 e5 2. e3
			variation => N__('English: King\'s, 2. e3'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/4p3/2P5/5N2/PP1PPPPP/RNBQKB1R b KQkq' => {
			eco => 'A20',
			# TRANSLATORS: A20: 1. c4 e5 2. Nf3
			variation => N__('English: King\'s, Nimzowitsch'),
			moves => {
				'b8c6' => 1,
				'e5e4' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4p3/2P5/5N2/PP1PPPPP/RNBQKB1R w KQkq' => {
			eco => 'A20',
			# TRANSLATORS: A20: 1. c4 e5 2. Nf3 Nc6
			variation => N__('English: King\'s, Nimzowitsch, 2... Nc6'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/8/2P1p3/5N2/PP1PPPPP/RNBQKB1R w KQkq' => {
			eco => 'A20',
			# TRANSLATORS: A20: 1. c4 e5 2. Nf3 e4
			variation => N__('English: King\'s, Nimzowitsch, Flohr Variation'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/4p3/2P5/6P1/PP1PPP1P/RNBQKBNR b KQkq' => {
			eco => 'A20',
			# TRANSLATORS: A20: 1. c4 e5 2. g3
			variation => N__('English: King\'s, 2. g3'),
			moves => {
				'b8c6' => 1,
				'c7c6' => 1,
				'd7d6' => 1,
				'f7f5' => 1,
				'g7g6' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4p3/2P5/6P1/PP1PPP1P/RNBQKBNR w KQkq' => {
			eco => 'A20',
			# TRANSLATORS: A20: 1. c4 e5 2. g3 Nc6
			variation => N__('English: King\'s, 2. g3 Nc6'),
			moves => {
				'f1g2' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4p3/2P5/6P1/PP1PPPBP/RNBQK1NR b KQkq' => {
			eco => 'A20',
			# TRANSLATORS: A20: 1. c4 e5 2. g3 Nc6 3. Bg2
			variation => N__('English: King\'s, 2. g3 Nc6 3. Bg2'),
			moves => {
			},
		},
		'rnbqkbnr/pp1p1ppp/2p5/4p3/2P5/6P1/PP1PPP1P/RNBQKBNR w KQkq' => {
			eco => 'A20',
			# TRANSLATORS: A20: 1. c4 e5 2. g3 c6
			variation => N__('English: King\'s, 2. g3 c6'),
			moves => {
				'd2d4' => 1,
			},
		},
		'rnbqkbnr/pp1p1ppp/2p5/4p3/2PP4/6P1/PP2PP1P/RNBQKBNR b KQkq' => {
			eco => 'A20',
			# TRANSLATORS: A20: 1. c4 e5 2. g3 c6 3. d4
			variation => N__('English: King\'s, 2. g3 c6 3. d4'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/3p4/4p3/2P5/6P1/PP1PPP1P/RNBQKBNR w KQkq' => {
			eco => 'A20',
			# TRANSLATORS: A20: 1. c4 e5 2. g3 d6
			variation => N__('English: King\'s, 2. g3 d6'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/3p4/4p3/2P5/6P1/PP1PPPBP/RNBQK1NR b KQkq' => {
			eco => 'A20',
			# TRANSLATORS: A20: 1. c4 e5 2. g3 d6 3. Bg2
			variation => N__('English: King\'s, 2. g3 d6'),
			moves => {
			},
		},
		'rnbqkbnr/pppp2pp/8/4pp2/2P5/6P1/PP1PPP1P/RNBQKBNR w KQkq' => {
			eco => 'A20',
			# TRANSLATORS: A20: 1. c4 e5 2. g3 f5
			variation => N__('English: King\'s, 2. g3 f5'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1p1p/6p1/4p3/2P5/6P1/PP1PPP1P/RNBQKBNR w KQkq' => {
			eco => 'A20',
			# TRANSLATORS: A20: 1. c4 e5 2. g3 g6
			variation => N__('English: King\'s, 2. g3 g6'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkbnr/pppp1p1p/6p1/4p3/2P5/6P1/PP1PPPBP/RNBQK1NR b KQkq' => {
			eco => 'A20',
			# TRANSLATORS: A20: 1. c4 e5 2. g3 g6 3. Bg2
			variation => N__('English: King\'s, 2. g3 g6'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk1nr/pppp1pbp/6p1/4p3/2P5/6P1/PP1PPPBP/RNBQK1NR w KQkq' => {
			eco => 'A20',
			# TRANSLATORS: A20: 1. c4 e5 2. g3 g6 3. Bg2 Bg7
			variation => N__('English: King\'s, 2. g3 g6'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/4p3/2P5/6P1/PP1PPP1P/RNBQKBNR w KQkq' => {
			eco => 'A20',
			# TRANSLATORS: A20: 1. c4 e5 2. g3 Nf6
			variation => N__('English: King\'s, 2. g3 Nf6'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/4p3/2P5/6P1/PP1PPPBP/RNBQK1NR b KQkq' => {
			eco => 'A20',
			# TRANSLATORS: A20: 1. c4 e5 2. g3 Nf6 3. Bg2
			variation => N__('English: King\'s, 2. g3 Nf6 3. Bg2'),
			moves => {
				'b8c6' => 1,
				'c7c6' => 1,
				'd7d5' => 1,
				'f8c5' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4p3/2P5/6P1/PP1PPPBP/RNBQK1NR w KQkq' => {
			eco => 'A20',
			# TRANSLATORS: A20: 1. c4 e5 2. g3 Nf6 3. Bg2 Nc6
			variation => N__('English: King\'s, 2. g3 Nf6 3. Bg2 Nc6'),
			moves => {
			},
		},
		'rnbqkb1r/pp1p1ppp/2p2n2/4p3/2P5/6P1/PP1PPPBP/RNBQK1NR w KQkq' => {
			eco => 'A20',
			# TRANSLATORS: A20: 1. c4 e5 2. g3 Nf6 3. Bg2 c6
			variation => N__('English: King\'s, 2. g3 Nf6 3. Bg2 c6'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3pp3/2P5/6P1/PP1PPPBP/RNBQK1NR w KQkq' => {
			eco => 'A20',
			# TRANSLATORS: A20: 1. c4 e5 2. g3 Nf6 3. Bg2 d5
			variation => N__('English: King\'s, 2. g3 Nf6 3. Bg2 d5'),
			moves => {
			},
		},
		'rnbqk2r/pppp1ppp/5n2/2b1p3/2P5/6P1/PP1PPPBP/RNBQK1NR w KQkq' => {
			eco => 'A20',
			# TRANSLATORS: A20: 1. c4 e5 2. g3 Nf6 3. Bg2 Bc5
			variation => N__('English: King\'s, 2. g3 Nf6 3. Bg2 Bc5'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/4p3/2P5/2N5/PP1PPPPP/R1BQKBNR b KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3
			variation => N__('English: King\'s, 2. Nc3'),
			moves => {
				'b8c6' => 1,
				'd7d6' => 1,
				'f7f5' => 1,
				'f8b4' => 1,
				'g7g6' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/3p4/4p3/2P5/2N5/PP1PPPPP/R1BQKBNR w KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 d6
			variation => N__('English: King\'s, 2. Nc3 d6'),
			moves => {
				'd2d4' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/3p4/4p3/2PP4/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 d6 3. d4
			variation => N__('English: King\'s, 2. Nc3 d6 3. d4'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/3p4/4p3/2P5/2N2N2/PP1PPPPP/R1BQKB1R b KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 d6 3. Nf3
			variation => N__('English: King\'s, 2. Nc3 d6 3. Nf3'),
			moves => {
				'c8g4' => 1,
				'f7f5' => 1,
				'g7g6' => 1,
			},
		},
		'rn1qkbnr/ppp2ppp/3p4/4p3/2P3b1/2N2N2/PP1PPPPP/R1BQKB1R w KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 d6 3. Nf3 Bg4
			variation => N__('English: Smyslov Defence'),
			moves => {
			},
		},
		'rnbqkbnr/ppp3pp/3p4/4pp2/2P5/2N2N2/PP1PPPPP/R1BQKB1R w KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 d6 3. Nf3 f5
			variation => N__('English: Lukin Variation'),
			moves => {
				'd2d4' => 1,
			},
		},
		'rnbqkbnr/ppp3pp/3p4/4pp2/2PP4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 d6 3. Nf3 f5 4. d4
			variation => N__('English: Lukin Variation'),
			moves => {
				'e5e4' => 1,
			},
		},
		'rnbqkbnr/ppp3pp/3p4/5p2/2PPp3/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 d6 3. Nf3 f5 4. d4 e4
			variation => N__('English: Lukin, 4. d4 e4'),
			moves => {
				'f3d2' => 1,
				'f3g5' => 1,
			},
		},
		'rnbqkbnr/ppp3pp/3p4/5p2/2PPp3/2N5/PP1NPPPP/R1BQKB1R b KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 d6 3. Nf3 f5 4. d4 e4 5. Nd2
			variation => N__('English: Lukin, 5. Nd2'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/ppp3pp/3p1n2/5p2/2PPp3/2N5/PP1NPPPP/R1BQKB1R w KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 d6 3. Nf3 f5 4. d4 e4 5. Nd2 Nf6
			variation => N__('English: Lukin, 5. Nd2'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbqkb1r/ppp3pp/3p1n2/5p2/2PPp3/2N1P3/PP1N1PPP/R1BQKB1R b KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 d6 3. Nf3 f5 4. d4 e4 5. Nd2 Nf6 6. e3
			variation => N__('English: Lukin, 5. Nd2 Nf6 6. e3'),
			moves => {
			},
		},
		'rnbqkbnr/ppp3pp/3p4/5pN1/2PPp3/2N5/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 d6 3. Nf3 f5 4. d4 e4 5. Ng5
			variation => N__('English: Lukin, 5. Ng5'),
			moves => {
				'c7c6' => 1,
				'f8e7' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/pp4pp/2pp4/5pN1/2PPp3/2N5/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 d6 3. Nf3 f5 4. d4 e4 5. Ng5 c6
			variation => N__('English: Lukin, 5. Ng5 c6'),
			moves => {
			},
		},
		'rnbqk1nr/ppp1b1pp/3p4/5pN1/2PPp3/2N5/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 d6 3. Nf3 f5 4. d4 e4 5. Ng5 Be7
			variation => N__('English: Lukin, 5. Ng5 Be7'),
			moves => {
			},
		},
		'rnbqkb1r/ppp3pp/3p1n2/5pN1/2PPp3/2N5/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 d6 3. Nf3 f5 4. d4 e4 5. Ng5 Nf6
			variation => N__('English: Lukin, 5. Ng5 Nf6'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2p1p/3p2p1/4p3/2P5/2N2N2/PP1PPPPP/R1BQKB1R w KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 d6 3. Nf3 g6
			variation => N__('English: King\'s, 2. Nc3 d6 3. Nf3 g6'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/3p4/4p3/2P5/2N3P1/PP1PPP1P/R1BQKBNR b KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 d6 3. g3
			variation => N__('English: King\'s, 2. Nc3 d6 3. g3'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/2pp4/4p3/2P5/2N3P1/PP1PPP1P/R1BQKBNR w KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 d6 3. g3 c6
			variation => N__('English: King\'s, Keres Variation'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/2pp4/4p3/2P5/2N3P1/PP1PPPBP/R1BQK1NR b KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 d6 3. g3 c6 4. Bg2
			variation => N__('English: King\'s, Keres Variation'),
			moves => {
			},
		},
		'rnbqkbnr/pppp2pp/8/4pp2/2P5/2N5/PP1PPPPP/R1BQKBNR w KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 f5
			variation => N__('English: King\'s, 2. Nc3 f5'),
			moves => {
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/pppp2pp/8/4pp2/2P5/2N3P1/PP1PPP1P/R1BQKBNR b KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 f5 3. g3
			variation => N__('English: King\'s, 2. Nc3 f5'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/pppp2pp/5n2/4pp2/2P5/2N3P1/PP1PPP1P/R1BQKBNR w KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 f5 3. g3 Nf6
			variation => N__('English: King\'s, 2. Nc3 f5'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkb1r/pppp2pp/5n2/4pp2/2P5/2N3P1/PP1PPPBP/R1BQK1NR b KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 f5 3. g3 Nf6 4. Bg2
			variation => N__('English: King\'s, 2. Nc3 f5'),
			moves => {
			},
		},
		'rnbqk1nr/pppp1ppp/8/4p3/1bP5/2N5/PP1PPPPP/R1BQKBNR w KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 Bb4
			variation => N__('English: Kramnik-Shirov Counterattack'),
			moves => {
				'c3d5' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqk1nr/pppp1ppp/8/3Np3/1bP5/8/PP1PPPPP/R1BQKBNR b KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 Bb4 3. Nd5
			variation => N__('English: Kramnik-Shirov, 3. Nd5'),
			moves => {
				'a7a5' => 1,
				'b4a5' => 1,
				'b4c5' => 1,
				'b4e7' => 1,
			},
		},
		'rnbqk1nr/1ppp1ppp/8/p2Np3/1bP5/8/PP1PPPPP/R1BQKBNR w KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 Bb4 3. Nd5 a5
			variation => N__('English: Kramnik-Shirov, 3. Nd5 a5'),
			moves => {
			},
		},
		'rnbqk1nr/pppp1ppp/8/b2Np3/2P5/8/PP1PPPPP/R1BQKBNR w KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 Bb4 3. Nd5 Ba5
			variation => N__('English: Kramnik-Shirov, 3. Nd5 Ba5'),
			moves => {
			},
		},
		'rnbqk1nr/pppp1ppp/8/2bNp3/2P5/8/PP1PPPPP/R1BQKBNR w KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 Bb4 3. Nd5 Bc5
			variation => N__('English: Kramnik-Shirov, 3. Nd5 Bc5'),
			moves => {
			},
		},
		'rnbqk1nr/ppppbppp/8/3Np3/2P5/8/PP1PPPPP/R1BQKBNR w KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 Bb4 3. Nd5 Be7
			variation => N__('English: Kramnik-Shirov, 3. Nd5 Be7'),
			moves => {
				'd2d4' => 1,
			},
		},
		'rnbqk1nr/ppppbppp/8/3Np3/2PP4/8/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 Bb4 3. Nd5 Be7 4. d4
			variation => N__('English: Kramnik-Shirov, 3. Nd5 Be7 4. d4'),
			moves => {
			},
		},
		'rnbqk1nr/pppp1ppp/8/4p3/1bP5/2N3P1/PP1PPP1P/R1BQKBNR b KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 Bb4 3. g3
			variation => N__('English: Kramnik-Shirov, 3. g3'),
			moves => {
				'b4c3' => 1,
			},
		},
		'rnbqk1nr/pppp1ppp/8/4p3/2P5/2b3P1/PP1PPP1P/R1BQKBNR w KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 Bb4 3. g3 Bxc3
			variation => N__('English: Kramnik-Shirov, 3. g3 Bxc3'),
			moves => {
				'b2c3' => 1,
			},
		},
		'rnbqk1nr/pppp1ppp/8/4p3/2P5/2P3P1/P2PPP1P/R1BQKBNR b KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 Bb4 3. g3 Bxc3 4. bxc3
			variation => N__('English: Kramnik-Shirov, 3. g3 Bxc3 4.bxc3'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1p1p/6p1/4p3/2P5/2N5/PP1PPPPP/R1BQKBNR w KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 g6
			variation => N__('English: King\'s, 2. Nc3 g6'),
			moves => {
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/pppp1p1p/6p1/4p3/2P5/2N3P1/PP1PPP1P/R1BQKBNR b KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 g6 3. g3
			variation => N__('English: King\'s, 2. Nc3 g6'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk1nr/pppp1pbp/6p1/4p3/2P5/2N3P1/PP1PPP1P/R1BQKBNR w KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 g6 3. g3 Bg7
			variation => N__('English: King\'s, 2. Nc3 g6'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqk1nr/pppp1pbp/6p1/4p3/2P5/2N3P1/PP1PPPBP/R1BQK1NR b KQkq' => {
			eco => 'A21',
			# TRANSLATORS: A21: 1. c4 e5 2. Nc3 g6 3. g3 Bg7 4. Bg2
			variation => N__('English: King\'s, 2. Nc3 g6'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/4p3/2P5/2N5/PP1PPPPP/R1BQKBNR w KQkq' => {
			eco => 'A22',
			# TRANSLATORS: A22: 1. c4 e5 2. Nc3 Nf6
			variation => N__('English: King\'s, 2. Nc3 Nf6'),
			moves => {
				'e2e3' => 1,
				'e2e4' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/4p3/2P5/2N1P3/PP1P1PPP/R1BQKBNR b KQkq' => {
			eco => 'A22',
			# TRANSLATORS: A22: 1. c4 e5 2. Nc3 Nf6 3. e3
			variation => N__('English: King\'s, 2. Nc3 Nf6 3. e3'),
			moves => {
				'f8b4' => 1,
			},
		},
		'rnbqk2r/pppp1ppp/5n2/4p3/1bP5/2N1P3/PP1P1PPP/R1BQKBNR w KQkq' => {
			eco => 'A22',
			# TRANSLATORS: A22: 1. c4 e5 2. Nc3 Nf6 3. e3 Bb4
			variation => N__('English: King\'s, 2. Nc3 Nf6 3. e3 Bb4'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/4p3/2P1P3/2N5/PP1P1PPP/R1BQKBNR b KQkq' => {
			eco => 'A22',
			# TRANSLATORS: A22: 1. c4 e5 2. Nc3 Nf6 3. e4
			variation => N__('English: King\'s, 2. Nc3 Nf6 3. e4'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/4p3/2P5/2N2N2/PP1PPPPP/R1BQKB1R b KQkq' => {
			eco => 'A22',
			# TRANSLATORS: A22: 1. c4 e5 2. Nc3 Nf6 3. Nf3
			variation => N__('English: King\'s, 2. Nc3 Nf6 3. Nf3'),
			moves => {
				'd7d6' => 1,
				'e5e4' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/3p1n2/4p3/2P5/2N2N2/PP1PPPPP/R1BQKB1R w KQkq' => {
			eco => 'A22',
			# TRANSLATORS: A22: 1. c4 e5 2. Nc3 Nf6 3. Nf3 d6
			variation => N__('English: King\'s, 2. Nc3 Nf6 3. Nf3 d6'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/8/2P1p3/2N2N2/PP1PPPPP/R1BQKB1R w KQkq' => {
			eco => 'A22',
			# TRANSLATORS: A22: 1. c4 e5 2. Nc3 Nf6 3. Nf3 e4
			variation => N__('English: King\'s, 2. Nc3 Nf6 3. Nf3 e4'),
			moves => {
				'f3g5' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/6N1/2P1p3/2N5/PP1PPPPP/R1BQKB1R b KQkq' => {
			eco => 'A22',
			# TRANSLATORS: A22: 1. c4 e5 2. Nc3 Nf6 3. Nf3 e4 4. Ng5
			variation => N__('English: King\'s, 2. Nc3 Nf6 3. Nf3 e4'),
			moves => {
				'b7b5' => 1,
			},
		},
		'rnbqkb1r/p1pp1ppp/5n2/1p4N1/2P1p3/2N5/PP1PPPPP/R1BQKB1R w KQkq' => {
			eco => 'A22',
			# TRANSLATORS: A22: 1. c4 e5 2. Nc3 Nf6 3. Nf3 e4 4. Ng5 b5
			variation => N__('English: Bellon Gambit'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/4p3/2P5/2N3P1/PP1PPP1P/R1BQKBNR b KQkq' => {
			eco => 'A22',
			# TRANSLATORS: A22: 1. c4 e5 2. Nc3 Nf6 3. g3
			variation => N__('English: Bremen System'),
			moves => {
				'c7c6' => 1,
				'd7d5' => 1,
				'f8b4' => 1,
				'f8c5' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3pp3/2P5/2N3P1/PP1PPP1P/R1BQKBNR w KQkq' => {
			eco => 'A22',
			# TRANSLATORS: A22: 1. c4 e5 2. Nc3 Nf6 3. g3 d5
			variation => N__('English: Bremen, Reverse Dragon'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3Pp3/8/2N3P1/PP1PPP1P/R1BQKBNR b KQkq' => {
			eco => 'A22',
			# TRANSLATORS: A22: 1. c4 e5 2. Nc3 Nf6 3. g3 d5 4. cxd5
			variation => N__('English: Bremen, Reverse Dragon, 4.cxd5'),
			moves => {
				'f6d5' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/8/3np3/8/2N3P1/PP1PPP1P/R1BQKBNR w KQkq' => {
			eco => 'A22',
			# TRANSLATORS: A22: 1. c4 e5 2. Nc3 Nf6 3. g3 d5 4. cxd5 Nxd5
			variation => N__('English: Bremen, Reverse Dragon, 4.cxd5 Nxd5'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/8/3np3/8/2N3P1/PP1PPPBP/R1BQK1NR b KQkq' => {
			eco => 'A22',
			# TRANSLATORS: A22: 1. c4 e5 2. Nc3 Nf6 3. g3 d5 4. cxd5 Nxd5 5. Bg2
			variation => N__('English: Bremen, Reverse Dragon, 4.cxd5 Nxd5 5. Bg2'),
			moves => {
				'd5b6' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/1n6/4p3/8/2N3P1/PP1PPPBP/R1BQK1NR w KQkq' => {
			eco => 'A22',
			# TRANSLATORS: A22: 1. c4 e5 2. Nc3 Nf6 3. g3 d5 4. cxd5 Nxd5 5. Bg2 Nb6
			variation => N__('English: Bremen, Reverse Dragon, 4.cxd5 Nxd5 5. Bg2 Nb6'),
			moves => {
			},
		},
		'rnbqk2r/pppp1ppp/5n2/4p3/1bP5/2N3P1/PP1PPP1P/R1BQKBNR w KQkq' => {
			eco => 'A22',
			# TRANSLATORS: A22: 1. c4 e5 2. Nc3 Nf6 3. g3 Bb4
			variation => N__('English: Bremen, Smyslov System'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqk2r/pppp1ppp/5n2/4p3/1bP5/2N3P1/PP1PPPBP/R1BQK1NR b KQkq' => {
			eco => 'A22',
			# TRANSLATORS: A22: 1. c4 e5 2. Nc3 Nf6 3. g3 Bb4 4. Bg2
			variation => N__('English: Bremen, Smyslov, 4. Bg2'),
			moves => {
				'b4c3' => 1,
				'e8g8' => 1,
			},
		},
		'rnbqk2r/pppp1ppp/5n2/4p3/2P5/2b3P1/PP1PPPBP/R1BQK1NR w KQkq' => {
			eco => 'A22',
			# TRANSLATORS: A22: 1. c4 e5 2. Nc3 Nf6 3. g3 Bb4 4. Bg2 Bxc3
			variation => N__('English: Bremen, Smyslov, 4. Bg2 Bxc3'),
			moves => {
			},
		},
		'rnbq1rk1/pppp1ppp/5n2/4p3/1bP5/2N3P1/PP1PPPBP/R1BQK1NR w KQ' => {
			eco => 'A22',
			# TRANSLATORS: A22: 1. c4 e5 2. Nc3 Nf6 3. g3 Bb4 4. Bg2 O-O
			variation => N__('English: Bremen, Smyslov, 4. Bg2 O-O'),
			moves => {
				'e2e4' => 1,
			},
		},
		'rnbq1rk1/pppp1ppp/5n2/4p3/1bP1P3/2N3P1/PP1P1PBP/R1BQK1NR b KQ' => {
			eco => 'A22',
			# TRANSLATORS: A22: 1. c4 e5 2. Nc3 Nf6 3. g3 Bb4 4. Bg2 O-O 5. e4
			variation => N__('English: Bremen, Smyslov, 4. Bg2 O-O 5. e4'),
			moves => {
			},
		},
		'rnbqk2r/pppp1ppp/5n2/2b1p3/2P5/2N3P1/PP1PPP1P/R1BQKBNR w KQkq' => {
			eco => 'A22',
			# TRANSLATORS: A22: 1. c4 e5 2. Nc3 Nf6 3. g3 Bc5
			variation => N__('English: Bremen, 3... Bc5'),
			moves => {
			},
		},
		'rnbqkb1r/pp1p1ppp/2p2n2/4p3/2P5/2N3P1/PP1PPP1P/R1BQKBNR w KQkq' => {
			eco => 'A23',
			# TRANSLATORS: A23: 1. c4 e5 2. Nc3 Nf6 3. g3 c6
			variation => N__('English: Bremen, Keres System'),
			moves => {
				'f1g2' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/pp1p1ppp/2p2n2/4p3/2P5/2N3P1/PP1PPPBP/R1BQK1NR b KQkq' => {
			eco => 'A23',
			# TRANSLATORS: A23: 1. c4 e5 2. Nc3 Nf6 3. g3 c6 4. Bg2
			variation => N__('English: Bremen, Keres, 4. Bg2'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/2p2n2/3pp3/2P5/2N3P1/PP1PPPBP/R1BQK1NR w KQkq' => {
			eco => 'A23',
			# TRANSLATORS: A23: 1. c4 e5 2. Nc3 Nf6 3. g3 c6 4. Bg2 d5
			variation => N__('English: Bremen, Keres, 4. Bg2 d5'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/2p2n2/3Pp3/8/2N3P1/PP1PPPBP/R1BQK1NR b KQkq' => {
			eco => 'A23',
			# TRANSLATORS: A23: 1. c4 e5 2. Nc3 Nf6 3. g3 c6 4. Bg2 d5 5. cxd5
			variation => N__('English: Bremen, Keres, 4. Bg2 d5 5.cxd5'),
			moves => {
				'c6d5' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/5n2/3pp3/8/2N3P1/PP1PPPBP/R1BQK1NR w KQkq' => {
			eco => 'A23',
			# TRANSLATORS: A23: 1. c4 e5 2. Nc3 Nf6 3. g3 c6 4. Bg2 d5 5. cxd5 cxd5
			variation => N__('English: Bremen, Keres, 4. Bg2 d5 5.cxd5 cxd5'),
			moves => {
			},
		},
		'rnbqkb1r/pp1p1ppp/2p2n2/4p3/2P5/2N2NP1/PP1PPP1P/R1BQKB1R b KQkq' => {
			eco => 'A23',
			# TRANSLATORS: A23: 1. c4 e5 2. Nc3 Nf6 3. g3 c6 4. Nf3
			variation => N__('English: Bremen, Keres, 4. Nf3'),
			moves => {
				'd7d6' => 1,
				'e5e4' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/2pp1n2/4p3/2P5/2N2NP1/PP1PPP1P/R1BQKB1R w KQkq' => {
			eco => 'A23',
			# TRANSLATORS: A23: 1. c4 e5 2. Nc3 Nf6 3. g3 c6 4. Nf3 d6
			variation => N__('English: Bremen, Keres, 4. Nf3 d6'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/2pp1n2/4p3/2P5/2N2NP1/PP1PPPBP/R1BQK2R b KQkq' => {
			eco => 'A23',
			# TRANSLATORS: A23: 1. c4 e5 2. Nc3 Nf6 3. g3 c6 4. Nf3 d6 5. Bg2
			variation => N__('English: Bremen, Keres, 4. Nf3 d6'),
			moves => {
			},
		},
		'rnbqkb1r/pp1p1ppp/2p2n2/8/2P1p3/2N2NP1/PP1PPP1P/R1BQKB1R w KQkq' => {
			eco => 'A23',
			# TRANSLATORS: A23: 1. c4 e5 2. Nc3 Nf6 3. g3 c6 4. Nf3 e4
			variation => N__('English: Bremen, Keres, 4. Nf3 e4'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1p1p/5np1/4p3/2P5/2N3P1/PP1PPP1P/R1BQKBNR w KQkq' => {
			eco => 'A24',
			# TRANSLATORS: A24: 1. c4 e5 2. Nc3 Nf6 3. g3 g6
			variation => N__('English: Bremen, 3... g6'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkb1r/pppp1p1p/5np1/4p3/2P5/2N3P1/PP1PPPBP/R1BQK1NR b KQkq' => {
			eco => 'A24',
			# TRANSLATORS: A24: 1. c4 e5 2. Nc3 Nf6 3. g3 g6 4. Bg2
			variation => N__('English: Bremen, 3... g6'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/pppp1pbp/5np1/4p3/2P5/2N3P1/PP1PPPBP/R1BQK1NR w KQkq' => {
			eco => 'A24',
			# TRANSLATORS: A24: 1. c4 e5 2. Nc3 Nf6 3. g3 g6 4. Bg2 Bg7
			variation => N__('English: Bremen, 3... g6'),
			moves => {
				'd2d3' => 1,
				'e2e3' => 1,
				'e2e4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqk2r/pppp1pbp/5np1/4p3/2P5/2NP2P1/PP2PPBP/R1BQK1NR b KQkq' => {
			eco => 'A24',
			# TRANSLATORS: A24: 1. c4 e5 2. Nc3 Nf6 3. g3 g6 4. Bg2 Bg7 5. d3
			variation => N__('English: Bremen, 3... g6'),
			moves => {
			},
		},
		'rnbqk2r/pppp1pbp/5np1/4p3/2P5/2N1P1P1/PP1P1PBP/R1BQK1NR b KQkq' => {
			eco => 'A24',
			# TRANSLATORS: A24: 1. c4 e5 2. Nc3 Nf6 3. g3 g6 4. Bg2 Bg7 5. e3
			variation => N__('English: Bremen, 3... g6'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rnbqk2r/ppp2pbp/3p1np1/4p3/2P5/2N1P1P1/PP1P1PBP/R1BQK1NR w KQkq' => {
			eco => 'A24',
			# TRANSLATORS: A24: 1. c4 e5 2. Nc3 Nf6 3. g3 g6 4. Bg2 Bg7 5. e3 d6
			variation => N__('English: Bremen, 3... g6'),
			moves => {
				'g1e2' => 1,
			},
		},
		'rnbqk2r/ppp2pbp/3p1np1/4p3/2P5/2N1P1P1/PP1PNPBP/R1BQK2R b KQkq' => {
			eco => 'A24',
			# TRANSLATORS: A24: 1. c4 e5 2. Nc3 Nf6 3. g3 g6 4. Bg2 Bg7 5. e3 d6 6. Nge2
			variation => N__('English: Bremen, 3... g6'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppp2pbp/3p1np1/4p3/2P5/2N1P1P1/PP1PNPBP/R1BQK2R w KQ' => {
			eco => 'A24',
			# TRANSLATORS: A24: 1. c4 e5 2. Nc3 Nf6 3. g3 g6 4. Bg2 Bg7 5. e3 d6 6. Nge2 O-O
			variation => N__('English: Bremen, 3... g6'),
			moves => {
			},
		},
		'rnbqk2r/pppp1pbp/5np1/4p3/2P1P3/2N3P1/PP1P1PBP/R1BQK1NR b KQkq' => {
			eco => 'A24',
			# TRANSLATORS: A24: 1. c4 e5 2. Nc3 Nf6 3. g3 g6 4. Bg2 Bg7 5. e4
			variation => N__('English: Bremen, 3... g6'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rnbqk2r/ppp2pbp/3p1np1/4p3/2P1P3/2N3P1/PP1P1PBP/R1BQK1NR w KQkq' => {
			eco => 'A24',
			# TRANSLATORS: A24: 1. c4 e5 2. Nc3 Nf6 3. g3 g6 4. Bg2 Bg7 5. e4 d6
			variation => N__('English: Bremen, 3... g6'),
			moves => {
				'g1e2' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqk2r/ppp2pbp/3p1np1/4p3/2P1P3/2N3P1/PP1PNPBP/R1BQK2R b KQkq' => {
			eco => 'A24',
			# TRANSLATORS: A24: 1. c4 e5 2. Nc3 Nf6 3. g3 g6 4. Bg2 Bg7 5. e4 d6 6. Nge2
			variation => N__('English: Bremen, 3... g6'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppp2pbp/3p1np1/4p3/2P1P3/2N3P1/PP1PNPBP/R1BQK2R w KQ' => {
			eco => 'A24',
			# TRANSLATORS: A24: 1. c4 e5 2. Nc3 Nf6 3. g3 g6 4. Bg2 Bg7 5. e4 d6 6. Nge2 O-O
			variation => N__('English: Bremen, 3... g6'),
			moves => {
				'd2d3' => 1,
			},
		},
		'rnbq1rk1/ppp2pbp/3p1np1/4p3/2P1P3/2NP2P1/PP2NPBP/R1BQK2R b KQ' => {
			eco => 'A24',
			# TRANSLATORS: A24: 1. c4 e5 2. Nc3 Nf6 3. g3 g6 4. Bg2 Bg7 5. e4 d6 6. Nge2 O-O 7. d3
			variation => N__('English: Bremen, 3... g6'),
			moves => {
			},
		},
		'rnbqk2r/ppp2pbp/3p1np1/4p3/2P1P3/2N2NP1/PP1P1PBP/R1BQK2R b KQkq' => {
			eco => 'A24',
			# TRANSLATORS: A24: 1. c4 e5 2. Nc3 Nf6 3. g3 g6 4. Bg2 Bg7 5. e4 d6 6. Nf3
			variation => N__('English: Bremen, 3... g6'),
			moves => {
			},
		},
		'rnbqk2r/pppp1pbp/5np1/4p3/2P5/2N2NP1/PP1PPPBP/R1BQK2R b KQkq' => {
			eco => 'A24',
			# TRANSLATORS: A24: 1. c4 e5 2. Nc3 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3
			variation => N__('English: Bremen, 3... g6'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rnbqk2r/ppp2pbp/3p1np1/4p3/2P5/2N2NP1/PP1PPPBP/R1BQK2R w KQkq' => {
			eco => 'A24',
			# TRANSLATORS: A24: 1. c4 e5 2. Nc3 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 d6
			variation => N__('English: Bremen, 3... g6'),
			moves => {
				'd2d3' => 1,
				'e1g1' => 1,
			},
		},
		'rnbqk2r/ppp2pbp/3p1np1/4p3/2P5/2NP1NP1/PP2PPBP/R1BQK2R b KQkq' => {
			eco => 'A24',
			# TRANSLATORS: A24: 1. c4 e5 2. Nc3 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 d6 6. d3
			variation => N__('English: Bremen, 3... g6'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppp2pbp/3p1np1/4p3/2P5/2NP1NP1/PP2PPBP/R1BQK2R w KQ' => {
			eco => 'A24',
			# TRANSLATORS: A24: 1. c4 e5 2. Nc3 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 d6 6. d3 O-O
			variation => N__('English: Bremen, 3... g6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbq1rk1/ppp2pbp/3p1np1/4p3/2P5/2NP1NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'A24',
			# TRANSLATORS: A24: 1. c4 e5 2. Nc3 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 d6 6. d3 O-O 7. O-O
			variation => N__('English: Bremen, 3... g6'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/2pp1np1/4p3/2P5/2NP1NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A24',
			# TRANSLATORS: A24: 1. c4 e5 2. Nc3 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 d6 6. d3 O-O 7. O-O c6
			variation => N__('English: Bremen, 3... g6'),
			moves => {
			},
		},
		'rnbqk2r/ppp2pbp/3p1np1/4p3/2P5/2N2NP1/PP1PPPBP/R1BQ1RK1 b kq' => {
			eco => 'A24',
			# TRANSLATORS: A24: 1. c4 e5 2. Nc3 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 d6 6. O-O
			variation => N__('English: Bremen, 3... g6'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppp2pbp/3p1np1/4p3/2P5/2N2NP1/PP1PPPBP/R1BQ1RK1 w -' => {
			eco => 'A24',
			# TRANSLATORS: A24: 1. c4 e5 2. Nc3 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 d6 6. O-O O-O
			variation => N__('English: Bremen, 3... g6'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4p3/2P5/2N5/PP1PPPPP/R1BQKBNR w KQkq' => {
			eco => 'A25',
			# TRANSLATORS: A25: 1. c4 e5 2. Nc3 Nc6
			variation => N__('English: Closed'),
			moves => {
				'e2e3' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4p3/2P5/2N1P3/PP1P1PPP/R1BQKBNR b KQkq' => {
			eco => 'A25',
			# TRANSLATORS: A25: 1. c4 e5 2. Nc3 Nc6 3. e3
			variation => N__('English: Closed'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4p3/2P5/2N1P3/PP1P1PPP/R1BQKBNR w KQkq' => {
			eco => 'A25',
			# TRANSLATORS: A25: 1. c4 e5 2. Nc3 Nc6 3. e3 Nf6
			variation => N__('English: Closed'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4p3/2P5/2N3P1/PP1PPP1P/R1BQKBNR b KQkq' => {
			eco => 'A25',
			# TRANSLATORS: A25: 1. c4 e5 2. Nc3 Nc6 3. g3
			variation => N__('English: Closed'),
			moves => {
				'd7d6' => 1,
				'f7f5' => 1,
				'g7g6' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkbnr/ppp2ppp/2np4/4p3/2P5/2N3P1/PP1PPP1P/R1BQKBNR w KQkq' => {
			eco => 'A25',
			# TRANSLATORS: A25: 1. c4 e5 2. Nc3 Nc6 3. g3 d6
			variation => N__('English: Closed'),
			moves => {
				'f1g2' => 1,
			},
		},
		'r1bqkbnr/ppp2ppp/2np4/4p3/2P5/2N3P1/PP1PPPBP/R1BQK1NR b KQkq' => {
			eco => 'A25',
			# TRANSLATORS: A25: 1. c4 e5 2. Nc3 Nc6 3. g3 d6 4. Bg2
			variation => N__('English: Closed'),
			moves => {
				'c8e6' => 1,
			},
		},
		'r2qkbnr/ppp2ppp/2npb3/4p3/2P5/2N3P1/PP1PPPBP/R1BQK1NR w KQkq' => {
			eco => 'A25',
			# TRANSLATORS: A25: 1. c4 e5 2. Nc3 Nc6 3. g3 d6 4. Bg2 Be6
			variation => N__('English: Closed, Tröger Defence'),
			moves => {
				'd2d3' => 1,
			},
		},
		'r2qkbnr/ppp2ppp/2npb3/4p3/2P5/2NP2P1/PP2PPBP/R1BQK1NR b KQkq' => {
			eco => 'A25',
			# TRANSLATORS: A25: 1. c4 e5 2. Nc3 Nc6 3. g3 d6 4. Bg2 Be6 5. d3
			variation => N__('English: Closed, Tröger, 5. d3'),
			moves => {
			},
		},
		'r1bqkbnr/pppp2pp/2n5/4pp2/2P5/2N3P1/PP1PPP1P/R1BQKBNR w KQkq' => {
			eco => 'A25',
			# TRANSLATORS: A25: 1. c4 e5 2. Nc3 Nc6 3. g3 f5
			variation => N__('English: Closed'),
			moves => {
				'f1g2' => 1,
			},
		},
		'r1bqkbnr/pppp2pp/2n5/4pp2/2P5/2N3P1/PP1PPPBP/R1BQK1NR b KQkq' => {
			eco => 'A25',
			# TRANSLATORS: A25: 1. c4 e5 2. Nc3 Nc6 3. g3 f5 4. Bg2
			variation => N__('English: Closed'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r1bqkb1r/pppp2pp/2n2n2/4pp2/2P5/2N3P1/PP1PPPBP/R1BQK1NR w KQkq' => {
			eco => 'A25',
			# TRANSLATORS: A25: 1. c4 e5 2. Nc3 Nc6 3. g3 f5 4. Bg2 Nf6
			variation => N__('English: Closed'),
			moves => {
				'd2d3' => 1,
				'e2e3' => 1,
			},
		},
		'r1bqkb1r/pppp2pp/2n2n2/4pp2/2P5/2NP2P1/PP2PPBP/R1BQK1NR b KQkq' => {
			eco => 'A25',
			# TRANSLATORS: A25: 1. c4 e5 2. Nc3 Nc6 3. g3 f5 4. Bg2 Nf6 5. d3
			variation => N__('English: Closed'),
			moves => {
			},
		},
		'r1bqkb1r/pppp2pp/2n2n2/4pp2/2P5/2N1P1P1/PP1P1PBP/R1BQK1NR b KQkq' => {
			eco => 'A25',
			# TRANSLATORS: A25: 1. c4 e5 2. Nc3 Nc6 3. g3 f5 4. Bg2 Nf6 5. e3
			variation => N__('English: Closed'),
			moves => {
				'g7g6' => 1,
			},
		},
		'r1bqkb1r/pppp3p/2n2np1/4pp2/2P5/2N1P1P1/PP1P1PBP/R1BQK1NR w KQkq' => {
			eco => 'A25',
			# TRANSLATORS: A25: 1. c4 e5 2. Nc3 Nc6 3. g3 f5 4. Bg2 Nf6 5. e3 g6
			variation => N__('English: Closed'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1p1p/2n3p1/4p3/2P5/2N3P1/PP1PPP1P/R1BQKBNR w KQkq' => {
			eco => 'A25',
			# TRANSLATORS: A25: 1. c4 e5 2. Nc3 Nc6 3. g3 g6
			variation => N__('English: Closed'),
			moves => {
				'f1g2' => 1,
			},
		},
		'r1bqkbnr/pppp1p1p/2n3p1/4p3/2P5/2N3P1/PP1PPPBP/R1BQK1NR b KQkq' => {
			eco => 'A25',
			# TRANSLATORS: A25: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2
			variation => N__('English: Closed'),
			moves => {
				'f8g7' => 1,
			},
		},
		'r1bqk1nr/pppp1pbp/2n3p1/4p3/2P5/2N3P1/PP1PPPBP/R1BQK1NR w KQkq' => {
			eco => 'A25',
			# TRANSLATORS: A25: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7
			variation => N__('English: Closed'),
			moves => {
				'a1b1' => 1,
				'd2d3' => 1,
				'e2e3' => 1,
				'e2e4' => 1,
			},
		},
		'r1bqk1nr/pppp1pbp/2n3p1/4p3/2P5/2N3P1/PP1PPPBP/1RBQK1NR b Kkq' => {
			eco => 'A25',
			# TRANSLATORS: A25: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Rb1
			variation => N__('English: Closed, 5. Rb1'),
			moves => {
				'a7a5' => 1,
				'g8h6' => 1,
			},
		},
		'r1bqk1nr/1ppp1pbp/2n3p1/p3p3/2P5/2N3P1/PP1PPPBP/1RBQK1NR w Kkq' => {
			eco => 'A25',
			# TRANSLATORS: A25: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Rb1 a5
			variation => N__('English: Closed, 5. Rb1'),
			moves => {
			},
		},
		'r1bqk2r/pppp1pbp/2n3pn/4p3/2P5/2N3P1/PP1PPPBP/1RBQK1NR w Kkq' => {
			eco => 'A25',
			# TRANSLATORS: A25: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Rb1 Nh6
			variation => N__('English: Closed, 5. Rb1, Taimanov Variation'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1pbp/2n3p1/4p3/2P5/2NP2P1/PP2PPBP/R1BQK1NR b KQkq' => {
			eco => 'A25',
			# TRANSLATORS: A25: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3
			variation => N__('English: Closed, 5. d3'),
			moves => {
				'd7d6' => 1,
				'g8e7' => 1,
			},
		},
		'r1bqk2r/ppppnpbp/2n3p1/4p3/2P5/2NP2P1/PP2PPBP/R1BQK1NR w KQkq' => {
			eco => 'A25',
			# TRANSLATORS: A25: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 Nge7
			variation => N__('English: Closed, 5. d3 Nge7'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1pbp/2n3p1/4p3/2P5/2N1P1P1/PP1P1PBP/R1BQK1NR b KQkq' => {
			eco => 'A25',
			# TRANSLATORS: A25: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. e3
			variation => N__('English: Closed, 5. e3'),
			moves => {
				'd7d6' => 1,
			},
		},
		'r1bqk1nr/ppp2pbp/2np2p1/4p3/2P5/2N1P1P1/PP1P1PBP/R1BQK1NR w KQkq' => {
			eco => 'A25',
			# TRANSLATORS: A25: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. e3 d6
			variation => N__('English: Closed, 5. e3'),
			moves => {
				'g1e2' => 1,
			},
		},
		'r1bqk1nr/ppp2pbp/2np2p1/4p3/2P5/2N1P1P1/PP1PNPBP/R1BQK2R b KQkq' => {
			eco => 'A25',
			# TRANSLATORS: A25: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. e3 d6 6. Nge2
			variation => N__('English: Closed, 5. e3'),
			moves => {
				'c8e6' => 1,
				'g8h6' => 1,
			},
		},
		'r2qk1nr/ppp2pbp/2npb1p1/4p3/2P5/2N1P1P1/PP1PNPBP/R1BQK2R w KQkq' => {
			eco => 'A25',
			# TRANSLATORS: A25: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. e3 d6 6. Nge2 Be6
			variation => N__('English: Closed, Hort Variation'),
			moves => {
				'd2d3' => 1,
			},
		},
		'r2qk1nr/ppp2pbp/2npb1p1/4p3/2P5/2NPP1P1/PP2NPBP/R1BQK2R b KQkq' => {
			eco => 'A25',
			# TRANSLATORS: A25: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. e3 d6 6. Nge2 Be6 7. d3
			variation => N__('English: Closed, Hort, 7. d3'),
			moves => {
			},
		},
		'r1bqk2r/ppp2pbp/2np2pn/4p3/2P5/2N1P1P1/PP1PNPBP/R1BQK2R w KQkq' => {
			eco => 'A25',
			# TRANSLATORS: A25: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. e3 d6 6. Nge2 Nh6
			variation => N__('English: Closed, Taimanov Variation'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1pbp/2n3p1/4p3/2P1P3/2N3P1/PP1P1PBP/R1BQK1NR b KQkq' => {
			eco => 'A25',
			# TRANSLATORS: A25: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. e4
			variation => N__('English: Closed, 5. e4'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4p3/2P5/2N3P1/PP1PPP1P/R1BQKBNR w KQkq' => {
			eco => 'A25',
			# TRANSLATORS: A25: 1. c4 e5 2. Nc3 Nc6 3. g3 Nf6
			variation => N__('English: Closed'),
			moves => {
				'f1g2' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4p3/2P5/2N3P1/PP1PPPBP/R1BQK1NR b KQkq' => {
			eco => 'A25',
			# TRANSLATORS: A25: 1. c4 e5 2. Nc3 Nc6 3. g3 Nf6 4. Bg2
			variation => N__('English: Closed'),
			moves => {
				'f8b4' => 1,
				'f8c5' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/4p3/1bP5/2N3P1/PP1PPPBP/R1BQK1NR w KQkq' => {
			eco => 'A25',
			# TRANSLATORS: A25: 1. c4 e5 2. Nc3 Nc6 3. g3 Nf6 4. Bg2 Bb4
			variation => N__('English: Closed'),
			moves => {
				'c3d5' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/3Np3/1bP5/6P1/PP1PPPBP/R1BQK1NR b KQkq' => {
			eco => 'A25',
			# TRANSLATORS: A25: 1. c4 e5 2. Nc3 Nc6 3. g3 Nf6 4. Bg2 Bb4 5. Nd5
			variation => N__('English: Closed'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/2b1p3/2P5/2N3P1/PP1PPPBP/R1BQK1NR w KQkq' => {
			eco => 'A25',
			# TRANSLATORS: A25: 1. c4 e5 2. Nc3 Nc6 3. g3 Nf6 4. Bg2 Bc5
			variation => N__('English: Closed'),
			moves => {
				'e2e3' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/2b1p3/2P5/2N1P1P1/PP1P1PBP/R1BQK1NR b KQkq' => {
			eco => 'A25',
			# TRANSLATORS: A25: 1. c4 e5 2. Nc3 Nc6 3. g3 Nf6 4. Bg2 Bc5 5. e3
			variation => N__('English: Closed'),
			moves => {
			},
		},
		'r1bqk1nr/ppp2pbp/2np2p1/4p3/2P5/2NP2P1/PP2PPBP/R1BQK1NR w KQkq' => {
			eco => 'A26',
			# TRANSLATORS: A26: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6
			variation => N__('English: Closed, 5. d3 d6'),
			moves => {
				'a1b1' => 1,
				'e2e3' => 1,
				'e2e4' => 1,
				'g1f3' => 1,
			},
		},
		'r1bqk1nr/ppp2pbp/2np2p1/4p3/2P5/2NP2P1/PP2PPBP/1RBQK1NR b Kkq' => {
			eco => 'A26',
			# TRANSLATORS: A26: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. Rb1
			variation => N__('English: Closed, 5. d3 d6 6. Rb1'),
			moves => {
				'a7a5' => 1,
				'f7f5' => 1,
			},
		},
		'r1bqk1nr/1pp2pbp/2np2p1/p3p3/2P5/2NP2P1/PP2PPBP/1RBQK1NR w Kkq' => {
			eco => 'A26',
			# TRANSLATORS: A26: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. Rb1 a5
			variation => N__('English: Closed, 5. d3 d6 6. Rb1 a5'),
			moves => {
			},
		},
		'r1bqk1nr/ppp3bp/2np2p1/4pp2/2P5/2NP2P1/PP2PPBP/1RBQK1NR w Kkq' => {
			eco => 'A26',
			# TRANSLATORS: A26: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. Rb1 f5
			variation => N__('English: Closed, 5. d3 d6 6. Rb1 f5'),
			moves => {
			},
		},
		'r1bqk1nr/ppp2pbp/2np2p1/4p3/2P5/2NPP1P1/PP3PBP/R1BQK1NR b KQkq' => {
			eco => 'A26',
			# TRANSLATORS: A26: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. e3
			variation => N__('English: Closed, 5. d3 d6 6. e3'),
			moves => {
			},
		},
		'r1bqk1nr/ppp2pbp/2np2p1/4p3/2P1P3/2NP2P1/PP3PBP/R1BQK1NR b KQkq' => {
			eco => 'A26',
			# TRANSLATORS: A26: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. e4
			variation => N__('English: Botvinnik System'),
			moves => {
				'g8e7' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqk2r/ppp1npbp/2np2p1/4p3/2P1P3/2NP2P1/PP3PBP/R1BQK1NR w KQkq' => {
			eco => 'A26',
			# TRANSLATORS: A26: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. e4 Nge7
			variation => N__('English: Botvinnik System, 6...Nge7'),
			moves => {
				'g1e2' => 1,
			},
		},
		'r1bqk2r/ppp1npbp/2np2p1/4p3/2P1P3/2NP2P1/PP2NPBP/R1BQK2R b KQkq' => {
			eco => 'A26',
			# TRANSLATORS: A26: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. e4 Nge7 7. Nge2
			variation => N__('English: Botvinnik System, 6...Nge7 7.Nge2'),
			moves => {
			},
		},
		'r1bqk2r/ppp2pbp/2np1np1/4p3/2P1P3/2NP2P1/PP3PBP/R1BQK1NR w KQkq' => {
			eco => 'A26',
			# TRANSLATORS: A26: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. e4 Nf6
			variation => N__('English: Botvinnik System, 6... Nf6'),
			moves => {
				'g1e2' => 1,
				'g1f3' => 1,
			},
		},
		'r1bqk2r/ppp2pbp/2np1np1/4p3/2P1P3/2NP2P1/PP2NPBP/R1BQK2R b KQkq' => {
			eco => 'A26',
			# TRANSLATORS: A26: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. e4 Nf6 7. Nge2
			variation => N__('English: Botvinnik System, 6... Nf6'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/ppp2pbp/2np1np1/4p3/2P1P3/2NP2P1/PP2NPBP/R1BQK2R w KQ' => {
			eco => 'A26',
			# TRANSLATORS: A26: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. e4 Nf6 7. Nge2 O-O
			variation => N__('English: Botvinnik System, 6... Nf6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bq1rk1/ppp2pbp/2np1np1/4p3/2P1P3/2NP2P1/PP2NPBP/R1BQ1RK1 b -' => {
			eco => 'A26',
			# TRANSLATORS: A26: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. e4 Nf6 7. Nge2 O-O 8. O-O
			variation => N__('English: Botvinnik System, 6... Nf6'),
			moves => {
			},
		},
		'r1bqk2r/ppp2pbp/2np1np1/4p3/2P1P3/2NP1NP1/PP3PBP/R1BQK2R b KQkq' => {
			eco => 'A26',
			# TRANSLATORS: A26: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. e4 Nf6 7. Nf3
			variation => N__('English: Botvinnik System, 6... Nf6'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/ppp2pbp/2np1np1/4p3/2P1P3/2NP1NP1/PP3PBP/R1BQK2R w KQ' => {
			eco => 'A26',
			# TRANSLATORS: A26: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. e4 Nf6 7. Nf3 O-O
			variation => N__('English: Botvinnik System, 6... Nf6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bq1rk1/ppp2pbp/2np1np1/4p3/2P1P3/2NP1NP1/PP3PBP/R1BQ1RK1 b -' => {
			eco => 'A26',
			# TRANSLATORS: A26: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. e4 Nf6 7. Nf3 O-O 8. O-O
			variation => N__('English: Botvinnik System, 6... Nf6'),
			moves => {
			},
		},
		'r1bqk1nr/ppp2pbp/2np2p1/4p3/2P5/2NP1NP1/PP2PPBP/R1BQK2R b KQkq' => {
			eco => 'A26',
			# TRANSLATORS: A26: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. Nf3
			variation => N__('English: Closed, 5. d3 d6 6. Nf3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r1bqk2r/ppp2pbp/2np1np1/4p3/2P5/2NP1NP1/PP2PPBP/R1BQK2R w KQkq' => {
			eco => 'A26',
			# TRANSLATORS: A26: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. Nf3 Nf6
			variation => N__('English: Closed, 5. d3 d6 6. Nf3 Nf6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqk2r/ppp2pbp/2np1np1/4p3/2P5/2NP1NP1/PP2PPBP/R1BQ1RK1 b kq' => {
			eco => 'A26',
			# TRANSLATORS: A26: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. Nf3 Nf6 7. O-O
			variation => N__('English: Closed, 5. d3 d6 6. Nf3 Nf6 7.O-O'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/ppp2pbp/2np1np1/4p3/2P5/2NP1NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A26',
			# TRANSLATORS: A26: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. Nf3 Nf6 7. O-O O-O
			variation => N__('English: Closed, 5. d3 d6 6. Nf3 Nf6 7.O-O O-O'),
			moves => {
				'a1b1' => 1,
			},
		},
		'r1bq1rk1/ppp2pbp/2np1np1/4p3/2P5/2NP1NP1/PP2PPBP/1RBQ1RK1 b -' => {
			eco => 'A26',
			# TRANSLATORS: A26: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. Nf3 Nf6 7. O-O O-O 8. Rb1
			variation => N__('English: Closed, 5. d3 d6 6. Nf3 Nf6 7.O-O O-O 8. Rb1'),
			moves => {
				'a7a5' => 1,
			},
		},
		'r1bq1rk1/1pp2pbp/2np1np1/p3p3/2P5/2NP1NP1/PP2PPBP/1RBQ1RK1 w -' => {
			eco => 'A26',
			# TRANSLATORS: A26: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. Nf3 Nf6 7. O-O O-O 8. Rb1 a5
			variation => N__('English: Closed, 5. d3 d6 6. Nf3 Nf6 7.O-O O-O 8. Rb1 a5'),
			moves => {
				'a2a3' => 1,
			},
		},
		'r1bq1rk1/1pp2pbp/2np1np1/p3p3/2P5/P1NP1NP1/1P2PPBP/1RBQ1RK1 b -' => {
			eco => 'A26',
			# TRANSLATORS: A26: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. Nf3 Nf6 7. O-O O-O 8. Rb1 a5 9. a3
			variation => N__('English: Closed, 5. d3 d6 6. Nf3 Nf6 7.O-O O-O 8. Rb1 a5 9. a3'),
			moves => {
				'h7h6' => 1,
			},
		},
		'r1bq1rk1/1pp2pb1/2np1npp/p3p3/2P5/P1NP1NP1/1P2PPBP/1RBQ1RK1 w -' => {
			eco => 'A26',
			# TRANSLATORS: A26: 1. c4 e5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. Nf3 Nf6 7. O-O O-O 8. Rb1 a5 9. a3 h6
			variation => N__('English: Closed, 5. d3 d6 6. Nf3 Nf6 7.O-O O-O 8. Rb1 a5 9. a3 h6'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4p3/2P5/2N2N2/PP1PPPPP/R1BQKB1R b KQkq' => {
			eco => 'A27',
			# TRANSLATORS: A27: 1. c4 e5 2. Nc3 Nc6 3. Nf3
			variation => N__('English: Three Knights'),
			moves => {
				'd7d6' => 1,
				'f7f5' => 1,
				'f8b4' => 1,
				'g7g6' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkbnr/ppp2ppp/2np4/4p3/2P5/2N2N2/PP1PPPPP/R1BQKB1R w KQkq' => {
			eco => 'A27',
			# TRANSLATORS: A27: 1. c4 e5 2. Nc3 Nc6 3. Nf3 d6
			variation => N__('English: Three Knights, 3... d6'),
			moves => {
			},
		},
		'r1bqkbnr/pppp2pp/2n5/4pp2/2P5/2N2N2/PP1PPPPP/R1BQKB1R w KQkq' => {
			eco => 'A27',
			# TRANSLATORS: A27: 1. c4 e5 2. Nc3 Nc6 3. Nf3 f5
			variation => N__('English: Three Knights, 3... f5'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bqkbnr/pppp2pp/2n5/4pp2/2PP4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'A27',
			# TRANSLATORS: A27: 1. c4 e5 2. Nc3 Nc6 3. Nf3 f5 4. d4
			variation => N__('English: Three Knights, 3... f5 4. d4'),
			moves => {
				'e5e4' => 1,
			},
		},
		'r1bqkbnr/pppp2pp/2n5/5p2/2PPp3/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'A27',
			# TRANSLATORS: A27: 1. c4 e5 2. Nc3 Nc6 3. Nf3 f5 4. d4 e4
			variation => N__('English: Three Knights, 3... f5 4. d4 e4'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/4p3/1bP5/2N2N2/PP1PPPPP/R1BQKB1R w KQkq' => {
			eco => 'A27',
			# TRANSLATORS: A27: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Bb4
			variation => N__('English: Three Knights, 3... Bb4'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1p1p/2n3p1/4p3/2P5/2N2N2/PP1PPPPP/R1BQKB1R w KQkq' => {
			eco => 'A27',
			# TRANSLATORS: A27: 1. c4 e5 2. Nc3 Nc6 3. Nf3 g6
			variation => N__('English: Three Knights, 3... g6'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bqkbnr/pppp1p1p/2n3p1/4p3/2PP4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'A27',
			# TRANSLATORS: A27: 1. c4 e5 2. Nc3 Nc6 3. Nf3 g6 4. d4
			variation => N__('English: Three Knights, 3... g6 4. d4'),
			moves => {
				'e5d4' => 1,
			},
		},
		'r1bqkbnr/pppp1p1p/2n3p1/8/2Pp4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'A27',
			# TRANSLATORS: A27: 1. c4 e5 2. Nc3 Nc6 3. Nf3 g6 4. d4 exd4
			variation => N__('English: Three Knights, 3... g6 4. d4 exd4'),
			moves => {
				'f3d4' => 1,
			},
		},
		'r1bqkbnr/pppp1p1p/2n3p1/8/2PN4/2N5/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'A27',
			# TRANSLATORS: A27: 1. c4 e5 2. Nc3 Nc6 3. Nf3 g6 4. d4 exd4 5. Nxd4
			variation => N__('English: Three Knights, 3... g6 4. d4 exd4 5.Nxd4'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4p3/2P5/2N2N2/PP1PPPPP/R1BQKB1R w KQkq' => {
			eco => 'A28',
			# TRANSLATORS: A28: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6
			variation => N__('English: Four Knights'),
			moves => {
				'a2a3' => 1,
				'd2d3' => 1,
				'd2d4' => 1,
				'e2e3' => 1,
				'e2e4' => 1,
				'g2g3' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4p3/2P5/P1N2N2/1P1PPPPP/R1BQKB1R b KQkq' => {
			eco => 'A28',
			# TRANSLATORS: A28: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. a3
			variation => N__('English: Four Knights, Marini Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4p3/2P5/2NP1N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'A28',
			# TRANSLATORS: A28: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. d3
			variation => N__('English: Four Knights, Capablanca Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4p3/2PP4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'A28',
			# TRANSLATORS: A28: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. d4
			variation => N__('English: Four Knights, 4. d4'),
			moves => {
				'e5d4' => 1,
				'e5e4' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/8/2Pp4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'A28',
			# TRANSLATORS: A28: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. d4 exd4
			variation => N__('English: Four Knights, 4. d4'),
			moves => {
				'f3d4' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/8/2PN4/2N5/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'A28',
			# TRANSLATORS: A28: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. d4 exd4 5. Nxd4
			variation => N__('English: Four Knights, 4. d4'),
			moves => {
				'f8b4' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/8/1bPN4/2N5/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'A28',
			# TRANSLATORS: A28: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. d4 exd4 5. Nxd4 Bb4
			variation => N__('English: Four Knights, 4. d4'),
			moves => {
				'c1g5' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/6B1/1bPN4/2N5/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'A28',
			# TRANSLATORS: A28: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. d4 exd4 5. Nxd4 Bb4 6. Bg5
			variation => N__('English: Four Knights, 4. d4'),
			moves => {
				'h7h6' => 1,
			},
		},
		'r1bqk2r/pppp1pp1/2n2n1p/6B1/1bPN4/2N5/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'A28',
			# TRANSLATORS: A28: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. d4 exd4 5. Nxd4 Bb4 6. Bg5 h6
			variation => N__('English: Four Knights, 4. d4'),
			moves => {
				'g5h4' => 1,
			},
		},
		'r1bqk2r/pppp1pp1/2n2n1p/8/1bPN3B/2N5/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'A28',
			# TRANSLATORS: A28: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. d4 exd4 5. Nxd4 Bb4 6. Bg5 h6 7. Bh4
			variation => N__('English: Four Knights, 4. d4'),
			moves => {
				'b4c3' => 1,
			},
		},
		'r1bqk2r/pppp1pp1/2n2n1p/8/2PN3B/2b5/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'A28',
			# TRANSLATORS: A28: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. d4 exd4 5. Nxd4 Bb4 6. Bg5 h6 7. Bh4 Bxc3+
			variation => N__('English: Four Knights, 4. d4'),
			moves => {
				'b2c3' => 1,
			},
		},
		'r1bqk2r/pppp1pp1/2n2n1p/8/2PN3B/2P5/P3PPPP/R2QKB1R b KQkq' => {
			eco => 'A28',
			# TRANSLATORS: A28: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. d4 exd4 5. Nxd4 Bb4 6. Bg5 h6 7. Bh4 Bxc3+ 8. bxc3
			variation => N__('English: Four Knights, 4. d4'),
			moves => {
				'c6e5' => 1,
			},
		},
		'r1bqk2r/pppp1pp1/5n1p/4n3/2PN3B/2P5/P3PPPP/R2QKB1R w KQkq' => {
			eco => 'A28',
			# TRANSLATORS: A28: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. d4 exd4 5. Nxd4 Bb4 6. Bg5 h6 7. Bh4 Bxc3+ 8. bxc3 Ne5
			variation => N__('English: Four Knights, Nenarokov Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/8/2PPp3/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'A28',
			# TRANSLATORS: A28: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. d4 e4
			variation => N__('English: Four Knights, Bradley Beach Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4p3/2P5/2N1PN2/PP1P1PPP/R1BQKB1R b KQkq' => {
			eco => 'A28',
			# TRANSLATORS: A28: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. e3
			variation => N__('English: Four Knights, 4. e3'),
			moves => {
				'f8b4' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/4p3/1bP5/2N1PN2/PP1P1PPP/R1BQKB1R w KQkq' => {
			eco => 'A28',
			# TRANSLATORS: A28: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. e3 Bb4
			variation => N__('English: Four Knights, 4. e3 Bb4'),
			moves => {
				'd1c2' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/4p3/1bP5/2N1PN2/PPQP1PPP/R1B1KB1R b KQkq' => {
			eco => 'A28',
			# TRANSLATORS: A28: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. e3 Bb4 5. Qc2
			variation => N__('English: Four Knights, 4. e3 Bb4 5. Qc2'),
			moves => {
				'b4c3' => 1,
				'e8g8' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/4p3/2P5/2b1PN2/PPQP1PPP/R1B1KB1R w KQkq' => {
			eco => 'A28',
			# TRANSLATORS: A28: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. e3 Bb4 5. Qc2 Bxc3
			variation => N__('English: Four Knights, Romanishin Variation'),
			moves => {
			},
		},
		'r1bq1rk1/pppp1ppp/2n2n2/4p3/1bP5/2N1PN2/PPQP1PPP/R1B1KB1R w KQ' => {
			eco => 'A28',
			# TRANSLATORS: A28: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. e3 Bb4 5. Qc2 O-O
			variation => N__('English: Four Knights, 4. e3 Bb4 5. Qc2'),
			moves => {
				'c3d5' => 1,
			},
		},
		'r1bq1rk1/pppp1ppp/2n2n2/3Np3/1bP5/4PN2/PPQP1PPP/R1B1KB1R b KQ' => {
			eco => 'A28',
			# TRANSLATORS: A28: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. e3 Bb4 5. Qc2 O-O 6. Nd5
			variation => N__('English: Four Knights, 4. e3 Bb4 5. Qc2'),
			moves => {
				'f8e8' => 1,
			},
		},
		'r1bqr1k1/pppp1ppp/2n2n2/3Np3/1bP5/4PN2/PPQP1PPP/R1B1KB1R w KQ' => {
			eco => 'A28',
			# TRANSLATORS: A28: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. e3 Bb4 5. Qc2 O-O 6. Nd5 Re8
			variation => N__('English: Four Knights, 4. e3 Bb4 5. Qc2'),
			moves => {
				'c2f5' => 1,
			},
		},
		'r1bqr1k1/pppp1ppp/2n2n2/3NpQ2/1bP5/4PN2/PP1P1PPP/R1B1KB1R b KQ' => {
			eco => 'A28',
			# TRANSLATORS: A28: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. e3 Bb4 5. Qc2 O-O 6. Nd5 Re8 7. Qf5
			variation => N__('English: Four Knights, Stean Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4p3/2P1P3/2N2N2/PP1P1PPP/R1BQKB1R b KQkq' => {
			eco => 'A28',
			# TRANSLATORS: A28: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. e4
			variation => N__('English: Four Knights, Nimzowitsch Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4p3/2P5/2N2NP1/PP1PPP1P/R1BQKB1R b KQkq' => {
			eco => 'A29',
			# TRANSLATORS: A29: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. g3
			variation => N__('English: Four Knights, 4. g3'),
			moves => {
				'd7d5' => 1,
				'f8b4' => 1,
				'f8c5' => 1,
				'g7g6' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2n2n2/3pp3/2P5/2N2NP1/PP1PPP1P/R1BQKB1R w KQkq' => {
			eco => 'A29',
			# TRANSLATORS: A29: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. g3 d5
			variation => N__('English: Four Knights, 4. g3 d5'),
			moves => {
				'c4d5' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2n2n2/3Pp3/8/2N2NP1/PP1PPP1P/R1BQKB1R b KQkq' => {
			eco => 'A29',
			# TRANSLATORS: A29: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. g3 d5 5. cxd5
			variation => N__('English: Four Knights, 4. g3 d5 5.cxd5'),
			moves => {
				'f6d5' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2n5/3np3/8/2N2NP1/PP1PPP1P/R1BQKB1R w KQkq' => {
			eco => 'A29',
			# TRANSLATORS: A29: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. g3 d5 5. cxd5 Nxd5
			variation => N__('English: Four Knights, 4. g3 d5 5.cxd5 Nxd5'),
			moves => {
				'f1g2' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2n5/3np3/8/2N2NP1/PP1PPPBP/R1BQK2R b KQkq' => {
			eco => 'A29',
			# TRANSLATORS: A29: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. g3 d5 5. cxd5 Nxd5 6. Bg2
			variation => N__('English: Four Knights, 4. g3 d5 5.cxd5 Nxd5 6. Bg2'),
			moves => {
				'c8e6' => 1,
				'd5b6' => 1,
			},
		},
		'r2qkb1r/ppp2ppp/2n1b3/3np3/8/2N2NP1/PP1PPPBP/R1BQK2R w KQkq' => {
			eco => 'A29',
			# TRANSLATORS: A29: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. g3 d5 5. cxd5 Nxd5 6. Bg2 Be6
			variation => N__('English: Four Knights, 4. g3 d5 5.cxd5 Nxd5 6. Bg2 Be6'),
			moves => {
			},
		},
		'r1bqkb1r/ppp2ppp/1nn5/4p3/8/2N2NP1/PP1PPPBP/R1BQK2R w KQkq' => {
			eco => 'A29',
			# TRANSLATORS: A29: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. g3 d5 5. cxd5 Nxd5 6. Bg2 Nb6
			variation => N__('English: Four Knights, 4. g3 d5 5.cxd5 Nxd5 6. Bg2 Nb6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/1nn5/4p3/8/2N2NP1/PP1PPPBP/R1BQ1RK1 b kq' => {
			eco => 'A29',
			# TRANSLATORS: A29: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. g3 d5 5. cxd5 Nxd5 6. Bg2 Nb6 7. O-O
			variation => N__('English: Four Knights, 4. g3 d5 5.cxd5 Nxd5 6. Bg2 Nb6 7.O-O'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r1bqk2r/ppp1bppp/1nn5/4p3/8/2N2NP1/PP1PPPBP/R1BQ1RK1 w kq' => {
			eco => 'A29',
			# TRANSLATORS: A29: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. g3 d5 5. cxd5 Nxd5 6. Bg2 Nb6 7. O-O Be7
			variation => N__('English: Four Knights, 4. g3 d5 5.cxd5 Nxd5 6. Bg2 Nb6 7.O-O Be7'),
			moves => {
				'a1b1' => 1,
				'a2a3' => 1,
				'd2d3' => 1,
			},
		},
		'r1bqk2r/ppp1bppp/1nn5/4p3/8/2N2NP1/PP1PPPBP/1RBQ1RK1 b kq' => {
			eco => 'A29',
			# TRANSLATORS: A29: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. g3 d5 5. cxd5 Nxd5 6. Bg2 Nb6 7. O-O Be7 8. Rb1
			variation => N__('English: Four Knights, 4. g3 d5 5.cxd5 Nxd5 6. Bg2 Nb6 7.O-O Be7 8. Rb1'),
			moves => {
			},
		},
		'r1bqk2r/ppp1bppp/1nn5/4p3/8/P1N2NP1/1P1PPPBP/R1BQ1RK1 b kq' => {
			eco => 'A29',
			# TRANSLATORS: A29: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. g3 d5 5. cxd5 Nxd5 6. Bg2 Nb6 7. O-O Be7 8. a3
			variation => N__('English: Four Knights, 4. g3 d5 5.cxd5 Nxd5 6. Bg2 Nb6 7.O-O Be7 8. a3'),
			moves => {
			},
		},
		'r1bqk2r/ppp1bppp/1nn5/4p3/8/2NP1NP1/PP2PPBP/R1BQ1RK1 b kq' => {
			eco => 'A29',
			# TRANSLATORS: A29: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. g3 d5 5. cxd5 Nxd5 6. Bg2 Nb6 7. O-O Be7 8. d3
			variation => N__('English: Four Knights, 4. g3 d5 5.cxd5 Nxd5 6. Bg2 Nb6 7.O-O Be7 8. d3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/ppp1bppp/1nn5/4p3/8/2NP1NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A29',
			# TRANSLATORS: A29: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. g3 d5 5. cxd5 Nxd5 6. Bg2 Nb6 7. O-O Be7 8. d3 O-O
			variation => N__('English: Four Knights, 4. g3 d5 5.cxd5 Nxd5 6. Bg2 Nb6 7.O-O Be7 8. d3'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/4p3/1bP5/2N2NP1/PP1PPP1P/R1BQKB1R w KQkq' => {
			eco => 'A29',
			# TRANSLATORS: A29: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. g3 Bb4
			variation => N__('English: Four Knights, 4. g3 Bb4'),
			moves => {
				'c3d5' => 1,
				'f1g2' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/3Np3/1bP5/5NP1/PP1PPP1P/R1BQKB1R b KQkq' => {
			eco => 'A29',
			# TRANSLATORS: A29: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. g3 Bb4 5. Nd5
			variation => N__('English: Four Knights, 4. g3 Bb4 5. Nd5'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/4p3/1bP5/2N2NP1/PP1PPPBP/R1BQK2R b KQkq' => {
			eco => 'A29',
			# TRANSLATORS: A29: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. g3 Bb4 5. Bg2
			variation => N__('English: Four Knights, 4. g3 Bb4 5. Bg2'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pppp1ppp/2n2n2/4p3/1bP5/2N2NP1/PP1PPPBP/R1BQK2R w KQ' => {
			eco => 'A29',
			# TRANSLATORS: A29: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. g3 Bb4 5. Bg2 O-O
			variation => N__('English: Four Knights, 4. g3 Bb4 5. Bg2'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bq1rk1/pppp1ppp/2n2n2/4p3/1bP5/2N2NP1/PP1PPPBP/R1BQ1RK1 b -' => {
			eco => 'A29',
			# TRANSLATORS: A29: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. g3 Bb4 5. Bg2 O-O 6. O-O
			variation => N__('English: Four Knights, Main Line 6.O-O'),
			moves => {
				'e5e4' => 1,
			},
		},
		'r1bq1rk1/pppp1ppp/2n2n2/8/1bP1p3/2N2NP1/PP1PPPBP/R1BQ1RK1 w -' => {
			eco => 'A29',
			# TRANSLATORS: A29: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. g3 Bb4 5. Bg2 O-O 6. O-O e4
			variation => N__('English: Four Knights, Main Line 6.O-O e4'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/2b1p3/2P5/2N2NP1/PP1PPP1P/R1BQKB1R w KQkq' => {
			eco => 'A29',
			# TRANSLATORS: A29: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. g3 Bc5
			variation => N__('English: Four Knights, 4. g3 Bc5'),
			moves => {
				'f1g2' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/2b1p3/2P5/2N2NP1/PP1PPPBP/R1BQK2R b KQkq' => {
			eco => 'A29',
			# TRANSLATORS: A29: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. g3 Bc5 5. Bg2
			variation => N__('English: Four Knights, 4. g3 Bc5'),
			moves => {
				'd7d6' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2np1n2/2b1p3/2P5/2N2NP1/PP1PPPBP/R1BQK2R w KQkq' => {
			eco => 'A29',
			# TRANSLATORS: A29: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. g3 Bc5 5. Bg2 d6
			variation => N__('English: Four Knights, 4. g3 Bc5'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2np1n2/2b1p3/2P5/2N2NP1/PP1PPPBP/R1BQ1RK1 b kq' => {
			eco => 'A29',
			# TRANSLATORS: A29: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. g3 Bc5 5. Bg2 d6 6. O-O
			variation => N__('English: Four Knights, 4. g3 Bc5'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/ppp2ppp/2np1n2/2b1p3/2P5/2N2NP1/PP1PPPBP/R1BQ1RK1 w -' => {
			eco => 'A29',
			# TRANSLATORS: A29: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. g3 Bc5 5. Bg2 d6 6. O-O O-O
			variation => N__('English: Four Knights, 4. g3 Bc5'),
			moves => {
				'd2d3' => 1,
			},
		},
		'r1bq1rk1/ppp2ppp/2np1n2/2b1p3/2P5/2NP1NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'A29',
			# TRANSLATORS: A29: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. g3 Bc5 5. Bg2 d6 6. O-O O-O 7. d3
			variation => N__('English: Four Knights, 4. g3 Bc5'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1p1p/2n2np1/4p3/2P5/2N2NP1/PP1PPP1P/R1BQKB1R w KQkq' => {
			eco => 'A29',
			# TRANSLATORS: A29: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. g3 g6
			variation => N__('English: Four Knights, 4. g3 g6'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bqkb1r/pppp1p1p/2n2np1/4p3/2PP4/2N2NP1/PP2PP1P/R1BQKB1R b KQkq' => {
			eco => 'A29',
			# TRANSLATORS: A29: 1. c4 e5 2. Nc3 Nc6 3. Nf3 Nf6 4. g3 g6 5. d4
			variation => N__('English: Four Knights, 4. g3 g6 5. d4'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/8/2p5/2P5/8/PP1PPPPP/RNBQKBNR w KQkq' => {
			eco => 'A30a',
			# TRANSLATORS: A30a: 1. c4 c5
			variation => N__('English: Symmetrical'),
			moves => {
				'b1c3' => 1,
				'b2b3' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/pp1ppppp/8/2p5/2P5/1P6/P2PPPPP/RNBQKBNR b KQkq' => {
			eco => 'A30a',
			# TRANSLATORS: A30a: 1. c4 c5 2. b3
			variation => N__('English: Symmetrical, 2. b3'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/8/2p5/2P5/6P1/PP1PPP1P/RNBQKBNR b KQkq' => {
			eco => 'A30a',
			# TRANSLATORS: A30a: 1. c4 c5 2. g3
			variation => N__('English: Symmetrical, 2. g3'),
			moves => {
				'g7g6' => 1,
			},
		},
		'rnbqkbnr/pp1ppp1p/6p1/2p5/2P5/6P1/PP1PPP1P/RNBQKBNR w KQkq' => {
			eco => 'A30a',
			# TRANSLATORS: A30a: 1. c4 c5 2. g3 g6
			variation => N__('English: Symmetrical, 2. g3 g6'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/8/2p5/2P5/5N2/PP1PPPPP/RNBQKB1R b KQkq' => {
			eco => 'A30b',
			# TRANSLATORS: A30b: 1. c4 c5 2. Nf3
			variation => N__('English: Symmetrical, 2. Nf3'),
			moves => {
				'b7b6' => 1,
				'b8c6' => 1,
				'g7g6' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/p2ppppp/1p6/2p5/2P5/5N2/PP1PPPPP/RNBQKB1R w KQkq' => {
			eco => 'A30b',
			# TRANSLATORS: A30b: 1. c4 c5 2. Nf3 b6
			variation => N__('English: Symmetrical, 2. Nf3 b6'),
			moves => {
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/p2ppppp/1p6/2p5/2P5/5NP1/PP1PPP1P/RNBQKB1R b KQkq' => {
			eco => 'A30b',
			# TRANSLATORS: A30b: 1. c4 c5 2. Nf3 b6 3. g3
			variation => N__('English: Symmetrical, 2. Nf3 b6 3. g3'),
			moves => {
				'c8b7' => 1,
			},
		},
		'rn1qkbnr/pb1ppppp/1p6/2p5/2P5/5NP1/PP1PPP1P/RNBQKB1R w KQkq' => {
			eco => 'A30b',
			# TRANSLATORS: A30b: 1. c4 c5 2. Nf3 b6 3. g3 Bb7
			variation => N__('English: Symmetrical, 2. Nf3 b6 3. g3'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rn1qkbnr/pb1ppppp/1p6/2p5/2P5/5NP1/PP1PPPBP/RNBQK2R b KQkq' => {
			eco => 'A30b',
			# TRANSLATORS: A30b: 1. c4 c5 2. Nf3 b6 3. g3 Bb7 4. Bg2
			variation => N__('English: Symmetrical, 2. Nf3 b6 3. g3 Bb7 4. Bg2'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/2p5/2P5/5N2/PP1PPPPP/RNBQKB1R w KQkq' => {
			eco => 'A30b',
			# TRANSLATORS: A30b: 1. c4 c5 2. Nf3 Nc6
			variation => N__('English: Symmetrical, 2. Nf3 Nc6'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppp1p/6p1/2p5/2P5/5N2/PP1PPPPP/RNBQKB1R w KQkq' => {
			eco => 'A30b',
			# TRANSLATORS: A30b: 1. c4 c5 2. Nf3 g6
			variation => N__('English: Symmetrical, 2. Nf3 g6'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/2p5/2P5/5N2/PP1PPPPP/RNBQKB1R w KQkq' => {
			eco => 'A30c',
			# TRANSLATORS: A30c: 1. c4 c5 2. Nf3 Nf6
			variation => N__('English: Symmetrical, 2. Nf3 Nf6'),
			moves => {
				'd2d4' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/2p5/2P5/5NP1/PP1PPP1P/RNBQKB1R b KQkq' => {
			eco => 'A30d',
			# TRANSLATORS: A30d: 1. c4 c5 2. Nf3 Nf6 3. g3
			variation => N__('English: Symmetrical, 2. Nf3 Nf6 3. g3'),
			moves => {
				'b7b6' => 1,
			},
		},
		'rnbqkb1r/p2ppppp/1p3n2/2p5/2P5/5NP1/PP1PPP1P/RNBQKB1R w KQkq' => {
			eco => 'A30e',
			# TRANSLATORS: A30e: 1. c4 c5 2. Nf3 Nf6 3. g3 b6
			variation => N__('English: Symmetrical, b6 System'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkb1r/p2ppppp/1p3n2/2p5/2P5/5NP1/PP1PPPBP/RNBQK2R b KQkq' => {
			eco => 'A30e',
			# TRANSLATORS: A30e: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2
			variation => N__('English: Symmetrical, b6 System'),
			moves => {
				'c8b7' => 1,
			},
		},
		'rn1qkb1r/pb1ppppp/1p3n2/2p5/2P5/5NP1/PP1PPPBP/RNBQK2R w KQkq' => {
			eco => 'A30e',
			# TRANSLATORS: A30e: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7
			variation => N__('English: Symmetrical, b6 System'),
			moves => {
				'b1c3' => 1,
				'e1g1' => 1,
			},
		},
		'rn1qkb1r/pb1ppppp/1p3n2/2p5/2P5/2N2NP1/PP1PPPBP/R1BQK2R b KQkq' => {
			eco => 'A30e',
			# TRANSLATORS: A30e: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. Nc3
			variation => N__('English: Symmetrical, b6 System'),
			moves => {
			},
		},
		'rn1qkb1r/pb1ppppp/1p3n2/2p5/2P5/5NP1/PP1PPPBP/RNBQ1RK1 b kq' => {
			eco => 'A30e',
			# TRANSLATORS: A30e: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O
			variation => N__('English: Symmetrical, b6 System'),
			moves => {
				'e7e6' => 1,
				'g7g6' => 1,
			},
		},
		'rn1qkb1r/pb1ppp1p/1p3np1/2p5/2P5/5NP1/PP1PPPBP/RNBQ1RK1 w kq' => {
			eco => 'A30f',
			# TRANSLATORS: A30f: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O g6
			variation => N__('English: Symmetrical, Double Fianchetto'),
			moves => {
				'b1c3' => 1,
				'b2b3' => 1,
			},
		},
		'rn1qkb1r/pb1ppp1p/1p3np1/2p5/2P5/2N2NP1/PP1PPPBP/R1BQ1RK1 b kq' => {
			eco => 'A30f',
			# TRANSLATORS: A30f: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O g6 6. Nc3
			variation => N__('English: Symmetrical, Double Fianchetto'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rn1qk2r/pb1pppbp/1p3np1/2p5/2P5/2N2NP1/PP1PPPBP/R1BQ1RK1 w kq' => {
			eco => 'A30f',
			# TRANSLATORS: A30f: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O g6 6. Nc3 Bg7
			variation => N__('English: Symmetrical, Double Fianchetto'),
			moves => {
			},
		},
		'rn1qkb1r/pb1ppp1p/1p3np1/2p5/2P5/1P3NP1/P2PPPBP/RNBQ1RK1 b kq' => {
			eco => 'A30g',
			# TRANSLATORS: A30g: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O g6 6. b3
			variation => N__('English: Symmetrical, Mutual Double Fianchetto'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rn1qk2r/pb1pppbp/1p3np1/2p5/2P5/1P3NP1/P2PPPBP/RNBQ1RK1 w kq' => {
			eco => 'A30g',
			# TRANSLATORS: A30g: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O g6 6. b3 Bg7
			variation => N__('English: Symmetrical, Mutual Double Fianchetto'),
			moves => {
				'c1b2' => 1,
			},
		},
		'rn1qk2r/pb1pppbp/1p3np1/2p5/2P5/1P3NP1/PB1PPPBP/RN1Q1RK1 b kq' => {
			eco => 'A30g',
			# TRANSLATORS: A30g: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O g6 6. b3 Bg7 7. Bb2
			variation => N__('English: Symmetrical, Mutual Double Fianchetto'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rn1q1rk1/pb1pppbp/1p3np1/2p5/2P5/1P3NP1/PB1PPPBP/RN1Q1RK1 w -' => {
			eco => 'A30g',
			# TRANSLATORS: A30g: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O g6 6. b3 Bg7 7. Bb2 O-O
			variation => N__('English: Symmetrical, Mutual Double Fianchetto'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rn1q1rk1/pb1pppbp/1p3np1/2p5/2P5/1PN2NP1/PB1PPPBP/R2Q1RK1 b -' => {
			eco => 'A30g',
			# TRANSLATORS: A30g: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O g6 6. b3 Bg7 7. Bb2 O-O 8. Nc3
			variation => N__('English: Symmetrical, Mutual Double Fianchetto'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rn1q1rk1/pb2ppbp/1p3np1/2pp4/2P5/1PN2NP1/PB1PPPBP/R2Q1RK1 w -' => {
			eco => 'A30g',
			# TRANSLATORS: A30g: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O g6 6. b3 Bg7 7. Bb2 O-O 8. Nc3 d5
			variation => N__('English: Symmetrical, Mutual Double Fianchetto with ...d5'),
			moves => {
			},
		},
		'rn1qkb1r/pb1p1ppp/1p2pn2/2p5/2P5/5NP1/PP1PPPBP/RNBQ1RK1 w kq' => {
			eco => 'A30h',
			# TRANSLATORS: A30h: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O e6
			variation => N__('English: Symmetrical, Hedgehog System'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rn1qkb1r/pb1p1ppp/1p2pn2/2p5/2P5/2N2NP1/PP1PPPBP/R1BQ1RK1 b kq' => {
			eco => 'A30h',
			# TRANSLATORS: A30h: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O e6 6. Nc3
			variation => N__('English: Symmetrical, Hedgehog System'),
			moves => {
				'a7a6' => 1,
				'd7d6' => 1,
				'f8e7' => 1,
			},
		},
		'rn1qkb1r/1b1p1ppp/pp2pn2/2p5/2P5/2N2NP1/PP1PPPBP/R1BQ1RK1 w kq' => {
			eco => 'A30i',
			# TRANSLATORS: A30i: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O e6 6. Nc3 a6
			variation => N__('English: Symmetrical, Hedgehog, 6... a6'),
			moves => {
			},
		},
		'rn1qkb1r/pb3ppp/1p1ppn2/2p5/2P5/2N2NP1/PP1PPPBP/R1BQ1RK1 w kq' => {
			eco => 'A30j',
			# TRANSLATORS: A30j: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O e6 6. Nc3 d6
			variation => N__('English: Symmetrical, Hedgehog, 6... d6'),
			moves => {
				'b2b3' => 1,
				'd2d4' => 1,
			},
		},
		'rn1qkb1r/pb3ppp/1p1ppn2/2p5/2P5/1PN2NP1/P2PPPBP/R1BQ1RK1 b kq' => {
			eco => 'A30k',
			# TRANSLATORS: A30k: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O e6 6. Nc3 d6 7. b3
			variation => N__('English: Symmetrical, Hedgehog, 6... d6 7. b3'),
			moves => {
			},
		},
		'rn1qkb1r/pb3ppp/1p1ppn2/2p5/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 b kq' => {
			eco => 'A30l',
			# TRANSLATORS: A30l: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O e6 6. Nc3 d6 7. d4
			variation => N__('English: Symmetrical, Hedgehog, 6... d6 7. d4'),
			moves => {
			},
		},
		'rn1qk2r/pb1pbppp/1p2pn2/2p5/2P5/2N2NP1/PP1PPPBP/R1BQ1RK1 w kq' => {
			eco => 'A30m',
			# TRANSLATORS: A30m: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O e6 6. Nc3 Be7
			variation => N__('English: Symmetrical, Hedgehog System'),
			moves => {
				'b2b3' => 1,
				'd2d4' => 1,
				'f1e1' => 1,
			},
		},
		'rn1qk2r/pb1pbppp/1p2pn2/2p5/2P5/2N2NP1/PP1PPPBP/R1BQR1K1 b kq' => {
			eco => 'A30n',
			# TRANSLATORS: A30n: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O e6 6. Nc3 Be7 7. Re1
			variation => N__('English: Symmetrical, Hedgehog, 7. Re1'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rn1qk2r/pb2bppp/1p2pn2/2pp4/2P5/2N2NP1/PP1PPPBP/R1BQR1K1 w kq' => {
			eco => 'A30o',
			# TRANSLATORS: A30o: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O e6 6. Nc3 Be7 7. Re1 d5
			variation => N__('English: Symmetrical, Hedgehog, 7. Re1 d5'),
			moves => {
			},
		},
		'rn1qk2r/pb1pbppp/1p2pn2/2p5/2P5/1PN2NP1/P2PPPBP/R1BQ1RK1 b kq' => {
			eco => 'A30p',
			# TRANSLATORS: A30p: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O e6 6. Nc3 Be7 7. b3
			variation => N__('English: Symmetrical, Hedgehog, 7. b3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rn1q1rk1/pb1pbppp/1p2pn2/2p5/2P5/1PN2NP1/P2PPPBP/R1BQ1RK1 w -' => {
			eco => 'A30p',
			# TRANSLATORS: A30p: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O e6 6. Nc3 Be7 7. b3 O-O
			variation => N__('English: Symmetrical, Hedgehog, 7. b3'),
			moves => {
				'c1b2' => 1,
			},
		},
		'rn1q1rk1/pb1pbppp/1p2pn2/2p5/2P5/1PN2NP1/PB1PPPBP/R2Q1RK1 b -' => {
			eco => 'A30p',
			# TRANSLATORS: A30p: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O e6 6. Nc3 Be7 7. b3 O-O 8. Bb2
			variation => N__('English: Symmetrical, Hedgehog, 7. b3'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rn1q1rk1/pb2bppp/1p1ppn2/2p5/2P5/1PN2NP1/PB1PPPBP/R2Q1RK1 w -' => {
			eco => 'A30p',
			# TRANSLATORS: A30p: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O e6 6. Nc3 Be7 7. b3 O-O 8. Bb2 d6
			variation => N__('English: Symmetrical, Hedgehog, 7. b3'),
			moves => {
			},
		},
		'rn1qk2r/pb1pbppp/1p2pn2/2p5/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 b kq' => {
			eco => 'A30q',
			# TRANSLATORS: A30q: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O e6 6. Nc3 Be7 7. d4
			variation => N__('English: Symmetrical, Hedgehog, 7. d4'),
			moves => {
				'c5d4' => 1,
			},
		},
		'rn1qk2r/pb1pbppp/1p2pn2/8/2Pp4/2N2NP1/PP2PPBP/R1BQ1RK1 w kq' => {
			eco => 'A30q',
			# TRANSLATORS: A30q: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O e6 6. Nc3 Be7 7. d4 cxd4
			variation => N__('English: Symmetrical, Hedgehog, 7. d4'),
			moves => {
				'd1d4' => 1,
			},
		},
		'rn1qk2r/pb1pbppp/1p2pn2/8/2PQ4/2N2NP1/PP2PPBP/R1B2RK1 b kq' => {
			eco => 'A30r',
			# TRANSLATORS: A30r: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O e6 6. Nc3 Be7 7. d4 cxd4 8. Qxd4
			variation => N__('English: Symmetrical, Hedgehog, 8.Qxd4'),
			moves => {
				'b8c6' => 1,
				'd7d6' => 1,
				'e8g8' => 1,
			},
		},
		'rn1q1rk1/pb1pbppp/1p2pn2/8/2PQ4/2N2NP1/PP2PPBP/R1B2RK1 w -' => {
			eco => 'A30s',
			# TRANSLATORS: A30s: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O e6 6. Nc3 Be7 7. d4 cxd4 8. Qxd4 O-O
			variation => N__('English: Symmetrical, Hedgehog, 8.Qxd4 O-O'),
			moves => {
				'f1d1' => 1,
			},
		},
		'rn1q1rk1/pb1pbppp/1p2pn2/8/2PQ4/2N2NP1/PP2PPBP/R1BR2K1 b -' => {
			eco => 'A30s',
			# TRANSLATORS: A30s: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O e6 6. Nc3 Be7 7. d4 cxd4 8. Qxd4 O-O 9. Rd1
			variation => N__('English: Symmetrical, Hedgehog, 8.Qxd4 O-O'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r2q1rk1/pb1pbppp/1pn1pn2/8/2PQ4/2N2NP1/PP2PPBP/R1BR2K1 w -' => {
			eco => 'A30s',
			# TRANSLATORS: A30s: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O e6 6. Nc3 Be7 7. d4 cxd4 8. Qxd4 O-O 9. Rd1 Nc6
			variation => N__('English: Symmetrical, Hedgehog, 8.Qxd4 O-O'),
			moves => {
			},
		},
		'r2qk2r/pb1pbppp/1pn1pn2/8/2PQ4/2N2NP1/PP2PPBP/R1B2RK1 w kq' => {
			eco => 'A30t',
			# TRANSLATORS: A30t: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O e6 6. Nc3 Be7 7. d4 cxd4 8. Qxd4 Nc6
			variation => N__('English: Symmetrical, Hedgehog, 8.Qxd4 Nc6'),
			moves => {
			},
		},
		'rn1qk2r/pb2bppp/1p1ppn2/8/2PQ4/2N2NP1/PP2PPBP/R1B2RK1 w kq' => {
			eco => 'A30u',
			# TRANSLATORS: A30u: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O e6 6. Nc3 Be7 7. d4 cxd4 8. Qxd4 d6
			variation => N__('English: Symmetrical, Hedgehog, 8.Qxd4 d6'),
			moves => {
				'b2b3' => 1,
				'f1d1' => 1,
			},
		},
		'rn1qk2r/pb2bppp/1p1ppn2/8/2PQ4/1PN2NP1/P3PPBP/R1B2RK1 b kq' => {
			eco => 'A30v',
			# TRANSLATORS: A30v: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O e6 6. Nc3 Be7 7. d4 cxd4 8. Qxd4 d6 9. b3
			variation => N__('English: Symmetrical, Hedgehog, 9. b3'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r2qk2r/pb1nbppp/1p1ppn2/8/2PQ4/1PN2NP1/P3PPBP/R1B2RK1 w kq' => {
			eco => 'A30v',
			# TRANSLATORS: A30v: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O e6 6. Nc3 Be7 7. d4 cxd4 8. Qxd4 d6 9. b3 Nbd7
			variation => N__('English: Symmetrical, Hedgehog, 9. b3 Nbd7'),
			moves => {
				'c3b5' => 1,
			},
		},
		'r2qk2r/pb1nbppp/1p1ppn2/1N6/2PQ4/1P3NP1/P3PPBP/R1B2RK1 b kq' => {
			eco => 'A30v',
			# TRANSLATORS: A30v: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O e6 6. Nc3 Be7 7. d4 cxd4 8. Qxd4 d6 9. b3 Nbd7 10. Nb5
			variation => N__('English: Symmetrical, Hedgehog, 9. b3 Nbd7 10. Nb5'),
			moves => {
			},
		},
		'rn1qk2r/pb2bppp/1p1ppn2/8/2PQ4/2N2NP1/PP2PPBP/R1BR2K1 b kq' => {
			eco => 'A30w',
			# TRANSLATORS: A30w: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O e6 6. Nc3 Be7 7. d4 cxd4 8. Qxd4 d6 9. Rd1
			variation => N__('English: Symmetrical, Hedgehog, 9. Rd1'),
			moves => {
				'a7a6' => 1,
			},
		},
		'rn1qk2r/1b2bppp/pp1ppn2/8/2PQ4/2N2NP1/PP2PPBP/R1BR2K1 w kq' => {
			eco => 'A30w',
			# TRANSLATORS: A30w: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O e6 6. Nc3 Be7 7. d4 cxd4 8. Qxd4 d6 9. Rd1 a6
			variation => N__('English: Symmetrical, Hedgehog, 9. Rd1'),
			moves => {
				'b2b3' => 1,
			},
		},
		'rn1qk2r/1b2bppp/pp1ppn2/8/2PQ4/1PN2NP1/P3PPBP/R1BR2K1 b kq' => {
			eco => 'A30w',
			# TRANSLATORS: A30w: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O e6 6. Nc3 Be7 7. d4 cxd4 8. Qxd4 d6 9. Rd1 a6 10. b3
			variation => N__('English: Symmetrical, Hedgehog, 9. Rd1'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r2qk2r/1b1nbppp/pp1ppn2/8/2PQ4/1PN2NP1/P3PPBP/R1BR2K1 w kq' => {
			eco => 'A30x',
			# TRANSLATORS: A30x: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O e6 6. Nc3 Be7 7. d4 cxd4 8. Qxd4 d6 9. Rd1 a6 10. b3 Nbd7
			variation => N__('English: Symmetrical, Hedgehog, Flexible Formation'),
			moves => {
				'e2e4' => 1,
			},
		},
		'r2qk2r/1b1nbppp/pp1ppn2/8/2PQP3/1PN2NP1/P4PBP/R1BR2K1 b kq' => {
			eco => 'A30y',
			# TRANSLATORS: A30y: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O e6 6. Nc3 Be7 7. d4 cxd4 8. Qxd4 d6 9. Rd1 a6 10. b3 Nbd7 11. e4
			variation => N__('English: Symmetrical, Hedgehog, Flexible Formation'),
			moves => {
				'd8c7' => 1,
				'e8g8' => 1,
			},
		},
		'r3k2r/1bqnbppp/pp1ppn2/8/2PQP3/1PN2NP1/P4PBP/R1BR2K1 w kq' => {
			eco => 'A30y',
			# TRANSLATORS: A30y: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O e6 6. Nc3 Be7 7. d4 cxd4 8. Qxd4 d6 9. Rd1 a6 10. b3 Nbd7 11. e4 Qc7
			variation => N__('English: Symmetrical, Hedgehog, Flexible Formation, 11. e4 Qc7'),
			moves => {
			},
		},
		'r2q1rk1/1b1nbppp/pp1ppn2/8/2PQP3/1PN2NP1/P4PBP/R1BR2K1 w -' => {
			eco => 'A30y',
			# TRANSLATORS: A30y: 1. c4 c5 2. Nf3 Nf6 3. g3 b6 4. Bg2 Bb7 5. O-O e6 6. Nc3 Be7 7. d4 cxd4 8. Qxd4 d6 9. Rd1 a6 10. b3 Nbd7 11. e4 O-O
			variation => N__('English: Symmetrical, Hedgehog, Flexible Formation, 11. e4 O-O'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/2p5/2PP4/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'A31',
			# TRANSLATORS: A31: 1. c4 c5 2. Nf3 Nf6 3. d4
			variation => N__('English: Symmetrical, Two Knights'),
			moves => {
				'a7a6' => 1,
				'c5d4' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/1p1ppppp/p4n2/2p5/2PP4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A31',
			# TRANSLATORS: A31: 1. c4 c5 2. Nf3 Nf6 3. d4 a6
			variation => N__('English: Symmetrical, Two Knights, 3... a6'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/8/2Pp4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A31',
			# TRANSLATORS: A31: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4
			variation => N__('English: Symmetrical, Two Knights'),
			moves => {
				'f3d4' => 1,
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/8/2PN4/8/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'A31',
			# TRANSLATORS: A31: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4
			variation => N__('English: Symmetrical, Two Knights'),
			moves => {
				'b7b6' => 1,
				'b8c6' => 1,
				'e7e5' => 1,
				'e7e6' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/p2ppppp/1p3n2/8/2PN4/8/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A31',
			# TRANSLATORS: A31: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 b6
			variation => N__('English: Symmetrical, Two Knights, 4... b6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkb1r/p2ppppp/1p3n2/8/2PN4/2N5/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'A31',
			# TRANSLATORS: A31: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 b6 5. Nc3
			variation => N__('English: Symmetrical, Two Knights, 4... b6'),
			moves => {
				'c8b7' => 1,
			},
		},
		'rn1qkb1r/pb1ppppp/1p3n2/8/2PN4/2N5/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'A31',
			# TRANSLATORS: A31: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 b6 5. Nc3 Bb7
			variation => N__('English: Symmetrical, Two Knights, 4... b6'),
			moves => {
			},
		},
		'r1bqkb1r/pp1ppppp/2n2n2/8/2PN4/8/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A31',
			# TRANSLATORS: A31: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 Nc6
			variation => N__('English: Symmetrical, Two Knights, 4... Nc6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r1bqkb1r/pp1ppppp/2n2n2/8/2PN4/2N5/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'A31',
			# TRANSLATORS: A31: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3
			variation => N__('English: Symmetrical, Two Knights, 4... Nc6'),
			moves => {
				'g7g6' => 1,
			},
		},
		'r1bqkb1r/pp1ppp1p/2n2np1/8/2PN4/2N5/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'A31',
			# TRANSLATORS: A31: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 g6
			variation => N__('English: Symmetrical, Two Knights, 4... Nc6'),
			moves => {
			},
		},
		'rnbqkb1r/pp1p1ppp/5n2/4p3/2PN4/8/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A31',
			# TRANSLATORS: A31: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e5
			variation => N__('English: Symmetrical, Two Knights, 4... e5'),
			moves => {
				'd4b5' => 1,
			},
		},
		'rnbqkb1r/pp1p1ppp/5n2/1N2p3/2P5/8/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'A31',
			# TRANSLATORS: A31: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e5 5. Nb5
			variation => N__('English: Symmetrical, Two Knights, 4... e5 5. Nb5'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppp1p/5np1/8/2PN4/8/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A31',
			# TRANSLATORS: A31: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 g6
			variation => N__('English: Symmetrical, Two Knights, 4... g6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkb1r/pp1ppp1p/5np1/8/2PN4/2N5/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'A31',
			# TRANSLATORS: A31: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 g6 5. Nc3
			variation => N__('English: Symmetrical, Two Knights, 4... g6'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/pp1pppbp/5np1/8/2PN4/2N5/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'A31',
			# TRANSLATORS: A31: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7
			variation => N__('English: Symmetrical, Two Knights, 4... g6'),
			moves => {
				'e2e4' => 1,
			},
		},
		'rnbqk2r/pp1pppbp/5np1/8/2PNP3/2N5/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'A31',
			# TRANSLATORS: A31: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. e4
			variation => N__('English: Symmetrical, Two Knights, 4... g6'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppp1p/5np1/2p5/2PP4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A31',
			# TRANSLATORS: A31: 1. c4 c5 2. Nf3 Nf6 3. d4 g6
			variation => N__('English: Symmetrical, Two Knights, 3... g6'),
			moves => {
				'b1c3' => 1,
				'd4d5' => 1,
			},
		},
		'rnbqkb1r/pp1ppp1p/5np1/2p5/2PP4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'A31',
			# TRANSLATORS: A31: 1. c4 c5 2. Nf3 Nf6 3. d4 g6 4. Nc3
			variation => N__('English: Symmetrical, Two Knights, 3... g6'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppp1p/5np1/2pP4/2P5/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'A31',
			# TRANSLATORS: A31: 1. c4 c5 2. Nf3 Nf6 3. d4 g6 4. d5
			variation => N__('English: Symmetrical, Two Knights, 3... g6'),
			moves => {
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/8/2PN4/8/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A32',
			# TRANSLATORS: A32: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6
			variation => N__('English: Symmetrical, Two Knights, 4... e6'),
			moves => {
				'b1c3' => 1,
				'e2e3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/8/2PN4/2N5/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'A32',
			# TRANSLATORS: A32: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. Nc3
			variation => N__('English: Symmetrical, Two Knights, 5. Nc3'),
			moves => {
				'a7a6' => 1,
				'b8c6' => 1,
				'd7d5' => 1,
				'f8b4' => 1,
			},
		},
		'rnbqkb1r/1p1p1ppp/p3pn2/8/2PN4/2N5/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'A32',
			# TRANSLATORS: A32: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. Nc3 a6
			variation => N__('English: Symmetrical, Two Knights, 5. Nc3 a6'),
			moves => {
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/1p1p1ppp/p3pn2/8/2PN4/2N3P1/PP2PP1P/R1BQKB1R b KQkq' => {
			eco => 'A32',
			# TRANSLATORS: A32: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. Nc3 a6 6. g3
			variation => N__('English: Symmetrical, Two Knights, 5. Nc3 a6 6. g3'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/3p4/2PN4/2N5/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'A32',
			# TRANSLATORS: A32: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. Nc3 d5
			variation => N__('English: Symmetrical, Two Knights, 5. Nc3 d5'),
			moves => {
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/8/1bPN4/2N5/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'A32',
			# TRANSLATORS: A32: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. Nc3 Bb4
			variation => N__('English: Symmetrical, Two Knights, 5. Nc3 Bb4'),
			moves => {
				'c1d2' => 1,
				'd1b3' => 1,
				'd4b5' => 1,
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/8/1bPN4/2N5/PP1BPPPP/R2QKB1R b KQkq' => {
			eco => 'A32',
			# TRANSLATORS: A32: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. Nc3 Bb4 6. Bd2
			variation => N__('English: Symmetrical, Two Knights, 5. Nc3 Bb4 6. Bd2'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqk2r/pp1p1ppp/2n1pn2/8/1bPN4/2N5/PP1BPPPP/R2QKB1R w KQkq' => {
			eco => 'A32',
			# TRANSLATORS: A32: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. Nc3 Bb4 6. Bd2 Nc6
			variation => N__('English: Symmetrical, Two Knights, 5. Nc3 Bb4 6. Bd2 Nc6'),
			moves => {
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/8/1bPN4/1QN5/PP2PPPP/R1B1KB1R b KQkq' => {
			eco => 'A32',
			# TRANSLATORS: A32: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. Nc3 Bb4 6. Qb3
			variation => N__('English: Symmetrical, Two Knights, 5. Nc3 Bb4 6. Qb3'),
			moves => {
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/1N6/1bP5/2N5/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'A32',
			# TRANSLATORS: A32: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. Nc3 Bb4 6. Nb5
			variation => N__('English: Symmetrical, Two Knights, 5. Nc3 Bb4 6. Nb5'),
			moves => {
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/8/2PN4/4P3/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'A32',
			# TRANSLATORS: A32: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. e3
			variation => N__('English: Symmetrical, Two Knights, 5. e3'),
			moves => {
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/8/2PN4/6P1/PP2PP1P/RNBQKB1R b KQkq' => {
			eco => 'A32',
			# TRANSLATORS: A32: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. g3
			variation => N__('English: Symmetrical, Two Knights, 5. g3'),
			moves => {
				'a7a6' => 1,
				'b8c6' => 1,
				'd7d5' => 1,
				'd8b6' => 1,
				'd8c7' => 1,
				'f8b4' => 1,
			},
		},
		'rnbqkb1r/1p1p1ppp/p3pn2/8/2PN4/6P1/PP2PP1P/RNBQKB1R w KQkq' => {
			eco => 'A32',
			# TRANSLATORS: A32: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. g3 a6
			variation => N__('English: Symmetrical, Two Knights, 5. g3 a6'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkb1r/1p1p1ppp/p3pn2/8/2PN4/6P1/PP2PPBP/RNBQK2R b KQkq' => {
			eco => 'A32',
			# TRANSLATORS: A32: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. g3 a6 6. Bg2
			variation => N__('English: Symmetrical, Two Knights, 5. g3 a6'),
			moves => {
			},
		},
		'r1bqkb1r/pp1p1ppp/2n1pn2/8/2PN4/6P1/PP2PP1P/RNBQKB1R w KQkq' => {
			eco => 'A32',
			# TRANSLATORS: A32: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. g3 Nc6
			variation => N__('English: Symmetrical, Two Knights, 5. g3 Nc6'),
			moves => {
				'f1g2' => 1,
			},
		},
		'r1bqkb1r/pp1p1ppp/2n1pn2/8/2PN4/6P1/PP2PPBP/RNBQK2R b KQkq' => {
			eco => 'A32',
			# TRANSLATORS: A32: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. g3 Nc6 6. Bg2
			variation => N__('English: Symmetrical, Two Knights, 5. g3 Nc6'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/3p4/2PN4/6P1/PP2PP1P/RNBQKB1R w KQkq' => {
			eco => 'A32',
			# TRANSLATORS: A32: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. g3 d5
			variation => N__('English: Symmetrical, Two Knights, 5. g3 d5'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/3p4/2PN4/6P1/PP2PPBP/RNBQK2R b KQkq' => {
			eco => 'A32',
			# TRANSLATORS: A32: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. g3 d5 6. Bg2
			variation => N__('English: Symmetrical, Two Knights, 5. g3 d5 6. Bg2'),
			moves => {
				'e6e5' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/5n2/3pp3/2PN4/6P1/PP2PPBP/RNBQK2R w KQkq' => {
			eco => 'A32',
			# TRANSLATORS: A32: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. g3 d5 6. Bg2 e5
			variation => N__('English: Symmetrical, Two Knights, 5. g3 d5 6. Bg2'),
			moves => {
				'd4f3' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/5n2/3pp3/2P5/5NP1/PP2PPBP/RNBQK2R b KQkq' => {
			eco => 'A32',
			# TRANSLATORS: A32: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. g3 d5 6. Bg2 e5 7. Nf3
			variation => N__('English: Symmetrical, Two Knights, 5. g3 d5 6. Bg2 e5 7. Nf3'),
			moves => {
			},
		},
		'rnb1kb1r/pp1p1ppp/1q2pn2/8/2PN4/6P1/PP2PP1P/RNBQKB1R w KQkq' => {
			eco => 'A32',
			# TRANSLATORS: A32: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. g3 Qb6
			variation => N__('English: Symmetrical, Two Knights, 5. g3 Qb6'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnb1kb1r/pp1p1ppp/1q2pn2/8/2PN4/6P1/PP2PPBP/RNBQK2R b KQkq' => {
			eco => 'A32',
			# TRANSLATORS: A32: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. g3 Qb6 6. Bg2
			variation => N__('English: Symmetrical, Two Knights, 5. g3 Qb6'),
			moves => {
			},
		},
		'rnb1kb1r/ppqp1ppp/4pn2/8/2PN4/6P1/PP2PP1P/RNBQKB1R w KQkq' => {
			eco => 'A32',
			# TRANSLATORS: A32: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. g3 Qc7
			variation => N__('English: Symmetrical, Two Knights, 5. g3 Qc7'),
			moves => {
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/8/1bPN4/6P1/PP2PP1P/RNBQKB1R w KQkq' => {
			eco => 'A32',
			# TRANSLATORS: A32: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. g3 Bb4+
			variation => N__('English: Symmetrical, Two Knights, 5. g3 Bb4+'),
			moves => {
			},
		},
		'r1bqkb1r/pp1p1ppp/2n1pn2/8/2PN4/2N5/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'A33a',
			# TRANSLATORS: A33a: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. Nc3 Nc6
			variation => N__('English: Symmetrical, Two Knights, 5. Nc3 Nc6'),
			moves => {
				'a2a3' => 1,
				'c1f4' => 1,
				'c1g5' => 1,
				'd4b5' => 1,
				'e2e3' => 1,
				'g2g3' => 1,
			},
		},
		'r1bqkb1r/pp1p1ppp/2n1pn2/8/2PN1B2/2N5/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'A33b',
			# TRANSLATORS: A33b: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. Nc3 Nc6 6. Bf4
			variation => N__('English: Symmetrical, Two Knights, 5. Nc3 Nc6 6. Bf4'),
			moves => {
			},
		},
		'r1bqkb1r/pp1p1ppp/2n1pn2/6B1/2PN4/2N5/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'A33c',
			# TRANSLATORS: A33c: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. Nc3 Nc6 6. Bg5
			variation => N__('English: Symmetrical, Two Knights, 5. Nc3 Nc6 6. Bg5'),
			moves => {
			},
		},
		'r1bqkb1r/pp1p1ppp/2n1pn2/8/2PN4/2N1P3/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'A33d',
			# TRANSLATORS: A33d: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. Nc3 Nc6 6. e3
			variation => N__('English: Symmetrical, Two Knights, 5. Nc3 Nc6 6. e3'),
			moves => {
			},
		},
		'r1bqkb1r/pp1p1ppp/2n1pn2/8/2PN4/P1N5/1P2PPPP/R1BQKB1R b KQkq' => {
			eco => 'A33e',
			# TRANSLATORS: A33e: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. Nc3 Nc6 6. a3
			variation => N__('English: Symmetrical, Two Knights, 5. Nc3 Nc6 6. a3'),
			moves => {
				'f8c5' => 1,
			},
		},
		'r1bqk2r/pp1p1ppp/2n1pn2/2b5/2PN4/P1N5/1P2PPPP/R1BQKB1R w KQkq' => {
			eco => 'A33f',
			# TRANSLATORS: A33f: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. Nc3 Nc6 6. a3 Bc5
			variation => N__('English: Symmetrical, Two Knights, 5. Nc3 Nc6 6. a3 Bc5'),
			moves => {
			},
		},
		'r1bqkb1r/pp1p1ppp/2n1pn2/1N6/2P5/2N5/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'A33g',
			# TRANSLATORS: A33g: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. Nc3 Nc6 6. Ndb5
			variation => N__('English: Symmetrical, Two Knights, 5. Nc3 Nc6 6.Ndb5'),
			moves => {
				'd7d5' => 1,
				'f8b4' => 1,
			},
		},
		'r1bqk2r/pp1p1ppp/2n1pn2/1N6/1bP5/2N5/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'A33h',
			# TRANSLATORS: A33h: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. Nc3 Nc6 6. Ndb5 Bb4
			variation => N__('English: Symmetrical, Two Knights, 5. Nc3 Nc6 6.Ndb5 Bb4'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2n1pn2/1N1p4/2P5/2N5/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'A33i',
			# TRANSLATORS: A33i: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. Nc3 Nc6 6. Ndb5 d5
			variation => N__('English: Symmetrical, Two Knights, 5. Nc3 Nc6 6.Ndb5 d5'),
			moves => {
				'c1f4' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2n1pn2/1N1p4/2P2B2/2N5/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'A33i',
			# TRANSLATORS: A33i: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. Nc3 Nc6 6. Ndb5 d5 7. Bf4
			variation => N__('English: Symmetrical, Two Knights, 5. Nc3 Nc6 6.Ndb5 d5'),
			moves => {
				'e6e5' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2n2n2/1N1pp3/2P2B2/2N5/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'A33i',
			# TRANSLATORS: A33i: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. Nc3 Nc6 6. Ndb5 d5 7. Bf4 e5
			variation => N__('English: Symmetrical, Two Knights, 5. Nc3 Nc6 6.Ndb5 d5'),
			moves => {
				'c4d5' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2n2n2/1N1Pp3/5B2/2N5/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'A33i',
			# TRANSLATORS: A33i: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. Nc3 Nc6 6. Ndb5 d5 7. Bf4 e5 8. cxd5
			variation => N__('English: Symmetrical, Two Knights, 5. Nc3 Nc6 6.Ndb5 d5'),
			moves => {
				'e5f4' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2n2n2/1N1P4/5p2/2N5/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'A33i',
			# TRANSLATORS: A33i: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. Nc3 Nc6 6. Ndb5 d5 7. Bf4 e5 8. cxd5 exf4
			variation => N__('English: Symmetrical, Two Knights, 5. Nc3 Nc6 6.Ndb5 d5'),
			moves => {
				'd5c6' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2P2n2/1N6/5p2/2N5/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'A33i',
			# TRANSLATORS: A33i: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. Nc3 Nc6 6. Ndb5 d5 7. Bf4 e5 8. cxd5 exf4 9. dxc6
			variation => N__('English: Symmetrical, Two Knights, 5. Nc3 Nc6 6.Ndb5 d5'),
			moves => {
				'b7c6' => 1,
			},
		},
		'r1bqkb1r/p4ppp/2p2n2/1N6/5p2/2N5/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'A33i',
			# TRANSLATORS: A33i: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. Nc3 Nc6 6. Ndb5 d5 7. Bf4 e5 8. cxd5 exf4 9. dxc6 bxc6
			variation => N__('English: Symmetrical, Two Knights, 5. Nc3 Nc6 6.Ndb5 d5'),
			moves => {
				'd1d8' => 1,
			},
		},
		'r1bQkb1r/p4ppp/2p2n2/1N6/5p2/2N5/PP2PPPP/R3KB1R b KQkq' => {
			eco => 'A33i',
			# TRANSLATORS: A33i: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. Nc3 Nc6 6. Ndb5 d5 7. Bf4 e5 8. cxd5 exf4 9. dxc6 bxc6 10. Qxd8+
			variation => N__('English: Symmetrical, Two Knights, 5. Nc3 Nc6 6.Ndb5 d5'),
			moves => {
				'e8d8' => 1,
			},
		},
		'r1bk1b1r/p4ppp/2p2n2/1N6/5p2/2N5/PP2PPPP/R3KB1R w KQ' => {
			eco => 'A33j',
			# TRANSLATORS: A33j: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. Nc3 Nc6 6. Ndb5 d5 7. Bf4 e5 8. cxd5 exf4 9. dxc6 bxc6 10. Qxd8+ Kxd8
			variation => N__('English: Symmetrical, Two Knights, 5. Nc3 Nc6 6.Ndb5 d5 Queenswap'),
			moves => {
			},
		},
		'r1bqkb1r/pp1p1ppp/2n1pn2/8/2PN4/2N3P1/PP2PP1P/R1BQKB1R b KQkq' => {
			eco => 'A33k',
			# TRANSLATORS: A33k: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. Nc3 Nc6 6. g3
			variation => N__('English: Symmetrical, Two Knights, 5. Nc3 Nc6 6. g3'),
			moves => {
				'a7a6' => 1,
				'd8b6' => 1,
				'f8b4' => 1,
				'f8c5' => 1,
			},
		},
		'r1bqkb1r/1p1p1ppp/p1n1pn2/8/2PN4/2N3P1/PP2PP1P/R1BQKB1R w KQkq' => {
			eco => 'A33l',
			# TRANSLATORS: A33l: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. Nc3 Nc6 6. g3 a6
			variation => N__('English: Symmetrical, Two Knights, 5. Nc3 Nc6 6. g3 a6'),
			moves => {
			},
		},
		'r1bqk2r/pp1p1ppp/2n1pn2/8/1bPN4/2N3P1/PP2PP1P/R1BQKB1R w KQkq' => {
			eco => 'A33m',
			# TRANSLATORS: A33m: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. Nc3 Nc6 6. g3 Bb4
			variation => N__('English: Symmetrical, Two Knights, 5. Nc3 Nc6 6. g3 Bb4'),
			moves => {
			},
		},
		'r1bqk2r/pp1p1ppp/2n1pn2/2b5/2PN4/2N3P1/PP2PP1P/R1BQKB1R w KQkq' => {
			eco => 'A33n',
			# TRANSLATORS: A33n: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. Nc3 Nc6 6. g3 Bc5
			variation => N__('English: Symmetrical, Two Knights, 5. Nc3 Nc6 6. g3 Bc5'),
			moves => {
			},
		},
		'r1b1kb1r/pp1p1ppp/1qn1pn2/8/2PN4/2N3P1/PP2PP1P/R1BQKB1R w KQkq' => {
			eco => 'A33o',
			# TRANSLATORS: A33o: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. Nc3 Nc6 6. g3 Qb6
			variation => N__('English: Symmetrical, Geller Variation'),
			moves => {
				'd4b3' => 1,
			},
		},
		'r1b1kb1r/pp1p1ppp/1qn1pn2/8/2P5/1NN3P1/PP2PP1P/R1BQKB1R b KQkq' => {
			eco => 'A33p',
			# TRANSLATORS: A33p: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. Nc3 Nc6 6. g3 Qb6 7. Nb3
			variation => N__('English: Symmetrical, Geller, 7. Nb3'),
			moves => {
				'c6e5' => 1,
			},
		},
		'r1b1kb1r/pp1p1ppp/1q2pn2/4n3/2P5/1NN3P1/PP2PP1P/R1BQKB1R w KQkq' => {
			eco => 'A33q',
			# TRANSLATORS: A33q: 1. c4 c5 2. Nf3 Nf6 3. d4 cxd4 4. Nxd4 e6 5. Nc3 Nc6 6. g3 Qb6 7. Nb3 Ne5
			variation => N__('English: Symmetrical, Geller, 7. Nb3 Ne5'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/8/2p5/2P5/2N5/PP1PPPPP/R1BQKBNR b KQkq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3
			variation => N__('English: Symmetrical'),
			moves => {
				'b7b6' => 1,
				'b8c6' => 1,
				'g7g6' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/p2ppppp/1p6/2p5/2P5/2N5/PP1PPPPP/R1BQKBNR w KQkq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3 b6
			variation => N__('English: Symmetrical, 2... b6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/p2ppppp/1p6/2p5/2P5/2N2N2/PP1PPPPP/R1BQKB1R b KQkq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3 b6 3. Nf3
			variation => N__('English: Symmetrical, 2... b6'),
			moves => {
				'c8b7' => 1,
			},
		},
		'rn1qkbnr/pb1ppppp/1p6/2p5/2P5/2N2N2/PP1PPPPP/R1BQKB1R w KQkq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3 b6 3. Nf3 Bb7
			variation => N__('English: Symmetrical, 2... b6'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppp1p/6p1/2p5/2P5/2N5/PP1PPPPP/R1BQKBNR w KQkq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3 g6
			variation => N__('English: Symmetrical, 2... g6'),
			moves => {
				'g1f3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/pp1ppp1p/6p1/2p5/2P5/2N2N2/PP1PPPPP/R1BQKB1R b KQkq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3 g6 3. Nf3
			variation => N__('English: Symmetrical, 2... g6'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppp1p/6p1/2p5/2P5/2N3P1/PP1PPP1P/R1BQKBNR b KQkq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3 g6 3. g3
			variation => N__('English: Symmetrical, 2... g6'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk1nr/pp1pppbp/6p1/2p5/2P5/2N3P1/PP1PPP1P/R1BQKBNR w KQkq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3 g6 3. g3 Bg7
			variation => N__('English: Symmetrical, 2... g6'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqk1nr/pp1pppbp/6p1/2p5/2P5/2N3P1/PP1PPPBP/R1BQK1NR b KQkq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3 g6 3. g3 Bg7 4. Bg2
			variation => N__('English: Symmetrical, 2... g6'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/2p5/2P5/2N5/PP1PPPPP/R1BQKBNR w KQkq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3 Nf6
			variation => N__('English: Symmetrical, 2... Nf6'),
			moves => {
				'g1f3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/2p5/2P5/2N2N2/PP1PPPPP/R1BQKB1R b KQkq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3 Nf6 3. Nf3
			variation => N__('English: Symmetrical, 3 Knights'),
			moves => {
				'b7b6' => 1,
				'd7d5' => 1,
				'e7e6' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/p2ppppp/1p3n2/2p5/2P5/2N2N2/PP1PPPPP/R1BQKB1R w KQkq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3 Nf6 3. Nf3 b6
			variation => N__('English: Symmetrical, 3 Knights, 3... b6'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/5n2/2pp4/2P5/2N2N2/PP1PPPPP/R1BQKB1R w KQkq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3 Nf6 3. Nf3 d5
			variation => N__('English: Symmetrical, 3 Knights'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/5n2/2pP4/8/2N2N2/PP1PPPPP/R1BQKB1R b KQkq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3 Nf6 3. Nf3 d5 4. cxd5
			variation => N__('English: Symmetrical, 3 Knights'),
			moves => {
				'f6d5' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/8/2pn4/8/2N2N2/PP1PPPPP/R1BQKB1R w KQkq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3 Nf6 3. Nf3 d5 4. cxd5 Nxd5
			variation => N__('English: Symmetrical, 3 Knights, Exchange'),
			moves => {
				'd2d4' => 1,
				'e2e4' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/8/2pn4/3P4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3 Nf6 3. Nf3 d5 4. cxd5 Nxd5 5. d4
			variation => N__('English: Symmetrical, 3 Knights, 5. d4'),
			moves => {
				'c5d4' => 1,
				'd5c3' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/8/3n4/3p4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3 Nf6 3. Nf3 d5 4. cxd5 Nxd5 5. d4 cxd4
			variation => N__('English: Symmetrical, 3 Knights, 5. d4 cxd4'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/8/2p5/3P4/2n2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3 Nf6 3. Nf3 d5 4. cxd5 Nxd5 5. d4 Nxc3
			variation => N__('English: Symmetrical, 3 Knights, 5. d4 Nxc3'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/8/2pn4/4P3/2N2N2/PP1P1PPP/R1BQKB1R b KQkq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3 Nf6 3. Nf3 d5 4. cxd5 Nxd5 5. e4
			variation => N__('English: Symmetrical, 3 Knights, 5. e4'),
			moves => {
				'd5b4' => 1,
				'd5c3' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/8/2p5/1n2P3/2N2N2/PP1P1PPP/R1BQKB1R w KQkq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3 Nf6 3. Nf3 d5 4. cxd5 Nxd5 5. e4 Nb4
			variation => N__('English: Symmetrical, 3 Knights, 5. e4 Nb4'),
			moves => {
				'f1b5' => 1,
				'f1c4' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/8/1Bp5/1n2P3/2N2N2/PP1P1PPP/R1BQK2R b KQkq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3 Nf6 3. Nf3 d5 4. cxd5 Nxd5 5. e4 Nb4 6. Bb5+
			variation => N__('English: Symmetrical, 3 Knights, 5. e4 Nb4 6. Bb5+'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/8/2p5/1nB1P3/2N2N2/PP1P1PPP/R1BQK2R b KQkq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3 Nf6 3. Nf3 d5 4. cxd5 Nxd5 5. e4 Nb4 6. Bc4
			variation => N__('English: Symmetrical, 3 Knights, 5. e4 Nb4 6. Bc4'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/8/2p5/4P3/2n2N2/PP1P1PPP/R1BQKB1R w KQkq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3 Nf6 3. Nf3 d5 4. cxd5 Nxd5 5. e4 Nxc3
			variation => N__('English: Symmetrical, 3 Knights, 5. e4 Nxc3'),
			moves => {
				'd2c3' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/8/2p5/4P3/2P2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3 Nf6 3. Nf3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. dxc3
			variation => N__('English: Symmetrical, 3 Knights, 5. e4 Nxc3'),
			moves => {
				'd8d1' => 1,
			},
		},
		'rnb1kb1r/pp2pppp/8/2p5/4P3/2P2N2/PP3PPP/R1BqKB1R w KQkq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3 Nf6 3. Nf3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. dxc3 Qxd1+
			variation => N__('English: Symmetrical, 3 Knights, 5. e4 Nxc3'),
			moves => {
				'e1d1' => 1,
			},
		},
		'rnb1kb1r/pp2pppp/8/2p5/4P3/2P2N2/PP3PPP/R1BK1B1R b kq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3 Nf6 3. Nf3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. dxc3 Qxd1+ 7. Kxd1
			variation => N__('English: Symmetrical, 3 Knights, Queenswap'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/8/2pn4/8/2N2NP1/PP1PPP1P/R1BQKB1R b KQkq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3 Nf6 3. Nf3 d5 4. cxd5 Nxd5 5. g3
			variation => N__('English: Symmetrical, 3 Knights, 5. g3'),
			moves => {
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/2p5/2P5/2N2N2/PP1PPPPP/R1BQKB1R w KQkq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3 Nf6 3. Nf3 e6
			variation => N__('English: Symmetrical, 3 Knights, 3... e6'),
			moves => {
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/2p5/2P5/2N2NP1/PP1PPP1P/R1BQKB1R b KQkq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3 Nf6 3. Nf3 e6 4. g3
			variation => N__('English: Symmetrical, 3 Knights, 3... e6 4. g3'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppp1p/5np1/2p5/2P5/2N2N2/PP1PPPPP/R1BQKB1R w KQkq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3 Nf6 3. Nf3 g6
			variation => N__('English: Symmetrical, 3 Knights, 3... g6'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/2p5/2P5/2N3P1/PP1PPP1P/R1BQKBNR b KQkq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3 Nf6 3. g3
			variation => N__('English: Symmetrical, 2... Nf6 3. g3'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/5n2/2pp4/2P5/2N3P1/PP1PPP1P/R1BQKBNR w KQkq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3 Nf6 3. g3 d5
			variation => N__('English: Symmetrical, 2... Nf6'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/5n2/2pP4/8/2N3P1/PP1PPP1P/R1BQKBNR b KQkq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3 Nf6 3. g3 d5 4. cxd5
			variation => N__('English: Symmetrical, 2... Nf6'),
			moves => {
				'f6d5' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/8/2pn4/8/2N3P1/PP1PPP1P/R1BQKBNR w KQkq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3 Nf6 3. g3 d5 4. cxd5 Nxd5
			variation => N__('English: Symmetrical, 2... Nf6'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/8/2pn4/8/2N3P1/PP1PPPBP/R1BQK1NR b KQkq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3 Nf6 3. g3 d5 4. cxd5 Nxd5 5. Bg2
			variation => N__('English: Symmetrical, 2... Nf6 3. g3'),
			moves => {
				'd5c7' => 1,
			},
		},
		'rnbqkb1r/ppn1pppp/8/2p5/8/2N3P1/PP1PPPBP/R1BQK1NR w KQkq' => {
			eco => 'A34',
			# TRANSLATORS: A34: 1. c4 c5 2. Nc3 Nf6 3. g3 d5 4. cxd5 Nxd5 5. Bg2 Nc7
			variation => N__('English: Symmetrical, Rubinstein System'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/2p5/2P5/2N5/PP1PPPPP/R1BQKBNR w KQkq' => {
			eco => 'A35a',
			# TRANSLATORS: A35a: 1. c4 c5 2. Nc3 Nc6
			variation => N__('English: Symmetrical'),
			moves => {
				'e2e3' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/2p5/2P5/2N1P3/PP1P1PPP/R1BQKBNR b KQkq' => {
			eco => 'A35b',
			# TRANSLATORS: A35b: 1. c4 c5 2. Nc3 Nc6 3. e3
			variation => N__('English: Symmetrical, 2. Nc3 Nc6 3. e3'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/2p5/2P5/2N2N2/PP1PPPPP/R1BQKB1R b KQkq' => {
			eco => 'A35c',
			# TRANSLATORS: A35c: 1. c4 c5 2. Nc3 Nc6 3. Nf3
			variation => N__('English: Symmetrical, 2. Nc3 Nc6 3. Nf3'),
			moves => {
				'g7g6' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkbnr/pp1ppp1p/2n3p1/2p5/2P5/2N2N2/PP1PPPPP/R1BQKB1R w KQkq' => {
			eco => 'A35d',
			# TRANSLATORS: A35d: 1. c4 c5 2. Nc3 Nc6 3. Nf3 g6
			variation => N__('English: Symmetrical, 2. Nc3 Nc6 3. Nf3 g6'),
			moves => {
				'e2e3' => 1,
			},
		},
		'r1bqkbnr/pp1ppp1p/2n3p1/2p5/2P5/2N1PN2/PP1P1PPP/R1BQKB1R b KQkq' => {
			eco => 'A35e',
			# TRANSLATORS: A35e: 1. c4 c5 2. Nc3 Nc6 3. Nf3 g6 4. e3
			variation => N__('English: Symmetrical, 2. Nc3 Nc6 3. Nf3 g6 4. e3'),
			moves => {
				'f8g7' => 1,
			},
		},
		'r1bqk1nr/pp1pppbp/2n3p1/2p5/2P5/2N1PN2/PP1P1PPP/R1BQKB1R w KQkq' => {
			eco => 'A35f',
			# TRANSLATORS: A35f: 1. c4 c5 2. Nc3 Nc6 3. Nf3 g6 4. e3 Bg7
			variation => N__('English: Symmetrical, 2. Nc3 Nc6 3. Nf3 g6 4. e3 Bg7'),
			moves => {
			},
		},
		'r1bqkb1r/pp1ppppp/2n2n2/2p5/2P5/2N2N2/PP1PPPPP/R1BQKB1R w KQkq' => {
			eco => 'A35g',
			# TRANSLATORS: A35g: 1. c4 c5 2. Nc3 Nc6 3. Nf3 Nf6
			variation => N__('English: Symmetrical, Four Knights'),
			moves => {
				'd2d4' => 1,
				'e2e3' => 1,
				'g2g3' => 1,
			},
		},
		'r1bqkb1r/pp1ppppp/2n2n2/2p5/2PP4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'A35g',
			# TRANSLATORS: A35g: 1. c4 c5 2. Nc3 Nc6 3. Nf3 Nf6 4. d4
			variation => N__('English: Symmetrical, Four Knights, 4. d4'),
			moves => {
			},
		},
		'r1bqkb1r/pp1ppppp/2n2n2/2p5/2P5/2N1PN2/PP1P1PPP/R1BQKB1R b KQkq' => {
			eco => 'A35h',
			# TRANSLATORS: A35h: 1. c4 c5 2. Nc3 Nc6 3. Nf3 Nf6 4. e3
			variation => N__('English: Symmetrical, Four Knights, 4. e3'),
			moves => {
				'e7e5' => 1,
			},
		},
		'r1bqkb1r/pp1p1ppp/2n2n2/2p1p3/2P5/2N1PN2/PP1P1PPP/R1BQKB1R w KQkq' => {
			eco => 'A35i',
			# TRANSLATORS: A35i: 1. c4 c5 2. Nc3 Nc6 3. Nf3 Nf6 4. e3 e5
			variation => N__('English: Symmetrical, Four Knights, 4. e3 e5'),
			moves => {
			},
		},
		'r1bqkb1r/pp1ppppp/2n2n2/2p5/2P5/2N2NP1/PP1PPP1P/R1BQKB1R b KQkq' => {
			eco => 'A35j',
			# TRANSLATORS: A35j: 1. c4 c5 2. Nc3 Nc6 3. Nf3 Nf6 4. g3
			variation => N__('English: Symmetrical, Four Knights, 4. g3'),
			moves => {
				'd7d5' => 1,
			},
		},
		'r1bqkb1r/pp2pppp/2n2n2/2pp4/2P5/2N2NP1/PP1PPP1P/R1BQKB1R w KQkq' => {
			eco => 'A35k',
			# TRANSLATORS: A35k: 1. c4 c5 2. Nc3 Nc6 3. Nf3 Nf6 4. g3 d5
			variation => N__('English: Symmetrical, Four Knights, 4. g3 d5'),
			moves => {
				'c4d5' => 1,
			},
		},
		'r1bqkb1r/pp2pppp/2n2n2/2pP4/8/2N2NP1/PP1PPP1P/R1BQKB1R b KQkq' => {
			eco => 'A35l',
			# TRANSLATORS: A35l: 1. c4 c5 2. Nc3 Nc6 3. Nf3 Nf6 4. g3 d5 5. cxd5
			variation => N__('English: Symmetrical, Four Knights, 4. g3 d5 5.cxd5'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/2p5/2P5/2N3P1/PP1PPP1P/R1BQKBNR b KQkq' => {
			eco => 'A36a',
			# TRANSLATORS: A36a: 1. c4 c5 2. Nc3 Nc6 3. g3
			variation => N__('English: Symmetrical, 3. g3'),
			moves => {
				'e7e6' => 1,
				'g7g6' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkb1r/pp1ppppp/2n2n2/2p5/2P5/2N3P1/PP1PPP1P/R1BQKBNR w KQkq' => {
			eco => 'A36b',
			# TRANSLATORS: A36b: 1. c4 c5 2. Nc3 Nc6 3. g3 Nf6
			variation => N__('English: Symmetrical, 3. g3 Nf6'),
			moves => {
			},
		},
		'r1bqkbnr/pp1p1ppp/2n1p3/2p5/2P5/2N3P1/PP1PPP1P/R1BQKBNR w KQkq' => {
			eco => 'A36c',
			# TRANSLATORS: A36c: 1. c4 c5 2. Nc3 Nc6 3. g3 e6
			variation => N__('English: Symmetrical, 3. g3 e6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'r1bqkbnr/pp1p1ppp/2n1p3/2p5/2P5/2N2NP1/PP1PPP1P/R1BQKB1R b KQkq' => {
			eco => 'A36c',
			# TRANSLATORS: A36c: 1. c4 c5 2. Nc3 Nc6 3. g3 e6 4. Nf3
			variation => N__('English: Symmetrical, 3. g3 e6 4. Nf3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r1bqkb1r/pp1p1ppp/2n1pn2/2p5/2P5/2N2NP1/PP1PPP1P/R1BQKB1R w KQkq' => {
			eco => 'A36c',
			# TRANSLATORS: A36c: 1. c4 c5 2. Nc3 Nc6 3. g3 e6 4. Nf3 Nf6
			variation => N__('English: Symmetrical, Keres-Parma System'),
			moves => {
				'f1g2' => 1,
			},
		},
		'r1bqkb1r/pp1p1ppp/2n1pn2/2p5/2P5/2N2NP1/PP1PPPBP/R1BQK2R b KQkq' => {
			eco => 'A36c',
			# TRANSLATORS: A36c: 1. c4 c5 2. Nc3 Nc6 3. g3 e6 4. Nf3 Nf6 5. Bg2
			variation => N__('English: Symmetrical, Keres-Parma System'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r1bqk2r/pp1pbppp/2n1pn2/2p5/2P5/2N2NP1/PP1PPPBP/R1BQK2R w KQkq' => {
			eco => 'A36c',
			# TRANSLATORS: A36c: 1. c4 c5 2. Nc3 Nc6 3. g3 e6 4. Nf3 Nf6 5. Bg2 Be7
			variation => N__('English: Symmetrical, Keres-Parma System'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqk2r/pp1pbppp/2n1pn2/2p5/2P5/2N2NP1/PP1PPPBP/R1BQ1RK1 b kq' => {
			eco => 'A36c',
			# TRANSLATORS: A36c: 1. c4 c5 2. Nc3 Nc6 3. g3 e6 4. Nf3 Nf6 5. Bg2 Be7 6. O-O
			variation => N__('English: Symmetrical, Keres-Parma System'),
			moves => {
				'd7d5' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2n1pn2/2pp4/2P5/2N2NP1/PP1PPPBP/R1BQ1RK1 w kq' => {
			eco => 'A36c',
			# TRANSLATORS: A36c: 1. c4 c5 2. Nc3 Nc6 3. g3 e6 4. Nf3 Nf6 5. Bg2 Be7 6. O-O d5
			variation => N__('English: Symmetrical, Keres-Parma System'),
			moves => {
				'c4d5' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2n1pn2/2pP4/8/2N2NP1/PP1PPPBP/R1BQ1RK1 b kq' => {
			eco => 'A36c',
			# TRANSLATORS: A36c: 1. c4 c5 2. Nc3 Nc6 3. g3 e6 4. Nf3 Nf6 5. Bg2 Be7 6. O-O d5 7. cxd5
			variation => N__('English: Symmetrical, Keres-Parma System'),
			moves => {
				'f6d5' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2n1p3/2pn4/8/2N2NP1/PP1PPPBP/R1BQ1RK1 w kq' => {
			eco => 'A36d',
			# TRANSLATORS: A36d: 1. c4 c5 2. Nc3 Nc6 3. g3 e6 4. Nf3 Nf6 5. Bg2 Be7 6. O-O d5 7. cxd5 Nxd5
			variation => N__('English: Symmetrical, Keres-Parma, Main Line Exchange'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppp1p/2n3p1/2p5/2P5/2N3P1/PP1PPP1P/R1BQKBNR w KQkq' => {
			eco => 'A36e',
			# TRANSLATORS: A36e: 1. c4 c5 2. Nc3 Nc6 3. g3 g6
			variation => N__('English: Symmetrical, 3. g3 g6'),
			moves => {
				'f1g2' => 1,
			},
		},
		'r1bqkbnr/pp1ppp1p/2n3p1/2p5/2P5/2N3P1/PP1PPPBP/R1BQK1NR b KQkq' => {
			eco => 'A36e',
			# TRANSLATORS: A36e: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2
			variation => N__('English: Symmetrical, 3. g3 g6'),
			moves => {
				'f8g7' => 1,
			},
		},
		'r1bqk1nr/pp1pppbp/2n3p1/2p5/2P5/2N3P1/PP1PPPBP/R1BQK1NR w KQkq' => {
			eco => 'A36e',
			# TRANSLATORS: A36e: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7
			variation => N__('English: Symmetrical, 3. g3 g6'),
			moves => {
				'a2a3' => 1,
				'b2b3' => 1,
				'd2d3' => 1,
				'e2e3' => 1,
				'e2e4' => 1,
				'g1f3' => 1,
			},
		},
		'r1bqk1nr/pp1pppbp/2n3p1/2p5/2P5/2NP2P1/PP2PPBP/R1BQK1NR b KQkq' => {
			eco => 'A36f',
			# TRANSLATORS: A36f: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3
			variation => N__('English: Symmetrical, 5. d3'),
			moves => {
			},
		},
		'r1bqk1nr/pp1pppbp/2n3p1/2p5/2P5/P1N3P1/1P1PPPBP/R1BQK1NR b KQkq' => {
			eco => 'A36g',
			# TRANSLATORS: A36g: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. a3
			variation => N__('English: Symmetrical, 5. a3'),
			moves => {
				'd7d6' => 1,
				'e7e6' => 1,
			},
		},
		'r1bqk1nr/pp1p1pbp/2n1p1p1/2p5/2P5/P1N3P1/1P1PPPBP/R1BQK1NR w KQkq' => {
			eco => 'A36h',
			# TRANSLATORS: A36h: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. a3 e6
			variation => N__('English: Symmetrical, 5. a3 e6'),
			moves => {
			},
		},
		'r1bqk1nr/pp2ppbp/2np2p1/2p5/2P5/P1N3P1/1P1PPPBP/R1BQK1NR w KQkq' => {
			eco => 'A36i',
			# TRANSLATORS: A36i: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. a3 d6
			variation => N__('English: Symmetrical, 5. a3 d6'),
			moves => {
			},
		},
		'r1bqk1nr/pp1pppbp/2n3p1/2p5/2P5/1PN3P1/P2PPPBP/R1BQK1NR b KQkq' => {
			eco => 'A36j',
			# TRANSLATORS: A36j: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. b3
			variation => N__('English: Symmetrical, 5. b3'),
			moves => {
			},
		},
		'r1bqk1nr/pp1pppbp/2n3p1/2p5/2P5/2N1P1P1/PP1P1PBP/R1BQK1NR b KQkq' => {
			eco => 'A36k',
			# TRANSLATORS: A36k: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. e3
			variation => N__('English: Symmetrical, 5. e3'),
			moves => {
				'e7e5' => 1,
				'e7e6' => 1,
			},
		},
		'r1bqk1nr/pp1p1pbp/2n3p1/2p1p3/2P5/2N1P1P1/PP1P1PBP/R1BQK1NR w KQkq' => {
			eco => 'A36l',
			# TRANSLATORS: A36l: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. e3 e5
			variation => N__('English: Symmetrical, 5. e3 e5 (Botvinnik Reversed)'),
			moves => {
			},
		},
		'r1bqk1nr/pp1p1pbp/2n1p1p1/2p5/2P5/2N1P1P1/PP1P1PBP/R1BQK1NR w KQkq' => {
			eco => 'A36m',
			# TRANSLATORS: A36m: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. e3 e6
			variation => N__('English: Symmetrical, 5. e3 e6'),
			moves => {
				'g1e2' => 1,
			},
		},
		'r1bqk1nr/pp1p1pbp/2n1p1p1/2p5/2P5/2N1P1P1/PP1PNPBP/R1BQK2R b KQkq' => {
			eco => 'A36m',
			# TRANSLATORS: A36m: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. e3 e6 6. Nge2
			variation => N__('English: Symmetrical, 5. e3 e6'),
			moves => {
				'g8e7' => 1,
			},
		},
		'r1bqk2r/pp1pnpbp/2n1p1p1/2p5/2P5/2N1P1P1/PP1PNPBP/R1BQK2R w KQkq' => {
			eco => 'A36m',
			# TRANSLATORS: A36m: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. e3 e6 6. Nge2 Nge7
			variation => N__('English: Symmetrical, 5. e3 e6'),
			moves => {
			},
		},
		'r1bqk1nr/pp1pppbp/2n3p1/2p5/2P1P3/2N3P1/PP1P1PBP/R1BQK1NR b KQkq' => {
			eco => 'A36n',
			# TRANSLATORS: A36n: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. e4
			variation => N__('English: Symmetrical, Botvinnik System'),
			moves => {
				'd7d6' => 1,
				'e7e6' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqk2r/pp1pppbp/2n2np1/2p5/2P1P3/2N3P1/PP1P1PBP/R1BQK1NR w KQkq' => {
			eco => 'A36o',
			# TRANSLATORS: A36o: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. e4 Nf6
			variation => N__('English: Symmetrical, Botvinnik, 5... Nf6'),
			moves => {
				'g1e2' => 1,
			},
		},
		'r1bqk2r/pp1pppbp/2n2np1/2p5/2P1P3/2N3P1/PP1PNPBP/R1BQK2R b KQkq' => {
			eco => 'A36o',
			# TRANSLATORS: A36o: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. e4 Nf6 6. Nge2
			variation => N__('English: Symmetrical, Botvinnik, 5... Nf6 6.Nge2'),
			moves => {
			},
		},
		'r1bqk1nr/pp1p1pbp/2n1p1p1/2p5/2P1P3/2N3P1/PP1P1PBP/R1BQK1NR w KQkq' => {
			eco => 'A36p',
			# TRANSLATORS: A36p: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. e4 e6
			variation => N__('English: Symmetrical, Botvinnik, 5... e6'),
			moves => {
				'g1e2' => 1,
			},
		},
		'r1bqk1nr/pp1p1pbp/2n1p1p1/2p5/2P1P3/2N3P1/PP1PNPBP/R1BQK2R b KQkq' => {
			eco => 'A36p',
			# TRANSLATORS: A36p: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. e4 e6 6. Nge2
			variation => N__('English: Symmetrical, Botvinnik, 5... e6'),
			moves => {
				'g8e7' => 1,
			},
		},
		'r1bqk2r/pp1pnpbp/2n1p1p1/2p5/2P1P3/2N3P1/PP1PNPBP/R1BQK2R w KQkq' => {
			eco => 'A36p',
			# TRANSLATORS: A36p: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. e4 e6 6. Nge2 Nge7
			variation => N__('English: Symmetrical, Botvinnik, 5... e6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqk2r/pp1pnpbp/2n1p1p1/2p5/2P1P3/2N3P1/PP1PNPBP/R1BQ1RK1 b kq' => {
			eco => 'A36p',
			# TRANSLATORS: A36p: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. e4 e6 6. Nge2 Nge7 7. O-O
			variation => N__('English: Symmetrical, Botvinnik, 5... e6'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp1pnpbp/2n1p1p1/2p5/2P1P3/2N3P1/PP1PNPBP/R1BQ1RK1 w -' => {
			eco => 'A36p',
			# TRANSLATORS: A36p: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. e4 e6 6. Nge2 Nge7 7. O-O O-O
			variation => N__('English: Symmetrical, Botvinnik, 5... e6'),
			moves => {
				'd2d3' => 1,
			},
		},
		'r1bq1rk1/pp1pnpbp/2n1p1p1/2p5/2P1P3/2NP2P1/PP2NPBP/R1BQ1RK1 b -' => {
			eco => 'A36q',
			# TRANSLATORS: A36q: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. e4 e6 6. Nge2 Nge7 7. O-O O-O 8. d3
			variation => N__('English: Symmetrical, Botvinnik, 5... e6, 8. d3'),
			moves => {
				'd7d6' => 1,
			},
		},
		'r1bq1rk1/pp2npbp/2npp1p1/2p5/2P1P3/2NP2P1/PP2NPBP/R1BQ1RK1 w -' => {
			eco => 'A36r',
			# TRANSLATORS: A36r: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. e4 e6 6. Nge2 Nge7 7. O-O O-O 8. d3 d6
			variation => N__('English: Symmetrical, Botvinnik, 5... e6, 8. d3 d6'),
			moves => {
			},
		},
		'r1bqk1nr/pp2ppbp/2np2p1/2p5/2P1P3/2N3P1/PP1P1PBP/R1BQK1NR w KQkq' => {
			eco => 'A36s',
			# TRANSLATORS: A36s: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. e4 d6
			variation => N__('English: Symmetrical, Botvinnik, 5... d6'),
			moves => {
				'g1e2' => 1,
			},
		},
		'r1bqk1nr/pp2ppbp/2np2p1/2p5/2P1P3/2N3P1/PP1PNPBP/R1BQK2R b KQkq' => {
			eco => 'A36t',
			# TRANSLATORS: A36t: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. e4 d6 6. Nge2
			variation => N__('English: Symmetrical, Botvinnik, 5... d6 6.Nge2'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r1bqk2r/pp2ppbp/2np1np1/2p5/2P1P3/2N3P1/PP1PNPBP/R1BQK2R w KQkq' => {
			eco => 'A36u',
			# TRANSLATORS: A36u: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. e4 d6 6. Nge2 Nf6
			variation => N__('English: Symmetrical, Botvinnik, 5... d6 6.Nge2 Nf6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqk2r/pp2ppbp/2np1np1/2p5/2P1P3/2N3P1/PP1PNPBP/R1BQ1RK1 b kq' => {
			eco => 'A36u',
			# TRANSLATORS: A36u: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. e4 d6 6. Nge2 Nf6 7. O-O
			variation => N__('English: Symmetrical, Botvinnik, 5... d6 6.Nge2 Nf6'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/2p5/2P1P3/2N3P1/PP1PNPBP/R1BQ1RK1 w -' => {
			eco => 'A36v',
			# TRANSLATORS: A36v: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. e4 d6 6. Nge2 Nf6 7. O-O O-O
			variation => N__('English: Symmetrical, Botvinnik System, 5... d6, 7.O-O O-O'),
			moves => {
				'd2d3' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/2p5/2P1P3/2NP2P1/PP2NPBP/R1BQ1RK1 b -' => {
			eco => 'A36w',
			# TRANSLATORS: A36w: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. e4 d6 6. Nge2 Nf6 7. O-O O-O 8. d3
			variation => N__('English: Symmetrical, Botvinnik System, 5... d6, 8. d3'),
			moves => {
				'a7a6' => 1,
				'a8b8' => 1,
				'f6e8' => 1,
			},
		},
		'1rbq1rk1/pp2ppbp/2np1np1/2p5/2P1P3/2NP2P1/PP2NPBP/R1BQ1RK1 w -' => {
			eco => 'A36x',
			# TRANSLATORS: A36x: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. e4 d6 6. Nge2 Nf6 7. O-O O-O 8. d3 Rb8
			variation => N__('English: Symmetrical, Botvinnik System, 5... d6, 8. d3 Rb8'),
			moves => {
			},
		},
		'r1bqnrk1/pp2ppbp/2np2p1/2p5/2P1P3/2NP2P1/PP2NPBP/R1BQ1RK1 w -' => {
			eco => 'A36y',
			# TRANSLATORS: A36y: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. e4 d6 6. Nge2 Nf6 7. O-O O-O 8. d3 Ne8
			variation => N__('English: Symmetrical, Botvinnik System, 5... d6, 8. d3 Ne8'),
			moves => {
			},
		},
		'r1bq1rk1/1p2ppbp/p1np1np1/2p5/2P1P3/2NP2P1/PP2NPBP/R1BQ1RK1 w -' => {
			eco => 'A36z',
			# TRANSLATORS: A36z: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. e4 d6 6. Nge2 Nf6 7. O-O O-O 8. d3 a6
			variation => N__('English: Symmetrical, Botvinnik System, 5... d6, 8. d3 a6'),
			moves => {
			},
		},
		'r1bqk1nr/pp1pppbp/2n3p1/2p5/2P5/2N2NP1/PP1PPPBP/R1BQK2R b KQkq' => {
			eco => 'A37a',
			# TRANSLATORS: A37a: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3
			variation => N__('English: Symmetrical, 5. Nf3'),
			moves => {
				'a7a6' => 1,
				'd7d6' => 1,
				'e7e5' => 1,
				'e7e6' => 1,
				'g8f6' => 1,
				'g8h6' => 1,
			},
		},
		'r1bqk1nr/1p1pppbp/p1n3p1/2p5/2P5/2N2NP1/PP1PPPBP/R1BQK2R w KQkq' => {
			eco => 'A37b',
			# TRANSLATORS: A37b: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 a6
			variation => N__('English: Symmetrical, 5. Nf3 a6'),
			moves => {
			},
		},
		'r1bqk2r/pp1pppbp/2n3pn/2p5/2P5/2N2NP1/PP1PPPBP/R1BQK2R w KQkq' => {
			eco => 'A37c',
			# TRANSLATORS: A37c: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nh6
			variation => N__('English: Symmetrical, 5. Nf3 Nh6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqk2r/pp1pppbp/2n3pn/2p5/2P5/2N2NP1/PP1PPPBP/R1BQ1RK1 b kq' => {
			eco => 'A37d',
			# TRANSLATORS: A37d: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nh6 6. O-O
			variation => N__('English: Symmetrical, 5. Nf3 Nh6 6.O-O'),
			moves => {
			},
		},
		'r1bqk1nr/pp2ppbp/2np2p1/2p5/2P5/2N2NP1/PP1PPPBP/R1BQK2R w KQkq' => {
			eco => 'A37e',
			# TRANSLATORS: A37e: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 d6
			variation => N__('English: Symmetrical, 5. Nf3 d6'),
			moves => {
				'd2d3' => 1,
				'e1g1' => 1,
			},
		},
		'r1bqk1nr/pp2ppbp/2np2p1/2p5/2P5/2NP1NP1/PP2PPBP/R1BQK2R b KQkq' => {
			eco => 'A37f',
			# TRANSLATORS: A37f: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 d6 6. d3
			variation => N__('English: Symmetrical, 5. Nf3 d6 6. d3'),
			moves => {
			},
		},
		'r1bqk1nr/pp2ppbp/2np2p1/2p5/2P5/2N2NP1/PP1PPPBP/R1BQ1RK1 b kq' => {
			eco => 'A37g',
			# TRANSLATORS: A37g: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 d6 6. O-O
			variation => N__('English: Symmetrical, 5. Nf3 d6 6.O-O'),
			moves => {
				'g8h6' => 1,
			},
		},
		'r1bqk2r/pp2ppbp/2np2pn/2p5/2P5/2N2NP1/PP1PPPBP/R1BQ1RK1 w kq' => {
			eco => 'A37h',
			# TRANSLATORS: A37h: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 d6 6. O-O Nh6
			variation => N__('English: Symmetrical, 5. Nf3 d6 6.O-O Nh6'),
			moves => {
			},
		},
		'r1bqk1nr/pp1p1pbp/2n1p1p1/2p5/2P5/2N2NP1/PP1PPPBP/R1BQK2R w KQkq' => {
			eco => 'A37i',
			# TRANSLATORS: A37i: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 e6
			variation => N__('English: Symmetrical, 5. Nf3 e6'),
			moves => {
				'd2d3' => 1,
				'e1g1' => 1,
				'e2e3' => 1,
			},
		},
		'r1bqk1nr/pp1p1pbp/2n1p1p1/2p5/2P5/2NP1NP1/PP2PPBP/R1BQK2R b KQkq' => {
			eco => 'A37j',
			# TRANSLATORS: A37j: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 e6 6. d3
			variation => N__('English: Symmetrical, 5. Nf3 e6 6. d3'),
			moves => {
			},
		},
		'r1bqk1nr/pp1p1pbp/2n1p1p1/2p5/2P5/2N1PNP1/PP1P1PBP/R1BQK2R b KQkq' => {
			eco => 'A37k',
			# TRANSLATORS: A37k: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 e6 6. e3
			variation => N__('English: Symmetrical, 5. Nf3 e6 6. e3'),
			moves => {
			},
		},
		'r1bqk1nr/pp1p1pbp/2n1p1p1/2p5/2P5/2N2NP1/PP1PPPBP/R1BQ1RK1 b kq' => {
			eco => 'A37l',
			# TRANSLATORS: A37l: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 e6 6. O-O
			variation => N__('English: Symmetrical, 5. Nf3 e6 6.O-O'),
			moves => {
				'g8e7' => 1,
			},
		},
		'r1bqk2r/pp1pnpbp/2n1p1p1/2p5/2P5/2N2NP1/PP1PPPBP/R1BQ1RK1 w kq' => {
			eco => 'A37l',
			# TRANSLATORS: A37l: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 e6 6. O-O Nge7
			variation => N__('English: Symmetrical, 5. Nf3 e6 6.O-O Nge7'),
			moves => {
				'd2d3' => 1,
				'e2e3' => 1,
			},
		},
		'r1bqk2r/pp1pnpbp/2n1p1p1/2p5/2P5/2N1PNP1/PP1P1PBP/R1BQ1RK1 b kq' => {
			eco => 'A37m',
			# TRANSLATORS: A37m: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 e6 6. O-O Nge7 7. e3
			variation => N__('English: Symmetrical, 5. Nf3 e6 6.O-O Nge7 7. e3'),
			moves => {
			},
		},
		'r1bqk2r/pp1pnpbp/2n1p1p1/2p5/2P5/2NP1NP1/PP2PPBP/R1BQ1RK1 b kq' => {
			eco => 'A37n',
			# TRANSLATORS: A37n: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 e6 6. O-O Nge7 7. d3
			variation => N__('English: Symmetrical, 5. Nf3 e6 6.O-O Nge7 7. d3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp1pnpbp/2n1p1p1/2p5/2P5/2NP1NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A37o',
			# TRANSLATORS: A37o: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 e6 6. O-O Nge7 7. d3 O-O
			variation => N__('English: Symmetrical, 5. Nf3 e6 6.O-O Nge7 7. d3 O-O'),
			moves => {
				'c1d2' => 1,
			},
		},
		'r1bq1rk1/pp1pnpbp/2n1p1p1/2p5/2P5/2NP1NP1/PP1BPPBP/R2Q1RK1 b -' => {
			eco => 'A37p',
			# TRANSLATORS: A37p: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 e6 6. O-O Nge7 7. d3 O-O 8. Bd2
			variation => N__('English: Symmetrical, 5. Nf3 e6 6.O-O Nge7 7. d3 O-O 8. Bd2'),
			moves => {
			},
		},
		'r1bqk1nr/pp1p1pbp/2n3p1/2p1p3/2P5/2N2NP1/PP1PPPBP/R1BQK2R w KQkq' => {
			eco => 'A37q',
			# TRANSLATORS: A37q: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 e5
			variation => N__('English: Symmetrical, 5. Nf3 e5'),
			moves => {
				'a2a3' => 1,
				'd2d3' => 1,
				'e1g1' => 1,
			},
		},
		'r1bqk1nr/pp1p1pbp/2n3p1/2p1p3/2P5/P1N2NP1/1P1PPPBP/R1BQK2R b KQkq' => {
			eco => 'A37r',
			# TRANSLATORS: A37r: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 e5 6. a3
			variation => N__('English: Symmetrical, 5. Nf3 e5 6. a3'),
			moves => {
			},
		},
		'r1bqk1nr/pp1p1pbp/2n3p1/2p1p3/2P5/2NP1NP1/PP2PPBP/R1BQK2R b KQkq' => {
			eco => 'A37s',
			# TRANSLATORS: A37s: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 e5 6. d3
			variation => N__('English: Symmetrical, 5. Nf3 e5 6. d3'),
			moves => {
				'g8e7' => 1,
			},
		},
		'r1bqk2r/pp1pnpbp/2n3p1/2p1p3/2P5/2NP1NP1/PP2PPBP/R1BQK2R w KQkq' => {
			eco => 'A37t',
			# TRANSLATORS: A37t: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 e5 6. d3 Nge7
			variation => N__('English: Symmetrical, 5. Nf3 e5 6. d3 Nge7'),
			moves => {
			},
		},
		'r1bqk1nr/pp1p1pbp/2n3p1/2p1p3/2P5/2N2NP1/PP1PPPBP/R1BQ1RK1 b kq' => {
			eco => 'A37u',
			# TRANSLATORS: A37u: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 e5 6. O-O
			variation => N__('English: Symmetrical, 5. Nf3 e5 6.O-O'),
			moves => {
				'd7d6' => 1,
				'g8e7' => 1,
			},
		},
		'r1bqk1nr/pp3pbp/2np2p1/2p1p3/2P5/2N2NP1/PP1PPPBP/R1BQ1RK1 w kq' => {
			eco => 'A37u',
			# TRANSLATORS: A37u: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 e5 6. O-O d6
			variation => N__('English: Symmetrical, 5. Nf3 e5 6.O-O d6'),
			moves => {
				'd2d3' => 1,
			},
		},
		'r1bqk1nr/pp3pbp/2np2p1/2p1p3/2P5/2NP1NP1/PP2PPBP/R1BQ1RK1 b kq' => {
			eco => 'A37v',
			# TRANSLATORS: A37v: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 e5 6. O-O d6 7. d3
			variation => N__('English: Symmetrical, 5. Nf3 e5 6.O-O d6 7. d3'),
			moves => {
				'g8e7' => 1,
			},
		},
		'r1bqk2r/pp2npbp/2np2p1/2p1p3/2P5/2NP1NP1/PP2PPBP/R1BQ1RK1 w kq' => {
			eco => 'A37v',
			# TRANSLATORS: A37v: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 e5 6. O-O d6 7. d3 Nge7
			variation => N__('English: Symmetrical, 5. Nf3 e5 6.O-O d6 7. d3 Nge7'),
			moves => {
				'a2a3' => 1,
			},
		},
		'r1bqk2r/pp2npbp/2np2p1/2p1p3/2P5/P1NP1NP1/1P2PPBP/R1BQ1RK1 b kq' => {
			eco => 'A37w',
			# TRANSLATORS: A37w: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 e5 6. O-O d6 7. d3 Nge7 8. a3
			variation => N__('English: Symmetrical, 5. Nf3 e5 6.O-O d6 7. d3 Nge7 8. a3'),
			moves => {
			},
		},
		'r1bqk2r/pp1pnpbp/2n3p1/2p1p3/2P5/2N2NP1/PP1PPPBP/R1BQ1RK1 w kq' => {
			eco => 'A37x',
			# TRANSLATORS: A37x: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 e5 6. O-O Nge7
			variation => N__('English: Symmetrical, 5. Nf3 e5 6.O-O Nge7'),
			moves => {
				'd2d3' => 1,
			},
		},
		'r1bqk2r/pp1pnpbp/2n3p1/2p1p3/2P5/2NP1NP1/PP2PPBP/R1BQ1RK1 b kq' => {
			eco => 'A37y',
			# TRANSLATORS: A37y: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 e5 6. O-O Nge7 7. d3
			variation => N__('English: Symmetrical, 5. Nf3 e5 6.O-O Nge7 7. d3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp1pnpbp/2n3p1/2p1p3/2P5/2NP1NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A37y',
			# TRANSLATORS: A37y: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 e5 6. O-O Nge7 7. d3 O-O
			variation => N__('English: Symmetrical, 5. Nf3 e5 6.O-O Nge7 7. d3 O-O'),
			moves => {
				'a2a3' => 1,
			},
		},
		'r1bq1rk1/pp1pnpbp/2n3p1/2p1p3/2P5/P1NP1NP1/1P2PPBP/R1BQ1RK1 b -' => {
			eco => 'A37y',
			# TRANSLATORS: A37y: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 e5 6. O-O Nge7 7. d3 O-O 8. a3
			variation => N__('English: Symmetrical, 5. Nf3 e5 6.O-O Nge7 7. d3 O-O 8. a3'),
			moves => {
			},
		},
		'r1bqk2r/pp1pppbp/2n2np1/2p5/2P5/2N2NP1/PP1PPPBP/R1BQK2R w KQkq' => {
			eco => 'A38a',
			# TRANSLATORS: A38a: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6
			variation => N__('English: Symmetrical, Main Line'),
			moves => {
				'd2d4' => 1,
				'e1g1' => 1,
			},
		},
		'r1bqk2r/pp1pppbp/2n2np1/2p5/2PP4/2N2NP1/PP2PPBP/R1BQK2R b KQkq' => {
			eco => 'A38b',
			# TRANSLATORS: A38b: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. d4
			variation => N__('English: Symmetrical, Main Line, 6. d4'),
			moves => {
			},
		},
		'r1bqk2r/pp1pppbp/2n2np1/2p5/2P5/2N2NP1/PP1PPPBP/R1BQ1RK1 b kq' => {
			eco => 'A38c',
			# TRANSLATORS: A38c: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O
			variation => N__('English: Symmetrical, Main Line, 6.O-O'),
			moves => {
				'd7d5' => 1,
				'd7d6' => 1,
				'e8g8' => 1,
			},
		},
		'r1bqk2r/pp2ppbp/2n2np1/2pp4/2P5/2N2NP1/PP1PPPBP/R1BQ1RK1 w kq' => {
			eco => 'A38d',
			# TRANSLATORS: A38d: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O d5
			variation => N__('English: Symmetrical, Main Line, 6.O-O d5'),
			moves => {
			},
		},
		'r1bqk2r/pp2ppbp/2np1np1/2p5/2P5/2N2NP1/PP1PPPBP/R1BQ1RK1 w kq' => {
			eco => 'A38e',
			# TRANSLATORS: A38e: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O d6
			variation => N__('English: Symmetrical, Main Line, 6.O-O d6'),
			moves => {
			},
		},
		'r1bq1rk1/pp1pppbp/2n2np1/2p5/2P5/2N2NP1/PP1PPPBP/R1BQ1RK1 w -' => {
			eco => 'A38f',
			# TRANSLATORS: A38f: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O O-O
			variation => N__('English: Symmetrical, Main Line, 6.O-O O-O'),
			moves => {
				'a1b1' => 1,
				'a2a3' => 1,
				'b2b3' => 1,
				'd2d3' => 1,
				'd2d4' => 1,
			},
		},
		'r1bq1rk1/pp1pppbp/2n2np1/2p5/2P5/2N2NP1/PP1PPPBP/1RBQ1RK1 b -' => {
			eco => 'A38g',
			# TRANSLATORS: A38g: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O O-O 7. Rb1
			variation => N__('English: Symmetrical, Main Line, 7. Rb1'),
			moves => {
			},
		},
		'r1bq1rk1/pp1pppbp/2n2np1/2p5/2P5/1PN2NP1/P2PPPBP/R1BQ1RK1 b -' => {
			eco => 'A38h',
			# TRANSLATORS: A38h: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O O-O 7. b3
			variation => N__('English: Symmetrical, Main Line, 7. b3'),
			moves => {
			},
		},
		'r1bq1rk1/pp1pppbp/2n2np1/2p5/2P5/P1N2NP1/1P1PPPBP/R1BQ1RK1 b -' => {
			eco => 'A38i',
			# TRANSLATORS: A38i: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O O-O 7. a3
			variation => N__('English: Symmetrical, Main Line, 7. a3'),
			moves => {
				'd7d6' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/2p5/2P5/P1N2NP1/1P1PPPBP/R1BQ1RK1 w -' => {
			eco => 'A38j',
			# TRANSLATORS: A38j: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O O-O 7. a3 d6
			variation => N__('English: Symmetrical, Main Line, 7. a3 d6'),
			moves => {
			},
		},
		'r1bq1rk1/pp1pppbp/2n2np1/2p5/2P5/2NP1NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'A38k',
			# TRANSLATORS: A38k: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O O-O 7. d3
			variation => N__('English: Symmetrical, Main Line, 7. d3'),
			moves => {
				'a7a6' => 1,
				'd7d5' => 1,
				'd7d6' => 1,
			},
		},
		'r1bq1rk1/1p1pppbp/p1n2np1/2p5/2P5/2NP1NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A38l',
			# TRANSLATORS: A38l: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O O-O 7. d3 a6
			variation => N__('English: Symmetrical, Main Line, 7. d3 a6'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/2n2np1/2pp4/2P5/2NP1NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A38m',
			# TRANSLATORS: A38m: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O O-O 7. d3 d5
			variation => N__('English: Symmetrical, Main Line, 7. d3 d5'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/2p5/2P5/2NP1NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A38n',
			# TRANSLATORS: A38n: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O O-O 7. d3 d6
			variation => N__('English: Symmetrical, Main Line, 7. d3 d6'),
			moves => {
				'a1b1' => 1,
				'a2a3' => 1,
				'c1d2' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/2p5/2P5/2NP1NP1/PP2PPBP/1RBQ1RK1 b -' => {
			eco => 'A38o',
			# TRANSLATORS: A38o: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O O-O 7. d3 d6 8. Rb1
			variation => N__('English: Symmetrical, Main Line, 7. d3 d6 8. Rb1'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/2p5/2P5/2NP1NP1/PP1BPPBP/R2Q1RK1 b -' => {
			eco => 'A38p',
			# TRANSLATORS: A38p: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O O-O 7. d3 d6 8. Bd2
			variation => N__('English: Symmetrical, Main Line, 7. d3 d6 8. Bd2'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/2p5/2P5/P1NP1NP1/1P2PPBP/R1BQ1RK1 b -' => {
			eco => 'A38q',
			# TRANSLATORS: A38q: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O O-O 7. d3 d6 8. a3
			variation => N__('English: Symmetrical, Main Line, 7. d3 d6 8. a3'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r1bq1rk1/1p2ppbp/p1np1np1/2p5/2P5/P1NP1NP1/1P2PPBP/R1BQ1RK1 w -' => {
			eco => 'A38r',
			# TRANSLATORS: A38r: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O O-O 7. d3 d6 8. a3 a6
			variation => N__('English: Symmetrical, Main Line, 7. d3 d6 8. a3 a6'),
			moves => {
			},
		},
		'r1bq1rk1/pp1pppbp/2n2np1/2p5/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'A39a',
			# TRANSLATORS: A39a: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O O-O 7. d4
			variation => N__('English: Symmetrical, Main Line 7. d4'),
			moves => {
				'c5d4' => 1,
			},
		},
		'r1bq1rk1/pp1pppbp/2n2np1/8/2Pp4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A39b',
			# TRANSLATORS: A39b: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O O-O 7. d4 cxd4
			variation => N__('English: Symmetrical, Main Line 7. d4'),
			moves => {
				'f3d4' => 1,
			},
		},
		'r1bq1rk1/pp1pppbp/2n2np1/8/2PN4/2N3P1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'A39c',
			# TRANSLATORS: A39c: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O O-O 7. d4 cxd4 8. Nxd4
			variation => N__('English: Symmetrical, Main Line 7. d4'),
			moves => {
				'a7a6' => 1,
				'c6d4' => 1,
				'd7d6' => 1,
				'd8a5' => 1,
				'd8b6' => 1,
				'f6g4' => 1,
			},
		},
		'r1b2rk1/pp1pppbp/2n2np1/q7/2PN4/2N3P1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A39d',
			# TRANSLATORS: A39d: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O O-O 7. d4 cxd4 8. Nxd4 Qa5
			variation => N__('English: Symmetrical, Main Line 7. d4, 8... Qa5'),
			moves => {
			},
		},
		'r1b2rk1/pp1pppbp/1qn2np1/8/2PN4/2N3P1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A39e',
			# TRANSLATORS: A39e: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O O-O 7. d4 cxd4 8. Nxd4 Qb6
			variation => N__('English: Symmetrical, Main Line 7. d4, 8... Qb6'),
			moves => {
				'd4c2' => 1,
			},
		},
		'r1b2rk1/pp1pppbp/1qn2np1/8/2P5/2N3P1/PPN1PPBP/R1BQ1RK1 b -' => {
			eco => 'A39e',
			# TRANSLATORS: A39e: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O O-O 7. d4 cxd4 8. Nxd4 Qb6 9. Nc2
			variation => N__('English: Symmetrical, Main Line 7. d4, 8... Qb6'),
			moves => {
			},
		},
		'r1bq1rk1/1p1pppbp/p1n2np1/8/2PN4/2N3P1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A39f',
			# TRANSLATORS: A39f: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O O-O 7. d4 cxd4 8. Nxd4 a6
			variation => N__('English: Symmetrical, Main Line 7. d4, 8... a6'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/8/2PN4/2N3P1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A39g',
			# TRANSLATORS: A39g: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O O-O 7. d4 cxd4 8. Nxd4 d6
			variation => N__('English: Symmetrical, Main Line 7. d4, 8... d6'),
			moves => {
			},
		},
		'r1bq1rk1/pp1pppbp/2n3p1/8/2PN2n1/2N3P1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A39h',
			# TRANSLATORS: A39h: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O O-O 7. d4 cxd4 8. Nxd4 Ng4
			variation => N__('English: Symmetrical, Main Line 7. d4, 8... Ng4'),
			moves => {
				'e2e3' => 1,
			},
		},
		'r1bq1rk1/pp1pppbp/2n3p1/8/2PN2n1/2N1P1P1/PP3PBP/R1BQ1RK1 b -' => {
			eco => 'A39h',
			# TRANSLATORS: A39h: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O O-O 7. d4 cxd4 8. Nxd4 Ng4 9. e3
			variation => N__('English: Symmetrical, Main Line 7. d4, 8... Ng4'),
			moves => {
				'd7d6' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2np2p1/8/2PN2n1/2N1P1P1/PP3PBP/R1BQ1RK1 w -' => {
			eco => 'A39i',
			# TRANSLATORS: A39i: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O O-O 7. d4 cxd4 8. Nxd4 Ng4 9. e3 d6
			variation => N__('English: Symmetrical, Main Line 7. d4, 8... Ng4 9. e3 d6'),
			moves => {
			},
		},
		'r1bq1rk1/pp1pppbp/5np1/8/2Pn4/2N3P1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A39j',
			# TRANSLATORS: A39j: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O O-O 7. d4 cxd4 8. Nxd4 Nxd4
			variation => N__('English: Symmetrical, Main Line 7. d4, 8...Nxd4'),
			moves => {
				'd1d4' => 1,
			},
		},
		'r1bq1rk1/pp1pppbp/5np1/8/2PQ4/2N3P1/PP2PPBP/R1B2RK1 b -' => {
			eco => 'A39j',
			# TRANSLATORS: A39j: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O O-O 7. d4 cxd4 8. Nxd4 Nxd4 9. Qxd4
			variation => N__('English: Symmetrical, Main Line 7. d4, 9.Qxd4'),
			moves => {
				'd7d6' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/3p1np1/8/2PQ4/2N3P1/PP2PPBP/R1B2RK1 w -' => {
			eco => 'A39k',
			# TRANSLATORS: A39k: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O O-O 7. d4 cxd4 8. Nxd4 Nxd4 9. Qxd4 d6
			variation => N__('English: Symmetrical, Main Line 7. d4, 9... d6'),
			moves => {
				'd4d2' => 1,
				'd4d3' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/3p1np1/8/2P5/2N3P1/PP1QPPBP/R1B2RK1 b -' => {
			eco => 'A39l',
			# TRANSLATORS: A39l: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O O-O 7. d4 cxd4 8. Nxd4 Nxd4 9. Qxd4 d6 10. Qd2
			variation => N__('English: Symmetrical, Main Line 7. d4, 10. Qd2'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/3p1np1/8/2P5/2NQ2P1/PP2PPBP/R1B2RK1 b -' => {
			eco => 'A39m',
			# TRANSLATORS: A39m: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O O-O 7. d4 cxd4 8. Nxd4 Nxd4 9. Qxd4 d6 10. Qd3
			variation => N__('English: Symmetrical, Main Line 7. d4, 10. Qd3'),
			moves => {
				'a7a6' => 1,
				'a8b8' => 1,
				'c8f5' => 1,
			},
		},
		'r2q1rk1/pp2ppbp/3p1np1/5b2/2P5/2NQ2P1/PP2PPBP/R1B2RK1 w -' => {
			eco => 'A39n',
			# TRANSLATORS: A39n: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O O-O 7. d4 cxd4 8. Nxd4 Nxd4 9. Qxd4 d6 10. Qd3 Bf5
			variation => N__('English: Symmetrical, Main Line 7. d4, 10. Qd3 Bf5'),
			moves => {
			},
		},
		'1rbq1rk1/pp2ppbp/3p1np1/8/2P5/2NQ2P1/PP2PPBP/R1B2RK1 w -' => {
			eco => 'A39o',
			# TRANSLATORS: A39o: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O O-O 7. d4 cxd4 8. Nxd4 Nxd4 9. Qxd4 d6 10. Qd3 Rb8
			variation => N__('English: Symmetrical, Main Line 7. d4, 10. Qd3 Rb8'),
			moves => {
			},
		},
		'r1bq1rk1/1p2ppbp/p2p1np1/8/2P5/2NQ2P1/PP2PPBP/R1B2RK1 w -' => {
			eco => 'A39p',
			# TRANSLATORS: A39p: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O O-O 7. d4 cxd4 8. Nxd4 Nxd4 9. Qxd4 d6 10. Qd3 a6
			variation => N__('English: Symmetrical, Main Line 7. d4, 10. Qd3 a6'),
			moves => {
				'c1d2' => 1,
			},
		},
		'r1bq1rk1/1p2ppbp/p2p1np1/8/2P5/2NQ2P1/PP1BPPBP/R4RK1 b -' => {
			eco => 'A39q',
			# TRANSLATORS: A39q: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O O-O 7. d4 cxd4 8. Nxd4 Nxd4 9. Qxd4 d6 10. Qd3 a6 11. Bd2
			variation => N__('English: Symmetrical, Main Line 7. d4, 10. Qd3 a6 11. Bd2'),
			moves => {
				'a8b8' => 1,
			},
		},
		'1rbq1rk1/1p2ppbp/p2p1np1/8/2P5/2NQ2P1/PP1BPPBP/R4RK1 w -' => {
			eco => 'A39q',
			# TRANSLATORS: A39q: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O O-O 7. d4 cxd4 8. Nxd4 Nxd4 9. Qxd4 d6 10. Qd3 a6 11. Bd2 Rb8
			variation => N__('English: Symmetrical, Main Line 7. d4, 10. Qd3 a6 11. Bd2 Rb8'),
			moves => {
				'a1c1' => 1,
			},
		},
		'1rbq1rk1/1p2ppbp/p2p1np1/8/2P5/2NQ2P1/PP1BPPBP/2R2RK1 b -' => {
			eco => 'A39r',
			# TRANSLATORS: A39r: 1. c4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nf3 Nf6 6. O-O O-O 7. d4 cxd4 8. Nxd4 Nxd4 9. Qxd4 d6 10. Qd3 a6 11. Bd2 Rb8 12. Rac1
			variation => N__('English: Symmetrical, Main Line 7. d4, 10. Qd3 a6 11. Bd2 Rb8 12.Rac1'),
			moves => {
			},
		},
		'rnbqkbnr/pppppppp/8/8/3P4/8/PPP1PPPP/RNBQKBNR b KQkq' => {
			eco => 'A40a',
			# TRANSLATORS: A40a: 1. d4
			variation => N__('Queen\'s Pawn Game'),
			moves => {
				'b7b5' => 1,
				'b7b6' => 1,
				'b8c6' => 1,
				'c7c5' => 1,
				'c7c6' => 1,
				'd7d5' => 1,
				'd7d6' => 1,
				'e7e5' => 1,
				'e7e6' => 1,
				'f7f5' => 1,
				'g7g6' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/pp1ppppp/2p5/8/3P4/8/PPP1PPPP/RNBQKBNR w KQkq' => {
			eco => 'A40b',
			# TRANSLATORS: A40b: 1. d4 c6
			variation => N__('Queen\'s Pawn: 1... c6'),
			moves => {
				'c2c4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pp1ppppp/2p5/8/2PP4/8/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'A40b',
			# TRANSLATORS: A40b: 1. d4 c6 2. c4
			variation => N__('Queen\'s Pawn: 1... c6 2. c4'),
			moves => {
				'b7b5' => 1,
			},
		},
		'rnbqkbnr/p2ppppp/2p5/1p6/2PP4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A40b',
			# TRANSLATORS: A40b: 1. d4 c6 2. c4 b5
			variation => N__('Queen\'s Pawn: Jadoul'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/2p5/8/3P4/5N2/PPP1PPPP/RNBQKB1R b KQkq' => {
			eco => 'A40b',
			# TRANSLATORS: A40b: 1. d4 c6 2. Nf3
			variation => N__('Queen\'s Pawn: 1... c6 2. Nf3'),
			moves => {
			},
		},
		'rnbqkbnr/p1pppppp/8/1p6/3P4/8/PPP1PPPP/RNBQKBNR w KQkq' => {
			eco => 'A40c',
			# TRANSLATORS: A40c: 1. d4 b5
			variation => N__('Queen\'s Pawn: Polish Defence'),
			moves => {
				'e2e4' => 1,
			},
		},
		'rnbqkbnr/p1pppppp/8/1p6/3PP3/8/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'A40c',
			# TRANSLATORS: A40c: 1. d4 b5 2. e4
			variation => N__('Queen\'s Pawn: Polish Defence'),
			moves => {
				'c8b7' => 1,
			},
		},
		'rn1qkbnr/pbpppppp/8/1p6/3PP3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'A40c',
			# TRANSLATORS: A40c: 1. d4 b5 2. e4 Bb7
			variation => N__('Queen\'s Pawn: Polish Defence'),
			moves => {
				'f1b5' => 1,
			},
		},
		'rn1qkbnr/pbpppppp/8/1B6/3PP3/8/PPP2PPP/RNBQK1NR b KQkq' => {
			eco => 'A40c',
			# TRANSLATORS: A40c: 1. d4 b5 2. e4 Bb7 3. Bxb5
			variation => N__('Queen\'s Pawn: Polish Defence, Spassky Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/p1pppppp/1p6/8/3P4/8/PPP1PPPP/RNBQKBNR w KQkq' => {
			eco => 'A40d',
			# TRANSLATORS: A40d: 1. d4 b6
			variation => N__('Queen\'s Pawn: English Defence'),
			moves => {
				'c2c4' => 1,
			},
		},
		'rnbqkbnr/p1pppppp/1p6/8/2PP4/8/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'A40d',
			# TRANSLATORS: A40d: 1. d4 b6 2. c4
			variation => N__('Queen\'s Pawn: English Defence, 2. c4'),
			moves => {
				'c8b7' => 1,
				'e7e6' => 1,
			},
		},
		'rn1qkbnr/pbpppppp/1p6/8/2PP4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A40d',
			# TRANSLATORS: A40d: 1. d4 b6 2. c4 Bb7
			variation => N__('Queen\'s Pawn: English Defence, 2. c4 Bb7'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rn1qkbnr/pbpppppp/1p6/8/2PP4/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'A40d',
			# TRANSLATORS: A40d: 1. d4 b6 2. c4 Bb7 3. Nc3
			variation => N__('Queen\'s Pawn: English Defence, 2. c4 Bb7'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rn1qkbnr/pbpp1ppp/1p2p3/8/2PP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'A40d',
			# TRANSLATORS: A40d: 1. d4 b6 2. c4 Bb7 3. Nc3 e6
			variation => N__('Queen\'s Pawn: English Defence, 2. c4 Bb7'),
			moves => {
				'e2e4' => 1,
			},
		},
		'rn1qkbnr/pbpp1ppp/1p2p3/8/2PPP3/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'A40d',
			# TRANSLATORS: A40d: 1. d4 b6 2. c4 Bb7 3. Nc3 e6 4. e4
			variation => N__('Queen\'s Pawn: English Defence, 2. c4 Bb7'),
			moves => {
				'f7f5' => 1,
			},
		},
		'rnbqkbnr/p1pp1ppp/1p2p3/8/2PP4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A40e',
			# TRANSLATORS: A40e: 1. d4 b6 2. c4 e6
			variation => N__('Queen\'s Pawn: English Defence, 2. c4 e6'),
			moves => {
				'a2a3' => 1,
				'b1c3' => 1,
				'e2e4' => 1,
			},
		},
		'rnbqkbnr/p1pp1ppp/1p2p3/8/2PP4/P7/1P2PPPP/RNBQKBNR b KQkq' => {
			eco => 'A40f',
			# TRANSLATORS: A40f: 1. d4 b6 2. c4 e6 3. a3
			variation => N__('Queen\'s Pawn: English Defence, 3. a3'),
			moves => {
			},
		},
		'rn1qkbnr/pbpp2pp/1p2p3/5p2/2PPP3/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'A40g',
			# TRANSLATORS: A40g: 1. d4 b6 2. c4 Bb7 3. Nc3 e6 4. e4 f5
			variation => N__('Queen\'s Pawn: English Defence, Hartlaub Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/p1pp1ppp/1p2p3/8/2PPP3/8/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'A40g',
			# TRANSLATORS: A40g: 1. d4 b6 2. c4 e6 3. e4
			variation => N__('Queen\'s Pawn: English Defence, 3. e4'),
			moves => {
				'c8b7' => 1,
			},
		},
		'rn1qkbnr/pbpp1ppp/1p2p3/8/2PPP3/8/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'A40g',
			# TRANSLATORS: A40g: 1. d4 b6 2. c4 e6 3. e4 Bb7
			variation => N__('Queen\'s Pawn: English Defence, 3. e4'),
			moves => {
				'f2f3' => 1,
			},
		},
		'rn1qkbnr/pbpp1ppp/1p2p3/8/2PPP3/5P2/PP4PP/RNBQKBNR b KQkq' => {
			eco => 'A40g',
			# TRANSLATORS: A40g: 1. d4 b6 2. c4 e6 3. e4 Bb7 4. f3
			variation => N__('Queen\'s Pawn: English Defence, 3. e4'),
			moves => {
				'f7f5' => 1,
			},
		},
		'rn1qkbnr/pbpp2pp/1p2p3/5p2/2PPP3/5P2/PP4PP/RNBQKBNR w KQkq' => {
			eco => 'A40g',
			# TRANSLATORS: A40g: 1. d4 b6 2. c4 e6 3. e4 Bb7 4. f3 f5
			variation => N__('Queen\'s Pawn: English Defence, Polli Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/p1pp1ppp/1p2p3/8/2PP4/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'A40h',
			# TRANSLATORS: A40h: 1. d4 b6 2. c4 e6 3. Nc3
			variation => N__('Queen\'s Pawn: English Defence, 3. Nc3'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/4p3/3P4/8/PPP1PPPP/RNBQKBNR w KQkq' => {
			eco => 'A40i',
			# TRANSLATORS: A40i: 1. d4 e5
			variation => N__('Englund Gambit'),
			moves => {
				'd4e5' => 1,
			},
		},
		'rnbqkbnr/pppp1ppp/8/4P3/8/8/PPP1PPPP/RNBQKBNR b KQkq' => {
			eco => 'A40i',
			# TRANSLATORS: A40i: 1. d4 e5 2. dxe5
			variation => N__('Englund Gambit Accepted'),
			moves => {
				'b8c6' => 1,
				'd7d6' => 1,
				'f7f6' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4P3/8/8/PPP1PPPP/RNBQKBNR w KQkq' => {
			eco => 'A40i',
			# TRANSLATORS: A40i: 1. d4 e5 2. dxe5 Nc6
			variation => N__('Englund Gambit: 2.dxe5 Nc6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4P3/8/5N2/PPP1PPPP/RNBQKB1R b KQkq' => {
			eco => 'A40i',
			# TRANSLATORS: A40i: 1. d4 e5 2. dxe5 Nc6 3. Nf3
			variation => N__('Englund Gambit: 2.dxe5 Nc6 3. Nf3'),
			moves => {
				'd8e7' => 1,
				'f7f6' => 1,
				'g8e7' => 1,
			},
		},
		'r1b1kbnr/ppppqppp/2n5/4P3/8/5N2/PPP1PPPP/RNBQKB1R w KQkq' => {
			eco => 'A40i',
			# TRANSLATORS: A40i: 1. d4 e5 2. dxe5 Nc6 3. Nf3 Qe7
			variation => N__('Englund Gambit: 2.dxe5 Nc6 3. Nf3 Qe7'),
			moves => {
			},
		},
		'r1bqkbnr/pppp2pp/2n2p2/4P3/8/5N2/PPP1PPPP/RNBQKB1R w KQkq' => {
			eco => 'A40i',
			# TRANSLATORS: A40i: 1. d4 e5 2. dxe5 Nc6 3. Nf3 f6
			variation => N__('Englund Gambit: Soller Deferred'),
			moves => {
			},
		},
		'r1bqkb1r/ppppnppp/2n5/4P3/8/5N2/PPP1PPPP/RNBQKB1R w KQkq' => {
			eco => 'A40i',
			# TRANSLATORS: A40i: 1. d4 e5 2. dxe5 Nc6 3. Nf3 Nge7
			variation => N__('Englund Gambit: Zilbermints'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/3p4/4P3/8/8/PPP1PPPP/RNBQKBNR w KQkq' => {
			eco => 'A40i',
			# TRANSLATORS: A40i: 1. d4 e5 2. dxe5 d6
			variation => N__('Englund Gambit: Hartlaub'),
			moves => {
			},
		},
		'rnbqkbnr/pppp2pp/5p2/4P3/8/8/PPP1PPPP/RNBQKBNR w KQkq' => {
			eco => 'A40i',
			# TRANSLATORS: A40i: 1. d4 e5 2. dxe5 f6
			variation => N__('Englund Gambit: Soller'),
			moves => {
			},
		},
		'r1bqkbnr/pppppppp/2n5/8/3P4/8/PPP1PPPP/RNBQKBNR w KQkq' => {
			eco => 'A40j',
			# TRANSLATORS: A40j: 1. d4 Nc6
			variation => N__('Queen\'s Pawn: Bogoljubow-Miles Defence'),
			moves => {
				'c1g5' => 1,
				'c2c4' => 1,
				'd4d5' => 1,
				'g1f3' => 1,
			},
		},
		'r1bqkbnr/pppppppp/2n5/6B1/3P4/8/PPP1PPPP/RN1QKBNR b KQkq' => {
			eco => 'A40j',
			# TRANSLATORS: A40j: 1. d4 Nc6 2. Bg5
			variation => N__('Queen\'s Pawn: Bogoljubow-Miles, 2. Bg5'),
			moves => {
			},
		},
		'r1bqkbnr/pppppppp/2n5/3P4/8/8/PPP1PPPP/RNBQKBNR b KQkq' => {
			eco => 'A40j',
			# TRANSLATORS: A40j: 1. d4 Nc6 2. d5
			variation => N__('Queen\'s Pawn: Bogoljubow-Miles, 2. d5'),
			moves => {
			},
		},
		'r1bqkbnr/pppppppp/2n5/8/2PP4/8/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'A40k',
			# TRANSLATORS: A40k: 1. d4 Nc6 2. c4
			variation => N__('Queen\'s Pawn: Bogoljubow-Miles, 2. c4'),
			moves => {
				'e7e5' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4p3/2PP4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A40k',
			# TRANSLATORS: A40k: 1. d4 Nc6 2. c4 e5
			variation => N__('Queen\'s Pawn: Bogoljubow-Miles, 2. c4'),
			moves => {
				'd4e5' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4P3/2P5/8/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'A40k',
			# TRANSLATORS: A40k: 1. d4 Nc6 2. c4 e5 3. dxe5
			variation => N__('Queen\'s Pawn: Bogoljubow-Miles, 2. c4'),
			moves => {
				'c6e5' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/8/4n3/2P5/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A40k',
			# TRANSLATORS: A40k: 1. d4 Nc6 2. c4 e5 3. dxe5 Nxe5
			variation => N__('Queen\'s Pawn: Bogoljubow-Miles, 2. c4'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/8/4n3/2P5/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'A40k',
			# TRANSLATORS: A40k: 1. d4 Nc6 2. c4 e5 3. dxe5 Nxe5 4. Nc3
			variation => N__('Queen\'s Pawn: Bogoljubow-Miles, 2. c4'),
			moves => {
				'e5c4' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/8/8/2n5/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'A40k',
			# TRANSLATORS: A40k: 1. d4 Nc6 2. c4 e5 3. dxe5 Nxe5 4. Nc3 Nxc4
			variation => N__('Queen\'s Pawn: Bogoljubow-Miles, Pozarek Gambit'),
			moves => {
			},
		},
		'r1bqkbnr/pppppppp/2n5/8/3P4/5N2/PPP1PPPP/RNBQKB1R b KQkq' => {
			eco => 'A40l',
			# TRANSLATORS: A40l: 1. d4 Nc6 2. Nf3
			variation => N__('Queen\'s Pawn: Bogoljubow-Miles, 2. Nf3'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/4p3/8/3P4/8/PPP1PPPP/RNBQKBNR w KQkq' => {
			eco => 'A40m',
			# TRANSLATORS: A40m: 1. d4 e6
			variation => N__('Queen\'s Pawn: 1... e6'),
			moves => {
				'c2c4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pppp1ppp/4p3/8/3P4/5N2/PPP1PPPP/RNBQKB1R b KQkq' => {
			eco => 'A40n',
			# TRANSLATORS: A40n: 1. d4 e6 2. Nf3
			variation => N__('Queen\'s Pawn: 1... e6 2. Nf3'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqkbnr/pp1p1ppp/4p3/2p5/3P4/5N2/PPP1PPPP/RNBQKB1R w KQkq' => {
			eco => 'A40n',
			# TRANSLATORS: A40n: 1. d4 e6 2. Nf3 c5
			variation => N__('Queen\'s Pawn: 1... e6 2. Nf3 c5'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/4p3/8/2PP4/8/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'A40o',
			# TRANSLATORS: A40o: 1. d4 e6 2. c4
			variation => N__('Queen\'s Pawn: 1... e6 2. c4'),
			moves => {
				'f8b4' => 1,
			},
		},
		'rnbqk1nr/pppp1ppp/4p3/8/1bPP4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A40p',
			# TRANSLATORS: A40p: 1. d4 e6 2. c4 Bb4+
			variation => N__('Queen\'s Pawn: Keres Defence'),
			moves => {
				'c1d2' => 1,
			},
		},
		'rnbqk1nr/pppp1ppp/4p3/8/1bPP4/8/PP1BPPPP/RN1QKBNR b KQkq' => {
			eco => 'A40q',
			# TRANSLATORS: A40q: 1. d4 e6 2. c4 Bb4+ 3. Bd2
			variation => N__('Queen\'s Pawn: Keres Defence, 3. Bd2'),
			moves => {
				'a7a5' => 1,
				'b4d2' => 1,
			},
		},
		'rnbqk1nr/pppp1ppp/4p3/8/2PP4/8/PP1bPPPP/RN1QKBNR w KQkq' => {
			eco => 'A40q',
			# TRANSLATORS: A40q: 1. d4 e6 2. c4 Bb4+ 3. Bd2 Bxd2+
			variation => N__('Queen\'s Pawn: Keres Defence, 3. Bd2 Bxd2+'),
			moves => {
				'd1d2' => 1,
			},
		},
		'rnbqk1nr/pppp1ppp/4p3/8/2PP4/8/PP1QPPPP/RN2KBNR b KQkq' => {
			eco => 'A40q',
			# TRANSLATORS: A40q: 1. d4 e6 2. c4 Bb4+ 3. Bd2 Bxd2+ 4. Qxd2
			variation => N__('Queen\'s Pawn: Keres Defence, 3. Bd2 Bxd2+'),
			moves => {
				'b7b6' => 1,
			},
		},
		'rnbqk1nr/p1pp1ppp/1p2p3/8/2PP4/8/PP1QPPPP/RN2KBNR w KQkq' => {
			eco => 'A40q',
			# TRANSLATORS: A40q: 1. d4 e6 2. c4 Bb4+ 3. Bd2 Bxd2+ 4. Qxd2 b6
			variation => N__('Queen\'s Pawn: Keres Defence, 3. Bd2 Bxd2+'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqk1nr/p1pp1ppp/1p2p3/8/2PP4/2N5/PP1QPPPP/R3KBNR b KQkq' => {
			eco => 'A40q',
			# TRANSLATORS: A40q: 1. d4 e6 2. c4 Bb4+ 3. Bd2 Bxd2+ 4. Qxd2 b6 5. Nc3
			variation => N__('Queen\'s Pawn: Keres Defence, 3. Bd2 Bxd2+'),
			moves => {
				'c8b7' => 1,
			},
		},
		'rn1qk1nr/pbpp1ppp/1p2p3/8/2PP4/2N5/PP1QPPPP/R3KBNR w KQkq' => {
			eco => 'A40q',
			# TRANSLATORS: A40q: 1. d4 e6 2. c4 Bb4+ 3. Bd2 Bxd2+ 4. Qxd2 b6 5. Nc3 Bb7
			variation => N__('Queen\'s Pawn: Keres Defence, 3. Bd2 Bxd2+'),
			moves => {
				'e2e4' => 1,
			},
		},
		'rn1qk1nr/pbpp1ppp/1p2p3/8/2PPP3/2N5/PP1Q1PPP/R3KBNR b KQkq' => {
			eco => 'A40q',
			# TRANSLATORS: A40q: 1. d4 e6 2. c4 Bb4+ 3. Bd2 Bxd2+ 4. Qxd2 b6 5. Nc3 Bb7 6. e4
			variation => N__('Queen\'s Pawn: Keres Defence, 3. Bd2 Bxd2+'),
			moves => {
				'g8h6' => 1,
			},
		},
		'rn1qk2r/pbpp1ppp/1p2p2n/8/2PPP3/2N5/PP1Q1PPP/R3KBNR w KQkq' => {
			eco => 'A40q',
			# TRANSLATORS: A40q: 1. d4 e6 2. c4 Bb4+ 3. Bd2 Bxd2+ 4. Qxd2 b6 5. Nc3 Bb7 6. e4 Nh6
			variation => N__('Queen\'s Pawn: Keres Defence, Kangaroo Variation'),
			moves => {
			},
		},
		'rnbqk1nr/1ppp1ppp/4p3/p7/1bPP4/8/PP1BPPPP/RN1QKBNR w KQkq' => {
			eco => 'A40r',
			# TRANSLATORS: A40r: 1. d4 e6 2. c4 Bb4+ 3. Bd2 a5
			variation => N__('Queen\'s Pawn: Keres Defence, 3. Bd2 a5'),
			moves => {
			},
		},
		'rnbqkbnr/pppppp1p/6p1/8/3P4/8/PPP1PPPP/RNBQKBNR w KQkq' => {
			eco => 'A40s',
			# TRANSLATORS: A40s: 1. d4 g6
			variation => N__('Queen\'s Pawn: Modern'),
			moves => {
				'c2c4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pppppp1p/6p1/8/3P4/5N2/PPP1PPPP/RNBQKB1R b KQkq' => {
			eco => 'A40t',
			# TRANSLATORS: A40t: 1. d4 g6 2. Nf3
			variation => N__('Queen\'s Pawn: Modern'),
			moves => {
			},
		},
		'rnbqkbnr/pppppp1p/6p1/8/2PP4/8/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'A40u',
			# TRANSLATORS: A40u: 1. d4 g6 2. c4
			variation => N__('Queen\'s Pawn: Modern'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk1nr/ppppppbp/6p1/8/2PP4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A40u',
			# TRANSLATORS: A40u: 1. d4 g6 2. c4 Bg7
			variation => N__('Queen\'s Pawn: Modern'),
			moves => {
				'b1c3' => 1,
				'e2e4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqk1nr/ppppppbp/6p1/8/2PPP3/8/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'A40v',
			# TRANSLATORS: A40v: 1. d4 g6 2. c4 Bg7 3. e4
			variation => N__('Queen\'s Pawn: Modern'),
			moves => {
			},
		},
		'rnbqk1nr/ppppppbp/6p1/8/2PP4/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'A40w',
			# TRANSLATORS: A40w: 1. d4 g6 2. c4 Bg7 3. Nf3
			variation => N__('Queen\'s Pawn: Modern'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqk1nr/pp1pppbp/6p1/2p5/2PP4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A40w',
			# TRANSLATORS: A40w: 1. d4 g6 2. c4 Bg7 3. Nf3 c5
			variation => N__('Queen\'s Pawn: Modern'),
			moves => {
			},
		},
		'rnbqk1nr/ppppppbp/6p1/8/2PP4/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'A40x',
			# TRANSLATORS: A40x: 1. d4 g6 2. c4 Bg7 3. Nc3
			variation => N__('Queen\'s Pawn: Modern'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqk1nr/pp1pppbp/6p1/2p5/2PP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'A40x',
			# TRANSLATORS: A40x: 1. d4 g6 2. c4 Bg7 3. Nc3 c5
			variation => N__('Queen\'s Pawn: Modern'),
			moves => {
				'd4d5' => 1,
			},
		},
		'rnbqk1nr/pp1pppbp/6p1/2pP4/2P5/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'A40x',
			# TRANSLATORS: A40x: 1. d4 g6 2. c4 Bg7 3. Nc3 c5 4. d5
			variation => N__('Queen\'s Pawn: Modern'),
			moves => {
				'g7c3' => 1,
			},
		},
		'rnbqk1nr/pp1ppp1p/6p1/2pP4/2P5/2b5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'A40x',
			# TRANSLATORS: A40x: 1. d4 g6 2. c4 Bg7 3. Nc3 c5 4. d5 Bxc3+
			variation => N__('Queen\'s Pawn: Modern'),
			moves => {
				'b2c3' => 1,
			},
		},
		'rnbqk1nr/pp1ppp1p/6p1/2pP4/2P5/2P5/P3PPPP/R1BQKBNR b KQkq' => {
			eco => 'A40x',
			# TRANSLATORS: A40x: 1. d4 g6 2. c4 Bg7 3. Nc3 c5 4. d5 Bxc3+ 5. bxc3
			variation => N__('Queen\'s Pawn: Modern'),
			moves => {
				'f7f5' => 1,
			},
		},
		'rnbqk1nr/pp1pp2p/6p1/2pP1p2/2P5/2P5/P3PPPP/R1BQKBNR w KQkq' => {
			eco => 'A40y',
			# TRANSLATORS: A40y: 1. d4 g6 2. c4 Bg7 3. Nc3 c5 4. d5 Bxc3+ 5. bxc3 f5
			variation => N__('Queen\'s Pawn: Modern, Beefeater Defence'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/3p4/8/3P4/8/PPP1PPPP/RNBQKBNR w KQkq' => {
			eco => 'A41a',
			# TRANSLATORS: A41a: 1. d4 d6
			variation => N__('Neo-Old Indian'),
			moves => {
				'c1g5' => 1,
				'c2c4' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/ppp1pppp/3p4/6B1/3P4/8/PPP1PPPP/RN1QKBNR b KQkq' => {
			eco => 'A41b',
			# TRANSLATORS: A41b: 1. d4 d6 2. Bg5
			variation => N__('Neo-Old Indian: 2. Bg5'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/3p4/8/3P4/6P1/PPP1PP1P/RNBQKBNR b KQkq' => {
			eco => 'A41c',
			# TRANSLATORS: A41c: 1. d4 d6 2. g3
			variation => N__('Neo-Old Indian: 2. g3'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/3p4/8/3P4/5N2/PPP1PPPP/RNBQKB1R b KQkq' => {
			eco => 'A41d',
			# TRANSLATORS: A41d: 1. d4 d6 2. Nf3
			variation => N__('Neo-Old Indian: 2. Nf3'),
			moves => {
				'c8g4' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkbnr/ppp1pp1p/3p2p1/8/3P4/5N2/PPP1PPPP/RNBQKB1R w KQkq' => {
			eco => 'A41e',
			# TRANSLATORS: A41e: 1. d4 d6 2. Nf3 g6
			variation => N__('Neo-Old Indian / Modern'),
			moves => {
				'c1f4' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/ppp1pp1p/3p2p1/8/3P1B2/5N2/PPP1PPPP/RN1QKB1R b KQkq' => {
			eco => 'A41e',
			# TRANSLATORS: A41e: 1. d4 d6 2. Nf3 g6 3. Bf4
			variation => N__('Neo-Old Indian / Modern: 3. Bf4'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk1nr/ppp1ppbp/3p2p1/8/3P1B2/5N2/PPP1PPPP/RN1QKB1R w KQkq' => {
			eco => 'A41e',
			# TRANSLATORS: A41e: 1. d4 d6 2. Nf3 g6 3. Bf4 Bg7
			variation => N__('Neo-Old Indian / Modern: 3. Bf4'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pp1p/3p2p1/8/3P4/5NP1/PPP1PP1P/RNBQKB1R b KQkq' => {
			eco => 'A41e',
			# TRANSLATORS: A41e: 1. d4 d6 2. Nf3 g6 3. g3
			variation => N__('Neo-Old Indian / Modern: 3. g3'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk1nr/ppp1ppbp/3p2p1/8/3P4/5NP1/PPP1PP1P/RNBQKB1R w KQkq' => {
			eco => 'A41e',
			# TRANSLATORS: A41e: 1. d4 d6 2. Nf3 g6 3. g3 Bg7
			variation => N__('Neo-Old Indian / Modern: 3. g3'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqk1nr/ppp1ppbp/3p2p1/8/3P4/5NP1/PPP1PPBP/RNBQK2R b KQkq' => {
			eco => 'A41e',
			# TRANSLATORS: A41e: 1. d4 d6 2. Nf3 g6 3. g3 Bg7 4. Bg2
			variation => N__('Neo-Old Indian / Modern: 3. g3'),
			moves => {
			},
		},
		'rn1qkbnr/ppp1pppp/3p4/8/3P2b1/5N2/PPP1PPPP/RNBQKB1R w KQkq' => {
			eco => 'A41f',
			# TRANSLATORS: A41f: 1. d4 d6 2. Nf3 Bg4
			variation => N__('Neo-Old Indian: Wade Defence'),
			moves => {
				'c2c4' => 1,
				'e2e3' => 1,
				'e2e4' => 1,
			},
		},
		'rn1qkbnr/ppp1pppp/3p4/8/3P2b1/4PN2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'A41f',
			# TRANSLATORS: A41f: 1. d4 d6 2. Nf3 Bg4 3. e3
			variation => N__('Neo-Old Indian: Wade Defence, 3. e3'),
			moves => {
				'b8d7' => 1,
				'g8f6' => 1,
			},
		},
		'r2qkbnr/pppnpppp/3p4/8/3P2b1/4PN2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'A41f',
			# TRANSLATORS: A41f: 1. d4 d6 2. Nf3 Bg4 3. e3 Nd7
			variation => N__('Neo-Old Indian: Wade Defence, 3. e3 Nd7'),
			moves => {
			},
		},
		'rn1qkb1r/ppp1pppp/3p1n2/8/3P2b1/4PN2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'A41f',
			# TRANSLATORS: A41f: 1. d4 d6 2. Nf3 Bg4 3. e3 Nf6
			variation => N__('Neo-Old Indian: Wade Defence, 3. e3 Nf6'),
			moves => {
			},
		},
		'rn1qkbnr/ppp1pppp/3p4/8/2PP2b1/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'A41g',
			# TRANSLATORS: A41g: 1. d4 d6 2. Nf3 Bg4 3. c4
			variation => N__('Neo-Old Indian: Wade Defence, 3. c4'),
			moves => {
				'b8d7' => 1,
				'e7e5' => 1,
				'g4f3' => 1,
			},
		},
		'rn1qkbnr/ppp2ppp/3p4/4p3/2PP2b1/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A41g',
			# TRANSLATORS: A41g: 1. d4 d6 2. Nf3 Bg4 3. c4 e5
			variation => N__('Neo-Old Indian: Wade Defence, 3. c4 e5'),
			moves => {
				'b1c3' => 1,
				'd4e5' => 1,
			},
		},
		'rn1qkbnr/ppp2ppp/3p4/4p3/2PP2b1/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'A41g',
			# TRANSLATORS: A41g: 1. d4 d6 2. Nf3 Bg4 3. c4 e5 4. Nc3
			variation => N__('Neo-Old Indian: Wade Defence, 3. c4 e5 4. Nc3'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r2qkbnr/ppp2ppp/2np4/4p3/2PP2b1/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'A41g',
			# TRANSLATORS: A41g: 1. d4 d6 2. Nf3 Bg4 3. c4 e5 4. Nc3 Nc6
			variation => N__('Neo-Old Indian: Wade Defence, 3. c4 e5 4. Nc3 Nc6'),
			moves => {
			},
		},
		'rn1qkbnr/ppp2ppp/3p4/4P3/2P3b1/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'A41g',
			# TRANSLATORS: A41g: 1. d4 d6 2. Nf3 Bg4 3. c4 e5 4. dxe5
			variation => N__('Neo-Old Indian: Wade Defence, 3. c4 e5 4.dxe5'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r2qkbnr/ppp2ppp/2np4/4P3/2P3b1/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A41g',
			# TRANSLATORS: A41g: 1. d4 d6 2. Nf3 Bg4 3. c4 e5 4. dxe5 Nc6
			variation => N__('Neo-Old Indian: Wade Defence, 3. c4 e5 4.dxe5 Nc6 Gambit'),
			moves => {
			},
		},
		'r2qkbnr/pppnpppp/3p4/8/2PP2b1/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A41h',
			# TRANSLATORS: A41h: 1. d4 d6 2. Nf3 Bg4 3. c4 Nd7
			variation => N__('Neo-Old Indian: Wade Defence, 3. c4 Nd7'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r2qkbnr/pppnpppp/3p4/8/2PP2b1/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'A41h',
			# TRANSLATORS: A41h: 1. d4 d6 2. Nf3 Bg4 3. c4 Nd7 4. Nc3
			variation => N__('Neo-Old Indian: Wade Defence, 3. c4 Nd7 4. Nc3'),
			moves => {
				'e7e5' => 1,
			},
		},
		'r2qkbnr/pppn1ppp/3p4/4p3/2PP2b1/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'A41h',
			# TRANSLATORS: A41h: 1. d4 d6 2. Nf3 Bg4 3. c4 Nd7 4. Nc3 e5
			variation => N__('Neo-Old Indian: Wade Defence, 3. c4 Nd7 4. Nc3 e5'),
			moves => {
			},
		},
		'rn1qkbnr/ppp1pppp/3p4/8/2PP4/5b2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A41i',
			# TRANSLATORS: A41i: 1. d4 d6 2. Nf3 Bg4 3. c4 Bxf3
			variation => N__('Neo-Old Indian: Wade Defence, 3. c4 Bxf3'),
			moves => {
			},
		},
		'rn1qkbnr/ppp1pppp/3p4/8/3PP1b1/5N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'A41j',
			# TRANSLATORS: A41j: 1. d4 d6 2. Nf3 Bg4 3. e4
			variation => N__('Neo-Old Indian: Wade Defence, 3. e4'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rn1qkb1r/ppp1pppp/3p1n2/8/3PP1b1/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'A41k',
			# TRANSLATORS: A41k: 1. d4 d6 2. Nf3 Bg4 3. e4 Nf6
			variation => N__('Neo-Old Indian: Wade Defence, 3. e4 Nf6'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/3p4/8/2PP4/8/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'A41l',
			# TRANSLATORS: A41l: 1. d4 d6 2. c4
			variation => N__('Neo-Old Indian: 2. c4'),
			moves => {
				'e7e5' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/3p4/4p3/2PP4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A41m',
			# TRANSLATORS: A41m: 1. d4 d6 2. c4 e5
			variation => N__('Neo-Old Indian: 2. c4 e5'),
			moves => {
				'd4d5' => 1,
				'd4e5' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/3p4/3Pp3/2P5/8/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'A41n',
			# TRANSLATORS: A41n: 1. d4 d6 2. c4 e5 3. d5
			variation => N__('Neo-Old Indian: 2. c4 e5 3. d5'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/3p4/4P3/2P5/8/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'A41o',
			# TRANSLATORS: A41o: 1. d4 d6 2. c4 e5 3. dxe5
			variation => N__('Neo-Old Indian: 2. c4 e5 3.dxe5'),
			moves => {
				'd6e5' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/8/4p3/2P5/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A41o',
			# TRANSLATORS: A41o: 1. d4 d6 2. c4 e5 3. dxe5 dxe5
			variation => N__('Neo-Old Indian: 2. c4 e5 3.dxe5'),
			moves => {
				'd1d8' => 1,
			},
		},
		'rnbQkbnr/ppp2ppp/8/4p3/2P5/8/PP2PPPP/RNB1KBNR b KQkq' => {
			eco => 'A41o',
			# TRANSLATORS: A41o: 1. d4 d6 2. c4 e5 3. dxe5 dxe5 4. Qxd8+
			variation => N__('Neo-Old Indian: 2. c4 e5 3.dxe5'),
			moves => {
				'e8d8' => 1,
			},
		},
		'rnbk1bnr/ppp2ppp/8/4p3/2P5/8/PP2PPPP/RNB1KBNR w KQ' => {
			eco => 'A41o',
			# TRANSLATORS: A41o: 1. d4 d6 2. c4 e5 3. dxe5 dxe5 4. Qxd8+ Kxd8
			variation => N__('Neo-Old Indian: Queenswap'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/3p4/4p3/2PP4/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'A41p',
			# TRANSLATORS: A41p: 1. d4 d6 2. c4 e5 3. Nf3
			variation => N__('Neo-Old Indian: 2. c4 e5 3. Nf3'),
			moves => {
				'e5e4' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/3p4/8/2PPp3/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A41p',
			# TRANSLATORS: A41p: 1. d4 d6 2. c4 e5 3. Nf3 e4
			variation => N__('Neo-Old Indian: 2. c4 e5 3. Nf3 e4'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pp1p/3p2p1/8/2PP4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A41q',
			# TRANSLATORS: A41q: 1. d4 d6 2. c4 g6
			variation => N__('Neo-Old Indian: Modern'),
			moves => {
				'b1c3' => 1,
				'e2e4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/ppp1pp1p/3p2p1/8/2PPP3/8/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'A41q',
			# TRANSLATORS: A41q: 1. d4 d6 2. c4 g6 3. e4
			variation => N__('Neo-Old Indian: Modern, 3. e4'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk1nr/ppp1ppbp/3p2p1/8/2PPP3/8/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'A41q',
			# TRANSLATORS: A41q: 1. d4 d6 2. c4 g6 3. e4 Bg7
			variation => N__('Neo-Old Indian: Modern, 3. e4 Bg7'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pp1p/3p2p1/8/2PP4/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'A41r',
			# TRANSLATORS: A41r: 1. d4 d6 2. c4 g6 3. Nf3
			variation => N__('Neo-Old Indian: Modern, 3. Nf3'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk1nr/ppp1ppbp/3p2p1/8/2PP4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A41r',
			# TRANSLATORS: A41r: 1. d4 d6 2. c4 g6 3. Nf3 Bg7
			variation => N__('Neo-Old Indian: Modern, 3. Nf3 Bg7'),
			moves => {
				'e2e4' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqk1nr/ppp1ppbp/3p2p1/8/2PP4/5NP1/PP2PP1P/RNBQKB1R b KQkq' => {
			eco => 'A41r',
			# TRANSLATORS: A41r: 1. d4 d6 2. c4 g6 3. Nf3 Bg7 4. g3
			variation => N__('Neo-Old Indian: Modern, 3. Nf3 Bg7 4. g3'),
			moves => {
			},
		},
		'rnbqk1nr/ppp1ppbp/3p2p1/8/2PPP3/5N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'A41s',
			# TRANSLATORS: A41s: 1. d4 d6 2. c4 g6 3. Nf3 Bg7 4. e4
			variation => N__('Neo-Old Indian: Modern, 3. Nf3 Bg7 4. e4'),
			moves => {
				'c8g4' => 1,
			},
		},
		'rn1qk1nr/ppp1ppbp/3p2p1/8/2PPP1b1/5N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'A41s',
			# TRANSLATORS: A41s: 1. d4 d6 2. c4 g6 3. Nf3 Bg7 4. e4 Bg4
			variation => N__('Neo-Old Indian: Modern, Rossolimo Variation'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pp1p/3p2p1/8/2PP4/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'A41t',
			# TRANSLATORS: A41t: 1. d4 d6 2. c4 g6 3. Nc3
			variation => N__('Neo-Old Indian: Modern, 3. Nc3'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk1nr/ppp1ppbp/3p2p1/8/2PP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'A41t',
			# TRANSLATORS: A41t: 1. d4 d6 2. c4 g6 3. Nc3 Bg7
			variation => N__('Neo-Old Indian: Modern, 3. Nc3 Bg7'),
			moves => {
				'e2e4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqk1nr/ppp1ppbp/3p2p1/8/2PP4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'A41u',
			# TRANSLATORS: A41u: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. Nf3
			variation => N__('Neo-Old Indian: Modern, 3. Nc3 Bg7 4. Nf3'),
			moves => {
				'c8g4' => 1,
			},
		},
		'rn1qk1nr/ppp1ppbp/3p2p1/8/2PP2b1/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'A41v',
			# TRANSLATORS: A41v: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. Nf3 Bg4
			variation => N__('Neo-Old Indian: Modern, 3. Nc3 Bg7 4. Nf3 Bf4'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rn1qk1nr/ppp1ppbp/3p2p1/8/2PP2b1/2N1PN2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'A41w',
			# TRANSLATORS: A41w: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. Nf3 Bg4 5. e3
			variation => N__('Neo-Old Indian: Modern, 3. Nc3 Bg7 4. Nf3 Bf4 5. e3'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r2qk1nr/ppp1ppbp/2np2p1/8/2PP2b1/2N1PN2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'A41w',
			# TRANSLATORS: A41w: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. Nf3 Bg4 5. e3 Nc6
			variation => N__('Neo-Old Indian: Modern, 3. Nc3 Bg7 4. Nf3 Bf4 5. e3 Nc6'),
			moves => {
			},
		},
		'rnbqk1nr/ppp1ppbp/3p2p1/8/2PPP3/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'A42a',
			# TRANSLATORS: A42a: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. e4
			variation => N__('Modern: Averbakh'),
			moves => {
				'b8c6' => 1,
				'b8d7' => 1,
				'c7c5' => 1,
				'c7c6' => 1,
				'e7e5' => 1,
				'f7f5' => 1,
			},
		},
		'rnbqk1nr/ppp1p1bp/3p2p1/5p2/2PPP3/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'A42b',
			# TRANSLATORS: A42b: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. e4 f5
			variation => N__('Modern: Averbakh, Randspringer Variation'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqk1nr/ppp1p1bp/3p2p1/5p2/2PPP3/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'A42b',
			# TRANSLATORS: A42b: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. e4 f5 5. Nf3
			variation => N__('Modern: Averbakh, Randspringer, 5. Nf3'),
			moves => {
			},
		},
		'rnbqk1nr/pp2ppbp/3p2p1/2p5/2PPP3/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'A42c',
			# TRANSLATORS: A42c: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. e4 c5
			variation => N__('Modern: c4 Pterodactyl'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqk1nr/pp2ppbp/3p2p1/2p5/2PPP3/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'A42c',
			# TRANSLATORS: A42c: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. e4 c5 5. Nf3
			variation => N__('Modern: c4 Pterodactyl'),
			moves => {
				'd8a5' => 1,
			},
		},
		'rnb1k1nr/pp2ppbp/3p2p1/q1p5/2PPP3/2N2N2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'A42c',
			# TRANSLATORS: A42c: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. e4 c5 5. Nf3 Qa5
			variation => N__('Modern: c4 Pterodactyl'),
			moves => {
			},
		},
		'rnbqk1nr/pp2ppbp/2pp2p1/8/2PPP3/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'A42d',
			# TRANSLATORS: A42d: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. e4 c6
			variation => N__('Modern: Averbakh, 4... c6'),
			moves => {
				'c1e3' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqk1nr/pp2ppbp/2pp2p1/8/2PPP3/2N1B3/PP3PPP/R2QKBNR b KQkq' => {
			eco => 'A42d',
			# TRANSLATORS: A42d: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. e4 c6 5. Be3
			variation => N__('Modern: Averbakh, 4... c6 5. Be3'),
			moves => {
			},
		},
		'rnbqk1nr/pp2ppbp/2pp2p1/8/2PPP3/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'A42e',
			# TRANSLATORS: A42e: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. e4 c6 5. Nf3
			variation => N__('Modern: Averbakh, 4... c6 5. Nf3'),
			moves => {
			},
		},
		'r1bqk1nr/pppnppbp/3p2p1/8/2PPP3/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'A42f',
			# TRANSLATORS: A42f: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. e4 Nd7
			variation => N__('Modern: Averbakh, 4... Nd7'),
			moves => {
				'g1f3' => 1,
			},
		},
		'r1bqk1nr/pppnppbp/3p2p1/8/2PPP3/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'A42f',
			# TRANSLATORS: A42f: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. e4 Nd7 5. Nf3
			variation => N__('Modern: Averbakh, 4... Nd7 5. Nf3'),
			moves => {
			},
		},
		'r1bqk1nr/ppp1ppbp/2np2p1/8/2PPP3/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'A42g',
			# TRANSLATORS: A42g: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. e4 Nc6
			variation => N__('Modern: Averbakh, Kotov Variation'),
			moves => {
				'c1e3' => 1,
				'd4d5' => 1,
				'g1e2' => 1,
				'g1f3' => 1,
			},
		},
		'r1bqk1nr/ppp1ppbp/2np2p1/8/2PPP3/2N5/PP2NPPP/R1BQKB1R b KQkq' => {
			eco => 'A42g',
			# TRANSLATORS: A42g: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. e4 Nc6 5. Nge2
			variation => N__('Modern: Averbakh, Kotov, 5.Nge2'),
			moves => {
			},
		},
		'r1bqk1nr/ppp1ppbp/2np2p1/8/2PPP3/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'A42g',
			# TRANSLATORS: A42g: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. e4 Nc6 5. Nf3
			variation => N__('Modern: Averbakh, Kotov, 5. Nf3'),
			moves => {
			},
		},
		'r1bqk1nr/ppp1ppbp/2np2p1/3P4/2P1P3/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'A42h',
			# TRANSLATORS: A42h: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. e4 Nc6 5. d5
			variation => N__('Modern: Averbakh, Kotov, 5. d5'),
			moves => {
			},
		},
		'r1bqk1nr/ppp1ppbp/2np2p1/8/2PPP3/2N1B3/PP3PPP/R2QKBNR b KQkq' => {
			eco => 'A42i',
			# TRANSLATORS: A42i: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. e4 Nc6 5. Be3
			variation => N__('Modern: Averbakh, Kotov, 5. Be3'),
			moves => {
				'e7e5' => 1,
			},
		},
		'r1bqk1nr/ppp2pbp/2np2p1/4p3/2PPP3/2N1B3/PP3PPP/R2QKBNR w KQkq' => {
			eco => 'A42j',
			# TRANSLATORS: A42j: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. e4 Nc6 5. Be3 e5
			variation => N__('Modern: Averbakh, Kotov, 5. Be3 e5'),
			moves => {
				'd4d5' => 1,
				'g1e2' => 1,
			},
		},
		'r1bqk1nr/ppp2pbp/2np2p1/4p3/2PPP3/2N1B3/PP2NPPP/R2QKB1R b KQkq' => {
			eco => 'A42j',
			# TRANSLATORS: A42j: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. e4 Nc6 5. Be3 e5 6. Nge2
			variation => N__('Modern: Averbakh, Kotov, 5. Be3 e5 6.Nge2'),
			moves => {
			},
		},
		'r1bqk1nr/ppp2pbp/2np2p1/3Pp3/2P1P3/2N1B3/PP3PPP/R2QKBNR b KQkq' => {
			eco => 'A42k',
			# TRANSLATORS: A42k: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. e4 Nc6 5. Be3 e5 6. d5
			variation => N__('Modern: Averbakh, Kotov, 5. Be3 e5 6. d5'),
			moves => {
				'c6e7' => 1,
			},
		},
		'r1bqk1nr/ppp1npbp/3p2p1/3Pp3/2P1P3/2N1B3/PP3PPP/R2QKBNR w KQkq' => {
			eco => 'A42l',
			# TRANSLATORS: A42l: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. e4 Nc6 5. Be3 e5 6. d5 Nce7
			variation => N__('Modern: Averbakh, Kotov, 5. Be3 e5 6. d5 Nce7'),
			moves => {
				'c4c5' => 1,
				'g2g4' => 1,
			},
		},
		'r1bqk1nr/ppp1npbp/3p2p1/2PPp3/4P3/2N1B3/PP3PPP/R2QKBNR b KQkq' => {
			eco => 'A42l',
			# TRANSLATORS: A42l: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. e4 Nc6 5. Be3 e5 6. d5 Nce7 7. c5
			variation => N__('Modern: Averbakh, Kotov, 5. Be3 e5 6. d5 Nce7 7. c5'),
			moves => {
			},
		},
		'r1bqk1nr/ppp1npbp/3p2p1/3Pp3/2P1P1P1/2N1B3/PP3P1P/R2QKBNR b KQkq' => {
			eco => 'A42m',
			# TRANSLATORS: A42m: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. e4 Nc6 5. Be3 e5 6. d5 Nce7 7. g4
			variation => N__('Modern: Averbakh, Kotov, 5. Be3 e5 6. d5 Nce7 7. g4'),
			moves => {
			},
		},
		'rnbqk1nr/ppp2pbp/3p2p1/4p3/2PPP3/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'A42n',
			# TRANSLATORS: A42n: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. e4 e5
			variation => N__('Modern: Averbakh, 4... e5'),
			moves => {
				'd4d5' => 1,
				'd4e5' => 1,
				'g1e2' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqk1nr/ppp2pbp/3p2p1/4p3/2PPP3/2N5/PP2NPPP/R1BQKB1R b KQkq' => {
			eco => 'A42o',
			# TRANSLATORS: A42o: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. e4 e5 5. Nge2
			variation => N__('Modern: Averbakh, 4... e5 5.Nge2'),
			moves => {
			},
		},
		'rnbqk1nr/ppp2pbp/3p2p1/4p3/2PPP3/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'A42p',
			# TRANSLATORS: A42p: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. e4 e5 5. Nf3
			variation => N__('Modern: Averbakh, 4... e5 5. Nf3'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r1bqk1nr/pppn1pbp/3p2p1/4p3/2PPP3/2N2N2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'A42q',
			# TRANSLATORS: A42q: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. e4 e5 5. Nf3 Nd7
			variation => N__('Modern: Averbakh, 4... e5 5. Nf3 Nd7'),
			moves => {
				'f1e2' => 1,
			},
		},
		'r1bqk1nr/pppn1pbp/3p2p1/4p3/2PPP3/2N2N2/PP2BPPP/R1BQK2R b KQkq' => {
			eco => 'A42r',
			# TRANSLATORS: A42r: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. e4 e5 5. Nf3 Nd7 6. Be2
			variation => N__('Modern: Averbakh, 4... e5 5. Nf3 Nd7 6. Be2'),
			moves => {
				'g8e7' => 1,
			},
		},
		'r1bqk2r/pppnnpbp/3p2p1/4p3/2PPP3/2N2N2/PP2BPPP/R1BQK2R w KQkq' => {
			eco => 'A42s',
			# TRANSLATORS: A42s: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. e4 e5 5. Nf3 Nd7 6. Be2 Ne7
			variation => N__('Modern: Averbakh, 4... e5 5. Nf3 Nd7 6. Be2 Ne7'),
			moves => {
			},
		},
		'rnbqk1nr/ppp2pbp/3p2p1/3Pp3/2P1P3/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'A42t',
			# TRANSLATORS: A42t: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. e4 e5 5. d5
			variation => N__('Modern: Averbakh, 4... e5 5. d5'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r1bqk1nr/pppn1pbp/3p2p1/3Pp3/2P1P3/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'A42u',
			# TRANSLATORS: A42u: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. e4 e5 5. d5 Nd7
			variation => N__('Modern: Averbakh, 4... e5 5. d5 Nd7'),
			moves => {
			},
		},
		'rnbqk1nr/ppp2pbp/3p2p1/4P3/2P1P3/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'A42v',
			# TRANSLATORS: A42v: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. e4 e5 5. dxe5
			variation => N__('Modern: Averbakh, 4... e5 5.dxe5'),
			moves => {
				'd6e5' => 1,
			},
		},
		'rnbqk1nr/ppp2pbp/6p1/4p3/2P1P3/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'A42v',
			# TRANSLATORS: A42v: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. e4 e5 5. dxe5 dxe5
			variation => N__('Modern: Averbakh, 4... e5 5.dxe5 dxe5'),
			moves => {
				'd1d8' => 1,
			},
		},
		'rnbQk1nr/ppp2pbp/6p1/4p3/2P1P3/2N5/PP3PPP/R1B1KBNR b KQkq' => {
			eco => 'A42v',
			# TRANSLATORS: A42v: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. e4 e5 5. dxe5 dxe5 6. Qxd8+
			variation => N__('Modern: Averbakh, 4... e5 5.dxe5 dxe5'),
			moves => {
				'e8d8' => 1,
			},
		},
		'rnbk2nr/ppp2pbp/6p1/4p3/2P1P3/2N5/PP3PPP/R1B1KBNR w KQ' => {
			eco => 'A42v',
			# TRANSLATORS: A42v: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. e4 e5 5. dxe5 dxe5 6. Qxd8+ Kxd8
			variation => N__('Modern: Averbakh, Queenswap'),
			moves => {
				'f2f4' => 1,
			},
		},
		'rnbk2nr/ppp2pbp/6p1/4p3/2P1PP2/2N5/PP4PP/R1B1KBNR b KQ' => {
			eco => 'A42w',
			# TRANSLATORS: A42w: 1. d4 d6 2. c4 g6 3. Nc3 Bg7 4. e4 e5 5. dxe5 dxe5 6. Qxd8+ Kxd8 7. f4
			variation => N__('Modern: Averbakh, Queenswap, 7. f4'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/8/2p5/3P4/8/PPP1PPPP/RNBQKBNR w KQkq' => {
			eco => 'A43a',
			# TRANSLATORS: A43a: 1. d4 c5
			variation => N__('Old Benoni'),
			moves => {
				'b2b4' => 1,
				'c2c3' => 1,
				'd4c5' => 1,
				'd4d5' => 1,
				'e2e3' => 1,
			},
		},
		'rnbqkbnr/pp1ppppp/8/2p5/1P1P4/8/P1P1PPPP/RNBQKBNR b KQkq' => {
			eco => 'A43a',
			# TRANSLATORS: A43a: 1. d4 c5 2. b4
			variation => N__('Old Benoni: Nakamura Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/8/2P5/8/8/PPP1PPPP/RNBQKBNR b KQkq' => {
			eco => 'A43b',
			# TRANSLATORS: A43b: 1. d4 c5 2. dxc5
			variation => N__('Old Benoni: 2.dxc5'),
			moves => {
				'b7b6' => 1,
			},
		},
		'rnbqkbnr/p2ppppp/1p6/2P5/8/8/PPP1PPPP/RNBQKBNR w KQkq' => {
			eco => 'A43b',
			# TRANSLATORS: A43b: 1. d4 c5 2. dxc5 b6
			variation => N__('Old Benoni: Cormorant Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/8/2p5/3P4/2P5/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'A43c',
			# TRANSLATORS: A43c: 1. d4 c5 2. c3
			variation => N__('Old Benoni: 2. c3'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/8/2p5/3P4/4P3/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'A43d',
			# TRANSLATORS: A43d: 1. d4 c5 2. e3
			variation => N__('Old Benoni: 2. e3'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/8/2pP4/8/8/PPP1PPPP/RNBQKBNR b KQkq' => {
			eco => 'A43e',
			# TRANSLATORS: A43e: 1. d4 c5 2. d5
			variation => N__('Old Benoni: 2. d5'),
			moves => {
				'b7b5' => 1,
				'd7d6' => 1,
				'e7e5' => 1,
				'e7e6' => 1,
				'f7f5' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/p2ppppp/8/1ppP4/8/8/PPP1PPPP/RNBQKBNR w KQkq' => {
			eco => 'A43e',
			# TRANSLATORS: A43e: 1. d4 c5 2. d5 b5
			variation => N__('Old Benoni: 2. d5 b5'),
			moves => {
			},
		},
		'rnbqkbnr/pp1p1ppp/4p3/2pP4/8/8/PPP1PPPP/RNBQKBNR w KQkq' => {
			eco => 'A43f',
			# TRANSLATORS: A43f: 1. d4 c5 2. d5 e6
			variation => N__('Old Benoni: 2. d5 e6'),
			moves => {
				'c2c4' => 1,
				'e2e4' => 1,
			},
		},
		'rnbqkbnr/pp1p1ppp/4p3/2pP4/4P3/8/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'A43g',
			# TRANSLATORS: A43g: 1. d4 c5 2. d5 e6 3. e4
			variation => N__('Old Benoni: Franco-Benoni'),
			moves => {
			},
		},
		'rnbqkbnr/pp1p1ppp/4p3/2pP4/2P5/8/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'A43h',
			# TRANSLATORS: A43h: 1. d4 c5 2. d5 e6 3. c4
			variation => N__('Old Benoni: 2. d5 e6 3. c4'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rnbqkbnr/pp1p1ppp/8/2pp4/2P5/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A43h',
			# TRANSLATORS: A43h: 1. d4 c5 2. d5 e6 3. c4 exd5
			variation => N__('Old Benoni: 2. d5 e6 3. c4'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rnbqkbnr/pp1p1ppp/8/2pP4/8/8/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'A43h',
			# TRANSLATORS: A43h: 1. d4 c5 2. d5 e6 3. c4 exd5 4. cxd5
			variation => N__('Old Benoni: 2. d5 e6 3. c4'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/3p4/2pP4/8/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A43h',
			# TRANSLATORS: A43h: 1. d4 c5 2. d5 e6 3. c4 exd5 4. cxd5 d6
			variation => N__('Old Benoni: 2. d5 e6 3. c4'),
			moves => {
				'b1c3' => 1,
				'e2e4' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/3p4/2pP4/4P3/8/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'A43h',
			# TRANSLATORS: A43h: 1. d4 c5 2. d5 e6 3. c4 exd5 4. cxd5 d6 5. e4
			variation => N__('Old Benoni: 2. d5 e6 3. c4'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/3p4/2pP4/8/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'A43i',
			# TRANSLATORS: A43i: 1. d4 c5 2. d5 e6 3. c4 exd5 4. cxd5 d6 5. Nc3
			variation => N__('Old Benoni: 2. d5 e6 3. c4'),
			moves => {
				'g7g6' => 1,
			},
		},
		'rnbqkbnr/pp3p1p/3p2p1/2pP4/8/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'A43i',
			# TRANSLATORS: A43i: 1. d4 c5 2. d5 e6 3. c4 exd5 4. cxd5 d6 5. Nc3 g6
			variation => N__('Old Benoni: 2. d5 e6 3. c4'),
			moves => {
				'e2e4' => 1,
			},
		},
		'rnbqkbnr/pp3p1p/3p2p1/2pP4/4P3/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'A43i',
			# TRANSLATORS: A43i: 1. d4 c5 2. d5 e6 3. c4 exd5 4. cxd5 d6 5. Nc3 g6 6. e4
			variation => N__('Old Benoni: 2. d5 e6 3. c4'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk1nr/pp3pbp/3p2p1/2pP4/4P3/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'A43i',
			# TRANSLATORS: A43i: 1. d4 c5 2. d5 e6 3. c4 exd5 4. cxd5 d6 5. Nc3 g6 6. e4 Bg7
			variation => N__('Old Benoni: 2. d5 e6 3. c4'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqk1nr/pp3pbp/3p2p1/2pP4/4P3/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'A43i',
			# TRANSLATORS: A43i: 1. d4 c5 2. d5 e6 3. c4 exd5 4. cxd5 d6 5. Nc3 g6 6. e4 Bg7 7. Nf3
			variation => N__('Old Benoni: 2. d5 e6 3. c4'),
			moves => {
			},
		},
		'rnbqkbnr/pp1pp1pp/8/2pP1p2/8/8/PPP1PPPP/RNBQKBNR w KQkq' => {
			eco => 'A43j',
			# TRANSLATORS: A43j: 1. d4 c5 2. d5 f5
			variation => N__('Old Benoni: Clarendon Court Defence'),
			moves => {
				'b1c3' => 1,
				'c2c4' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/pp1pp1pp/8/2pP1p2/8/2N5/PPP1PPPP/R1BQKBNR b KQkq' => {
			eco => 'A43j',
			# TRANSLATORS: A43j: 1. d4 c5 2. d5 f5 3. Nc3
			variation => N__('Old Benoni: Clarendon Court, 3. Nc3'),
			moves => {
			},
		},
		'rnbqkbnr/pp1pp1pp/8/2pP1p2/2P5/8/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'A43j',
			# TRANSLATORS: A43j: 1. d4 c5 2. d5 f5 3. c4
			variation => N__('Old Benoni: Clarendon Court, 3. c4'),
			moves => {
			},
		},
		'rnbqkbnr/pp1pp1pp/8/2pP1p2/8/6P1/PPP1PP1P/RNBQKBNR b KQkq' => {
			eco => 'A43j',
			# TRANSLATORS: A43j: 1. d4 c5 2. d5 f5 3. g3
			variation => N__('Old Benoni: Clarendon Court, 3. g3'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/2pP4/8/8/PPP1PPPP/RNBQKBNR w KQkq' => {
			eco => 'A43k',
			# TRANSLATORS: A43k: 1. d4 c5 2. d5 Nf6
			variation => N__('Old Benoni: 2. d5 Nf6'),
			moves => {
				'b1c3' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/2pP4/8/2N5/PPP1PPPP/R1BQKBNR b KQkq' => {
			eco => 'A43k',
			# TRANSLATORS: A43k: 1. d4 c5 2. d5 Nf6 3. Nc3
			variation => N__('Old Benoni: 2. d5 Nf6 3. Nc3'),
			moves => {
				'd8a5' => 1,
			},
		},
		'rnb1kb1r/pp1ppppp/5n2/q1pP4/8/2N5/PPP1PPPP/R1BQKBNR w KQkq' => {
			eco => 'A43k',
			# TRANSLATORS: A43k: 1. d4 c5 2. d5 Nf6 3. Nc3 Qa5
			variation => N__('Old Benoni: Woozle'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/2pP4/8/5N2/PPP1PPPP/RNBQKB1R b KQkq' => {
			eco => 'A43l',
			# TRANSLATORS: A43l: 1. d4 c5 2. d5 Nf6 3. Nf3
			variation => N__('Old Benoni: 2. d5 Nf6 3. Nf3'),
			moves => {
				'b7b5' => 1,
				'c5c4' => 1,
				'e7e6' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/2pP4/8/5N2/PPP1PPPP/RNBQKB1R w KQkq' => {
			eco => 'A43l',
			# TRANSLATORS: A43l: 1. d4 c5 2. d5 Nf6 3. Nf3 e6
			variation => N__('Old Benoni: 2. d5 Nf6 3. Nf3 e6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/2pP4/8/2N2N2/PPP1PPPP/R1BQKB1R b KQkq' => {
			eco => 'A43l',
			# TRANSLATORS: A43l: 1. d4 c5 2. d5 Nf6 3. Nf3 e6 4. Nc3
			variation => N__('Old Benoni: 2. d5 Nf6 3. Nf3 e6 4. Nc3'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppp1p/5np1/2pP4/8/5N2/PPP1PPPP/RNBQKB1R w KQkq' => {
			eco => 'A43m',
			# TRANSLATORS: A43m: 1. d4 c5 2. d5 Nf6 3. Nf3 g6
			variation => N__('Old Benoni: 2. d5 Nf6 3. Nf3 g6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkb1r/pp1ppp1p/5np1/2pP4/8/2N2N2/PPP1PPPP/R1BQKB1R b KQkq' => {
			eco => 'A43m',
			# TRANSLATORS: A43m: 1. d4 c5 2. d5 Nf6 3. Nf3 g6 4. Nc3
			variation => N__('Old Benoni: 2. d5 Nf6 3. Nf3 g6 4. Nc3'),
			moves => {
			},
		},
		'rnbqkb1r/p2ppppp/5n2/1ppP4/8/5N2/PPP1PPPP/RNBQKB1R w KQkq' => {
			eco => 'A43n',
			# TRANSLATORS: A43n: 1. d4 c5 2. d5 Nf6 3. Nf3 b5
			variation => N__('Old Benoni: Neo-Benko'),
			moves => {
				'c1g5' => 1,
			},
		},
		'rnbqkb1r/p2ppppp/5n2/1ppP2B1/8/5N2/PPP1PPPP/RN1QKB1R b KQkq' => {
			eco => 'A43o',
			# TRANSLATORS: A43o: 1. d4 c5 2. d5 Nf6 3. Nf3 b5 4. Bg5
			variation => N__('Old Benoni: Neo-Benko, 4. Bg5'),
			moves => {
				'd7d6' => 1,
				'f6e4' => 1,
			},
		},
		'rnbqkb1r/p3pppp/3p1n2/1ppP2B1/8/5N2/PPP1PPPP/RN1QKB1R w KQkq' => {
			eco => 'A43p',
			# TRANSLATORS: A43p: 1. d4 c5 2. d5 Nf6 3. Nf3 b5 4. Bg5 d6
			variation => N__('Old Benoni: Neo-Benko, 4. Bg5 d6'),
			moves => {
			},
		},
		'rnbqkb1r/p2ppppp/8/1ppP2B1/4n3/5N2/PPP1PPPP/RN1QKB1R w KQkq' => {
			eco => 'A43q',
			# TRANSLATORS: A43q: 1. d4 c5 2. d5 Nf6 3. Nf3 b5 4. Bg5 Ne4
			variation => N__('Old Benoni: Neo-Benko, 4. Bg5 Ne4'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/3P4/2p5/5N2/PPP1PPPP/RNBQKB1R w KQkq' => {
			eco => 'A43r',
			# TRANSLATORS: A43r: 1. d4 c5 2. d5 Nf6 3. Nf3 c4
			variation => N__('Old Benoni: Hawk'),
			moves => {
				'e2e4' => 1,
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/3P4/2p1P3/5N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'A43r',
			# TRANSLATORS: A43r: 1. d4 c5 2. d5 Nf6 3. Nf3 c4 4. e4
			variation => N__('Old Benoni: Hawk, 4. e4'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/3p4/2pP4/8/8/PPP1PPPP/RNBQKBNR w KQkq' => {
			eco => 'A43s',
			# TRANSLATORS: A43s: 1. d4 c5 2. d5 d6
			variation => N__('Old Benoni: Schmidt'),
			moves => {
				'b1c3' => 1,
				'e2e4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/3p4/2pP4/8/2N5/PPP1PPPP/R1BQKBNR b KQkq' => {
			eco => 'A43s',
			# TRANSLATORS: A43s: 1. d4 c5 2. d5 d6 3. Nc3
			variation => N__('Old Benoni: Schmidt, 3. Nc3'),
			moves => {
				'g7g6' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/pp2pp1p/3p2p1/2pP4/8/2N5/PPP1PPPP/R1BQKBNR w KQkq' => {
			eco => 'A43s',
			# TRANSLATORS: A43s: 1. d4 c5 2. d5 d6 3. Nc3 g6
			variation => N__('Old Benoni: Schmidt, 3. Nc3 g6'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/3p1n2/2pP4/8/2N5/PPP1PPPP/R1BQKBNR w KQkq' => {
			eco => 'A43s',
			# TRANSLATORS: A43s: 1. d4 c5 2. d5 d6 3. Nc3 Nf6
			variation => N__('Old Benoni: Schmidt, 3. Nc3 Nf6'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/3p4/2pP4/4P3/8/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'A43s',
			# TRANSLATORS: A43s: 1. d4 c5 2. d5 d6 3. e4
			variation => N__('Old Benoni: Schmidt, 3. e4'),
			moves => {
				'g7g6' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/3p4/2pP4/8/5N2/PPP1PPPP/RNBQKB1R b KQkq' => {
			eco => 'A43s',
			# TRANSLATORS: A43s: 1. d4 c5 2. d5 d6 3. Nf3
			variation => N__('Old Benoni: Schmidt, 3. Nf3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/3p1n2/2pP4/8/5N2/PPP1PPPP/RNBQKB1R w KQkq' => {
			eco => 'A43s',
			# TRANSLATORS: A43s: 1. d4 c5 2. d5 d6 3. Nf3 Nf6
			variation => N__('Old Benoni: Schmidt, 3. Nf3 Nf6'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pp1p/3p2p1/2pP4/4P3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'A43t',
			# TRANSLATORS: A43t: 1. d4 c5 2. d5 d6 3. e4 g6
			variation => N__('Old Benoni: Schmidt, 3. e4 g6'),
			moves => {
				'b1c3' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pp2pp1p/3p2p1/2pP4/4P3/2N5/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'A43t',
			# TRANSLATORS: A43t: 1. d4 c5 2. d5 d6 3. e4 g6 4. Nc3
			variation => N__('Old Benoni: Schmidt, 3. e4 g6'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk1nr/pp2ppbp/3p2p1/2pP4/4P3/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'A43t',
			# TRANSLATORS: A43t: 1. d4 c5 2. d5 d6 3. e4 g6 4. Nc3 Bg7
			variation => N__('Old Benoni: Schmidt, 3. e4 g6'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pp1p/3p2p1/2pP4/4P3/5N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'A43t',
			# TRANSLATORS: A43t: 1. d4 c5 2. d5 d6 3. e4 g6 4. Nf3
			variation => N__('Old Benoni: Schmidt, 3. e4 g6'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk1nr/pp2ppbp/3p2p1/2pP4/4P3/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'A43t',
			# TRANSLATORS: A43t: 1. d4 c5 2. d5 d6 3. e4 g6 4. Nf3 Bg7
			variation => N__('Old Benoni: Schmidt, 3. e4 g6'),
			moves => {
				'f1e2' => 1,
			},
		},
		'rnbqk1nr/pp2ppbp/3p2p1/2pP4/4P3/5N2/PPP1BPPP/RNBQK2R b KQkq' => {
			eco => 'A43t',
			# TRANSLATORS: A43t: 1. d4 c5 2. d5 d6 3. e4 g6 4. Nf3 Bg7 5. Be2
			variation => N__('Old Benoni: Schmidt, 3. e4 g6'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/3p1n2/2pP4/4P3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'A43u',
			# TRANSLATORS: A43u: 1. d4 c5 2. d5 d6 3. e4 Nf6
			variation => N__('Old Benoni: Schmidt, 3. e4 Nf6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/3p1n2/2pP4/4P3/2N5/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'A43u',
			# TRANSLATORS: A43u: 1. d4 c5 2. d5 d6 3. e4 Nf6 4. Nc3
			variation => N__('Old Benoni: Schmidt, 3. e4 Nf6'),
			moves => {
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/pp2pp1p/3p1np1/2pP4/4P3/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'A43u',
			# TRANSLATORS: A43u: 1. d4 c5 2. d5 d6 3. e4 Nf6 4. Nc3 g6
			variation => N__('Old Benoni: Schmidt, 3. e4 Nf6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/pp2pp1p/3p1np1/2pP4/4P3/2N2N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'A43u',
			# TRANSLATORS: A43u: 1. d4 c5 2. d5 d6 3. e4 Nf6 4. Nc3 g6 5. Nf3
			variation => N__('Old Benoni: Schmidt, 3. e4 Nf6'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/3p1np1/2pP4/4P3/2N2N2/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'A43u',
			# TRANSLATORS: A43u: 1. d4 c5 2. d5 d6 3. e4 Nf6 4. Nc3 g6 5. Nf3 Bg7
			variation => N__('Old Benoni: Schmidt, 3. e4 Nf6'),
			moves => {
				'f1b5' => 1,
				'f1e2' => 1,
				'h2h3' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/3p1np1/2pP4/4P3/2N2N1P/PPP2PP1/R1BQKB1R b KQkq' => {
			eco => 'A43v',
			# TRANSLATORS: A43v: 1. d4 c5 2. d5 d6 3. e4 Nf6 4. Nc3 g6 5. Nf3 Bg7 6. h3
			variation => N__('Old Benoni: Schmidt, 6. h3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2pP4/4P3/2N2N1P/PPP2PP1/R1BQKB1R w KQ' => {
			eco => 'A43v',
			# TRANSLATORS: A43v: 1. d4 c5 2. d5 d6 3. e4 Nf6 4. Nc3 g6 5. Nf3 Bg7 6. h3 O-O
			variation => N__('Old Benoni: Schmidt, 6. h3'),
			moves => {
			},
		},
		'rnbqk2r/pp2ppbp/3p1np1/1BpP4/4P3/2N2N2/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'A43w',
			# TRANSLATORS: A43w: 1. d4 c5 2. d5 d6 3. e4 Nf6 4. Nc3 g6 5. Nf3 Bg7 6. Bb5+
			variation => N__('Old Benoni: Schmidt, 6. Bb5+'),
			moves => {
			},
		},
		'rnbqk2r/pp2ppbp/3p1np1/2pP4/4P3/2N2N2/PPP1BPPP/R1BQK2R b KQkq' => {
			eco => 'A43x',
			# TRANSLATORS: A43x: 1. d4 c5 2. d5 d6 3. e4 Nf6 4. Nc3 g6 5. Nf3 Bg7 6. Be2
			variation => N__('Old Benoni: Schmidt, 6. Be2'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2pP4/4P3/2N2N2/PPP1BPPP/R1BQK2R w KQ' => {
			eco => 'A43x',
			# TRANSLATORS: A43x: 1. d4 c5 2. d5 d6 3. e4 Nf6 4. Nc3 g6 5. Nf3 Bg7 6. Be2 O-O
			variation => N__('Old Benoni: Schmidt, 6. Be2 O-O'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2pP4/4P3/2N2N2/PPP1BPPP/R1BQ1RK1 b -' => {
			eco => 'A43x',
			# TRANSLATORS: A43x: 1. d4 c5 2. d5 d6 3. e4 Nf6 4. Nc3 g6 5. Nf3 Bg7 6. Be2 O-O 7. O-O
			variation => N__('Old Benoni: Schmidt, 6. Be2 O-O 7.O-O'),
			moves => {
				'b8a6' => 1,
				'e7e6' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3ppnp1/2pP4/4P3/2N2N2/PPP1BPPP/R1BQ1RK1 w -' => {
			eco => 'A43x',
			# TRANSLATORS: A43x: 1. d4 c5 2. d5 d6 3. e4 Nf6 4. Nc3 g6 5. Nf3 Bg7 6. Be2 O-O 7. O-O e6
			variation => N__('Old Benoni: Schmidt, 6. Be2 O-O 7.O-O e6'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/n2p1np1/2pP4/4P3/2N2N2/PPP1BPPP/R1BQ1RK1 w -' => {
			eco => 'A43y',
			# TRANSLATORS: A43y: 1. d4 c5 2. d5 d6 3. e4 Nf6 4. Nc3 g6 5. Nf3 Bg7 6. Be2 O-O 7. O-O Na6
			variation => N__('Old Benoni: Schmidt, 6. Be2 O-O 7.O-O Na6'),
			moves => {
				'h2h3' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/n2p1np1/2pP4/4P3/2N2N1P/PPP1BPP1/R1BQ1RK1 b -' => {
			eco => 'A43z',
			# TRANSLATORS: A43z: 1. d4 c5 2. d5 d6 3. e4 Nf6 4. Nc3 g6 5. Nf3 Bg7 6. Be2 O-O 7. O-O Na6 8. h3
			variation => N__('Old Benoni: Schmidt, 6. Be2 O-O 7.O-O Na6 8. h3'),
			moves => {
			},
		},
		'rnbqkbnr/pp1p1ppp/8/2pPp3/8/8/PPP1PPPP/RNBQKBNR w KQkq' => {
			eco => 'A44a',
			# TRANSLATORS: A44a: 1. d4 c5 2. d5 e5
			variation => N__('Old Benoni: Czech'),
			moves => {
				'c2c4' => 1,
				'd5e6' => 1,
				'e2e4' => 1,
			},
		},
		'rnbqkbnr/pp1p1ppp/4P3/2p5/8/8/PPP1PPPP/RNBQKBNR b KQkq' => {
			eco => 'A44b',
			# TRANSLATORS: A44b: 1. d4 c5 2. d5 e5 3. dxe6
			variation => N__('Old Benoni: Czech, 3.dxe6'),
			moves => {
			},
		},
		'rnbqkbnr/pp1p1ppp/8/2pPp3/2P5/8/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'A44c',
			# TRANSLATORS: A44c: 1. d4 c5 2. d5 e5 3. c4
			variation => N__('Old Benoni: Czech, 3. c4'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/3p4/2pPp3/2P5/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A44d',
			# TRANSLATORS: A44d: 1. d4 c5 2. d5 e5 3. c4 d6
			variation => N__('Old Benoni: Czech, 3. c4 d6'),
			moves => {
				'e2e4' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/3p4/2pPp3/2P1P3/8/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'A44e',
			# TRANSLATORS: A44e: 1. d4 c5 2. d5 e5 3. c4 d6 4. e4
			variation => N__('Old Benoni: Czech, 3. c4 d6 4. e4'),
			moves => {
				'f8e7' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqk1nr/pp2bppp/3p4/2pPp3/2P1P3/8/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'A44f',
			# TRANSLATORS: A44f: 1. d4 c5 2. d5 e5 3. c4 d6 4. e4 Be7
			variation => N__('Old Benoni: Czech, 3. c4 d6 4. e4 Be7'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqk1nr/pp2bppp/3p4/2pPp3/2P1P3/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'A44g',
			# TRANSLATORS: A44g: 1. d4 c5 2. d5 e5 3. c4 d6 4. e4 Be7 5. Nc3
			variation => N__('Old Benoni: Czech, 3. c4 d6 4. e4 Be7 5. Nc3'),
			moves => {
			},
		},
		'rnbqkbnr/pp3p1p/3p2p1/2pPp3/2P1P3/8/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'A44h',
			# TRANSLATORS: A44h: 1. d4 c5 2. d5 e5 3. c4 d6 4. e4 g6
			variation => N__('Old Benoni: Czech, 3. c4 d6 4. e4 g6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkbnr/pp3p1p/3p2p1/2pPp3/2P1P3/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'A44h',
			# TRANSLATORS: A44h: 1. d4 c5 2. d5 e5 3. c4 d6 4. e4 g6 5. Nc3
			variation => N__('Old Benoni: Czech, 3. c4 d6 4. e4 g6 5. Nc3'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk1nr/pp3pbp/3p2p1/2pPp3/2P1P3/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'A44i',
			# TRANSLATORS: A44i: 1. d4 c5 2. d5 e5 3. c4 d6 4. e4 g6 5. Nc3 Bg7
			variation => N__('Old Benoni: Czech, 3. c4 d6 4. e4 g6 5. Nc3 Bg7'),
			moves => {
				'f1d3' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqk1nr/pp3pbp/3p2p1/2pPp3/2P1P3/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'A44j',
			# TRANSLATORS: A44j: 1. d4 c5 2. d5 e5 3. c4 d6 4. e4 g6 5. Nc3 Bg7 6. Nf3
			variation => N__('Old Benoni: Czech, 3. c4 d6 4. e4 g6 5. Nc3 Bg7 6. Nf3'),
			moves => {
			},
		},
		'rnbqk1nr/pp3pbp/3p2p1/2pPp3/2P1P3/2NB4/PP3PPP/R1BQK1NR b KQkq' => {
			eco => 'A44k',
			# TRANSLATORS: A44k: 1. d4 c5 2. d5 e5 3. c4 d6 4. e4 g6 5. Nc3 Bg7 6. Bd3
			variation => N__('Old Benoni: Czech, 3. c4 d6 4. e4 g6 5. Nc3 Bg7 6. Bd3'),
			moves => {
			},
		},
		'rnbqkbnr/pp1p1ppp/8/2pPp3/4P3/8/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'A44l',
			# TRANSLATORS: A44l: 1. d4 c5 2. d5 e5 3. e4
			variation => N__('Old Benoni: Czech, 3. e4'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/3p4/2pPp3/4P3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'A44m',
			# TRANSLATORS: A44m: 1. d4 c5 2. d5 e5 3. e4 d6
			variation => N__('Old Benoni: Czech, 3. e4 d6'),
			moves => {
				'b1c3' => 1,
				'f1b5' => 1,
				'f1d3' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/3p4/2pPp3/4P3/5N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'A44n',
			# TRANSLATORS: A44n: 1. d4 c5 2. d5 e5 3. e4 d6 4. Nf3
			variation => N__('Old Benoni: Czech, 3. e4 d6 4. Nf3'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/3p4/1BpPp3/4P3/8/PPP2PPP/RNBQK1NR b KQkq' => {
			eco => 'A44o',
			# TRANSLATORS: A44o: 1. d4 c5 2. d5 e5 3. e4 d6 4. Bb5+
			variation => N__('Old Benoni: Czech, 3. e4 d6 4. Bb5+'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/3p4/2pPp3/4P3/3B4/PPP2PPP/RNBQK1NR b KQkq' => {
			eco => 'A44p',
			# TRANSLATORS: A44p: 1. d4 c5 2. d5 e5 3. e4 d6 4. Bd3
			variation => N__('Old Benoni: Czech, 3. e4 d6 4. Bd3'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/3p4/2pPp3/4P3/2N5/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'A44q',
			# TRANSLATORS: A44q: 1. d4 c5 2. d5 e5 3. e4 d6 4. Nc3
			variation => N__('Old Benoni: Czech, 3. e4 d6 4. Nc3'),
			moves => {
				'a7a6' => 1,
				'f8e7' => 1,
				'g7g6' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/3p1n2/2pPp3/4P3/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'A44r',
			# TRANSLATORS: A44r: 1. d4 c5 2. d5 e5 3. e4 d6 4. Nc3 Nf6
			variation => N__('Old Benoni: Czech, 3. e4 d6 4. Nc3 Nf6'),
			moves => {
			},
		},
		'rnbqkbnr/pp3p1p/3p2p1/2pPp3/4P3/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'A44s',
			# TRANSLATORS: A44s: 1. d4 c5 2. d5 e5 3. e4 d6 4. Nc3 g6
			variation => N__('Old Benoni: Czech, 3. e4 d6 4. Nc3 g6'),
			moves => {
			},
		},
		'rnbqkbnr/1p3ppp/p2p4/2pPp3/4P3/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'A44t',
			# TRANSLATORS: A44t: 1. d4 c5 2. d5 e5 3. e4 d6 4. Nc3 a6
			variation => N__('Old Benoni: Czech, 3. e4 d6 4. Nc3 a6'),
			moves => {
				'a2a4' => 1,
			},
		},
		'rnbqkbnr/1p3ppp/p2p4/2pPp3/P3P3/2N5/1PP2PPP/R1BQKBNR b KQkq' => {
			eco => 'A44t',
			# TRANSLATORS: A44t: 1. d4 c5 2. d5 e5 3. e4 d6 4. Nc3 a6 5. a4
			variation => N__('Old Benoni: Czech, 3. e4 d6 4. Nc3 a6'),
			moves => {
				'f8e7' => 1,
			},
		},
		'rnbqk1nr/1p2bppp/p2p4/2pPp3/P3P3/2N5/1PP2PPP/R1BQKBNR w KQkq' => {
			eco => 'A44u',
			# TRANSLATORS: A44u: 1. d4 c5 2. d5 e5 3. e4 d6 4. Nc3 a6 5. a4 Be7
			variation => N__('Old Benoni: Czech, 3. e4 d6 4. Nc3 a6 5. a4 Be7'),
			moves => {
			},
		},
		'rnbqk1nr/pp2bppp/3p4/2pPp3/4P3/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'A44v',
			# TRANSLATORS: A44v: 1. d4 c5 2. d5 e5 3. e4 d6 4. Nc3 Be7
			variation => N__('Old Benoni: Czech, 3. e4 d6 4. Nc3 Be7'),
			moves => {
				'f1b5' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqk1nr/pp2bppp/3p4/1BpPp3/4P3/2N5/PPP2PPP/R1BQK1NR b KQkq' => {
			eco => 'A44w',
			# TRANSLATORS: A44w: 1. d4 c5 2. d5 e5 3. e4 d6 4. Nc3 Be7 5. Bb5+
			variation => N__('Old Benoni: Czech, 3. e4 d6 4. Nc3 Be7 5. Bb5+'),
			moves => {
			},
		},
		'rnbqk1nr/pp2bppp/3p4/2pPp3/4P3/2N2N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'A44x',
			# TRANSLATORS: A44x: 1. d4 c5 2. d5 e5 3. e4 d6 4. Nc3 Be7 5. Nf3
			variation => N__('Old Benoni: Czech, 3. e4 d6 4. Nc3 Be7 5. Nf3'),
			moves => {
				'c8g4' => 1,
			},
		},
		'rn1qk1nr/pp2bppp/3p4/2pPp3/4P1b1/2N2N2/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'A44y',
			# TRANSLATORS: A44y: 1. d4 c5 2. d5 e5 3. e4 d6 4. Nc3 Be7 5. Nf3 Bg4
			variation => N__('Old Benoni: Czech, 3. e4 d6 4. Nc3 Be7 5. Nf3 Bg4'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/3P4/8/PPP1PPPP/RNBQKBNR w KQkq' => {
			eco => 'A45a',
			# TRANSLATORS: A45a: 1. d4 Nf6
			variation => N__('Queen\'s Pawn: Indian'),
			moves => {
				'b1c3' => 1,
				'b1d2' => 1,
				'c1f4' => 1,
				'c1g5' => 1,
				'c2c3' => 1,
				'c2c4' => 1,
				'e2e3' => 1,
				'e2e4' => 1,
				'f2f3' => 1,
				'f2f4' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
				'g2g4' => 1,
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/3PP3/8/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'A45a',
			# TRANSLATORS: A45a: 1. d4 Nf6 2. e4
			variation => N__('Indian: Omega Gambit'),
			moves => {
				'f6e4' => 1,
			},
		},
		'rnbqkb1r/pppppppp/8/8/3Pn3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'A45a',
			# TRANSLATORS: A45a: 1. d4 Nf6 2. e4 Nxe4
			variation => N__('Indian: Omega Gambit'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rnbqkb1r/pppppppp/8/8/3Pn3/3B4/PPP2PPP/RNBQK1NR b KQkq' => {
			eco => 'A45a',
			# TRANSLATORS: A45a: 1. d4 Nf6 2. e4 Nxe4 3. Bd3
			variation => N__('Indian: Omega Gambit'),
			moves => {
				'e4f6' => 1,
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/3P4/3B4/PPP2PPP/RNBQK1NR w KQkq' => {
			eco => 'A45a',
			# TRANSLATORS: A45a: 1. d4 Nf6 2. e4 Nxe4 3. Bd3 Nf6
			variation => N__('Indian: Omega Gambit'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/3P4/3B1N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'A45a',
			# TRANSLATORS: A45a: 1. d4 Nf6 2. e4 Nxe4 3. Bd3 Nf6 4. Nf3
			variation => N__('Indian: Arafat Gambit'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/3P4/5P2/PPP1P1PP/RNBQKBNR b KQkq' => {
			eco => 'A45a',
			# TRANSLATORS: A45a: 1. d4 Nf6 2. f3
			variation => N__('Indian: Paleface Attack'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/3P4/5P2/PPP1P1PP/RNBQKBNR w KQkq' => {
			eco => 'A45a',
			# TRANSLATORS: A45a: 1. d4 Nf6 2. f3 d5
			variation => N__('Indian: Paleface Attack'),
			moves => {
				'e2e4' => 1,
				'g2g4' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/3PP3/5P2/PPP3PP/RNBQKBNR b KQkq' => {
			eco => 'A45a',
			# TRANSLATORS: A45a: 1. d4 Nf6 2. f3 d5 3. e4
			variation => N__('Indian: Blackmar-Diemer Gambit (without Nc3)'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/3P2P1/5P2/PPP1P2P/RNBQKBNR b KQkq' => {
			eco => 'A45a',
			# TRANSLATORS: A45a: 1. d4 Nf6 2. f3 d5 3. g4
			variation => N__('Indian: Gedult Attack'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/3P2P1/8/PPP1PP1P/RNBQKBNR b KQkq' => {
			eco => 'A45a',
			# TRANSLATORS: A45a: 1. d4 Nf6 2. g4
			variation => N__('Indian: Gibbins Gambit'),
			moves => {
				'e7e5' => 1,
				'f6g4' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/4p3/3P2P1/8/PPP1PP1P/RNBQKBNR w KQkq' => {
			eco => 'A45a',
			# TRANSLATORS: A45a: 1. d4 Nf6 2. g4 e5
			variation => N__('Indian: Gibbins Gambit, Oshima Defence'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/8/8/3P2n1/8/PPP1PP1P/RNBQKBNR w KQkq' => {
			eco => 'A45a',
			# TRANSLATORS: A45a: 1. d4 Nf6 2. g4 Nxg4
			variation => N__('Indian: Gibbins Gambit Accepted'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/3P1P2/8/PPP1P1PP/RNBQKBNR b KQkq' => {
			eco => 'A45b',
			# TRANSLATORS: A45b: 1. d4 Nf6 2. f4
			variation => N__('Indian: Canard Opening'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/3P4/8/PPPNPPPP/R1BQKBNR b KQkq' => {
			eco => 'A45c',
			# TRANSLATORS: A45c: 1. d4 Nf6 2. Nd2
			variation => N__('Indian: 2. Nd2'),
			moves => {
				'e7e5' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/4p3/3P4/8/PPPNPPPP/R1BQKBNR w KQkq' => {
			eco => 'A45c',
			# TRANSLATORS: A45c: 1. d4 Nf6 2. Nd2 e5
			variation => N__('Indian: Lazard Gambit'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/3P4/4P3/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'A45d',
			# TRANSLATORS: A45d: 1. d4 Nf6 2. e3
			variation => N__('Indian: 2. e3'),
			moves => {
				'e7e6' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/4pn2/8/3P4/4P3/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'A45d',
			# TRANSLATORS: A45d: 1. d4 Nf6 2. e3 e6
			variation => N__('Indian: 2. e3 e6'),
			moves => {
			},
		},
		'rnbqkb1r/pppppp1p/5np1/8/3P4/4P3/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'A45d',
			# TRANSLATORS: A45d: 1. d4 Nf6 2. e3 g6
			variation => N__('Indian: 2. e3 g6'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/3P4/2P5/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'A45e',
			# TRANSLATORS: A45e: 1. d4 Nf6 2. c3
			variation => N__('Indian: 2. c3'),
			moves => {
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/pppppp1p/5np1/8/3P4/2P5/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A45e',
			# TRANSLATORS: A45e: 1. d4 Nf6 2. c3 g6
			variation => N__('Indian: 2. c3 g6'),
			moves => {
				'c1g5' => 1,
			},
		},
		'rnbqkb1r/pppppp1p/5np1/6B1/3P4/2P5/PP2PPPP/RN1QKBNR b KQkq' => {
			eco => 'A45e',
			# TRANSLATORS: A45e: 1. d4 Nf6 2. c3 g6 3. Bg5
			variation => N__('Indian: 2. c3 g6 3. Bg5'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/3P4/2N5/PPP1PPPP/R1BQKBNR b KQkq' => {
			eco => 'A45f',
			# TRANSLATORS: A45f: 1. d4 Nf6 2. Nc3
			variation => N__('Indian: 2. Nc3'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/3P1B2/8/PPP1PPPP/RN1QKBNR b KQkq' => {
			eco => 'A45g',
			# TRANSLATORS: A45g: 1. d4 Nf6 2. Bf4
			variation => N__('Indian: 2. Bf4'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/3P4/6P1/PPP1PP1P/RNBQKBNR b KQkq' => {
			eco => 'A45h',
			# TRANSLATORS: A45h: 1. d4 Nf6 2. g3
			variation => N__('Indian: 2. g3'),
			moves => {
				'c7c5' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/pppppp1p/5np1/8/3P4/6P1/PPP1PP1P/RNBQKBNR w KQkq' => {
			eco => 'A45h',
			# TRANSLATORS: A45h: 1. d4 Nf6 2. g3 g6
			variation => N__('Indian: 2. g3 g6'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/2p5/3P4/6P1/PPP1PP1P/RNBQKBNR w KQkq' => {
			eco => 'A45i',
			# TRANSLATORS: A45i: 1. d4 Nf6 2. g3 c5
			variation => N__('Indian: 2. g3 c5'),
			moves => {
				'd4d5' => 1,
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/2pP4/8/6P1/PPP1PP1P/RNBQKBNR b KQkq' => {
			eco => 'A45i',
			# TRANSLATORS: A45i: 1. d4 Nf6 2. g3 c5 3. d5
			variation => N__('Indian: 2. g3 c5'),
			moves => {
				'b7b5' => 1,
			},
		},
		'rnbqkb1r/p2ppppp/5n2/1ppP4/8/6P1/PPP1PP1P/RNBQKBNR w KQkq' => {
			eco => 'A45i',
			# TRANSLATORS: A45i: 1. d4 Nf6 2. g3 c5 3. d5 b5
			variation => N__('Indian: 2. g3 c5 3. d5 b5'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/5n2/6B1/3P4/8/PPP1PPPP/RN1QKBNR b KQkq' => {
			eco => 'A45j',
			# TRANSLATORS: A45j: 1. d4 Nf6 2. Bg5
			variation => N__('Trompowsky Opening'),
			moves => {
				'c7c5' => 1,
				'd7d5' => 1,
				'd7d6' => 1,
				'e7e6' => 1,
				'f6e4' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/3p1n2/6B1/3P4/8/PPP1PPPP/RN1QKBNR w KQkq' => {
			eco => 'A45j',
			# TRANSLATORS: A45j: 1. d4 Nf6 2. Bg5 d6
			variation => N__('Trompowsky 2... d6'),
			moves => {
				'b1c3' => 1,
				'g5f6' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/3p1n2/6B1/3P4/2N5/PPP1PPPP/R2QKBNR b KQkq' => {
			eco => 'A45j',
			# TRANSLATORS: A45j: 1. d4 Nf6 2. Bg5 d6 3. Nc3
			variation => N__('Trompowsky 2... d6 3. Nc3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/3p1B2/8/3P4/8/PPP1PPPP/RN1QKBNR b KQkq' => {
			eco => 'A45j',
			# TRANSLATORS: A45j: 1. d4 Nf6 2. Bg5 d6 3. Bxf6
			variation => N__('Trompowsky 2... d6 3.Bxf6'),
			moves => {
			},
		},
		'rnbqkb1r/pppppp1p/5np1/6B1/3P4/8/PPP1PPPP/RN1QKBNR w KQkq' => {
			eco => 'A45k',
			# TRANSLATORS: A45k: 1. d4 Nf6 2. Bg5 g6
			variation => N__('Trompowsky 2... g6'),
			moves => {
				'b1c3' => 1,
				'g5f6' => 1,
			},
		},
		'rnbqkb1r/pppppp1p/5np1/6B1/3P4/2N5/PPP1PPPP/R2QKBNR b KQkq' => {
			eco => 'A45k',
			# TRANSLATORS: A45k: 1. d4 Nf6 2. Bg5 g6 3. Nc3
			variation => N__('Trompowsky 2... g6 3. Nc3'),
			moves => {
			},
		},
		'rnbqkb1r/pppppp1p/5Bp1/8/3P4/8/PPP1PPPP/RN1QKBNR b KQkq' => {
			eco => 'A45k',
			# TRANSLATORS: A45k: 1. d4 Nf6 2. Bg5 g6 3. Bxf6
			variation => N__('Trompowsky 2... g6 3.Bxf6'),
			moves => {
				'e7f6' => 1,
			},
		},
		'rnbqkb1r/pppp1p1p/5pp1/8/3P4/8/PPP1PPPP/RN1QKBNR w KQkq' => {
			eco => 'A45k',
			# TRANSLATORS: A45k: 1. d4 Nf6 2. Bg5 g6 3. Bxf6 exf6
			variation => N__('Trompowsky 2... g6 3.Bxf6'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbqkb1r/pppp1p1p/5pp1/8/3P4/4P3/PPP2PPP/RN1QKBNR b KQkq' => {
			eco => 'A45l',
			# TRANSLATORS: A45l: 1. d4 Nf6 2. Bg5 g6 3. Bxf6 exf6 4. e3
			variation => N__('Trompowsky 2... g6 3.Bxf6 exf6 4. e3'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/4pn2/6B1/3P4/8/PPP1PPPP/RN1QKBNR w KQkq' => {
			eco => 'A45m',
			# TRANSLATORS: A45m: 1. d4 Nf6 2. Bg5 e6
			variation => N__('Trompowsky: 2... e6'),
			moves => {
				'b1c3' => 1,
				'b1d2' => 1,
				'e2e3' => 1,
				'e2e4' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/4pn2/6B1/3P4/2N5/PPP1PPPP/R2QKBNR b KQkq' => {
			eco => 'A45m',
			# TRANSLATORS: A45m: 1. d4 Nf6 2. Bg5 e6 3. Nc3
			variation => N__('Trompowsky: 2... e6 3. Nc3'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/4pn2/6B1/3P4/8/PPPNPPPP/R2QKBNR b KQkq' => {
			eco => 'A45m',
			# TRANSLATORS: A45m: 1. d4 Nf6 2. Bg5 e6 3. Nd2
			variation => N__('Trompowsky: 2... e6 3. Nd2'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/4pn2/6B1/3P4/4P3/PPP2PPP/RN1QKBNR b KQkq' => {
			eco => 'A45m',
			# TRANSLATORS: A45m: 1. d4 Nf6 2. Bg5 e6 3. e3
			variation => N__('Trompowsky: 2... e6 3. e3'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/4pn2/6B1/3PP3/8/PPP2PPP/RN1QKBNR b KQkq' => {
			eco => 'A45n',
			# TRANSLATORS: A45n: 1. d4 Nf6 2. Bg5 e6 3. e4
			variation => N__('Trompowsky: 2... e6 3. e4'),
			moves => {
				'h7h6' => 1,
			},
		},
		'rnbqkb1r/pppp1pp1/4pn1p/6B1/3PP3/8/PPP2PPP/RN1QKBNR w KQkq' => {
			eco => 'A45n',
			# TRANSLATORS: A45n: 1. d4 Nf6 2. Bg5 e6 3. e4 h6
			variation => N__('Trompowsky: 2... e6 3. e4 h6'),
			moves => {
				'g5f6' => 1,
			},
		},
		'rnbqkb1r/pppp1pp1/4pB1p/8/3PP3/8/PPP2PPP/RN1QKBNR b KQkq' => {
			eco => 'A45n',
			# TRANSLATORS: A45n: 1. d4 Nf6 2. Bg5 e6 3. e4 h6 4. Bxf6
			variation => N__('Trompowsky: 2... e6 3. e4 h6 4.Bxf6'),
			moves => {
				'd8f6' => 1,
			},
		},
		'rnb1kb1r/pppp1pp1/4pq1p/8/3PP3/8/PPP2PPP/RN1QKBNR w KQkq' => {
			eco => 'A45n',
			# TRANSLATORS: A45n: 1. d4 Nf6 2. Bg5 e6 3. e4 h6 4. Bxf6 Qxf6
			variation => N__('Trompowsky: 2... e6 3. e4 h6 4.Bxf6 Qxf6'),
			moves => {
				'b1c3' => 1,
				'c2c3' => 1,
			},
		},
		'rnb1kb1r/pppp1pp1/4pq1p/8/3PP3/2P5/PP3PPP/RN1QKBNR b KQkq' => {
			eco => 'A45n',
			# TRANSLATORS: A45n: 1. d4 Nf6 2. Bg5 e6 3. e4 h6 4. Bxf6 Qxf6 5. c3
			variation => N__('Trompowsky: 2... e6 3. e4 h6 4.Bxf6 Qxf6 5. c3'),
			moves => {
			},
		},
		'rnb1kb1r/pppp1pp1/4pq1p/8/3PP3/2N5/PPP2PPP/R2QKBNR b KQkq' => {
			eco => 'A45o',
			# TRANSLATORS: A45o: 1. d4 Nf6 2. Bg5 e6 3. e4 h6 4. Bxf6 Qxf6 5. Nc3
			variation => N__('Trompowsky: 2... e6 3. e4 h6 4.Bxf6 Qxf6 5. Nc3'),
			moves => {
				'd7d6' => 1,
				'f8b4' => 1,
			},
		},
		'rnb1kb1r/ppp2pp1/3ppq1p/8/3PP3/2N5/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'A45o',
			# TRANSLATORS: A45o: 1. d4 Nf6 2. Bg5 e6 3. e4 h6 4. Bxf6 Qxf6 5. Nc3 d6
			variation => N__('Trompowsky: 2... e6 3. e4 h6 4.Bxf6 Qxf6 5. Nc3 d6'),
			moves => {
				'd1d2' => 1,
			},
		},
		'rnb1kb1r/ppp2pp1/3ppq1p/8/3PP3/2N5/PPPQ1PPP/R3KBNR b KQkq' => {
			eco => 'A45o',
			# TRANSLATORS: A45o: 1. d4 Nf6 2. Bg5 e6 3. e4 h6 4. Bxf6 Qxf6 5. Nc3 d6 6. Qd2
			variation => N__('Trompowsky: 2... e6 3. e4 h6 4.Bxf6 Qxf6 5. Nc3 d6 6. Qd2'),
			moves => {
				'g7g5' => 1,
			},
		},
		'rnb1kb1r/ppp2p2/3ppq1p/6p1/3PP3/2N5/PPPQ1PPP/R3KBNR w KQkq' => {
			eco => 'A45o',
			# TRANSLATORS: A45o: 1. d4 Nf6 2. Bg5 e6 3. e4 h6 4. Bxf6 Qxf6 5. Nc3 d6 6. Qd2 g5
			variation => N__('Trompowsky: 2... e6 3. e4 h6 4.Bxf6 Qxf6 5. Nc3 d6 6. Qd2 g5'),
			moves => {
			},
		},
		'rnb1k2r/pppp1pp1/4pq1p/8/1b1PP3/2N5/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'A45o',
			# TRANSLATORS: A45o: 1. d4 Nf6 2. Bg5 e6 3. e4 h6 4. Bxf6 Qxf6 5. Nc3 Bb4
			variation => N__('Trompowsky: 2... e6 3. e4 h6 4.Bxf6 Qxf6 5. Nc3 Bb4'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/2p3B1/3P4/8/PPP1PPPP/RN1QKBNR w KQkq' => {
			eco => 'A45p',
			# TRANSLATORS: A45p: 1. d4 Nf6 2. Bg5 c5
			variation => N__('Trompowsky: 2... c5'),
			moves => {
				'b1c3' => 1,
				'd4c5' => 1,
				'd4d5' => 1,
				'g5f6' => 1,
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/2p3B1/3P4/2N5/PPP1PPPP/R2QKBNR b KQkq' => {
			eco => 'A45p',
			# TRANSLATORS: A45p: 1. d4 Nf6 2. Bg5 c5 3. Nc3
			variation => N__('Trompowsky: 2... c5 3. Nc3'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/2P3B1/8/8/PPP1PPPP/RN1QKBNR b KQkq' => {
			eco => 'A45p',
			# TRANSLATORS: A45p: 1. d4 Nf6 2. Bg5 c5 3. dxc5
			variation => N__('Trompowsky: 2... c5 3.dxc5'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/2pP2B1/8/8/PPP1PPPP/RN1QKBNR b KQkq' => {
			eco => 'A45p',
			# TRANSLATORS: A45p: 1. d4 Nf6 2. Bg5 c5 3. d5
			variation => N__('Trompowsky: 2... c5 3. d5'),
			moves => {
				'd8b6' => 1,
			},
		},
		'rnb1kb1r/pp1ppppp/1q3n2/2pP2B1/8/8/PPP1PPPP/RN1QKBNR w KQkq' => {
			eco => 'A45p',
			# TRANSLATORS: A45p: 1. d4 Nf6 2. Bg5 c5 3. d5 Qb6
			variation => N__('Trompowsky: 2... c5 3. d5 Qb6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnb1kb1r/pp1ppppp/1q3n2/2pP2B1/8/2N5/PPP1PPPP/R2QKBNR b KQkq' => {
			eco => 'A45p',
			# TRANSLATORS: A45p: 1. d4 Nf6 2. Bg5 c5 3. d5 Qb6 4. Nc3
			variation => N__('Trompowsky: 2... c5 3. d5 Qb6 4. Nc3'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/5B2/2p5/3P4/8/PPP1PPPP/RN1QKBNR b KQkq' => {
			eco => 'A45q',
			# TRANSLATORS: A45q: 1. d4 Nf6 2. Bg5 c5 3. Bxf6
			variation => N__('Trompowsky: 2... c5 3.Bxf6'),
			moves => {
				'g7f6' => 1,
			},
		},
		'rnbqkb1r/pp1ppp1p/5p2/2p5/3P4/8/PPP1PPPP/RN1QKBNR w KQkq' => {
			eco => 'A45q',
			# TRANSLATORS: A45q: 1. d4 Nf6 2. Bg5 c5 3. Bxf6 gxf6
			variation => N__('Trompowsky: 2... c5 3.Bxf6 gxf6'),
			moves => {
				'd4d5' => 1,
			},
		},
		'rnbqkb1r/pp1ppp1p/5p2/2pP4/8/8/PPP1PPPP/RN1QKBNR b KQkq' => {
			eco => 'A45q',
			# TRANSLATORS: A45q: 1. d4 Nf6 2. Bg5 c5 3. Bxf6 gxf6 4. d5
			variation => N__('Trompowsky: 2... c5 3.Bxf6 gxf6 4. d5'),
			moves => {
				'd8b6' => 1,
			},
		},
		'rnb1kb1r/pp1ppp1p/1q3p2/2pP4/8/8/PPP1PPPP/RN1QKBNR w KQkq' => {
			eco => 'A45r',
			# TRANSLATORS: A45r: 1. d4 Nf6 2. Bg5 c5 3. Bxf6 gxf6 4. d5 Qb6
			variation => N__('Trompowsky: 2... c5 3.Bxf6 gxf6 4. d5 Qb6'),
			moves => {
				'd1c1' => 1,
			},
		},
		'rnb1kb1r/pp1ppp1p/1q3p2/2pP4/8/8/PPP1PPPP/RNQ1KBNR b KQkq' => {
			eco => 'A45r',
			# TRANSLATORS: A45r: 1. d4 Nf6 2. Bg5 c5 3. Bxf6 gxf6 4. d5 Qb6 5. Qc1
			variation => N__('Trompowsky: 2... c5 3.Bxf6 gxf6 4. d5 Qb6 5. Qc1'),
			moves => {
				'f6f5' => 1,
			},
		},
		'rnb1kb1r/pp1ppp1p/1q6/2pP1p2/8/8/PPP1PPPP/RNQ1KBNR w KQkq' => {
			eco => 'A45r',
			# TRANSLATORS: A45r: 1. d4 Nf6 2. Bg5 c5 3. Bxf6 gxf6 4. d5 Qb6 5. Qc1 f5
			variation => N__('Trompowsky: 2... c5 3.Bxf6 gxf6 4. d5 Qb6 5. Qc1 f5'),
			moves => {
				'c2c4' => 1,
				'e2e3' => 1,
				'g2g3' => 1,
			},
		},
		'rnb1kb1r/pp1ppp1p/1q6/2pP1p2/2P5/8/PP2PPPP/RNQ1KBNR b KQkq' => {
			eco => 'A45r',
			# TRANSLATORS: A45r: 1. d4 Nf6 2. Bg5 c5 3. Bxf6 gxf6 4. d5 Qb6 5. Qc1 f5 6. c4
			variation => N__('Trompowsky: 2... c5 3.Bxf6 gxf6 4. d5 Qb6 5. Qc1 f5 6. c4'),
			moves => {
			},
		},
		'rnb1kb1r/pp1ppp1p/1q6/2pP1p2/8/4P3/PPP2PPP/RNQ1KBNR b KQkq' => {
			eco => 'A45r',
			# TRANSLATORS: A45r: 1. d4 Nf6 2. Bg5 c5 3. Bxf6 gxf6 4. d5 Qb6 5. Qc1 f5 6. e3
			variation => N__('Trompowsky: 2... c5 3.Bxf6 gxf6 4. d5 Qb6 5. Qc1 f5 6. e3'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnb1k2r/pp1pppbp/1q6/2pP1p2/8/4P3/PPP2PPP/RNQ1KBNR w KQkq' => {
			eco => 'A45r',
			# TRANSLATORS: A45r: 1. d4 Nf6 2. Bg5 c5 3. Bxf6 gxf6 4. d5 Qb6 5. Qc1 f5 6. e3 Bg7
			variation => N__('Trompowsky: 2... c5 3.Bxf6 gxf6 4. d5 Qb6 5. Qc1 f5 6. e3 Bg7'),
			moves => {
			},
		},
		'rnb1kb1r/pp1ppp1p/1q6/2pP1p2/8/6P1/PPP1PP1P/RNQ1KBNR b KQkq' => {
			eco => 'A45r',
			# TRANSLATORS: A45r: 1. d4 Nf6 2. Bg5 c5 3. Bxf6 gxf6 4. d5 Qb6 5. Qc1 f5 6. g3
			variation => N__('Trompowsky: 2... c5 3.Bxf6 gxf6 4. d5 Qb6 5. Qc1 f5 6. g3'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/8/6B1/3Pn3/8/PPP1PPPP/RN1QKBNR w KQkq' => {
			eco => 'A45s',
			# TRANSLATORS: A45s: 1. d4 Nf6 2. Bg5 Ne4
			variation => N__('Trompowsky: 2... Ne4'),
			moves => {
				'g5f4' => 1,
				'g5h4' => 1,
				'h2h4' => 1,
			},
		},
		'rnbqkb1r/pppppppp/8/6B1/3Pn2P/8/PPP1PPP1/RN1QKBNR b KQkq' => {
			eco => 'A45s',
			# TRANSLATORS: A45s: 1. d4 Nf6 2. Bg5 Ne4 3. h4
			variation => N__('Trompowsky: 2... Ne4 3. h4'),
			moves => {
				'c7c5' => 1,
				'd7d5' => 1,
			},
		},
		'rnbqkb1r/pp1ppppp/8/2p3B1/3Pn2P/8/PPP1PPP1/RN1QKBNR w KQkq' => {
			eco => 'A45s',
			# TRANSLATORS: A45s: 1. d4 Nf6 2. Bg5 Ne4 3. h4 c5
			variation => N__('Trompowsky: 2... Ne4 3. h4 c5'),
			moves => {
				'd4c5' => 1,
				'd4d5' => 1,
			},
		},
		'rnbqkb1r/pp1ppppp/8/2P3B1/4n2P/8/PPP1PPP1/RN1QKBNR b KQkq' => {
			eco => 'A45s',
			# TRANSLATORS: A45s: 1. d4 Nf6 2. Bg5 Ne4 3. h4 c5 4. dxc5
			variation => N__('Trompowsky: 2... Ne4 3. h4 c5 4.dxc5'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/8/2pP2B1/4n2P/8/PPP1PPP1/RN1QKBNR b KQkq' => {
			eco => 'A45s',
			# TRANSLATORS: A45s: 1. d4 Nf6 2. Bg5 Ne4 3. h4 c5 4. d5
			variation => N__('Trompowsky: 2... Ne4 3. h4 c5 4. d5'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/8/3p2B1/3Pn2P/8/PPP1PPP1/RN1QKBNR w KQkq' => {
			eco => 'A45s',
			# TRANSLATORS: A45s: 1. d4 Nf6 2. Bg5 Ne4 3. h4 d5
			variation => N__('Trompowsky: 2... Ne4 3. h4 d5'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/8/8/3Pn2B/8/PPP1PPPP/RN1QKBNR b KQkq' => {
			eco => 'A45t',
			# TRANSLATORS: A45t: 1. d4 Nf6 2. Bg5 Ne4 3. Bh4
			variation => N__('Trompowsky: 2... Ne4 3. Bh4'),
			moves => {
				'c7c5' => 1,
				'd7d5' => 1,
				'g7g5' => 1,
			},
		},
		'rnbqkb1r/pp1ppppp/8/2p5/3Pn2B/8/PPP1PPPP/RN1QKBNR w KQkq' => {
			eco => 'A45t',
			# TRANSLATORS: A45t: 1. d4 Nf6 2. Bg5 Ne4 3. Bh4 c5
			variation => N__('Trompowsky: 2... Ne4 3. Bh4 c5'),
			moves => {
				'f2f3' => 1,
			},
		},
		'rnbqkb1r/pp1ppppp/8/2p5/3Pn2B/5P2/PPP1P1PP/RN1QKBNR b KQkq' => {
			eco => 'A45t',
			# TRANSLATORS: A45t: 1. d4 Nf6 2. Bg5 Ne4 3. Bh4 c5 4. f3
			variation => N__('Trompowsky: 2... Ne4 3. Bh4 c5 4. f3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/8/3p4/3Pn2B/8/PPP1PPPP/RN1QKBNR w KQkq' => {
			eco => 'A45t',
			# TRANSLATORS: A45t: 1. d4 Nf6 2. Bg5 Ne4 3. Bh4 d5
			variation => N__('Trompowsky: 2... Ne4 3. Bh4 d5'),
			moves => {
			},
		},
		'rnbqkb1r/pppppp1p/8/6p1/3Pn2B/8/PPP1PPPP/RN1QKBNR w KQkq' => {
			eco => 'A45t',
			# TRANSLATORS: A45t: 1. d4 Nf6 2. Bg5 Ne4 3. Bh4 g5
			variation => N__('Trompowsky: 2... Ne4 3. Bh4 g5'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/8/8/3PnB2/8/PPP1PPPP/RN1QKBNR b KQkq' => {
			eco => 'A45u',
			# TRANSLATORS: A45u: 1. d4 Nf6 2. Bg5 Ne4 3. Bf4
			variation => N__('Trompowsky: 2... Ne4 3. Bf4'),
			moves => {
				'c7c5' => 1,
				'd7d5' => 1,
				'g7g5' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/8/3p4/3PnB2/8/PPP1PPPP/RN1QKBNR w KQkq' => {
			eco => 'A45u',
			# TRANSLATORS: A45u: 1. d4 Nf6 2. Bg5 Ne4 3. Bf4 d5
			variation => N__('Trompowsky: 2... Ne4 3. Bf4 d5'),
			moves => {
				'b1d2' => 1,
				'e2e3' => 1,
				'f2f3' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/8/3p4/3PnB2/8/PPPNPPPP/R2QKBNR b KQkq' => {
			eco => 'A45u',
			# TRANSLATORS: A45u: 1. d4 Nf6 2. Bg5 Ne4 3. Bf4 d5 4. Nd2
			variation => N__('Trompowsky: 2... Ne4 3. Bf4 d5 4. Nd2'),
			moves => {
			},
		},
		'rnbqkb1r/pppppp1p/8/6p1/3PnB2/8/PPP1PPPP/RN1QKBNR w KQkq' => {
			eco => 'A45u',
			# TRANSLATORS: A45u: 1. d4 Nf6 2. Bg5 Ne4 3. Bf4 g5
			variation => N__('Trompowsky: Borg Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/8/3p4/3PnB2/5P2/PPP1P1PP/RN1QKBNR b KQkq' => {
			eco => 'A45v',
			# TRANSLATORS: A45v: 1. d4 Nf6 2. Bg5 Ne4 3. Bf4 d5 4. f3
			variation => N__('Trompowsky: 2... Ne4 3. Bf4 d5 4. f3'),
			moves => {
				'e4f6' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/3P1B2/5P2/PPP1P1PP/RN1QKBNR w KQkq' => {
			eco => 'A45v',
			# TRANSLATORS: A45v: 1. d4 Nf6 2. Bg5 Ne4 3. Bf4 d5 4. f3 Nf6
			variation => N__('Trompowsky: 2... Ne4 3. Bf4 d5 4. f3 Nf6'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/8/3p4/3PnB2/4P3/PPP2PPP/RN1QKBNR b KQkq' => {
			eco => 'A45w',
			# TRANSLATORS: A45w: 1. d4 Nf6 2. Bg5 Ne4 3. Bf4 d5 4. e3
			variation => N__('Trompowsky: 2... Ne4 3. Bf4 d5 4. e3'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/8/2pp4/3PnB2/4P3/PPP2PPP/RN1QKBNR w KQkq' => {
			eco => 'A45w',
			# TRANSLATORS: A45w: 1. d4 Nf6 2. Bg5 Ne4 3. Bf4 d5 4. e3 c5
			variation => N__('Trompowsky: 2... Ne4 3. Bf4 d5 4. e3 c5'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/8/2p5/3PnB2/8/PPP1PPPP/RN1QKBNR w KQkq' => {
			eco => 'A45x',
			# TRANSLATORS: A45x: 1. d4 Nf6 2. Bg5 Ne4 3. Bf4 c5
			variation => N__('Trompowsky: 2... Ne4 3. Bf4 c5'),
			moves => {
				'd4d5' => 1,
				'f2f3' => 1,
			},
		},
		'rnbqkb1r/pp1ppppp/8/2pP4/4nB2/8/PPP1PPPP/RN1QKBNR b KQkq' => {
			eco => 'A45x',
			# TRANSLATORS: A45x: 1. d4 Nf6 2. Bg5 Ne4 3. Bf4 c5 4. d5
			variation => N__('Trompowsky: 2... Ne4 3. Bf4 c5 4. d5'),
			moves => {
				'd8b6' => 1,
			},
		},
		'rnb1kb1r/pp1ppppp/1q6/2pP4/4nB2/8/PPP1PPPP/RN1QKBNR w KQkq' => {
			eco => 'A45x',
			# TRANSLATORS: A45x: 1. d4 Nf6 2. Bg5 Ne4 3. Bf4 c5 4. d5 Qb6
			variation => N__('Trompowsky: 2... Ne4 3. Bf4 c5 4. d5 Qb6'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/8/2p5/3PnB2/5P2/PPP1P1PP/RN1QKBNR b KQkq' => {
			eco => 'A45y',
			# TRANSLATORS: A45y: 1. d4 Nf6 2. Bg5 Ne4 3. Bf4 c5 4. f3
			variation => N__('Trompowsky: 2... Ne4 3. Bf4 c5 4. f3'),
			moves => {
				'd8a5' => 1,
			},
		},
		'rnb1kb1r/pp1ppppp/8/q1p5/3PnB2/5P2/PPP1P1PP/RN1QKBNR w KQkq' => {
			eco => 'A45y',
			# TRANSLATORS: A45y: 1. d4 Nf6 2. Bg5 Ne4 3. Bf4 c5 4. f3 Qa5+
			variation => N__('Trompowsky: 2... Ne4 3. Bf4 c5 4. f3 Qa5+'),
			moves => {
				'c2c3' => 1,
			},
		},
		'rnb1kb1r/pp1ppppp/8/q1p5/3PnB2/2P2P2/PP2P1PP/RN1QKBNR b KQkq' => {
			eco => 'A45y',
			# TRANSLATORS: A45y: 1. d4 Nf6 2. Bg5 Ne4 3. Bf4 c5 4. f3 Qa5+ 5. c3
			variation => N__('Trompowsky: 2... Ne4 3. Bf4 c5 4. f3 Qa5+'),
			moves => {
				'e4f6' => 1,
			},
		},
		'rnb1kb1r/pp1ppppp/5n2/q1p5/3P1B2/2P2P2/PP2P1PP/RN1QKBNR w KQkq' => {
			eco => 'A45y',
			# TRANSLATORS: A45y: 1. d4 Nf6 2. Bg5 Ne4 3. Bf4 c5 4. f3 Qa5+ 5. c3 Nf6
			variation => N__('Trompowsky: 2... Ne4 3. Bf4 c5 4. f3 Qa5+'),
			moves => {
				'b1d2' => 1,
				'd4d5' => 1,
			},
		},
		'rnb1kb1r/pp1ppppp/5n2/q1pP4/5B2/2P2P2/PP2P1PP/RN1QKBNR b KQkq' => {
			eco => 'A45y',
			# TRANSLATORS: A45y: 1. d4 Nf6 2. Bg5 Ne4 3. Bf4 c5 4. f3 Qa5+ 5. c3 Nf6 6. d5
			variation => N__('Trompowsky: 2... Ne4 3. Bf4 c5 4. f3 Qa5+ 5. c3 Nf6 6. d5'),
			moves => {
			},
		},
		'rnb1kb1r/pp1ppppp/5n2/q1p5/3P1B2/2P2P2/PP1NP1PP/R2QKBNR b KQkq' => {
			eco => 'A45z',
			# TRANSLATORS: A45z: 1. d4 Nf6 2. Bg5 Ne4 3. Bf4 c5 4. f3 Qa5+ 5. c3 Nf6 6. Nd2
			variation => N__('Trompowsky: 2... Ne4 3. Bf4 c5 4. f3 Qa5+ 5. c3 Nf6 6. Nd2'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/3P4/5N2/PPP1PPPP/RNBQKB1R b KQkq' => {
			eco => 'A46a',
			# TRANSLATORS: A46a: 1. d4 Nf6 2. Nf3
			variation => N__('Indian: 2. Nf3'),
			moves => {
				'b7b5' => 1,
				'b7b6' => 1,
				'c7c5' => 1,
				'd7d6' => 1,
				'e7e6' => 1,
				'f6e4' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/pppppppp/8/8/3Pn3/5N2/PPP1PPPP/RNBQKB1R w KQkq' => {
			eco => 'A46a',
			# TRANSLATORS: A46a: 1. d4 Nf6 2. Nf3 Ne4
			variation => N__('Indian: Döry Defence'),
			moves => {
			},
		},
		'rnbqkb1r/p1pppppp/5n2/1p6/3P4/5N2/PPP1PPPP/RNBQKB1R w KQkq' => {
			eco => 'A46b',
			# TRANSLATORS: A46b: 1. d4 Nf6 2. Nf3 b5
			variation => N__('Indian: 2. Nf3 b5'),
			moves => {
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/p1pppppp/5n2/1p6/3P4/5NP1/PPP1PP1P/RNBQKB1R b KQkq' => {
			eco => 'A46b',
			# TRANSLATORS: A46b: 1. d4 Nf6 2. Nf3 b5 3. g3
			variation => N__('Indian: 2. Nf3 b5 3. g3'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/2p5/3P4/5N2/PPP1PPPP/RNBQKB1R w KQkq' => {
			eco => 'A46c',
			# TRANSLATORS: A46c: 1. d4 Nf6 2. Nf3 c5
			variation => N__('Neo-Benoni'),
			moves => {
				'c2c3' => 1,
				'd4c5' => 1,
				'e2e3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/2P5/8/5N2/PPP1PPPP/RNBQKB1R b KQkq' => {
			eco => 'A46c',
			# TRANSLATORS: A46c: 1. d4 Nf6 2. Nf3 c5 3. dxc5
			variation => N__('Neo-Benoni 3.dxc5'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/2p5/3P4/4PN2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'A46c',
			# TRANSLATORS: A46c: 1. d4 Nf6 2. Nf3 c5 3. e3
			variation => N__('Neo-Benoni: 3. e3'),
			moves => {
				'c5d4' => 1,
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/8/3p4/4PN2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'A46c',
			# TRANSLATORS: A46c: 1. d4 Nf6 2. Nf3 c5 3. e3 cxd4
			variation => N__('Neo-Benoni: 3. e3 cxd4'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/2p5/3P4/2P2N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'A46d',
			# TRANSLATORS: A46d: 1. d4 Nf6 2. Nf3 c5 3. c3
			variation => N__('Neo-Benoni: 3. c3'),
			moves => {
				'b7b6' => 1,
				'c5d4' => 1,
				'e7e6' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/p2ppppp/1p3n2/2p5/3P4/2P2N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A46d',
			# TRANSLATORS: A46d: 1. d4 Nf6 2. Nf3 c5 3. c3 b6
			variation => N__('Neo-Benoni: 3. c3 b6'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/8/3p4/2P2N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A46d',
			# TRANSLATORS: A46d: 1. d4 Nf6 2. Nf3 c5 3. c3 cxd4
			variation => N__('Neo-Benoni: 3. c3 cxd4'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppp1p/5np1/2p5/3P4/2P2N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A46d',
			# TRANSLATORS: A46d: 1. d4 Nf6 2. Nf3 c5 3. c3 g6
			variation => N__('Neo-Benoni: 3. c3 g6'),
			moves => {
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/2p5/3P4/2P2N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A46e',
			# TRANSLATORS: A46e: 1. d4 Nf6 2. Nf3 c5 3. c3 e6
			variation => N__('Neo-Benoni: 3. c3 e6'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/2p5/3P4/5NP1/PPP1PP1P/RNBQKB1R b KQkq' => {
			eco => 'A46f',
			# TRANSLATORS: A46f: 1. d4 Nf6 2. Nf3 c5 3. g3
			variation => N__('Neo-Benoni: 3. g3'),
			moves => {
				'c5d4' => 1,
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/8/3p4/5NP1/PPP1PP1P/RNBQKB1R w KQkq' => {
			eco => 'A46f',
			# TRANSLATORS: A46f: 1. d4 Nf6 2. Nf3 c5 3. g3 cxd4
			variation => N__('Neo-Benoni: 3. g3 cxd4'),
			moves => {
				'f3d4' => 1,
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/8/3N4/6P1/PPP1PP1P/RNBQKB1R b KQkq' => {
			eco => 'A46f',
			# TRANSLATORS: A46f: 1. d4 Nf6 2. Nf3 c5 3. g3 cxd4 4. Nxd4
			variation => N__('Neo-Benoni: 3. g3 cxd4 4.Nxd4'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/3p1n2/8/3P4/5N2/PPP1PPPP/RNBQKB1R w KQkq' => {
			eco => 'A46g',
			# TRANSLATORS: A46g: 1. d4 Nf6 2. Nf3 d6
			variation => N__('Indian: 2. Nf3 d6'),
			moves => {
				'c1g5' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/3p1n2/8/3P4/5NP1/PPP1PP1P/RNBQKB1R b KQkq' => {
			eco => 'A46h',
			# TRANSLATORS: A46h: 1. d4 Nf6 2. Nf3 d6 3. g3
			variation => N__('Indian: 2. Nf3 d6 3. g3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/3p1n2/6B1/3P4/5N2/PPP1PPPP/RN1QKB1R b KQkq' => {
			eco => 'A46i',
			# TRANSLATORS: A46i: 1. d4 Nf6 2. Nf3 d6 3. Bg5
			variation => N__('Indian: 2. Nf3 d6 3. Bg5'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r1bqkb1r/pppnpppp/3p1n2/6B1/3P4/5N2/PPP1PPPP/RN1QKB1R w KQkq' => {
			eco => 'A46i',
			# TRANSLATORS: A46i: 1. d4 Nf6 2. Nf3 d6 3. Bg5 Nbd7
			variation => N__('Indian: 2. Nf3 d6 3. Bg5 Nbd7'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/4pn2/8/3P4/5N2/PPP1PPPP/RNBQKB1R w KQkq' => {
			eco => 'A46j',
			# TRANSLATORS: A46j: 1. d4 Nf6 2. Nf3 e6
			variation => N__('Indian: 2. Nf3 e6'),
			moves => {
				'c1f4' => 1,
				'c1g5' => 1,
				'c2c3' => 1,
				'e2e3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/4pn2/8/3P4/2P2N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'A46j',
			# TRANSLATORS: A46j: 1. d4 Nf6 2. Nf3 e6 3. c3
			variation => N__('Indian: 2. Nf3 e6 3. c3'),
			moves => {
				'b7b6' => 1,
			},
		},
		'rnbqkb1r/p1pp1ppp/1p2pn2/8/3P4/2P2N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A46j',
			# TRANSLATORS: A46j: 1. d4 Nf6 2. Nf3 e6 3. c3 b6
			variation => N__('Indian: 2. Nf3 e6 3. c3 b6'),
			moves => {
				'c1g5' => 1,
			},
		},
		'rnbqkb1r/p1pp1ppp/1p2pn2/6B1/3P4/2P2N2/PP2PPPP/RN1QKB1R b KQkq' => {
			eco => 'A46j',
			# TRANSLATORS: A46j: 1. d4 Nf6 2. Nf3 e6 3. c3 b6 4. Bg5
			variation => N__('Indian: 1. d4 Nf6 2. Nf3 e6 3. c3 b6 4. Bg5'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/4pn2/8/3P4/4PN2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'A46k',
			# TRANSLATORS: A46k: 1. d4 Nf6 2. Nf3 e6 3. e3
			variation => N__('Indian: 1. d4 Nf6 2. Nf3 e6 3. e3'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/2p5/3P4/4PN2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'A46k',
			# TRANSLATORS: A46k: 1. d4 Nf6 2. Nf3 e6 3. e3 c5
			variation => N__('Indian: 1. d4 Nf6 2. Nf3 e6 3. e3 c5'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/2p5/3P4/3BPN2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'A46l',
			# TRANSLATORS: A46l: 1. d4 Nf6 2. Nf3 e6 3. e3 c5 4. Bd3
			variation => N__('Indian: 1. d4 Nf6 2. Nf3 e6 3. e3 c5 4. Bd3'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/4pn2/8/3P4/5NP1/PPP1PP1P/RNBQKB1R b KQkq' => {
			eco => 'A46m',
			# TRANSLATORS: A46m: 1. d4 Nf6 2. Nf3 e6 3. g3
			variation => N__('Indian: 1. d4 Nf6 2. Nf3 e6 3. g3'),
			moves => {
				'b7b5' => 1,
				'c7c5' => 1,
			},
		},
		'rnbqkb1r/p1pp1ppp/4pn2/1p6/3P4/5NP1/PPP1PP1P/RNBQKB1R w KQkq' => {
			eco => 'A46m',
			# TRANSLATORS: A46m: 1. d4 Nf6 2. Nf3 e6 3. g3 b5
			variation => N__('Indian: 1. d4 Nf6 2. Nf3 e6 3. g3 b5'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkb1r/p1pp1ppp/4pn2/1p6/3P4/5NP1/PPP1PPBP/RNBQK2R b KQkq' => {
			eco => 'A46m',
			# TRANSLATORS: A46m: 1. d4 Nf6 2. Nf3 e6 3. g3 b5 4. Bg2
			variation => N__('Indian: 1. d4 Nf6 2. Nf3 e6 3. g3 b5'),
			moves => {
				'c8b7' => 1,
			},
		},
		'rn1qkb1r/pbpp1ppp/4pn2/1p6/3P4/5NP1/PPP1PPBP/RNBQK2R w KQkq' => {
			eco => 'A46m',
			# TRANSLATORS: A46m: 1. d4 Nf6 2. Nf3 e6 3. g3 b5 4. Bg2 Bb7
			variation => N__('Indian: 1. d4 Nf6 2. Nf3 e6 3. g3 b5 4. Bg2 Bb7'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rn1qkb1r/pbpp1ppp/4pn2/1p6/3P4/5NP1/PPP1PPBP/RNBQ1RK1 b kq' => {
			eco => 'A46n',
			# TRANSLATORS: A46n: 1. d4 Nf6 2. Nf3 e6 3. g3 b5 4. Bg2 Bb7 5. O-O
			variation => N__('Indian: 1. d4 Nf6 2. Nf3 e6 3. g3 b5 4. Bg2 Bb7 5.O-O'),
			moves => {
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/2p5/3P4/5NP1/PPP1PP1P/RNBQKB1R w KQkq' => {
			eco => 'A46o',
			# TRANSLATORS: A46o: 1. d4 Nf6 2. Nf3 e6 3. g3 c5
			variation => N__('Indian: 1. d4 Nf6 2. Nf3 e6 3. g3 c5'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/2p5/3P4/5NP1/PPP1PPBP/RNBQK2R b KQkq' => {
			eco => 'A46o',
			# TRANSLATORS: A46o: 1. d4 Nf6 2. Nf3 e6 3. g3 c5 4. Bg2
			variation => N__('Indian: 1. d4 Nf6 2. Nf3 e6 3. g3 c5 4. Bg2'),
			moves => {
				'b8c6' => 1,
				'c5d4' => 1,
				'd8a5' => 1,
				'd8c7' => 1,
			},
		},
		'r1bqkb1r/pp1p1ppp/2n1pn2/2p5/3P4/5NP1/PPP1PPBP/RNBQK2R w KQkq' => {
			eco => 'A46o',
			# TRANSLATORS: A46o: 1. d4 Nf6 2. Nf3 e6 3. g3 c5 4. Bg2 Nc6
			variation => N__('Indian: 1. d4 Nf6 2. Nf3 e6 3. g3 c5 4. Bg2 Nc6'),
			moves => {
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/8/3p4/5NP1/PPP1PPBP/RNBQK2R w KQkq' => {
			eco => 'A46o',
			# TRANSLATORS: A46o: 1. d4 Nf6 2. Nf3 e6 3. g3 c5 4. Bg2 cxd4
			variation => N__('Indian: 1. d4 Nf6 2. Nf3 e6 3. g3 c5 4. Bg2 cxd4'),
			moves => {
			},
		},
		'rnb1kb1r/pp1p1ppp/4pn2/q1p5/3P4/5NP1/PPP1PPBP/RNBQK2R w KQkq' => {
			eco => 'A46o',
			# TRANSLATORS: A46o: 1. d4 Nf6 2. Nf3 e6 3. g3 c5 4. Bg2 Qa5+
			variation => N__('Indian: 1. d4 Nf6 2. Nf3 e6 3. g3 c5 4. Bg2 Qa5+'),
			moves => {
			},
		},
		'rnb1kb1r/ppqp1ppp/4pn2/2p5/3P4/5NP1/PPP1PPBP/RNBQK2R w KQkq' => {
			eco => 'A46o',
			# TRANSLATORS: A46o: 1. d4 Nf6 2. Nf3 e6 3. g3 c5 4. Bg2 Qc7
			variation => N__('Indian: 1. d4 Nf6 2. Nf3 e6 3. g3 c5 4. Bg2 Qc7'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/4pn2/8/3P1B2/5N2/PPP1PPPP/RN1QKB1R b KQkq' => {
			eco => 'A46p',
			# TRANSLATORS: A46p: 1. d4 Nf6 2. Nf3 e6 3. Bf4
			variation => N__('Indian: London System'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/2p5/3P1B2/5N2/PPP1PPPP/RN1QKB1R w KQkq' => {
			eco => 'A46p',
			# TRANSLATORS: A46p: 1. d4 Nf6 2. Nf3 e6 3. Bf4 c5
			variation => N__('Indian: London, 3... c5'),
			moves => {
				'c2c3' => 1,
				'e2e3' => 1,
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/2p5/3P1B2/4PN2/PPP2PPP/RN1QKB1R b KQkq' => {
			eco => 'A46p',
			# TRANSLATORS: A46p: 1. d4 Nf6 2. Nf3 e6 3. Bf4 c5 4. e3
			variation => N__('Indian: London, 3... c5 4. e3'),
			moves => {
				'd8b6' => 1,
			},
		},
		'rnb1kb1r/pp1p1ppp/1q2pn2/2p5/3P1B2/4PN2/PPP2PPP/RN1QKB1R w KQkq' => {
			eco => 'A46p',
			# TRANSLATORS: A46p: 1. d4 Nf6 2. Nf3 e6 3. Bf4 c5 4. e3 Qb6
			variation => N__('Indian: London, 3... c5 4. e3 Qb6'),
			moves => {
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/2p5/3P1B2/2P2N2/PP2PPPP/RN1QKB1R b KQkq' => {
			eco => 'A46q',
			# TRANSLATORS: A46q: 1. d4 Nf6 2. Nf3 e6 3. Bf4 c5 4. c3
			variation => N__('Indian: London, 3... c5 4. c3'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/4pn2/6B1/3P4/5N2/PPP1PPPP/RN1QKB1R b KQkq' => {
			eco => 'A46r',
			# TRANSLATORS: A46r: 1. d4 Nf6 2. Nf3 e6 3. Bg5
			variation => N__('Torre Attack'),
			moves => {
				'b7b6' => 1,
				'c7c5' => 1,
				'f8e7' => 1,
				'h7h6' => 1,
			},
		},
		'rnbqkb1r/p1pp1ppp/1p2pn2/6B1/3P4/5N2/PPP1PPPP/RN1QKB1R w KQkq' => {
			eco => 'A46r',
			# TRANSLATORS: A46r: 1. d4 Nf6 2. Nf3 e6 3. Bg5 b6
			variation => N__('Torre Attack: 3... b6'),
			moves => {
			},
		},
		'rnbqk2r/ppppbppp/4pn2/6B1/3P4/5N2/PPP1PPPP/RN1QKB1R w KQkq' => {
			eco => 'A46r',
			# TRANSLATORS: A46r: 1. d4 Nf6 2. Nf3 e6 3. Bg5 Be7
			variation => N__('Torre Attack: 3... Be7'),
			moves => {
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/2p3B1/3P4/5N2/PPP1PPPP/RN1QKB1R w KQkq' => {
			eco => 'A46s',
			# TRANSLATORS: A46s: 1. d4 Nf6 2. Nf3 e6 3. Bg5 c5
			variation => N__('Torre Attack: 3... c5'),
			moves => {
				'c2c3' => 1,
				'e2e3' => 1,
				'e2e4' => 1,
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/2p3B1/3PP3/5N2/PPP2PPP/RN1QKB1R b KQkq' => {
			eco => 'A46s',
			# TRANSLATORS: A46s: 1. d4 Nf6 2. Nf3 e6 3. Bg5 c5 4. e4
			variation => N__('Torre Attack: Wagner Gambit'),
			moves => {
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/2p3B1/3P4/2P2N2/PP2PPPP/RN1QKB1R b KQkq' => {
			eco => 'A46t',
			# TRANSLATORS: A46t: 1. d4 Nf6 2. Nf3 e6 3. Bg5 c5 4. c3
			variation => N__('Torre Attack: 3... c5 4. c3'),
			moves => {
				'd8b6' => 1,
				'h7h6' => 1,
			},
		},
		'rnb1kb1r/pp1p1ppp/1q2pn2/2p3B1/3P4/2P2N2/PP2PPPP/RN1QKB1R w KQkq' => {
			eco => 'A46t',
			# TRANSLATORS: A46t: 1. d4 Nf6 2. Nf3 e6 3. Bg5 c5 4. c3 Qb6
			variation => N__('Torre Attack: 3... c5 4. c3 Qb6'),
			moves => {
			},
		},
		'rnbqkb1r/pp1p1pp1/4pn1p/2p3B1/3P4/2P2N2/PP2PPPP/RN1QKB1R w KQkq' => {
			eco => 'A46t',
			# TRANSLATORS: A46t: 1. d4 Nf6 2. Nf3 e6 3. Bg5 c5 4. c3 h6
			variation => N__('Torre Attack: 3... c5 4. c3 h6'),
			moves => {
				'g5h4' => 1,
			},
		},
		'rnbqkb1r/pp1p1pp1/4pn1p/2p5/3P3B/2P2N2/PP2PPPP/RN1QKB1R b KQkq' => {
			eco => 'A46t',
			# TRANSLATORS: A46t: 1. d4 Nf6 2. Nf3 e6 3. Bg5 c5 4. c3 h6 5. Bh4
			variation => N__('Torre Attack: 3... c5 4. c3 h6 5. Bh4'),
			moves => {
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/2p3B1/3P4/4PN2/PPP2PPP/RN1QKB1R b KQkq' => {
			eco => 'A46u',
			# TRANSLATORS: A46u: 1. d4 Nf6 2. Nf3 e6 3. Bg5 c5 4. e3
			variation => N__('Torre Attack: 3... c5 4. e3'),
			moves => {
				'c5d4' => 1,
				'd8b6' => 1,
				'f8e7' => 1,
				'h7h6' => 1,
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/6B1/3p4/4PN2/PPP2PPP/RN1QKB1R w KQkq' => {
			eco => 'A46u',
			# TRANSLATORS: A46u: 1. d4 Nf6 2. Nf3 e6 3. Bg5 c5 4. e3 cxd4
			variation => N__('Torre Attack: 3... c5 4. e3 cxd4'),
			moves => {
			},
		},
		'rnb1kb1r/pp1p1ppp/1q2pn2/2p3B1/3P4/4PN2/PPP2PPP/RN1QKB1R w KQkq' => {
			eco => 'A46u',
			# TRANSLATORS: A46u: 1. d4 Nf6 2. Nf3 e6 3. Bg5 c5 4. e3 Qb6
			variation => N__('Torre Attack: 3... c5 4. e3 Qb6'),
			moves => {
			},
		},
		'rnbqk2r/pp1pbppp/4pn2/2p3B1/3P4/4PN2/PPP2PPP/RN1QKB1R w KQkq' => {
			eco => 'A46v',
			# TRANSLATORS: A46v: 1. d4 Nf6 2. Nf3 e6 3. Bg5 c5 4. e3 Be7
			variation => N__('Torre Attack: 3... c5 4. e3 Be7'),
			moves => {
			},
		},
		'rnbqkb1r/pp1p1pp1/4pn1p/2p3B1/3P4/4PN2/PPP2PPP/RN1QKB1R w KQkq' => {
			eco => 'A46w',
			# TRANSLATORS: A46w: 1. d4 Nf6 2. Nf3 e6 3. Bg5 c5 4. e3 h6
			variation => N__('Torre Attack: 3... c5 4. e3 h6'),
			moves => {
				'g5h4' => 1,
			},
		},
		'rnbqkb1r/pp1p1pp1/4pn1p/2p5/3P3B/4PN2/PPP2PPP/RN1QKB1R b KQkq' => {
			eco => 'A46w',
			# TRANSLATORS: A46w: 1. d4 Nf6 2. Nf3 e6 3. Bg5 c5 4. e3 h6 5. Bh4
			variation => N__('Torre Attack: 3... c5 4. e3 h6 5. Bh4'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1pp1/4pn1p/6B1/3P4/5N2/PPP1PPPP/RN1QKB1R w KQkq' => {
			eco => 'A46x',
			# TRANSLATORS: A46x: 1. d4 Nf6 2. Nf3 e6 3. Bg5 h6
			variation => N__('Torre Attack: 3... h6'),
			moves => {
				'g5f6' => 1,
				'g5h4' => 1,
			},
		},
		'rnbqkb1r/pppp1pp1/4pn1p/8/3P3B/5N2/PPP1PPPP/RN1QKB1R b KQkq' => {
			eco => 'A46x',
			# TRANSLATORS: A46x: 1. d4 Nf6 2. Nf3 e6 3. Bg5 h6 4. Bh4
			variation => N__('Torre Attack: 3... h6 4. Bh4'),
			moves => {
				'g7g5' => 1,
			},
		},
		'rnbqkb1r/pppp1p2/4pn1p/6p1/3P3B/5N2/PPP1PPPP/RN1QKB1R w KQkq' => {
			eco => 'A46x',
			# TRANSLATORS: A46x: 1. d4 Nf6 2. Nf3 e6 3. Bg5 h6 4. Bh4 g5
			variation => N__('Torre Attack: 3... h6 4. Bh4 g5'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1pp1/4pB1p/8/3P4/5N2/PPP1PPPP/RN1QKB1R b KQkq' => {
			eco => 'A46y',
			# TRANSLATORS: A46y: 1. d4 Nf6 2. Nf3 e6 3. Bg5 h6 4. Bxf6
			variation => N__('Torre Attack: 3... h6 4.Bxf6'),
			moves => {
				'd8f6' => 1,
			},
		},
		'rnb1kb1r/pppp1pp1/4pq1p/8/3P4/5N2/PPP1PPPP/RN1QKB1R w KQkq' => {
			eco => 'A46y',
			# TRANSLATORS: A46y: 1. d4 Nf6 2. Nf3 e6 3. Bg5 h6 4. Bxf6 Qxf6
			variation => N__('Torre Attack: 3... h6 4.Bxf6'),
			moves => {
				'e2e4' => 1,
			},
		},
		'rnb1kb1r/pppp1pp1/4pq1p/8/3PP3/5N2/PPP2PPP/RN1QKB1R b KQkq' => {
			eco => 'A46y',
			# TRANSLATORS: A46y: 1. d4 Nf6 2. Nf3 e6 3. Bg5 h6 4. Bxf6 Qxf6 5. e4
			variation => N__('Torre Attack: 3... h6 4.Bxf6 Qxf6 5. e4'),
			moves => {
				'b7b6' => 1,
				'c7c5' => 1,
				'd7d6' => 1,
			},
		},
		'rnb1kb1r/p1pp1pp1/1p2pq1p/8/3PP3/5N2/PPP2PPP/RN1QKB1R w KQkq' => {
			eco => 'A46y',
			# TRANSLATORS: A46y: 1. d4 Nf6 2. Nf3 e6 3. Bg5 h6 4. Bxf6 Qxf6 5. e4 b6
			variation => N__('Torre Attack: 3... h6 4.Bxf6 Qxf6 5. e4 b6'),
			moves => {
			},
		},
		'rnb1kb1r/pp1p1pp1/4pq1p/2p5/3PP3/5N2/PPP2PPP/RN1QKB1R w KQkq' => {
			eco => 'A46y',
			# TRANSLATORS: A46y: 1. d4 Nf6 2. Nf3 e6 3. Bg5 h6 4. Bxf6 Qxf6 5. e4 c5
			variation => N__('Torre Attack: 3... h6 4.Bxf6 Qxf6 5. e4 c5'),
			moves => {
			},
		},
		'rnb1kb1r/ppp2pp1/3ppq1p/8/3PP3/5N2/PPP2PPP/RN1QKB1R w KQkq' => {
			eco => 'A46z',
			# TRANSLATORS: A46z: 1. d4 Nf6 2. Nf3 e6 3. Bg5 h6 4. Bxf6 Qxf6 5. e4 d6
			variation => N__('Torre Attack: 3... h6 4.Bxf6 Qxf6 5. e4 d6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnb1kb1r/ppp2pp1/3ppq1p/8/3PP3/2N2N2/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'A46z',
			# TRANSLATORS: A46z: 1. d4 Nf6 2. Nf3 e6 3. Bg5 h6 4. Bxf6 Qxf6 5. e4 d6 6. Nc3
			variation => N__('Torre Attack: 3... h6 4.Bxf6 Qxf6 5. e4 d6 6. Nc3'),
			moves => {
				'b8d7' => 1,
				'g7g6' => 1,
			},
		},
		'r1b1kb1r/pppn1pp1/3ppq1p/8/3PP3/2N2N2/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'A46z',
			# TRANSLATORS: A46z: 1. d4 Nf6 2. Nf3 e6 3. Bg5 h6 4. Bxf6 Qxf6 5. e4 d6 6. Nc3 Nd7
			variation => N__('Torre Attack: 3... h6 4.Bxf6 Qxf6 5. e4 d6 6. Nc3 Nd7'),
			moves => {
				'd1d2' => 1,
			},
		},
		'r1b1kb1r/pppn1pp1/3ppq1p/8/3PP3/2N2N2/PPPQ1PPP/R3KB1R b KQkq' => {
			eco => 'A46z',
			# TRANSLATORS: A46z: 1. d4 Nf6 2. Nf3 e6 3. Bg5 h6 4. Bxf6 Qxf6 5. e4 d6 6. Nc3 Nd7 7. Qd2
			variation => N__('Torre Attack: 3... h6 4.Bxf6 Qxf6 5. e4 d6 6. Nc3 Nd7 7. Qd2'),
			moves => {
			},
		},
		'rnb1kb1r/ppp2p2/3ppqpp/8/3PP3/2N2N2/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'A46z',
			# TRANSLATORS: A46z: 1. d4 Nf6 2. Nf3 e6 3. Bg5 h6 4. Bxf6 Qxf6 5. e4 d6 6. Nc3 g6
			variation => N__('Torre Attack: 3... h6 4.Bxf6 Qxf6 5. e4 d6 6. Nc3 g6'),
			moves => {
			},
		},
		'rnbqkb1r/p1pppppp/1p3n2/8/3P4/5N2/PPP1PPPP/RNBQKB1R w KQkq' => {
			eco => 'A47',
			# TRANSLATORS: A47: 1. d4 Nf6 2. Nf3 b6
			variation => N__('Neo-Queen\'s Indian'),
			moves => {
				'c1f4' => 1,
				'c1g5' => 1,
				'e2e3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/p1pppppp/1p3n2/8/3P1B2/5N2/PPP1PPPP/RN1QKB1R b KQkq' => {
			eco => 'A47',
			# TRANSLATORS: A47: 1. d4 Nf6 2. Nf3 b6 3. Bf4
			variation => N__('Neo-Queen\'s Indian'),
			moves => {
				'c8b7' => 1,
				'e7e6' => 1,
			},
		},
		'rn1qkb1r/pbpppppp/1p3n2/8/3P1B2/5N2/PPP1PPPP/RN1QKB1R w KQkq' => {
			eco => 'A47',
			# TRANSLATORS: A47: 1. d4 Nf6 2. Nf3 b6 3. Bf4 Bb7
			variation => N__('Neo-Queen\'s Indian'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rn1qkb1r/pbpppppp/1p3n2/8/3P1B2/4PN2/PPP2PPP/RN1QKB1R b KQkq' => {
			eco => 'A47',
			# TRANSLATORS: A47: 1. d4 Nf6 2. Nf3 b6 3. Bf4 Bb7 4. e3
			variation => N__('Neo-Queen\'s Indian'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rn1qkb1r/pbpp1ppp/1p2pn2/8/3P1B2/4PN2/PPP2PPP/RN1QKB1R w KQkq' => {
			eco => 'A47',
			# TRANSLATORS: A47: 1. d4 Nf6 2. Nf3 b6 3. Bf4 Bb7 4. e3 e6
			variation => N__('Neo-Queen\'s Indian'),
			moves => {
			},
		},
		'rnbqkb1r/p1pp1ppp/1p2pn2/8/3P1B2/5N2/PPP1PPPP/RN1QKB1R w KQkq' => {
			eco => 'A47',
			# TRANSLATORS: A47: 1. d4 Nf6 2. Nf3 b6 3. Bf4 e6
			variation => N__('Neo-Queen\'s Indian'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbqkb1r/p1pp1ppp/1p2pn2/8/3P1B2/4PN2/PPP2PPP/RN1QKB1R b KQkq' => {
			eco => 'A47',
			# TRANSLATORS: A47: 1. d4 Nf6 2. Nf3 b6 3. Bf4 e6 4. e3
			variation => N__('Neo-Queen\'s Indian'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqkb1r/p2p1ppp/1p2pn2/2p5/3P1B2/4PN2/PPP2PPP/RN1QKB1R w KQkq' => {
			eco => 'A47',
			# TRANSLATORS: A47: 1. d4 Nf6 2. Nf3 b6 3. Bf4 e6 4. e3 c5
			variation => N__('Neo-Queen\'s Indian'),
			moves => {
			},
		},
		'rnbqkb1r/p1pppppp/1p3n2/6B1/3P4/5N2/PPP1PPPP/RN1QKB1R b KQkq' => {
			eco => 'A47',
			# TRANSLATORS: A47: 1. d4 Nf6 2. Nf3 b6 3. Bg5
			variation => N__('Neo-Queen\'s Indian'),
			moves => {
				'c8b7' => 1,
			},
		},
		'rn1qkb1r/pbpppppp/1p3n2/6B1/3P4/5N2/PPP1PPPP/RN1QKB1R w KQkq' => {
			eco => 'A47',
			# TRANSLATORS: A47: 1. d4 Nf6 2. Nf3 b6 3. Bg5 Bb7
			variation => N__('Neo-Queen\'s Indian'),
			moves => {
			},
		},
		'rnbqkb1r/p1pppppp/1p3n2/8/3P4/4PN2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'A47',
			# TRANSLATORS: A47: 1. d4 Nf6 2. Nf3 b6 3. e3
			variation => N__('Neo-Queen\'s Indian'),
			moves => {
				'c8b7' => 1,
				'e7e6' => 1,
			},
		},
		'rn1qkb1r/pbpppppp/1p3n2/8/3P4/4PN2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'A47',
			# TRANSLATORS: A47: 1. d4 Nf6 2. Nf3 b6 3. e3 Bb7
			variation => N__('Neo-Queen\'s Indian'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rn1qkb1r/pbpppppp/1p3n2/8/3P4/3BPN2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'A47',
			# TRANSLATORS: A47: 1. d4 Nf6 2. Nf3 b6 3. e3 Bb7 4. Bd3
			variation => N__('Neo-Queen\'s Indian'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rn1qkb1r/pbpp1ppp/1p2pn2/8/3P4/3BPN2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'A47',
			# TRANSLATORS: A47: 1. d4 Nf6 2. Nf3 b6 3. e3 Bb7 4. Bd3 e6
			variation => N__('Neo-Queen\'s Indian'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rn1qkb1r/pbpp1ppp/1p2pn2/8/3P4/3BPN2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'A47',
			# TRANSLATORS: A47: 1. d4 Nf6 2. Nf3 b6 3. e3 Bb7 4. Bd3 e6 5. O-O
			variation => N__('Neo-Queen\'s Indian'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rn1qkb1r/pb1p1ppp/1p2pn2/2p5/3P4/3BPN2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'A47',
			# TRANSLATORS: A47: 1. d4 Nf6 2. Nf3 b6 3. e3 Bb7 4. Bd3 e6 5. O-O c5
			variation => N__('Neo-Queen\'s Indian'),
			moves => {
			},
		},
		'rnbqkb1r/p1pp1ppp/1p2pn2/8/3P4/4PN2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'A47',
			# TRANSLATORS: A47: 1. d4 Nf6 2. Nf3 b6 3. e3 e6
			variation => N__('Neo-Queen\'s Indian'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rnbqkb1r/p1pp1ppp/1p2pn2/8/3P4/3BPN2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'A47',
			# TRANSLATORS: A47: 1. d4 Nf6 2. Nf3 b6 3. e3 e6 4. Bd3
			variation => N__('Neo-Queen\'s Indian'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqkb1r/p2p1ppp/1p2pn2/2p5/3P4/3BPN2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'A47',
			# TRANSLATORS: A47: 1. d4 Nf6 2. Nf3 b6 3. e3 e6 4. Bd3 c5
			variation => N__('Neo-Queen\'s Indian'),
			moves => {
			},
		},
		'rnbqkb1r/p1pppppp/1p3n2/8/3P4/5NP1/PPP1PP1P/RNBQKB1R b KQkq' => {
			eco => 'A47',
			# TRANSLATORS: A47: 1. d4 Nf6 2. Nf3 b6 3. g3
			variation => N__('Neo-Queen\'s Indian'),
			moves => {
				'c8b7' => 1,
				'e7e6' => 1,
			},
		},
		'rn1qkb1r/pbpppppp/1p3n2/8/3P4/5NP1/PPP1PP1P/RNBQKB1R w KQkq' => {
			eco => 'A47',
			# TRANSLATORS: A47: 1. d4 Nf6 2. Nf3 b6 3. g3 Bb7
			variation => N__('Neo-Queen\'s Indian'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rn1qkb1r/pbpppppp/1p3n2/8/3P4/5NP1/PPP1PPBP/RNBQK2R b KQkq' => {
			eco => 'A47',
			# TRANSLATORS: A47: 1. d4 Nf6 2. Nf3 b6 3. g3 Bb7 4. Bg2
			variation => N__('Neo-Queen\'s Indian'),
			moves => {
				'c7c5' => 1,
				'e7e6' => 1,
			},
		},
		'rn1qkb1r/pb1ppppp/1p3n2/2p5/3P4/5NP1/PPP1PPBP/RNBQK2R w KQkq' => {
			eco => 'A47',
			# TRANSLATORS: A47: 1. d4 Nf6 2. Nf3 b6 3. g3 Bb7 4. Bg2 c5
			variation => N__('Neo-Queen\'s Indian: Marienbad System'),
			moves => {
				'c2c4' => 1,
			},
		},
		'rn1qkb1r/pb1ppppp/1p3n2/2p5/2PP4/5NP1/PP2PPBP/RNBQK2R b KQkq' => {
			eco => 'A47',
			# TRANSLATORS: A47: 1. d4 Nf6 2. Nf3 b6 3. g3 Bb7 4. Bg2 c5 5. c4
			variation => N__('Neo-Queen\'s Indian: Marienbad System'),
			moves => {
				'c5d4' => 1,
			},
		},
		'rn1qkb1r/pb1ppppp/1p3n2/8/2Pp4/5NP1/PP2PPBP/RNBQK2R w KQkq' => {
			eco => 'A47',
			# TRANSLATORS: A47: 1. d4 Nf6 2. Nf3 b6 3. g3 Bb7 4. Bg2 c5 5. c4 cxd4
			variation => N__('Neo-Queen\'s Indian: Marienbad System'),
			moves => {
				'd1d4' => 1,
			},
		},
		'rn1qkb1r/pb1ppppp/1p3n2/8/2PQ4/5NP1/PP2PPBP/RNB1K2R b KQkq' => {
			eco => 'A47',
			# TRANSLATORS: A47: 1. d4 Nf6 2. Nf3 b6 3. g3 Bb7 4. Bg2 c5 5. c4 cxd4 6. Qxd4
			variation => N__('Neo-Queen\'s Indian: Marienbad System, Berg Variation'),
			moves => {
			},
		},
		'rn1qkb1r/pbpp1ppp/1p2pn2/8/3P4/5NP1/PPP1PPBP/RNBQK2R w KQkq' => {
			eco => 'A47',
			# TRANSLATORS: A47: 1. d4 Nf6 2. Nf3 b6 3. g3 Bb7 4. Bg2 e6
			variation => N__('Neo-Queen\'s Indian'),
			moves => {
			},
		},
		'rnbqkb1r/p1pp1ppp/1p2pn2/8/3P4/5NP1/PPP1PP1P/RNBQKB1R w KQkq' => {
			eco => 'A47',
			# TRANSLATORS: A47: 1. d4 Nf6 2. Nf3 b6 3. g3 e6
			variation => N__('Neo-Queen\'s Indian'),
			moves => {
			},
		},
		'rnbqkb1r/pppppp1p/5np1/8/3P4/5N2/PPP1PPPP/RNBQKB1R w KQkq' => {
			eco => 'A48a',
			# TRANSLATORS: A48a: 1. d4 Nf6 2. Nf3 g6
			variation => N__('Neo-King\'s Indian'),
			moves => {
				'b1c3' => 1,
				'b1d2' => 1,
				'c1f4' => 1,
				'c1g5' => 1,
				'c2c3' => 1,
				'e2e3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/pppppp1p/5np1/8/3P4/5N2/PPPNPPPP/R1BQKB1R b KQkq' => {
			eco => 'A48a',
			# TRANSLATORS: A48a: 1. d4 Nf6 2. Nf3 g6 3. Nbd2
			variation => N__('Neo-King\'s Indian'),
			moves => {
			},
		},
		'rnbqkb1r/pppppp1p/5np1/8/3P4/2P2N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'A48b',
			# TRANSLATORS: A48b: 1. d4 Nf6 2. Nf3 g6 3. c3
			variation => N__('Neo-King\'s Indian'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppppppbp/5np1/8/3P4/2P2N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A48b',
			# TRANSLATORS: A48b: 1. d4 Nf6 2. Nf3 g6 3. c3 Bg7
			variation => N__('Neo-King\'s Indian'),
			moves => {
			},
		},
		'rnbqkb1r/pppppp1p/5np1/8/3P4/4PN2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'A48c',
			# TRANSLATORS: A48c: 1. d4 Nf6 2. Nf3 g6 3. e3
			variation => N__('Neo-King\'s Indian'),
			moves => {
				'c7c5' => 1,
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppppppbp/5np1/8/3P4/4PN2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'A48c',
			# TRANSLATORS: A48c: 1. d4 Nf6 2. Nf3 g6 3. e3 Bg7
			variation => N__('Neo-King\'s Indian'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppp1p/5np1/2p5/3P4/4PN2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'A48d',
			# TRANSLATORS: A48d: 1. d4 Nf6 2. Nf3 g6 3. e3 c5
			variation => N__('Neo-King\'s Indian'),
			moves => {
			},
		},
		'rnbqkb1r/pppppp1p/5np1/8/3P4/2N2N2/PPP1PPPP/R1BQKB1R b KQkq' => {
			eco => 'A48e',
			# TRANSLATORS: A48e: 1. d4 Nf6 2. Nf3 g6 3. Nc3
			variation => N__('Neo-King\'s Indian'),
			moves => {
			},
		},
		'rnbqkb1r/pppppp1p/5np1/8/3P1B2/5N2/PPP1PPPP/RN1QKB1R b KQkq' => {
			eco => 'A48f',
			# TRANSLATORS: A48f: 1. d4 Nf6 2. Nf3 g6 3. Bf4
			variation => N__('Neo-King\'s Indian: London System'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppppppbp/5np1/8/3P1B2/5N2/PPP1PPPP/RN1QKB1R w KQkq' => {
			eco => 'A48g',
			# TRANSLATORS: A48g: 1. d4 Nf6 2. Nf3 g6 3. Bf4 Bg7
			variation => N__('Neo-King\'s Indian: London System'),
			moves => {
				'b1d2' => 1,
				'c2c3' => 1,
				'e2e3' => 1,
			},
		},
		'rnbqk2r/ppppppbp/5np1/8/3P1B2/5N2/PPPNPPPP/R2QKB1R b KQkq' => {
			eco => 'A48h',
			# TRANSLATORS: A48h: 1. d4 Nf6 2. Nf3 g6 3. Bf4 Bg7 4. Nbd2
			variation => N__('Neo-King\'s Indian: London System'),
			moves => {
			},
		},
		'rnbqk2r/ppppppbp/5np1/8/3P1B2/2P2N2/PP2PPPP/RN1QKB1R b KQkq' => {
			eco => 'A48i',
			# TRANSLATORS: A48i: 1. d4 Nf6 2. Nf3 g6 3. Bf4 Bg7 4. c3
			variation => N__('Neo-King\'s Indian: London System'),
			moves => {
			},
		},
		'rnbqk2r/ppppppbp/5np1/8/3P1B2/4PN2/PPP2PPP/RN1QKB1R b KQkq' => {
			eco => 'A48j',
			# TRANSLATORS: A48j: 1. d4 Nf6 2. Nf3 g6 3. Bf4 Bg7 4. e3
			variation => N__('Neo-King\'s Indian: London System'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppppppbp/5np1/8/3P1B2/4PN2/PPP2PPP/RN1QKB1R w KQ' => {
			eco => 'A48j',
			# TRANSLATORS: A48j: 1. d4 Nf6 2. Nf3 g6 3. Bf4 Bg7 4. e3 O-O
			variation => N__('Neo-King\'s Indian: London System'),
			moves => {
				'f1e2' => 1,
			},
		},
		'rnbq1rk1/ppppppbp/5np1/8/3P1B2/4PN2/PPP1BPPP/RN1QK2R b KQ' => {
			eco => 'A48k',
			# TRANSLATORS: A48k: 1. d4 Nf6 2. Nf3 g6 3. Bf4 Bg7 4. e3 O-O 5. Be2
			variation => N__('Neo-King\'s Indian: London System'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/3P1B2/4PN2/PPP1BPPP/RN1QK2R w KQ' => {
			eco => 'A48k',
			# TRANSLATORS: A48k: 1. d4 Nf6 2. Nf3 g6 3. Bf4 Bg7 4. e3 O-O 5. Be2 d6
			variation => N__('Neo-King\'s Indian: London System'),
			moves => {
				'h2h3' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/3P1B2/4PN1P/PPP1BPP1/RN1QK2R b KQ' => {
			eco => 'A48l',
			# TRANSLATORS: A48l: 1. d4 Nf6 2. Nf3 g6 3. Bf4 Bg7 4. e3 O-O 5. Be2 d6 6. h3
			variation => N__('Neo-King\'s Indian: London System'),
			moves => {
			},
		},
		'rnbqkb1r/pppppp1p/5np1/6B1/3P4/5N2/PPP1PPPP/RN1QKB1R b KQkq' => {
			eco => 'A48m',
			# TRANSLATORS: A48m: 1. d4 Nf6 2. Nf3 g6 3. Bg5
			variation => N__('Neo-King\'s Indian: Torre Attack'),
			moves => {
				'f6e4' => 1,
				'f8g7' => 1,
			},
		},
		'rnbqkb1r/pppppp1p/6p1/6B1/3Pn3/5N2/PPP1PPPP/RN1QKB1R w KQkq' => {
			eco => 'A48n',
			# TRANSLATORS: A48n: 1. d4 Nf6 2. Nf3 g6 3. Bg5 Ne4
			variation => N__('Neo-King\'s Indian: Torre Attack'),
			moves => {
			},
		},
		'rnbqk2r/ppppppbp/5np1/6B1/3P4/5N2/PPP1PPPP/RN1QKB1R w KQkq' => {
			eco => 'A48o',
			# TRANSLATORS: A48o: 1. d4 Nf6 2. Nf3 g6 3. Bg5 Bg7
			variation => N__('Neo-King\'s Indian: Torre Attack'),
			moves => {
				'b1c3' => 1,
				'b1d2' => 1,
				'c2c3' => 1,
				'e2e3' => 1,
			},
		},
		'rnbqk2r/ppppppbp/5np1/6B1/3P4/2P2N2/PP2PPPP/RN1QKB1R b KQkq' => {
			eco => 'A48o',
			# TRANSLATORS: A48o: 1. d4 Nf6 2. Nf3 g6 3. Bg5 Bg7 4. c3
			variation => N__('Neo-King\'s Indian: Torre Attack'),
			moves => {
			},
		},
		'rnbqk2r/ppppppbp/5np1/6B1/3P4/4PN2/PPP2PPP/RN1QKB1R b KQkq' => {
			eco => 'A48o',
			# TRANSLATORS: A48o: 1. d4 Nf6 2. Nf3 g6 3. Bg5 Bg7 4. e3
			variation => N__('Neo-King\'s Indian: Torre Attack'),
			moves => {
			},
		},
		'rnbqk2r/ppppppbp/5np1/6B1/3P4/2N2N2/PPP1PPPP/R2QKB1R b KQkq' => {
			eco => 'A48p',
			# TRANSLATORS: A48p: 1. d4 Nf6 2. Nf3 g6 3. Bg5 Bg7 4. Nc3
			variation => N__('Neo-King\'s Indian: Torre Attack'),
			moves => {
			},
		},
		'rnbqk2r/ppppppbp/5np1/6B1/3P4/5N2/PPPNPPPP/R2QKB1R b KQkq' => {
			eco => 'A48q',
			# TRANSLATORS: A48q: 1. d4 Nf6 2. Nf3 g6 3. Bg5 Bg7 4. Nbd2
			variation => N__('Neo-King\'s Indian: Torre Attack'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppppppbp/5np1/6B1/3P4/5N2/PPPNPPPP/R2QKB1R w KQ' => {
			eco => 'A48r',
			# TRANSLATORS: A48r: 1. d4 Nf6 2. Nf3 g6 3. Bg5 Bg7 4. Nbd2 O-O
			variation => N__('Neo-King\'s Indian: Torre Attack'),
			moves => {
				'c2c3' => 1,
				'e2e4' => 1,
			},
		},
		'rnbq1rk1/ppppppbp/5np1/6B1/3PP3/5N2/PPPN1PPP/R2QKB1R b KQ' => {
			eco => 'A48s',
			# TRANSLATORS: A48s: 1. d4 Nf6 2. Nf3 g6 3. Bg5 Bg7 4. Nbd2 O-O 5. e4
			variation => N__('Neo-King\'s Indian: Torre Attack'),
			moves => {
				'd7d5' => 1,
				'd7d6' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/6B1/3PP3/5N2/PPPN1PPP/R2QKB1R w KQ' => {
			eco => 'A48t',
			# TRANSLATORS: A48t: 1. d4 Nf6 2. Nf3 g6 3. Bg5 Bg7 4. Nbd2 O-O 5. e4 d6
			variation => N__('Neo-King\'s Indian: Torre Attack'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/3p2B1/3PP3/5N2/PPPN1PPP/R2QKB1R w KQ' => {
			eco => 'A48u',
			# TRANSLATORS: A48u: 1. d4 Nf6 2. Nf3 g6 3. Bg5 Bg7 4. Nbd2 O-O 5. e4 d5
			variation => N__('Neo-King\'s Indian: Torre Attack'),
			moves => {
			},
		},
		'rnbq1rk1/ppppppbp/5np1/6B1/3P4/2P2N2/PP1NPPPP/R2QKB1R b KQ' => {
			eco => 'A48v',
			# TRANSLATORS: A48v: 1. d4 Nf6 2. Nf3 g6 3. Bg5 Bg7 4. Nbd2 O-O 5. c3
			variation => N__('Neo-King\'s Indian: Torre Attack'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/6B1/3P4/2P2N2/PP1NPPPP/R2QKB1R w KQ' => {
			eco => 'A48v',
			# TRANSLATORS: A48v: 1. d4 Nf6 2. Nf3 g6 3. Bg5 Bg7 4. Nbd2 O-O 5. c3 d6
			variation => N__('Neo-King\'s Indian: Torre Attack'),
			moves => {
				'e2e4' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/6B1/3PP3/2P2N2/PP1N1PPP/R2QKB1R b KQ' => {
			eco => 'A48w',
			# TRANSLATORS: A48w: 1. d4 Nf6 2. Nf3 g6 3. Bg5 Bg7 4. Nbd2 O-O 5. c3 d6 6. e4
			variation => N__('Neo-King\'s Indian: Torre Attack'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2p3B1/3PP3/2P2N2/PP1N1PPP/R2QKB1R w KQ' => {
			eco => 'A48x',
			# TRANSLATORS: A48x: 1. d4 Nf6 2. Nf3 g6 3. Bg5 Bg7 4. Nbd2 O-O 5. c3 d6 6. e4 c5
			variation => N__('Neo-King\'s Indian: Torre Attack'),
			moves => {
			},
		},
		'rnbqkb1r/pppppp1p/5np1/8/3P4/5NP1/PPP1PP1P/RNBQKB1R b KQkq' => {
			eco => 'A49',
			# TRANSLATORS: A49: 1. d4 Nf6 2. Nf3 g6 3. g3
			variation => N__('Neo-King\'s Indian: Fianchetto System'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppppppbp/5np1/8/3P4/5NP1/PPP1PP1P/RNBQKB1R w KQkq' => {
			eco => 'A49',
			# TRANSLATORS: A49: 1. d4 Nf6 2. Nf3 g6 3. g3 Bg7
			variation => N__('Neo-King\'s Indian: Fianchetto System'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqk2r/ppppppbp/5np1/8/3P4/5NP1/PPP1PPBP/RNBQK2R b KQkq' => {
			eco => 'A49',
			# TRANSLATORS: A49: 1. d4 Nf6 2. Nf3 g6 3. g3 Bg7 4. Bg2
			variation => N__('Neo-King\'s Indian: Fianchetto System'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppppppbp/5np1/8/3P4/5NP1/PPP1PPBP/RNBQK2R w KQ' => {
			eco => 'A49',
			# TRANSLATORS: A49: 1. d4 Nf6 2. Nf3 g6 3. g3 Bg7 4. Bg2 O-O
			variation => N__('Neo-King\'s Indian: Fianchetto System'),
			moves => {
				'b2b3' => 1,
				'e1g1' => 1,
			},
		},
		'rnbq1rk1/ppppppbp/5np1/8/3P4/1P3NP1/P1P1PPBP/RNBQK2R b KQ' => {
			eco => 'A49',
			# TRANSLATORS: A49: 1. d4 Nf6 2. Nf3 g6 3. g3 Bg7 4. Bg2 O-O 5. b3
			variation => N__('Neo-King\'s Indian: Fianchetto System'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/3P4/1P3NP1/P1P1PPBP/RNBQK2R w KQ' => {
			eco => 'A49',
			# TRANSLATORS: A49: 1. d4 Nf6 2. Nf3 g6 3. g3 Bg7 4. Bg2 O-O 5. b3 d6
			variation => N__('Neo-King\'s Indian: Fianchetto System'),
			moves => {
				'c1b2' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/3P4/1P3NP1/PBP1PPBP/RN1QK2R b KQ' => {
			eco => 'A49',
			# TRANSLATORS: A49: 1. d4 Nf6 2. Nf3 g6 3. g3 Bg7 4. Bg2 O-O 5. b3 d6 6. Bb2
			variation => N__('Neo-King\'s Indian: Double Fianchetto System'),
			moves => {
			},
		},
		'rnbq1rk1/ppppppbp/5np1/8/3P4/5NP1/PPP1PPBP/RNBQ1RK1 b -' => {
			eco => 'A49',
			# TRANSLATORS: A49: 1. d4 Nf6 2. Nf3 g6 3. g3 Bg7 4. Bg2 O-O 5. O-O
			variation => N__('Neo-King\'s Indian: Fianchetto System'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/3P4/5NP1/PPP1PPBP/RNBQ1RK1 w -' => {
			eco => 'A49',
			# TRANSLATORS: A49: 1. d4 Nf6 2. Nf3 g6 3. g3 Bg7 4. Bg2 O-O 5. O-O d6
			variation => N__('Neo-King\'s Indian: Fianchetto System'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/2PP4/8/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'A50a',
			# TRANSLATORS: A50a: 1. d4 Nf6 2. c4
			variation => N__('Indian: 2. c4'),
			moves => {
				'a7a6' => 1,
				'b7b6' => 1,
				'b8c6' => 1,
				'c7c5' => 1,
				'c7c6' => 1,
				'd7d6' => 1,
				'e7e5' => 1,
				'e7e6' => 1,
				'g7g6' => 1,
			},
		},
		'r1bqkb1r/pppppppp/2n2n2/8/2PP4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A50b',
			# TRANSLATORS: A50b: 1. d4 Nf6 2. c4 Nc6
			variation => N__('Indian: Mexican Defence (Two Knights Tango)'),
			moves => {
				'b1c3' => 1,
				'g1f3' => 1,
			},
		},
		'r1bqkb1r/pppppppp/2n2n2/8/2PP4/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'A50c',
			# TRANSLATORS: A50c: 1. d4 Nf6 2. c4 Nc6 3. Nc3
			variation => N__('Indian: Mexican Defence, 3. Nc3'),
			moves => {
			},
		},
		'r1bqkb1r/pppppppp/2n2n2/8/2PP4/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'A50d',
			# TRANSLATORS: A50d: 1. d4 Nf6 2. c4 Nc6 3. Nf3
			variation => N__('Indian: Mexican Defence, 3. Nf3'),
			moves => {
				'd7d6' => 1,
				'e7e6' => 1,
			},
		},
		'r1bqkb1r/ppp1pppp/2np1n2/8/2PP4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A50d',
			# TRANSLATORS: A50d: 1. d4 Nf6 2. c4 Nc6 3. Nf3 d6
			variation => N__('Indian: Mexican Defence, 3. Nf3 d6'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n1pn2/8/2PP4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A50e',
			# TRANSLATORS: A50e: 1. d4 Nf6 2. c4 Nc6 3. Nf3 e6
			variation => N__('Indian: Mexican Defence, 3. Nf3 e6'),
			moves => {
				'a2a3' => 1,
				'b1c3' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n1pn2/8/2PP4/P4N2/1P2PPPP/RNBQKB1R b KQkq' => {
			eco => 'A50f',
			# TRANSLATORS: A50f: 1. d4 Nf6 2. c4 Nc6 3. Nf3 e6 4. a3
			variation => N__('Indian: Mexican Defence, 3. Nf3 e6 4. a3'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n1pn2/8/2PP4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'A50g',
			# TRANSLATORS: A50g: 1. d4 Nf6 2. c4 Nc6 3. Nf3 e6 4. Nc3
			variation => N__('Indian: Mexican Defence, 3. Nf3 e6 4. Nc3'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/2p2n2/8/2PP4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A50h',
			# TRANSLATORS: A50h: 1. d4 Nf6 2. c4 c6
			variation => N__('Indian: Slav-Indian'),
			moves => {
				'b1c3' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/pp1ppppp/2p2n2/8/2PP4/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'A50i',
			# TRANSLATORS: A50i: 1. d4 Nf6 2. c4 c6 3. Nf3
			variation => N__('Indian: Slav-Indian, 3. Nf3'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/2p2n2/8/2PP4/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'A50j',
			# TRANSLATORS: A50j: 1. d4 Nf6 2. c4 c6 3. Nc3
			variation => N__('Indian: Slav-Indian, 3. Nc3'),
			moves => {
			},
		},
		'rnbqkb1r/1ppppppp/p4n2/8/2PP4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A50k',
			# TRANSLATORS: A50k: 1. d4 Nf6 2. c4 a6
			variation => N__('Indian: 2. c4 a6'),
			moves => {
			},
		},
		'rnbqkb1r/p1pppppp/1p3n2/8/2PP4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A50l',
			# TRANSLATORS: A50l: 1. d4 Nf6 2. c4 b6
			variation => N__('Indian: Queen\'s Indian Accelerated'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkb1r/p1pppppp/1p3n2/8/2PP4/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'A50l',
			# TRANSLATORS: A50l: 1. d4 Nf6 2. c4 b6 3. Nc3
			variation => N__('Indian: Queen\'s Indian Accelerated'),
			moves => {
				'c8b7' => 1,
			},
		},
		'rn1qkb1r/pbpppppp/1p3n2/8/2PP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'A50m',
			# TRANSLATORS: A50m: 1. d4 Nf6 2. c4 b6 3. Nc3 Bb7
			variation => N__('Indian: Queen\'s Indian Accelerated'),
			moves => {
				'd1c2' => 1,
			},
		},
		'rn1qkb1r/pbpppppp/1p3n2/8/2PP4/2N5/PPQ1PPPP/R1B1KBNR b KQkq' => {
			eco => 'A50n',
			# TRANSLATORS: A50n: 1. d4 Nf6 2. c4 b6 3. Nc3 Bb7 4. Qc2
			variation => N__('Indian: Queen\'s Indian Accelerated'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/4p3/2PP4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A51a',
			# TRANSLATORS: A51a: 1. d4 Nf6 2. c4 e5
			variation => N__('Budapest'),
			moves => {
				'd4d5' => 1,
				'd4e5' => 1,
				'e2e3' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/4p3/2PP4/4P3/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'A51b',
			# TRANSLATORS: A51b: 1. d4 Nf6 2. c4 e5 3. e3
			variation => N__('Budapest: 3. e3'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/3Pp3/2P5/8/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'A51c',
			# TRANSLATORS: A51c: 1. d4 Nf6 2. c4 e5 3. d5
			variation => N__('Budapest: 3. d5'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/4P3/2P5/8/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'A51d',
			# TRANSLATORS: A51d: 1. d4 Nf6 2. c4 e5 3. dxe5
			variation => N__('Budapest: 3.dxe5'),
			moves => {
				'f6e4' => 1,
				'f6g4' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/8/4P3/2P1n3/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A51d',
			# TRANSLATORS: A51d: 1. d4 Nf6 2. c4 e5 3. dxe5 Ne4
			variation => N__('Budapest: Fajarowicz'),
			moves => {
				'a2a3' => 1,
				'b1d2' => 1,
				'd1c2' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/8/4P3/2P1n3/8/PPQ1PPPP/RNB1KBNR b KQkq' => {
			eco => 'A51e',
			# TRANSLATORS: A51e: 1. d4 Nf6 2. c4 e5 3. dxe5 Ne4 4. Qc2
			variation => N__('Budapest: Fajarowicz, Steiner Variation'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/8/4P3/2P1n3/8/PP1NPPPP/R1BQKBNR b KQkq' => {
			eco => 'A51f',
			# TRANSLATORS: A51f: 1. d4 Nf6 2. c4 e5 3. dxe5 Ne4 4. Nd2
			variation => N__('Budapest: Fajarowicz, 4. Nd2'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/8/4P3/2P1n3/P7/1P2PPPP/RNBQKBNR b KQkq' => {
			eco => 'A51g',
			# TRANSLATORS: A51g: 1. d4 Nf6 2. c4 e5 3. dxe5 Ne4 4. a3
			variation => N__('Budapest: Fajarowicz, 4. a3'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/8/4P3/2P1n3/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'A51h',
			# TRANSLATORS: A51h: 1. d4 Nf6 2. c4 e5 3. dxe5 Ne4 4. Nf3
			variation => N__('Budapest: Fajarowicz, 4. Nf3'),
			moves => {
				'b8c6' => 1,
				'f8b4' => 1,
			},
		},
		'rnbqk2r/pppp1ppp/8/4P3/1bP1n3/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A51i',
			# TRANSLATORS: A51i: 1. d4 Nf6 2. c4 e5 3. dxe5 Ne4 4. Nf3 Bb4+
			variation => N__('Budapest: Fajarowicz, 4. Nf3 Bb4+'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n5/4P3/2P1n3/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A51j',
			# TRANSLATORS: A51j: 1. d4 Nf6 2. c4 e5 3. dxe5 Ne4 4. Nf3 Nc6
			variation => N__('Budapest: Fajarowicz, 4. Nf3 Nc6'),
			moves => {
				'a2a3' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n5/4P3/2P1n3/P4N2/1P2PPPP/RNBQKB1R b KQkq' => {
			eco => 'A51k',
			# TRANSLATORS: A51k: 1. d4 Nf6 2. c4 e5 3. dxe5 Ne4 4. Nf3 Nc6 5. a3
			variation => N__('Budapest: Fajarowicz, 4. Nf3 Nc6 5. a3'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/8/4P3/2P3n1/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A52a',
			# TRANSLATORS: A52a: 1. d4 Nf6 2. c4 e5 3. dxe5 Ng4
			variation => N__('Budapest: 3... Ng4'),
			moves => {
				'c1f4' => 1,
				'e2e3' => 1,
				'e2e4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/8/4P3/2P3n1/4P3/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'A52b',
			# TRANSLATORS: A52b: 1. d4 Nf6 2. c4 e5 3. dxe5 Ng4 4. e3
			variation => N__('Budapest: 3... Ng4 4. e3'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/8/4P3/2P1P1n1/8/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'A52c',
			# TRANSLATORS: A52c: 1. d4 Nf6 2. c4 e5 3. dxe5 Ng4 4. e4
			variation => N__('Budapest: Alekhine Variation'),
			moves => {
				'd7d6' => 1,
				'g4e5' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/3p4/4P3/2P1P1n1/8/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'A52c',
			# TRANSLATORS: A52c: 1. d4 Nf6 2. c4 e5 3. dxe5 Ng4 4. e4 d6
			variation => N__('Budapest: Alekhine, Balogh Gambit'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/8/4n3/2P1P3/8/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'A52c',
			# TRANSLATORS: A52c: 1. d4 Nf6 2. c4 e5 3. dxe5 Ng4 4. e4 Nxe5
			variation => N__('Budapest: Alekhine Variation'),
			moves => {
				'f2f4' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/8/4n3/2P1PP2/8/PP4PP/RNBQKBNR b KQkq' => {
			eco => 'A52c',
			# TRANSLATORS: A52c: 1. d4 Nf6 2. c4 e5 3. dxe5 Ng4 4. e4 Nxe5 5. f4
			variation => N__('Budapest: Alekhine Variation'),
			moves => {
				'e5c6' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/2n5/8/2P1PP2/8/PP4PP/RNBQKBNR w KQkq' => {
			eco => 'A52d',
			# TRANSLATORS: A52d: 1. d4 Nf6 2. c4 e5 3. dxe5 Ng4 4. e4 Nxe5 5. f4 Nec6
			variation => N__('Budapest: Alekhine, Abonyi Variation'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/8/4P3/2P3n1/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'A52e',
			# TRANSLATORS: A52e: 1. d4 Nf6 2. c4 e5 3. dxe5 Ng4 4. Nf3
			variation => N__('Budapest: Adler Variation'),
			moves => {
				'f8c5' => 1,
			},
		},
		'rnbqk2r/pppp1ppp/8/2b1P3/2P3n1/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A52f',
			# TRANSLATORS: A52f: 1. d4 Nf6 2. c4 e5 3. dxe5 Ng4 4. Nf3 Bc5
			variation => N__('Budapest: Adler, 4... Bc5'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbqk2r/pppp1ppp/8/2b1P3/2P3n1/4PN2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'A52f',
			# TRANSLATORS: A52f: 1. d4 Nf6 2. c4 e5 3. dxe5 Ng4 4. Nf3 Bc5 5. e3
			variation => N__('Budapest: Adler, 4... Bc5'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n5/2b1P3/2P3n1/4PN2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'A52f',
			# TRANSLATORS: A52f: 1. d4 Nf6 2. c4 e5 3. dxe5 Ng4 4. Nf3 Bc5 5. e3 Nc6
			variation => N__('Budapest: Adler, 4... Bc5'),
			moves => {
				'f1e2' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n5/2b1P3/2P3n1/4PN2/PP2BPPP/RNBQK2R b KQkq' => {
			eco => 'A52g',
			# TRANSLATORS: A52g: 1. d4 Nf6 2. c4 e5 3. dxe5 Ng4 4. Nf3 Bc5 5. e3 Nc6 6. Be2
			variation => N__('Budapest: Adler, 4... Bc5 5. e3 Nc6 6. Be2'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/8/4P3/2P2Bn1/8/PP2PPPP/RN1QKBNR b KQkq' => {
			eco => 'A52h',
			# TRANSLATORS: A52h: 1. d4 Nf6 2. c4 e5 3. dxe5 Ng4 4. Bf4
			variation => N__('Budapest: Rubinstein Variation'),
			moves => {
				'b8c6' => 1,
				'f8b4' => 1,
			},
		},
		'rnbqk2r/pppp1ppp/8/4P3/1bP2Bn1/8/PP2PPPP/RN1QKBNR w KQkq' => {
			eco => 'A52i',
			# TRANSLATORS: A52i: 1. d4 Nf6 2. c4 e5 3. dxe5 Ng4 4. Bf4 Bb4+
			variation => N__('Budapest: Rubinstein, 4... Bb4+'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n5/4P3/2P2Bn1/8/PP2PPPP/RN1QKBNR w KQkq' => {
			eco => 'A52j',
			# TRANSLATORS: A52j: 1. d4 Nf6 2. c4 e5 3. dxe5 Ng4 4. Bf4 Nc6
			variation => N__('Budapest: Rubinstein, 4... Nc6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n5/4P3/2P2Bn1/5N2/PP2PPPP/RN1QKB1R b KQkq' => {
			eco => 'A52j',
			# TRANSLATORS: A52j: 1. d4 Nf6 2. c4 e5 3. dxe5 Ng4 4. Bf4 Nc6 5. Nf3
			variation => N__('Budapest: Rubinstein, 4... Nc6'),
			moves => {
				'f8b4' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n5/4P3/1bP2Bn1/5N2/PP2PPPP/RN1QKB1R w KQkq' => {
			eco => 'A52k',
			# TRANSLATORS: A52k: 1. d4 Nf6 2. c4 e5 3. dxe5 Ng4 4. Bf4 Nc6 5. Nf3 Bb4+
			variation => N__('Budapest: Rubinstein, Main Line'),
			moves => {
				'b1d2' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n5/4P3/1bP2Bn1/5N2/PP1NPPPP/R2QKB1R b KQkq' => {
			eco => 'A52l',
			# TRANSLATORS: A52l: 1. d4 Nf6 2. c4 e5 3. dxe5 Ng4 4. Bf4 Nc6 5. Nf3 Bb4+ 6. Nbd2
			variation => N__('Budapest: Rubinstein, Main Line, 6.Nbd2'),
			moves => {
				'd8e7' => 1,
			},
		},
		'r1b1k2r/ppppqppp/2n5/4P3/1bP2Bn1/5N2/PP1NPPPP/R2QKB1R w KQkq' => {
			eco => 'A52l',
			# TRANSLATORS: A52l: 1. d4 Nf6 2. c4 e5 3. dxe5 Ng4 4. Bf4 Nc6 5. Nf3 Bb4+ 6. Nbd2 Qe7
			variation => N__('Budapest: Rubinstein, Main Line, 6.Nbd2'),
			moves => {
				'e2e3' => 1,
			},
		},
		'r1b1k2r/ppppqppp/2n5/4P3/1bP2Bn1/4PN2/PP1N1PPP/R2QKB1R b KQkq' => {
			eco => 'A52m',
			# TRANSLATORS: A52m: 1. d4 Nf6 2. c4 e5 3. dxe5 Ng4 4. Bf4 Nc6 5. Nf3 Bb4+ 6. Nbd2 Qe7 7. e3
			variation => N__('Budapest: Rubinstein, Main Line, 6.Nbd2 Qe7 7. e3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/3p1n2/8/2PP4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A53',
			# TRANSLATORS: A53: 1. d4 Nf6 2. c4 d6
			variation => N__('Old Indian'),
			moves => {
				'b1c3' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/3p1n2/8/2PP4/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'A53',
			# TRANSLATORS: A53: 1. d4 Nf6 2. c4 d6 3. Nc3
			variation => N__('Old Indian: 3. Nc3'),
			moves => {
				'b8d7' => 1,
				'c7c6' => 1,
				'c8f5' => 1,
				'e7e5' => 1,
			},
		},
		'r1bqkb1r/pppnpppp/3p1n2/8/2PP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'A53',
			# TRANSLATORS: A53: 1. d4 Nf6 2. c4 d6 3. Nc3 Nbd7
			variation => N__('Old Indian: 3. Nc3 Nbd7'),
			moves => {
				'e2e4' => 1,
				'g1f3' => 1,
			},
		},
		'r1bqkb1r/pppnpppp/3p1n2/8/2PPP3/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'A53',
			# TRANSLATORS: A53: 1. d4 Nf6 2. c4 d6 3. Nc3 Nbd7 4. e4
			variation => N__('Old Indian: 3. Nc3 Nbd7 4. e4'),
			moves => {
				'e7e5' => 1,
			},
		},
		'r1bqkb1r/pppn1ppp/3p1n2/4p3/2PPP3/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'A53',
			# TRANSLATORS: A53: 1. d4 Nf6 2. c4 d6 3. Nc3 Nbd7 4. e4 e5
			variation => N__('Old Indian: 3. Nc3 Nbd7 4. e4 e5'),
			moves => {
				'd4d5' => 1,
				'g1e2' => 1,
			},
		},
		'r1bqkb1r/pppn1ppp/3p1n2/3Pp3/2P1P3/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'A53',
			# TRANSLATORS: A53: 1. d4 Nf6 2. c4 d6 3. Nc3 Nbd7 4. e4 e5 5. d5
			variation => N__('Old Indian: 3. Nc3 Nbd7 4. e4 e5 5. d5'),
			moves => {
			},
		},
		'r1bqkb1r/pppn1ppp/3p1n2/4p3/2PPP3/2N5/PP2NPPP/R1BQKB1R b KQkq' => {
			eco => 'A53',
			# TRANSLATORS: A53: 1. d4 Nf6 2. c4 d6 3. Nc3 Nbd7 4. e4 e5 5. Nge2
			variation => N__('Old Indian: 3. Nc3 Nbd7 4. e4 e5 5.Nge2'),
			moves => {
			},
		},
		'r1bqkb1r/pppnpppp/3p1n2/8/2PP4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'A53',
			# TRANSLATORS: A53: 1. d4 Nf6 2. c4 d6 3. Nc3 Nbd7 4. Nf3
			variation => N__('Old Indian: 3. Nc3 Nbd7 4. Nf3'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/2pp1n2/8/2PP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'A53',
			# TRANSLATORS: A53: 1. d4 Nf6 2. c4 d6 3. Nc3 c6
			variation => N__('Old Indian: 3. Nc3 c6'),
			moves => {
			},
		},
		'rn1qkb1r/ppp1pppp/3p1n2/5b2/2PP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'A53',
			# TRANSLATORS: A53: 1. d4 Nf6 2. c4 d6 3. Nc3 Bf5
			variation => N__('Old Indian: Janowski'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/3p1n2/4p3/2PP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'A53',
			# TRANSLATORS: A53: 1. d4 Nf6 2. c4 d6 3. Nc3 e5
			variation => N__('Old Indian: Ukrainian'),
			moves => {
				'd4d5' => 1,
				'd4e5' => 1,
				'e2e3' => 1,
				'e2e4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/3p1n2/3Pp3/2P5/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'A53',
			# TRANSLATORS: A53: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. d5
			variation => N__('Old Indian: Ukrainian, 4. d5'),
			moves => {
				'f8e7' => 1,
			},
		},
		'rnbqk2r/ppp1bppp/3p1n2/3Pp3/2P5/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'A53',
			# TRANSLATORS: A53: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. d5 Be7
			variation => N__('Old Indian: Ukrainian, 4. d5 Be7'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/3p1n2/4P3/2P5/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'A53',
			# TRANSLATORS: A53: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. dxe5
			variation => N__('Old Indian: Ukrainian, 4.dxe5'),
			moves => {
				'd6e5' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/4p3/2P5/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'A53',
			# TRANSLATORS: A53: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. dxe5 dxe5
			variation => N__('Old Indian: Ukrainian, 4.dxe5'),
			moves => {
				'd1d8' => 1,
			},
		},
		'rnbQkb1r/ppp2ppp/5n2/4p3/2P5/2N5/PP2PPPP/R1B1KBNR b KQkq' => {
			eco => 'A53',
			# TRANSLATORS: A53: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. dxe5 dxe5 5. Qxd8+
			variation => N__('Old Indian: Ukrainian, 4.dxe5'),
			moves => {
				'e8d8' => 1,
			},
		},
		'rnbk1b1r/ppp2ppp/5n2/4p3/2P5/2N5/PP2PPPP/R1B1KBNR w KQ' => {
			eco => 'A53',
			# TRANSLATORS: A53: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. dxe5 dxe5 5. Qxd8+ Kxd8
			variation => N__('Old Indian: Ukrainian, Queenswap'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbk1b1r/ppp2ppp/5n2/4p3/2P5/2N2N2/PP2PPPP/R1B1KB1R b KQ' => {
			eco => 'A53',
			# TRANSLATORS: A53: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. dxe5 dxe5 5. Qxd8+ Kxd8 6. Nf3
			variation => N__('Old Indian: Ukrainian, Queenswap, 6. Nf3'),
			moves => {
				'f6d7' => 1,
			},
		},
		'rnbk1b1r/pppn1ppp/8/4p3/2P5/2N2N2/PP2PPPP/R1B1KB1R w KQ' => {
			eco => 'A53',
			# TRANSLATORS: A53: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. dxe5 dxe5 5. Qxd8+ Kxd8 6. Nf3 Nfd7
			variation => N__('Old Indian: Ukrainian, Queenswap, 6. Nf3 Nfd7'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/3p1n2/4p3/2PP4/2N1P3/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'A53',
			# TRANSLATORS: A53: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. e3
			variation => N__('Old Indian: Ukranian, 4. e3'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r1bqkb1r/pppn1ppp/3p1n2/4p3/2PP4/2N1P3/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'A53',
			# TRANSLATORS: A53: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. e3 Nbd7
			variation => N__('Old Indian: Ukranian, 4. e3'),
			moves => {
				'f1d3' => 1,
			},
		},
		'r1bqkb1r/pppn1ppp/3p1n2/4p3/2PP4/2NBP3/PP3PPP/R1BQK1NR b KQkq' => {
			eco => 'A53',
			# TRANSLATORS: A53: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. e3 Nbd7 5. Bd3
			variation => N__('Old Indian: Dus-Khotimirsky'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/3p1n2/4p3/2PPP3/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'A53',
			# TRANSLATORS: A53: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. e4
			variation => N__('Old Indian: Ukranian, 4. e4'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/3p1n2/8/2PP4/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'A53',
			# TRANSLATORS: A53: 1. d4 Nf6 2. c4 d6 3. Nf3
			variation => N__('Old Indian: 3. Nf3'),
			moves => {
				'b8d7' => 1,
				'c7c6' => 1,
				'c8f5' => 1,
				'c8g4' => 1,
			},
		},
		'r1bqkb1r/pppnpppp/3p1n2/8/2PP4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A53',
			# TRANSLATORS: A53: 1. d4 Nf6 2. c4 d6 3. Nf3 Nbd7
			variation => N__('Old Indian: 3. Nf3 Nbd7'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/2pp1n2/8/2PP4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A53',
			# TRANSLATORS: A53: 1. d4 Nf6 2. c4 d6 3. Nf3 c6
			variation => N__('Old Indian: 3. Nf3 c6'),
			moves => {
			},
		},
		'rn1qkb1r/ppp1pppp/3p1n2/5b2/2PP4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A53',
			# TRANSLATORS: A53: 1. d4 Nf6 2. c4 d6 3. Nf3 Bf5
			variation => N__('Old Indian: 3. Nf3 Bf5'),
			moves => {
			},
		},
		'rn1qkb1r/ppp1pppp/3p1n2/8/2PP2b1/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A53',
			# TRANSLATORS: A53: 1. d4 Nf6 2. c4 d6 3. Nf3 Bg4
			variation => N__('Old Indian: 3. Nf3 Bg4'),
			moves => {
				'b1c3' => 1,
				'd1b3' => 1,
			},
		},
		'rn1qkb1r/ppp1pppp/3p1n2/8/2PP2b1/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'A53',
			# TRANSLATORS: A53: 1. d4 Nf6 2. c4 d6 3. Nf3 Bg4 4. Nc3
			variation => N__('Old Indian: 3. Nf3 Bg4 4. Nc3'),
			moves => {
			},
		},
		'rn1qkb1r/ppp1pppp/3p1n2/8/2PP2b1/1Q3N2/PP2PPPP/RNB1KB1R b KQkq' => {
			eco => 'A53',
			# TRANSLATORS: A53: 1. d4 Nf6 2. c4 d6 3. Nf3 Bg4 4. Qb3
			variation => N__('Old Indian: 3. Nf3 Bg4 4. Qb3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/3p1n2/8/2PP4/6P1/PP2PP1P/RNBQKBNR b KQkq' => {
			eco => 'A53',
			# TRANSLATORS: A53: 1. d4 Nf6 2. c4 d6 3. g3
			variation => N__('Old Indian: 3. g3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/3p1n2/4p3/2PP4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'A54',
			# TRANSLATORS: A54: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3
			variation => N__('Old Indian: 4. Nf3'),
			moves => {
				'b8c6' => 1,
				'b8d7' => 1,
				'e5d4' => 1,
				'e5e4' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2np1n2/4p3/2PP4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'A54',
			# TRANSLATORS: A54: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nc6
			variation => N__('Old Indian: 4. Nf3 Nc6'),
			moves => {
			},
		},
		'r1bqkb1r/pppn1ppp/3p1n2/4p3/2PP4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'A54',
			# TRANSLATORS: A54: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7
			variation => N__('Old Indian: 4. Nf3 Nbd7'),
			moves => {
				'c1g5' => 1,
				'e2e3' => 1,
				'e2e4' => 1,
				'g2g3' => 1,
			},
		},
		'r1bqkb1r/pppn1ppp/3p1n2/4p1B1/2PP4/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'A54',
			# TRANSLATORS: A54: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. Bg5
			variation => N__('Old Indian: 5. Bg5'),
			moves => {
				'c7c6' => 1,
				'f8e7' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/2pp1n2/4p1B1/2PP4/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'A54',
			# TRANSLATORS: A54: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. Bg5 c6
			variation => N__('Old Indian: 5. Bg5 c6'),
			moves => {
			},
		},
		'r1bqk2r/pppnbppp/3p1n2/4p1B1/2PP4/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'A54',
			# TRANSLATORS: A54: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. Bg5 Be7
			variation => N__('Old Indian: 5. Bg5 Be7'),
			moves => {
				'e2e3' => 1,
			},
		},
		'r1bqk2r/pppnbppp/3p1n2/4p1B1/2PP4/2N1PN2/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'A54',
			# TRANSLATORS: A54: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. Bg5 Be7 6. e3
			variation => N__('Old Indian: 5. Bg5 Be7 6. e3'),
			moves => {
				'c7c6' => 1,
				'e8g8' => 1,
			},
		},
		'r1bqk2r/pp1nbppp/2pp1n2/4p1B1/2PP4/2N1PN2/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'A54',
			# TRANSLATORS: A54: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. Bg5 Be7 6. e3 c6
			variation => N__('Old Indian: 5. Bg5 Be7 6. e3 c6'),
			moves => {
			},
		},
		'r1bq1rk1/pppnbppp/3p1n2/4p1B1/2PP4/2N1PN2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'A54',
			# TRANSLATORS: A54: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. Bg5 Be7 6. e3 O-O
			variation => N__('Old Indian: 5. Bg5 Be7 6. e3 O-O'),
			moves => {
				'd1c2' => 1,
			},
		},
		'r1bq1rk1/pppnbppp/3p1n2/4p1B1/2PP4/2N1PN2/PPQ2PPP/R3KB1R b KQ' => {
			eco => 'A54',
			# TRANSLATORS: A54: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. Bg5 Be7 6. e3 O-O 7. Qc2
			variation => N__('Old Indian: 5. Bg5 Be7 6. e3 O-O 7. Qc2'),
			moves => {
				'c7c6' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/2pp1n2/4p1B1/2PP4/2N1PN2/PPQ2PPP/R3KB1R w KQ' => {
			eco => 'A54',
			# TRANSLATORS: A54: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. Bg5 Be7 6. e3 O-O 7. Qc2 c6
			variation => N__('Old Indian: 5. Bg5 Be7 6. e3 O-O 7. Qc2 c6'),
			moves => {
			},
		},
		'r1bqkb1r/pppn1ppp/3p1n2/4p3/2PP4/2N1PN2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'A54',
			# TRANSLATORS: A54: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. e3
			variation => N__('Old Indian: 5. e3'),
			moves => {
			},
		},
		'r1bqkb1r/pppn1ppp/3p1n2/4p3/2PP4/2N2NP1/PP2PP1P/R1BQKB1R b KQkq' => {
			eco => 'A54',
			# TRANSLATORS: A54: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. g3
			variation => N__('Old Indian: 5. g3'),
			moves => {
				'c7c6' => 1,
				'f8e7' => 1,
				'g7g6' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/2pp1n2/4p3/2PP4/2N2NP1/PP2PP1P/R1BQKB1R w KQkq' => {
			eco => 'A54',
			# TRANSLATORS: A54: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. g3 c6
			variation => N__('Old Indian: 5. g3 c6'),
			moves => {
				'f1g2' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/2pp1n2/4p3/2PP4/2N2NP1/PP2PPBP/R1BQK2R b KQkq' => {
			eco => 'A54',
			# TRANSLATORS: A54: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. g3 c6 6. Bg2
			variation => N__('Old Indian: 5. g3 c6'),
			moves => {
			},
		},
		'r1bqk2r/pppnbppp/3p1n2/4p3/2PP4/2N2NP1/PP2PP1P/R1BQKB1R w KQkq' => {
			eco => 'A54',
			# TRANSLATORS: A54: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. g3 Be7
			variation => N__('Old Indian: 5. g3 Be7'),
			moves => {
				'f1g2' => 1,
			},
		},
		'r1bqk2r/pppnbppp/3p1n2/4p3/2PP4/2N2NP1/PP2PPBP/R1BQK2R b KQkq' => {
			eco => 'A54',
			# TRANSLATORS: A54: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. g3 Be7 6. Bg2
			variation => N__('Old Indian: 5. g3 Be7'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pppnbppp/3p1n2/4p3/2PP4/2N2NP1/PP2PPBP/R1BQK2R w KQ' => {
			eco => 'A54',
			# TRANSLATORS: A54: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. g3 Be7 6. Bg2 O-O
			variation => N__('Old Indian: 5. g3 Be7'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bq1rk1/pppnbppp/3p1n2/4p3/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'A54',
			# TRANSLATORS: A54: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. g3 Be7 6. Bg2 O-O 7. O-O
			variation => N__('Old Indian: 5. g3 Be7'),
			moves => {
				'c7c6' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/2pp1n2/4p3/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A54',
			# TRANSLATORS: A54: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. g3 Be7 6. Bg2 O-O 7. O-O c6
			variation => N__('Old Indian: 5. g3 Be7, Main Line'),
			moves => {
				'd1c2' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/2pp1n2/4p3/2PP4/2N2NP1/PPQ1PPBP/R1B2RK1 b -' => {
			eco => 'A54',
			# TRANSLATORS: A54: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. g3 Be7 6. Bg2 O-O 7. O-O c6 8. Qc2
			variation => N__('Old Indian: 5. g3 Be7, Main Line, 8. Qc2'),
			moves => {
			},
		},
		'r1bqkb1r/pppn1p1p/3p1np1/4p3/2PP4/2N2NP1/PP2PP1P/R1BQKB1R w KQkq' => {
			eco => 'A54',
			# TRANSLATORS: A54: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. g3 g6
			variation => N__('Old Indian: 5. g3 g6'),
			moves => {
				'f1g2' => 1,
			},
		},
		'r1bqkb1r/pppn1p1p/3p1np1/4p3/2PP4/2N2NP1/PP2PPBP/R1BQK2R b KQkq' => {
			eco => 'A54',
			# TRANSLATORS: A54: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. g3 g6 6. Bg2
			variation => N__('Old Indian: 5. g3 g6'),
			moves => {
				'f8g7' => 1,
			},
		},
		'r1bqk2r/pppn1pbp/3p1np1/4p3/2PP4/2N2NP1/PP2PPBP/R1BQK2R w KQkq' => {
			eco => 'A54',
			# TRANSLATORS: A54: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. g3 g6 6. Bg2 Bg7
			variation => N__('Old Indian: 5. g3 g6'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/3p1n2/8/2Pp4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'A54',
			# TRANSLATORS: A54: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 exd4
			variation => N__('Old Indian: 4. Nf3 exd4'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/3p1n2/8/2PPp3/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'A54',
			# TRANSLATORS: A54: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 e4
			variation => N__('Old Indian: 4. Nf3 e4'),
			moves => {
				'f3g5' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/3p1n2/6N1/2PPp3/2N5/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'A54',
			# TRANSLATORS: A54: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 e4 5. Ng5
			variation => N__('Old Indian: 4. Nf3 e4 5. Ng5'),
			moves => {
			},
		},
		'r1bqkb1r/pppn1ppp/3p1n2/4p3/2PPP3/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'A55a',
			# TRANSLATORS: A55a: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. e4
			variation => N__('Old Indian: 5. e4'),
			moves => {
				'c7c6' => 1,
				'f8e7' => 1,
				'g7g6' => 1,
			},
		},
		'r1bqkb1r/pppn1p1p/3p1np1/4p3/2PPP3/2N2N2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'A55b',
			# TRANSLATORS: A55b: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. e4 g6
			variation => N__('Old Indian: 5. e4 g6'),
			moves => {
			},
		},
		'r1bqkb1r/pp1n1ppp/2pp1n2/4p3/2PPP3/2N2N2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'A55c',
			# TRANSLATORS: A55c: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. e4 c6
			variation => N__('Old Indian: 5. e4 c6'),
			moves => {
				'f1e2' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/2pp1n2/4p3/2PPP3/2N2N2/PP2BPPP/R1BQK2R b KQkq' => {
			eco => 'A55c',
			# TRANSLATORS: A55c: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. e4 c6 6. Be2
			variation => N__('Old Indian: 5. e4 c6 6. Be2'),
			moves => {
			},
		},
		'r1bqk2r/pppnbppp/3p1n2/4p3/2PPP3/2N2N2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'A55d',
			# TRANSLATORS: A55d: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. e4 Be7
			variation => N__('Old Indian: 5. e4 Be7'),
			moves => {
				'f1e2' => 1,
				'g2g3' => 1,
			},
		},
		'r1bqk2r/pppnbppp/3p1n2/4p3/2PPP3/2N2NP1/PP3P1P/R1BQKB1R b KQkq' => {
			eco => 'A55e',
			# TRANSLATORS: A55e: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. e4 Be7 6. g3
			variation => N__('Old Indian: 5. e4 Be7 6. g3'),
			moves => {
				'c7c6' => 1,
				'e8g8' => 1,
			},
		},
		'r1bqk2r/pp1nbppp/2pp1n2/4p3/2PPP3/2N2NP1/PP3P1P/R1BQKB1R w KQkq' => {
			eco => 'A55e',
			# TRANSLATORS: A55e: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. e4 Be7 6. g3 c6
			variation => N__('Old Indian: 5. e4 Be7 6. g3 c6'),
			moves => {
				'f1g2' => 1,
			},
		},
		'r1bqk2r/pp1nbppp/2pp1n2/4p3/2PPP3/2N2NP1/PP3PBP/R1BQK2R b KQkq' => {
			eco => 'A55e',
			# TRANSLATORS: A55e: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. e4 Be7 6. g3 c6 7. Bg2
			variation => N__('Old Indian: 5. e4 Be7 6. g3 c6 7. Bg2'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/2pp1n2/4p3/2PPP3/2N2NP1/PP3PBP/R1BQK2R w KQ' => {
			eco => 'A55e',
			# TRANSLATORS: A55e: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. e4 Be7 6. g3 c6 7. Bg2 O-O
			variation => N__('Old Indian: 5. e4 Be7 6. g3 c6 7. Bg2 O-O'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/2pp1n2/4p3/2PPP3/2N2NP1/PP3PBP/R1BQ1RK1 b -' => {
			eco => 'A55e',
			# TRANSLATORS: A55e: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. e4 Be7 6. g3 c6 7. Bg2 O-O 8. O-O
			variation => N__('Old Indian: 5. e4 Be7 6. g3 c6 7. Bg2 O-O 8.O-O'),
			moves => {
				'a7a6' => 1,
				'd8c7' => 1,
				'f8e8' => 1,
			},
		},
		'r1b2rk1/ppqnbppp/2pp1n2/4p3/2PPP3/2N2NP1/PP3PBP/R1BQ1RK1 w -' => {
			eco => 'A55e',
			# TRANSLATORS: A55e: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. e4 Be7 6. g3 c6 7. Bg2 O-O 8. O-O Qc7
			variation => N__('Old Indian: 5. e4 Be7 6. g3 c6 7. Bg2 O-O 8.O-O Qc7'),
			moves => {
			},
		},
		'r1bq1rk1/pppnbppp/3p1n2/4p3/2PPP3/2N2NP1/PP3P1P/R1BQKB1R w KQ' => {
			eco => 'A55e',
			# TRANSLATORS: A55e: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. e4 Be7 6. g3 O-O
			variation => N__('Old Indian: 5. e4 Be7 6. g3 O-O'),
			moves => {
			},
		},
		'r1bqr1k1/pp1nbppp/2pp1n2/4p3/2PPP3/2N2NP1/PP3PBP/R1BQ1RK1 w -' => {
			eco => 'A55f',
			# TRANSLATORS: A55f: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. e4 Be7 6. g3 c6 7. Bg2 O-O 8. O-O Re8
			variation => N__('Old Indian: 5. e4 Be7 6. g3 c6 7. Bg2 O-O 8.O-O Re8'),
			moves => {
			},
		},
		'r1bq1rk1/1p1nbppp/p1pp1n2/4p3/2PPP3/2N2NP1/PP3PBP/R1BQ1RK1 w -' => {
			eco => 'A55g',
			# TRANSLATORS: A55g: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. e4 Be7 6. g3 c6 7. Bg2 O-O 8. O-O a6
			variation => N__('Old Indian: 5. e4 Be7 6. g3 c6 7. Bg2 O-O 8.O-O a6'),
			moves => {
				'a2a4' => 1,
			},
		},
		'r1bq1rk1/1p1nbppp/p1pp1n2/4p3/P1PPP3/2N2NP1/1P3PBP/R1BQ1RK1 b -' => {
			eco => 'A55h',
			# TRANSLATORS: A55h: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. e4 Be7 6. g3 c6 7. Bg2 O-O 8. O-O a6 9. a4
			variation => N__('Old Indian: 5. e4 Be7 6. g3 c6 7. Bg2 O-O 8.O-O a6 9. a4'),
			moves => {
			},
		},
		'r1bqk2r/pppnbppp/3p1n2/4p3/2PPP3/2N2N2/PP2BPPP/R1BQK2R b KQkq' => {
			eco => 'A55i',
			# TRANSLATORS: A55i: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. e4 Be7 6. Be2
			variation => N__('Old Indian: 5. e4 Be7 6. Be2'),
			moves => {
				'c7c6' => 1,
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pppnbppp/3p1n2/4p3/2PPP3/2N2N2/PP2BPPP/R1BQK2R w KQ' => {
			eco => 'A55i',
			# TRANSLATORS: A55i: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. e4 Be7 6. Be2 O-O
			variation => N__('Old Indian: 5. e4 Be7 6. Be2 O-O'),
			moves => {
			},
		},
		'r1bqk2r/pp1nbppp/2pp1n2/4p3/2PPP3/2N2N2/PP2BPPP/R1BQK2R w KQkq' => {
			eco => 'A55j',
			# TRANSLATORS: A55j: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. e4 Be7 6. Be2 c6
			variation => N__('Old Indian: 5. e4 Be7 6. Be2 c6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqk2r/pp1nbppp/2pp1n2/4p3/2PPP3/2N2N2/PP2BPPP/R1BQ1RK1 b kq' => {
			eco => 'A55j',
			# TRANSLATORS: A55j: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. e4 Be7 6. Be2 c6 7. O-O
			variation => N__('Old Indian: 5. e4 Be7 6. Be2 c6 7.O-O'),
			moves => {
				'a7a6' => 1,
				'e8g8' => 1,
			},
		},
		'r1bqk2r/1p1nbppp/p1pp1n2/4p3/2PPP3/2N2N2/PP2BPPP/R1BQ1RK1 w kq' => {
			eco => 'A55j',
			# TRANSLATORS: A55j: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. e4 Be7 6. Be2 c6 7. O-O a6
			variation => N__('Old Indian: 5. e4 Be7 6. Be2 c6 7.O-O a6'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nbppp/2pp1n2/4p3/2PPP3/2N2N2/PP2BPPP/R1BQ1RK1 w -' => {
			eco => 'A55k',
			# TRANSLATORS: A55k: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. e4 Be7 6. Be2 c6 7. O-O O-O
			variation => N__('Old Indian: Main Line'),
			moves => {
				'c1e3' => 1,
				'd1c2' => 1,
				'f1e1' => 1,
				'h2h3' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/2pp1n2/4p3/2PPP3/2N2N1P/PP2BPP1/R1BQ1RK1 b -' => {
			eco => 'A55l',
			# TRANSLATORS: A55l: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. e4 Be7 6. Be2 c6 7. O-O O-O 8. h3
			variation => N__('Old Indian: Main Line, 8. h3'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nbppp/2pp1n2/4p3/2PPP3/2N1BN2/PP2BPPP/R2Q1RK1 b -' => {
			eco => 'A55m',
			# TRANSLATORS: A55m: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. e4 Be7 6. Be2 c6 7. O-O O-O 8. Be3
			variation => N__('Old Indian: Main Line, 8. Be3'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r1bq1rk1/1p1nbppp/p1pp1n2/4p3/2PPP3/2N1BN2/PP2BPPP/R2Q1RK1 w -' => {
			eco => 'A55n',
			# TRANSLATORS: A55n: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. e4 Be7 6. Be2 c6 7. O-O O-O 8. Be3 a6
			variation => N__('Old Indian: Main Line, 8. Be3 a6'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nbppp/2pp1n2/4p3/2PPP3/2N2N2/PPQ1BPPP/R1B2RK1 b -' => {
			eco => 'A55o',
			# TRANSLATORS: A55o: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. e4 Be7 6. Be2 c6 7. O-O O-O 8. Qc2
			variation => N__('Old Indian: Main Line, 8. Qc2'),
			moves => {
				'a7a6' => 1,
				'd8c7' => 1,
				'f8e8' => 1,
			},
		},
		'r1b2rk1/ppqnbppp/2pp1n2/4p3/2PPP3/2N2N2/PPQ1BPPP/R1B2RK1 w -' => {
			eco => 'A55o',
			# TRANSLATORS: A55o: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. e4 Be7 6. Be2 c6 7. O-O O-O 8. Qc2 Qc7
			variation => N__('Old Indian: Main Line, 8. Qc2 Qc7'),
			moves => {
			},
		},
		'r1bqr1k1/pp1nbppp/2pp1n2/4p3/2PPP3/2N2N2/PPQ1BPPP/R1B2RK1 w -' => {
			eco => 'A55o',
			# TRANSLATORS: A55o: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. e4 Be7 6. Be2 c6 7. O-O O-O 8. Qc2 Re8
			variation => N__('Old Indian: Main Line, 8. Qc2 Re8'),
			moves => {
			},
		},
		'r1bq1rk1/1p1nbppp/p1pp1n2/4p3/2PPP3/2N2N2/PPQ1BPPP/R1B2RK1 w -' => {
			eco => 'A55p',
			# TRANSLATORS: A55p: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. e4 Be7 6. Be2 c6 7. O-O O-O 8. Qc2 a6
			variation => N__('Old Indian: Main Line, 8. Qc2 a6'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nbppp/2pp1n2/4p3/2PPP3/2N2N2/PP2BPPP/R1BQR1K1 b -' => {
			eco => 'A55q',
			# TRANSLATORS: A55q: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. e4 Be7 6. Be2 c6 7. O-O O-O 8. Re1
			variation => N__('Old Indian: Main Line, 8. Re1'),
			moves => {
				'a7a6' => 1,
				'f8e8' => 1,
			},
		},
		'r1bqr1k1/pp1nbppp/2pp1n2/4p3/2PPP3/2N2N2/PP2BPPP/R1BQR1K1 w -' => {
			eco => 'A55r',
			# TRANSLATORS: A55r: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. e4 Be7 6. Be2 c6 7. O-O O-O 8. Re1 Re8
			variation => N__('Old Indian: Main Line, 8. Re1 Re8'),
			moves => {
			},
		},
		'r1bq1rk1/1p1nbppp/p1pp1n2/4p3/2PPP3/2N2N2/PP2BPPP/R1BQR1K1 w -' => {
			eco => 'A55s',
			# TRANSLATORS: A55s: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. e4 Be7 6. Be2 c6 7. O-O O-O 8. Re1 a6
			variation => N__('Old Indian: Main Line, 8. Re1 a6'),
			moves => {
				'e2f1' => 1,
			},
		},
		'r1bq1rk1/1p1nbppp/p1pp1n2/4p3/2PPP3/2N2N2/PP3PPP/R1BQRBK1 b -' => {
			eco => 'A55t',
			# TRANSLATORS: A55t: 1. d4 Nf6 2. c4 d6 3. Nc3 e5 4. Nf3 Nbd7 5. e4 Be7 6. Be2 c6 7. O-O O-O 8. Re1 a6 9. Bf1
			variation => N__('Old Indian: Main Line, 8. Re1 a6 9. Bf1'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/2p5/2PP4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A56a',
			# TRANSLATORS: A56a: 1. d4 Nf6 2. c4 c5
			variation => N__('Benoni: 2... c5'),
			moves => {
				'd4c5' => 1,
				'd4d5' => 1,
				'e2e3' => 1,
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/2p5/2PP4/4P3/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'A56b',
			# TRANSLATORS: A56b: 1. d4 Nf6 2. c4 c5 3. e3
			variation => N__('Benoni: 2... c5 3. e3'),
			moves => {
				'e7e6' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/2p5/2PP4/4P3/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'A56b',
			# TRANSLATORS: A56b: 1. d4 Nf6 2. c4 c5 3. e3 e6
			variation => N__('Benoni: 2... c5 3. e3 e6'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppp1p/5np1/2p5/2PP4/4P3/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'A56c',
			# TRANSLATORS: A56c: 1. d4 Nf6 2. c4 c5 3. e3 g6
			variation => N__('Benoni: 2... c5 3. e3 g6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkb1r/pp1ppp1p/5np1/2p5/2PP4/2N1P3/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'A56d',
			# TRANSLATORS: A56d: 1. d4 Nf6 2. c4 c5 3. e3 g6 4. Nc3
			variation => N__('Benoni: 2... c5 3. e3 g6 4. Nc3'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/2P5/2P5/8/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'A56e',
			# TRANSLATORS: A56e: 1. d4 Nf6 2. c4 c5 3. dxc5
			variation => N__('Benoni: 3.dxc5'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/2pP4/2P5/8/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'A56f',
			# TRANSLATORS: A56f: 1. d4 Nf6 2. c4 c5 3. d5
			variation => N__('Benoni: 3. d5'),
			moves => {
				'a7a6' => 1,
				'b7b5' => 1,
				'd7d6' => 1,
				'e7e5' => 1,
				'e7e6' => 1,
				'f6e4' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/1p1ppppp/p4n2/2pP4/2P5/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A56g',
			# TRANSLATORS: A56g: 1. d4 Nf6 2. c4 c5 3. d5 a6
			variation => N__('Benoni: 3. d5 a6'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppp1p/5np1/2pP4/2P5/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A56h',
			# TRANSLATORS: A56h: 1. d4 Nf6 2. c4 c5 3. d5 g6
			variation => N__('Benoni: 3. d5 g6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkb1r/pp1ppp1p/5np1/2pP4/2P5/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'A56h',
			# TRANSLATORS: A56h: 1. d4 Nf6 2. c4 c5 3. d5 g6 4. Nc3
			variation => N__('Benoni: 3. d5 g6'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/3p1n2/2pP4/2P5/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A56i',
			# TRANSLATORS: A56i: 1. d4 Nf6 2. c4 c5 3. d5 d6
			variation => N__('Benoni: 3. d5 d6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/3p1n2/2pP4/2P5/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'A56i',
			# TRANSLATORS: A56i: 1. d4 Nf6 2. c4 c5 3. d5 d6 4. Nc3
			variation => N__('Benoni: 3. d5 d6'),
			moves => {
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/pp2pp1p/3p1np1/2pP4/2P5/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'A56j',
			# TRANSLATORS: A56j: 1. d4 Nf6 2. c4 c5 3. d5 d6 4. Nc3 g6
			variation => N__('Benoni: 3. d5 d6 4. Nc3 g6'),
			moves => {
				'e2e4' => 1,
			},
		},
		'rnbqkb1r/pp2pp1p/3p1np1/2pP4/2P1P3/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'A56j',
			# TRANSLATORS: A56j: 1. d4 Nf6 2. c4 c5 3. d5 d6 4. Nc3 g6 5. e4
			variation => N__('Benoni: 3. d5 d6 4. Nc3 g6'),
			moves => {
				'b7b5' => 1,
				'f8g7' => 1,
			},
		},
		'rnbqkb1r/p3pp1p/3p1np1/1ppP4/2P1P3/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'A56j',
			# TRANSLATORS: A56j: 1. d4 Nf6 2. c4 c5 3. d5 g6 4. Nc3 d6 5. e4 b5
			variation => N__('Benoni: Bronstein\'s Gambit'),
			moves => {
			},
		},
		'rnbqk2r/pp2ppbp/3p1np1/2pP4/2P1P3/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'A56k',
			# TRANSLATORS: A56k: 1. d4 Nf6 2. c4 c5 3. d5 d6 4. Nc3 g6 5. e4 Bg7
			variation => N__('Benoni: 3. d5 d6 4. Nc3 g6 5. e4 Bg7'),
			moves => {
				'f1d3' => 1,
				'f2f3' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/3p1np1/2pP4/2P1P3/2N2P2/PP4PP/R1BQKBNR b KQkq' => {
			eco => 'A56l',
			# TRANSLATORS: A56l: 1. d4 Nf6 2. c4 c5 3. d5 d6 4. Nc3 g6 5. e4 Bg7 6. f3
			variation => N__('Benoni: 3. d5 d6 4. Nc3 g6 5. e4 Bg7 6. f3'),
			moves => {
			},
		},
		'rnbqk2r/pp2ppbp/3p1np1/2pP4/2P1P3/2NB4/PP3PPP/R1BQK1NR b KQkq' => {
			eco => 'A56m',
			# TRANSLATORS: A56m: 1. d4 Nf6 2. c4 c5 3. d5 d6 4. Nc3 g6 5. e4 Bg7 6. Bd3
			variation => N__('Benoni: 3. d5 d6 4. Nc3 g6 5. e4 Bg7 6. Bd3'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/8/2pP4/2P1n3/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A56n',
			# TRANSLATORS: A56n: 1. d4 Nf6 2. c4 c5 3. d5 Ne4
			variation => N__('Benoni: Vulture'),
			moves => {
			},
		},
		'rnbqkb1r/pp1p1ppp/5n2/2pPp3/2P5/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A56o',
			# TRANSLATORS: A56o: 1. d4 Nf6 2. c4 c5 3. d5 e5
			variation => N__('Benoni: Czech'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkb1r/pp1p1ppp/5n2/2pPp3/2P5/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'A56o',
			# TRANSLATORS: A56o: 1. d4 Nf6 2. c4 c5 3. d5 e5 4. Nc3
			variation => N__('Benoni: Czech'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/3p1n2/2pPp3/2P5/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'A56p',
			# TRANSLATORS: A56p: 1. d4 Nf6 2. c4 c5 3. d5 e5 4. Nc3 d6
			variation => N__('Benoni: Czech, 4. Nc3 d6'),
			moves => {
				'e2e4' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/3p1n2/2pPp3/2P1P3/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'A56p',
			# TRANSLATORS: A56p: 1. d4 Nf6 2. c4 c5 3. d5 e5 4. Nc3 d6 5. e4
			variation => N__('Benoni: Czech, 4. Nc3 d6'),
			moves => {
				'f8e7' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/pp3p1p/3p1np1/2pPp3/2P1P3/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'A56q',
			# TRANSLATORS: A56q: 1. d4 Nf6 2. c4 c5 3. d5 e5 4. Nc3 d6 5. e4 g6
			variation => N__('Benoni: Czech, 5. e4 g6'),
			moves => {
			},
		},
		'rnbqk2r/pp2bppp/3p1n2/2pPp3/2P1P3/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'A56r',
			# TRANSLATORS: A56r: 1. d4 Nf6 2. c4 c5 3. d5 e5 4. Nc3 d6 5. e4 Be7
			variation => N__('Benoni: Czech, 5. e4 Be7'),
			moves => {
				'f1d3' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqk2r/pp2bppp/3p1n2/2pPp3/2P1P3/2N3P1/PP3P1P/R1BQKBNR b KQkq' => {
			eco => 'A56s',
			# TRANSLATORS: A56s: 1. d4 Nf6 2. c4 c5 3. d5 e5 4. Nc3 d6 5. e4 Be7 6. g3
			variation => N__('Benoni: Czech, 5. e4 Be7 6. g3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/pp2bppp/3p1n2/2pPp3/2P1P3/2N3P1/PP3P1P/R1BQKBNR w KQ' => {
			eco => 'A56s',
			# TRANSLATORS: A56s: 1. d4 Nf6 2. c4 c5 3. d5 e5 4. Nc3 d6 5. e4 Be7 6. g3 O-O
			variation => N__('Benoni: Czech, 5. e4 Be7 6. g3 O-O'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbq1rk1/pp2bppp/3p1n2/2pPp3/2P1P3/2N3P1/PP3PBP/R1BQK1NR b KQ' => {
			eco => 'A56s',
			# TRANSLATORS: A56s: 1. d4 Nf6 2. c4 c5 3. d5 e5 4. Nc3 d6 5. e4 Be7 6. g3 O-O 7. Bg2
			variation => N__('Benoni: Czech, 5. e4 Be7 6. g3 O-O 7. Bg2'),
			moves => {
				'f6e8' => 1,
			},
		},
		'rnbqnrk1/pp2bppp/3p4/2pPp3/2P1P3/2N3P1/PP3PBP/R1BQK1NR w KQ' => {
			eco => 'A56t',
			# TRANSLATORS: A56t: 1. d4 Nf6 2. c4 c5 3. d5 e5 4. Nc3 d6 5. e4 Be7 6. g3 O-O 7. Bg2 Ne8
			variation => N__('Benoni: Czech, 5. e4 Be7 6. g3 O-O 7. Bg2 Ne8'),
			moves => {
			},
		},
		'rnbqk2r/pp2bppp/3p1n2/2pPp3/2P1P3/2NB4/PP3PPP/R1BQK1NR b KQkq' => {
			eco => 'A56u',
			# TRANSLATORS: A56u: 1. d4 Nf6 2. c4 c5 3. d5 e5 4. Nc3 d6 5. e4 Be7 6. Bd3
			variation => N__('Benoni: Czech, 5. e4 Be7 6. Bd3'),
			moves => {
			},
		},
		'rnbqk2r/pp2bppp/3p1n2/2pPp3/2P1P3/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'A56v',
			# TRANSLATORS: A56v: 1. d4 Nf6 2. c4 c5 3. d5 e5 4. Nc3 d6 5. e4 Be7 6. Nf3
			variation => N__('Benoni: Czech, 5. e4 Be7 6. Nf3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/pp2bppp/3p1n2/2pPp3/2P1P3/2N2N2/PP3PPP/R1BQKB1R w KQ' => {
			eco => 'A56w',
			# TRANSLATORS: A56w: 1. d4 Nf6 2. c4 c5 3. d5 e5 4. Nc3 d6 5. e4 Be7 6. Nf3 O-O
			variation => N__('Benoni: Czech, 5. e4 Be7 6. Nf3 O-O'),
			moves => {
				'f1e2' => 1,
				'h2h3' => 1,
			},
		},
		'rnbq1rk1/pp2bppp/3p1n2/2pPp3/2P1P3/2N2N1P/PP3PP1/R1BQKB1R b KQ' => {
			eco => 'A56w',
			# TRANSLATORS: A56w: 1. d4 Nf6 2. c4 c5 3. d5 e5 4. Nc3 d6 5. e4 Be7 6. Nf3 O-O 7. h3
			variation => N__('Benoni: Czech, 5. e4 Be7 6. Nf3 O-O 7. h3'),
			moves => {
			},
		},
		'rnbq1rk1/pp2bppp/3p1n2/2pPp3/2P1P3/2N2N2/PP2BPPP/R1BQK2R b KQ' => {
			eco => 'A56x',
			# TRANSLATORS: A56x: 1. d4 Nf6 2. c4 c5 3. d5 e5 4. Nc3 d6 5. e4 Be7 6. Nf3 O-O 7. Be2
			variation => N__('Benoni: Czech, 5. e4 Be7 6. Nf3 O-O 7. Be2'),
			moves => {
			},
		},
		'rnbqkb1r/p2ppppp/5n2/1ppP4/2P5/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A57a',
			# TRANSLATORS: A57a: 1. d4 Nf6 2. c4 c5 3. d5 b5
			variation => N__('Benko Gambit'),
			moves => {
				'a2a4' => 1,
				'b1d2' => 1,
				'c4b5' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/p2ppppp/5n2/1ppP4/P1P5/8/1P2PPPP/RNBQKBNR b KQkq' => {
			eco => 'A57b',
			# TRANSLATORS: A57b: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. a4
			variation => N__('Benko Gambit: 4. a4'),
			moves => {
			},
		},
		'rnbqkb1r/p2ppppp/5n2/1ppP4/2P5/8/PP1NPPPP/R1BQKBNR b KQkq' => {
			eco => 'A57c',
			# TRANSLATORS: A57c: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. Nd2
			variation => N__('Benko Gambit: 4. Nd2'),
			moves => {
			},
		},
		'rnbqkb1r/p2ppppp/5n2/1ppP4/2P5/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'A57d',
			# TRANSLATORS: A57d: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. Nf3
			variation => N__('Benko Gambit: 4. Nf3'),
			moves => {
				'b5c4' => 1,
				'c8b7' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/p2ppppp/5n2/2pP4/2p5/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A57d',
			# TRANSLATORS: A57d: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. Nf3 bxc4
			variation => N__('Benko Gambit: 4. Nf3 bxc4'),
			moves => {
			},
		},
		'rn1qkb1r/pb1ppppp/5n2/1ppP4/2P5/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A57e',
			# TRANSLATORS: A57e: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. Nf3 Bb7
			variation => N__('Benko Gambit: 4. Nf3 Bb7'),
			moves => {
				'a2a4' => 1,
			},
		},
		'rn1qkb1r/pb1ppppp/5n2/1ppP4/P1P5/5N2/1P2PPPP/RNBQKB1R b KQkq' => {
			eco => 'A57e',
			# TRANSLATORS: A57e: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. Nf3 Bb7 5. a4
			variation => N__('Benko Gambit: 4. Nf3 Bb7 5. a4'),
			moves => {
			},
		},
		'rnbqkb1r/p2ppp1p/5np1/1ppP4/2P5/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A57f',
			# TRANSLATORS: A57f: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. Nf3 g6
			variation => N__('Benko Gambit: 4. Nf3 g6'),
			moves => {
				'c4b5' => 1,
			},
		},
		'rnbqkb1r/p2ppp1p/5np1/1PpP4/8/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'A57g',
			# TRANSLATORS: A57g: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. Nf3 g6 5. cxb5
			variation => N__('Benko Gambit: 4. Nf3 g6 5.cxb5'),
			moves => {
				'a7a6' => 1,
			},
		},
		'rnbqkb1r/3ppp1p/p4np1/1PpP4/8/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A57g',
			# TRANSLATORS: A57g: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. Nf3 g6 5. cxb5 a6
			variation => N__('Benko Gambit: 4. Nf3 g6 5.cxb5 a6'),
			moves => {
			},
		},
		'rnbqkb1r/p2ppppp/5n2/1PpP4/8/8/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'A57h',
			# TRANSLATORS: A57h: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5
			variation => N__('Benko Gambit: 4.cxb5'),
			moves => {
				'a7a6' => 1,
			},
		},
		'rnbqkb1r/3ppppp/p4n2/1PpP4/8/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A57h',
			# TRANSLATORS: A57h: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6
			variation => N__('Benko Gambit: 4.cxb5 a6'),
			moves => {
				'b1c3' => 1,
				'b5a6' => 1,
				'b5b6' => 1,
				'e2e3' => 1,
				'f2f3' => 1,
			},
		},
		'rnbqkb1r/3ppppp/pP3n2/2pP4/8/8/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'A57i',
			# TRANSLATORS: A57i: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. b6
			variation => N__('Benko Gambit: 4.cxb5 a6 5. b6'),
			moves => {
				'd7d6' => 1,
				'd8b6' => 1,
				'e7e6' => 1,
			},
		},
		'rnb1kb1r/3ppppp/pq3n2/2pP4/8/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A57j',
			# TRANSLATORS: A57j: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. b6 Qxb6
			variation => N__('Benko Gambit: 4.cxb5 a6 5. b6 Qxb6'),
			moves => {
			},
		},
		'rnbqkb1r/4pppp/pP1p1n2/2pP4/8/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A57k',
			# TRANSLATORS: A57k: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. b6 d6
			variation => N__('Benko Gambit: 4.cxb5 a6 5. b6 d6'),
			moves => {
			},
		},
		'rnbqkb1r/3p1ppp/pP2pn2/2pP4/8/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A57l',
			# TRANSLATORS: A57l: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. b6 e6
			variation => N__('Benko Gambit: 4.cxb5 a6 5. b6 e6'),
			moves => {
			},
		},
		'rnbqkb1r/3ppppp/p4n2/1PpP4/8/4P3/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'A57m',
			# TRANSLATORS: A57m: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. e3
			variation => N__('Benko Gambit: 4.cxb5 a6 5. e3'),
			moves => {
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/3ppp1p/p4np1/1PpP4/8/4P3/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'A57n',
			# TRANSLATORS: A57n: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. e3 g6
			variation => N__('Benko Gambit: 4.cxb5 a6 5. e3 g6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkb1r/3ppp1p/p4np1/1PpP4/8/2N1P3/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'A57n',
			# TRANSLATORS: A57n: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. e3 g6 6. Nc3
			variation => N__('Benko Gambit: 4.cxb5 a6 5. e3 g6'),
			moves => {
				'd7d6' => 1,
				'f8g7' => 1,
			},
		},
		'rnbqkb1r/4pp1p/p2p1np1/1PpP4/8/2N1P3/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'A57n',
			# TRANSLATORS: A57n: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. e3 g6 6. Nc3 d6
			variation => N__('Benko Gambit: 4.cxb5 a6 5. e3 g6 6. Nc3 d6'),
			moves => {
			},
		},
		'rnbqk2r/3pppbp/p4np1/1PpP4/8/2N1P3/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'A57n',
			# TRANSLATORS: A57n: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. e3 g6 6. Nc3 Bg7
			variation => N__('Benko Gambit: 4.cxb5 a6 5. e3 g6 6. Nc3 Bg7'),
			moves => {
			},
		},
		'rnbqkb1r/3ppppp/p4n2/1PpP4/8/5P2/PP2P1PP/RNBQKBNR b KQkq' => {
			eco => 'A57o',
			# TRANSLATORS: A57o: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. f3
			variation => N__('Benko Gambit: 4.cxb5 a6 5. f3'),
			moves => {
				'a6b5' => 1,
				'e7e6' => 1,
			},
		},
		'rnbqkb1r/3p1ppp/p3pn2/1PpP4/8/5P2/PP2P1PP/RNBQKBNR w KQkq' => {
			eco => 'A57p',
			# TRANSLATORS: A57p: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. f3 e6
			variation => N__('Benko Gambit: 4.cxb5 a6 5. f3 e6'),
			moves => {
			},
		},
		'rnbqkb1r/3ppppp/5n2/1ppP4/8/5P2/PP2P1PP/RNBQKBNR w KQkq' => {
			eco => 'A57q',
			# TRANSLATORS: A57q: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. f3 axb5
			variation => N__('Benko Gambit: 4.cxb5 a6 5. f3 axb5'),
			moves => {
			},
		},
		'rnbqkb1r/3ppppp/p4n2/1PpP4/8/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'A57r',
			# TRANSLATORS: A57r: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. Nc3
			variation => N__('Benko Gambit: Zaitsev Variation'),
			moves => {
				'a6b5' => 1,
				'd8a5' => 1,
			},
		},
		'rnb1kb1r/3ppppp/p4n2/qPpP4/8/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'A57r',
			# TRANSLATORS: A57r: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. Nc3 Qa5
			variation => N__('Benko Gambit: Zaitsev, 5... Qa5'),
			moves => {
			},
		},
		'rnbqkb1r/3ppppp/5n2/1ppP4/8/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'A57s',
			# TRANSLATORS: A57s: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. Nc3 axb5
			variation => N__('Benko Gambit: Zaitsev, 5...axb5'),
			moves => {
				'e2e4' => 1,
			},
		},
		'rnbqkb1r/3ppppp/5n2/1ppP4/4P3/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'A57s',
			# TRANSLATORS: A57s: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. Nc3 axb5 6. e4
			variation => N__('Benko Gambit: Zaitsev, 5...axb5'),
			moves => {
				'b5b4' => 1,
			},
		},
		'rnbqkb1r/3ppppp/5n2/2pP4/1p2P3/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'A57s',
			# TRANSLATORS: A57s: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. Nc3 axb5 6. e4 b4
			variation => N__('Benko Gambit: Zaitsev, 5...axb5 6. e4 b4'),
			moves => {
				'c3b5' => 1,
			},
		},
		'rnbqkb1r/3ppppp/5n2/1NpP4/1p2P3/8/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'A57s',
			# TRANSLATORS: A57s: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. Nc3 axb5 6. e4 b4 7. Nb5
			variation => N__('Benko Gambit: Zaitsev, 5...axb5 6. e4 b4'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rnbqkb1r/4pppp/3p1n2/1NpP4/1p2P3/8/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'A57s',
			# TRANSLATORS: A57s: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. Nc3 axb5 6. e4 b4 7. Nb5 d6
			variation => N__('Benko Gambit: Zaitsev, 5...axb5 6. e4 b4'),
			moves => {
				'c1f4' => 1,
				'f1c4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/4pppp/3p1n2/1NpP4/1p2P3/5N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'A57t',
			# TRANSLATORS: A57t: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. Nc3 axb5 6. e4 b4 7. Nb5 d6 8. Nf3
			variation => N__('Benko Gambit: Zaitsev, 8. Nf3'),
			moves => {
			},
		},
		'rnbqkb1r/4pppp/3p1n2/1NpP4/1pB1P3/8/PP3PPP/R1BQK1NR b KQkq' => {
			eco => 'A57u',
			# TRANSLATORS: A57u: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. Nc3 axb5 6. e4 b4 7. Nb5 d6 8. Bc4
			variation => N__('Benko Gambit: Zaitsev, Nescafe Frappe Attack'),
			moves => {
			},
		},
		'rnbqkb1r/4pppp/3p1n2/1NpP4/1p2PB2/8/PP3PPP/R2QKBNR b KQkq' => {
			eco => 'A57v',
			# TRANSLATORS: A57v: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. Nc3 axb5 6. e4 b4 7. Nb5 d6 8. Bf4
			variation => N__('Benko Gambit: Zaitsev, 8. Bf4'),
			moves => {
				'g7g5' => 1,
			},
		},
		'rnbqkb1r/4pp1p/3p1n2/1NpP2p1/1p2PB2/8/PP3PPP/R2QKBNR w KQkq' => {
			eco => 'A57w',
			# TRANSLATORS: A57w: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. Nc3 axb5 6. e4 b4 7. Nb5 d6 8. Bf4 g5
			variation => N__('Benko Gambit: Zaitsev, 8. Bf4 g5'),
			moves => {
			},
		},
		'rnbqkb1r/3ppppp/P4n2/2pP4/8/8/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'A58a',
			# TRANSLATORS: A58a: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6
			variation => N__('Benko Gambit: 5.bxa6'),
			moves => {
				'c8a6' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/3ppp1p/P4np1/2pP4/8/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A58b',
			# TRANSLATORS: A58b: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 g6
			variation => N__('Benko Gambit: 5.bxa6 g6'),
			moves => {
			},
		},
		'rn1qkb1r/3ppppp/b4n2/2pP4/8/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A58c',
			# TRANSLATORS: A58c: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6
			variation => N__('Benko Gambit: 5.bxa6 Bxa6'),
			moves => {
				'b1c3' => 1,
				'g2g3' => 1,
			},
		},
		'rn1qkb1r/3ppppp/b4n2/2pP4/8/6P1/PP2PP1P/RNBQKBNR b KQkq' => {
			eco => 'A58c',
			# TRANSLATORS: A58c: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. g3
			variation => N__('Benko Gambit: Accepted, 6. g3'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rn1qkb1r/4pppp/b2p1n2/2pP4/8/6P1/PP2PP1P/RNBQKBNR w KQkq' => {
			eco => 'A58c',
			# TRANSLATORS: A58c: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. g3 d6
			variation => N__('Benko Gambit: Accepted, 6. g3'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rn1qkb1r/4pppp/b2p1n2/2pP4/8/6P1/PP2PPBP/RNBQK1NR b KQkq' => {
			eco => 'A58c',
			# TRANSLATORS: A58c: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. g3 d6 7. Bg2
			variation => N__('Benko Gambit: Accepted, 6. g3'),
			moves => {
				'g7g6' => 1,
			},
		},
		'rn1qkb1r/4pp1p/b2p1np1/2pP4/8/6P1/PP2PPBP/RNBQK1NR w KQkq' => {
			eco => 'A58d',
			# TRANSLATORS: A58d: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. g3 d6 7. Bg2 g6
			variation => N__('Benko Gambit: Accepted, 6. g3 d6 7. Bg2 g6'),
			moves => {
				'b2b3' => 1,
			},
		},
		'rn1qkb1r/4pp1p/b2p1np1/2pP4/8/1P4P1/P3PPBP/RNBQK1NR b KQkq' => {
			eco => 'A58d',
			# TRANSLATORS: A58d: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. g3 d6 7. Bg2 g6 8. b3
			variation => N__('Benko Gambit: Accepted, 6. g3 d6 7. Bg2 g6 8. b3'),
			moves => {
			},
		},
		'rn1qkb1r/3ppppp/b4n2/2pP4/8/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'A58e',
			# TRANSLATORS: A58e: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3
			variation => N__('Benko Gambit: Accepted, 6. Nc3'),
			moves => {
				'd7d6' => 1,
				'g7g6' => 1,
			},
		},
		'rn1qkb1r/3ppp1p/b4np1/2pP4/8/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'A58f',
			# TRANSLATORS: A58f: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 g6
			variation => N__('Benko Gambit: Accepted, 6. Nc3 g6'),
			moves => {
			},
		},
		'rn1qkb1r/4pppp/b2p1n2/2pP4/8/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'A58g',
			# TRANSLATORS: A58g: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6
			variation => N__('Benko Gambit: Accepted, 6. Nc3 d6'),
			moves => {
				'e2e4' => 1,
				'f2f4' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
			},
		},
		'rn1qkb1r/4pppp/b2p1n2/2pP4/5P2/2N5/PP2P1PP/R1BQKBNR b KQkq' => {
			eco => 'A58g',
			# TRANSLATORS: A58g: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. f4
			variation => N__('Benko Gambit: Accepted, 7. f4'),
			moves => {
				'g7g6' => 1,
			},
		},
		'rn1qkb1r/4pp1p/b2p1np1/2pP4/5P2/2N5/PP2P1PP/R1BQKBNR w KQkq' => {
			eco => 'A58g',
			# TRANSLATORS: A58g: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. f4 g6
			variation => N__('Benko Gambit: Accepted, 7. f4'),
			moves => {
			},
		},
		'rn1qkb1r/4pppp/b2p1n2/2pP4/8/2N3P1/PP2PP1P/R1BQKBNR b KQkq' => {
			eco => 'A58h',
			# TRANSLATORS: A58h: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. g3
			variation => N__('Benko Gambit: Accepted, 7. g3'),
			moves => {
				'g7g6' => 1,
			},
		},
		'rn1qkb1r/4pp1p/b2p1np1/2pP4/8/2N3P1/PP2PP1P/R1BQKBNR w KQkq' => {
			eco => 'A58h',
			# TRANSLATORS: A58h: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. g3 g6
			variation => N__('Benko Gambit: Accepted, 7. g3'),
			moves => {
			},
		},
		'rn1qkb1r/4pppp/b2p1n2/2pP4/8/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'A58i',
			# TRANSLATORS: A58i: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. Nf3
			variation => N__('Benko Gambit: Accepted, 7. Nf3'),
			moves => {
				'g7g6' => 1,
			},
		},
		'rn1qkb1r/4pp1p/b2p1np1/2pP4/8/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'A58i',
			# TRANSLATORS: A58i: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. Nf3 g6
			variation => N__('Benko Gambit: Accepted, 7. Nf3 g6'),
			moves => {
				'f3d2' => 1,
				'g2g3' => 1,
			},
		},
		'rn1qkb1r/4pp1p/b2p1np1/2pP4/8/2N5/PP1NPPPP/R1BQKB1R b KQkq' => {
			eco => 'A58j',
			# TRANSLATORS: A58j: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. Nf3 g6 8. Nd2
			variation => N__('Benko Gambit: Accepted, 7. Nf3 g6 8. Nd2'),
			moves => {
				'd8a5' => 1,
				'f8g7' => 1,
			},
		},
		'rn2kb1r/4pp1p/b2p1np1/q1pP4/8/2N5/PP1NPPPP/R1BQKB1R w KQkq' => {
			eco => 'A58j',
			# TRANSLATORS: A58j: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. Nf3 g6 8. Nd2 Qa5
			variation => N__('Benko Gambit: Accepted, 7. Nf3 g6 8. Nd2 Qa5'),
			moves => {
			},
		},
		'rn1qk2r/4ppbp/b2p1np1/2pP4/8/2N5/PP1NPPPP/R1BQKB1R w KQkq' => {
			eco => 'A58j',
			# TRANSLATORS: A58j: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. Nf3 g6 8. Nd2 Bg7
			variation => N__('Benko Gambit: Accepted, 7. Nf3 g6 8. Nd2 Bg7'),
			moves => {
			},
		},
		'rn1qkb1r/4pp1p/b2p1np1/2pP4/8/2N2NP1/PP2PP1P/R1BQKB1R b KQkq' => {
			eco => 'A58k',
			# TRANSLATORS: A58k: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. Nf3 g6 8. g3
			variation => N__('Benko Gambit: Fianchetto Variation'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rn1qk2r/4ppbp/b2p1np1/2pP4/8/2N2NP1/PP2PP1P/R1BQKB1R w KQkq' => {
			eco => 'A58k',
			# TRANSLATORS: A58k: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. Nf3 g6 8. g3 Bg7
			variation => N__('Benko Gambit: Fianchetto Variation'),
			moves => {
				'f1g2' => 1,
				'f1h3' => 1,
			},
		},
		'rn1qk2r/4ppbp/b2p1np1/2pP4/8/2N2NPB/PP2PP1P/R1BQK2R b KQkq' => {
			eco => 'A58l',
			# TRANSLATORS: A58l: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. Nf3 g6 8. g3 Bg7 9. Bh3
			variation => N__('Benko Gambit: Fianchetto, 9. Bh3'),
			moves => {
			},
		},
		'rn1qk2r/4ppbp/b2p1np1/2pP4/8/2N2NP1/PP2PPBP/R1BQK2R b KQkq' => {
			eco => 'A58m',
			# TRANSLATORS: A58m: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. Nf3 g6 8. g3 Bg7 9. Bg2
			variation => N__('Benko Gambit: Fianchetto, 9. Bg2'),
			moves => {
				'b8d7' => 1,
				'e8g8' => 1,
			},
		},
		'r2qk2r/3nppbp/b2p1np1/2pP4/8/2N2NP1/PP2PPBP/R1BQK2R w KQkq' => {
			eco => 'A58m',
			# TRANSLATORS: A58m: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. Nf3 g6 8. g3 Bg7 9. Bg2 Nbd7
			variation => N__('Benko Gambit: Fianchetto, 9...Nbd7'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r2qk2r/3nppbp/b2p1np1/2pP4/8/2N2NP1/PP2PPBP/R1BQ1RK1 b kq' => {
			eco => 'A58m',
			# TRANSLATORS: A58m: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. Nf3 g6 8. g3 Bg7 9. Bg2 Nbd7 10. O-O
			variation => N__('Benko Gambit: Fianchetto, 9...Nbd7'),
			moves => {
				'd7b6' => 1,
			},
		},
		'r2qk2r/4ppbp/bn1p1np1/2pP4/8/2N2NP1/PP2PPBP/R1BQ1RK1 w kq' => {
			eco => 'A58n',
			# TRANSLATORS: A58n: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. Nf3 g6 8. g3 Bg7 9. Bg2 Nbd7 10. O-O Nb6
			variation => N__('Benko Gambit: Fianchetto, 9...Nbd7 10.O-O Nb6'),
			moves => {
			},
		},
		'rn1q1rk1/4ppbp/b2p1np1/2pP4/8/2N2NP1/PP2PPBP/R1BQK2R w KQ' => {
			eco => 'A58o',
			# TRANSLATORS: A58o: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. Nf3 g6 8. g3 Bg7 9. Bg2 O-O
			variation => N__('Benko Gambit: Fianchetto, 9...O-O'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rn1q1rk1/4ppbp/b2p1np1/2pP4/8/2N2NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'A58o',
			# TRANSLATORS: A58o: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. Nf3 g6 8. g3 Bg7 9. Bg2 O-O 10. O-O
			variation => N__('Benko Gambit: Fianchetto, 9...O-O'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r2q1rk1/3nppbp/b2p1np1/2pP4/8/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A58p',
			# TRANSLATORS: A58p: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. Nf3 g6 8. g3 Bg7 9. Bg2 O-O 10. O-O Nbd7
			variation => N__('Benko Gambit: Fianchetto, Main Line'),
			moves => {
				'a1b1' => 1,
				'd1c2' => 1,
				'f1e1' => 1,
			},
		},
		'r2q1rk1/3nppbp/b2p1np1/2pP4/8/2N2NP1/PP2PPBP/1RBQ1RK1 b -' => {
			eco => 'A58q',
			# TRANSLATORS: A58q: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. Nf3 g6 8. g3 Bg7 9. Bg2 O-O 10. O-O Nbd7 11. Rb1
			variation => N__('Benko Gambit: Fianchetto, Main Line, 11. Rb1'),
			moves => {
			},
		},
		'r2q1rk1/3nppbp/b2p1np1/2pP4/8/2N2NP1/PP2PPBP/R1BQR1K1 b -' => {
			eco => 'A58r',
			# TRANSLATORS: A58r: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. Nf3 g6 8. g3 Bg7 9. Bg2 O-O 10. O-O Nbd7 11. Re1
			variation => N__('Benko Gambit: Fianchetto, Main Line, 11. Re1'),
			moves => {
			},
		},
		'r2q1rk1/3nppbp/b2p1np1/2pP4/8/2N2NP1/PPQ1PPBP/R1B2RK1 b -' => {
			eco => 'A58s',
			# TRANSLATORS: A58s: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. Nf3 g6 8. g3 Bg7 9. Bg2 O-O 10. O-O Nbd7 11. Qc2
			variation => N__('Benko Gambit: Fianchetto, Main Line, 11. Qc2'),
			moves => {
				'd8b6' => 1,
			},
		},
		'r4rk1/3nppbp/bq1p1np1/2pP4/8/2N2NP1/PPQ1PPBP/R1B2RK1 w -' => {
			eco => 'A58t',
			# TRANSLATORS: A58t: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. Nf3 g6 8. g3 Bg7 9. Bg2 O-O 10. O-O Nbd7 11. Qc2 Qb6
			variation => N__('Benko Gambit: Fianchetto, Main Line, 11. Qc2 Qb6'),
			moves => {
			},
		},
		'rn1qkb1r/4pppp/b2p1n2/2pP4/4P3/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'A59a',
			# TRANSLATORS: A59a: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. e4
			variation => N__('Benko Gambit: 7. e4'),
			moves => {
				'a6f1' => 1,
			},
		},
		'rn1qkb1r/4pppp/3p1n2/2pP4/4P3/2N5/PP3PPP/R1BQKbNR w KQkq' => {
			eco => 'A59a',
			# TRANSLATORS: A59a: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. e4 Bxf1
			variation => N__('Benko Gambit: 7. e4'),
			moves => {
				'e1f1' => 1,
			},
		},
		'rn1qkb1r/4pppp/3p1n2/2pP4/4P3/2N5/PP3PPP/R1BQ1KNR b kq' => {
			eco => 'A59a',
			# TRANSLATORS: A59a: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. e4 Bxf1 8. Kxf1
			variation => N__('Benko Gambit: 7. e4'),
			moves => {
				'g7g6' => 1,
			},
		},
		'rn1qkb1r/4pp1p/3p1np1/2pP4/4P3/2N5/PP3PPP/R1BQ1KNR w kq' => {
			eco => 'A59b',
			# TRANSLATORS: A59b: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. e4 Bxf1 8. Kxf1 g6
			variation => N__('Benko Gambit: 7. e4 Bxf1 8.Kxf1 g6'),
			moves => {
				'g1e2' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
				'g2g4' => 1,
			},
		},
		'rn1qkb1r/4pp1p/3p1np1/2pP4/4P3/2N5/PP2NPPP/R1BQ1K1R b kq' => {
			eco => 'A59c',
			# TRANSLATORS: A59c: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. e4 Bxf1 8. Kxf1 g6 9. Nge2
			variation => N__('Benko Gambit: 7. e4 Line, 9.Nge2'),
			moves => {
			},
		},
		'rn1qkb1r/4pp1p/3p1np1/2pP4/4P3/2N2N2/PP3PPP/R1BQ1K1R b kq' => {
			eco => 'A59d',
			# TRANSLATORS: A59d: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. e4 Bxf1 8. Kxf1 g6 9. Nf3
			variation => N__('Benko Gambit: 7. e4 Line, 9. Nf3'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rn1qk2r/4ppbp/3p1np1/2pP4/4P3/2N2N2/PP3PPP/R1BQ1K1R w kq' => {
			eco => 'A59d',
			# TRANSLATORS: A59d: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. e4 Bxf1 8. Kxf1 g6 9. Nf3 Bg7
			variation => N__('Benko Gambit: 7. e4 Line, 9. Nf3'),
			moves => {
				'h2h3' => 1,
			},
		},
		'rn1qk2r/4ppbp/3p1np1/2pP4/4P3/2N2N1P/PP3PP1/R1BQ1K1R b kq' => {
			eco => 'A59e',
			# TRANSLATORS: A59e: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. e4 Bxf1 8. Kxf1 g6 9. Nf3 Bg7 10. h3
			variation => N__('Benko Gambit: 7. e4 Line, 9. Nf3 Bg7 10. h3'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r2qk2r/3nppbp/3p1np1/2pP4/4P3/2N2N1P/PP3PP1/R1BQ1K1R w kq' => {
			eco => 'A59f',
			# TRANSLATORS: A59f: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. e4 Bxf1 8. Kxf1 g6 9. Nf3 Bg7 10. h3 Nbd7
			variation => N__('Benko Gambit: 7. e4 Line, 9. Nf3 Bg7 10. h3 Nbd7'),
			moves => {
			},
		},
		'rn1qkb1r/4pp1p/3p1np1/2pP4/4P1P1/2N5/PP3P1P/R1BQ1KNR b kq' => {
			eco => 'A59g',
			# TRANSLATORS: A59g: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. e4 Bxf1 8. Kxf1 g6 9. g4
			variation => N__('Benko Gambit: 7. e4 Line, 9. g4'),
			moves => {
			},
		},
		'rn1qkb1r/4pp1p/3p1np1/2pP4/4P3/2N3P1/PP3P1P/R1BQ1KNR b kq' => {
			eco => 'A59h',
			# TRANSLATORS: A59h: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. e4 Bxf1 8. Kxf1 g6 9. g3
			variation => N__('Benko Gambit: 7. e4 Line, 9. g3'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rn1qk2r/4ppbp/3p1np1/2pP4/4P3/2N3P1/PP3P1P/R1BQ1KNR w kq' => {
			eco => 'A59h',
			# TRANSLATORS: A59h: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. e4 Bxf1 8. Kxf1 g6 9. g3 Bg7
			variation => N__('Benko Gambit: 7. e4 Line, 9. g3'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rn1qk2r/4ppbp/3p1np1/2pP4/4P3/2N3P1/PP3PKP/R1BQ2NR b kq' => {
			eco => 'A59h',
			# TRANSLATORS: A59h: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. e4 Bxf1 8. Kxf1 g6 9. g3 Bg7 10. Kg2
			variation => N__('Benko Gambit: 7. e4 Line, 9. g3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rn1q1rk1/4ppbp/3p1np1/2pP4/4P3/2N3P1/PP3PKP/R1BQ2NR w -' => {
			eco => 'A59h',
			# TRANSLATORS: A59h: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. e4 Bxf1 8. Kxf1 g6 9. g3 Bg7 10. Kg2 O-O
			variation => N__('Benko Gambit: 7. e4 Line, 9. g3'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rn1q1rk1/4ppbp/3p1np1/2pP4/4P3/2N2NP1/PP3PKP/R1BQ3R b -' => {
			eco => 'A59i',
			# TRANSLATORS: A59i: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. e4 Bxf1 8. Kxf1 g6 9. g3 Bg7 10. Kg2 O-O 11. Nf3
			variation => N__('Benko Gambit: 7. e4, Main Line'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r2q1rk1/3nppbp/3p1np1/2pP4/4P3/2N2NP1/PP3PKP/R1BQ3R w -' => {
			eco => 'A59j',
			# TRANSLATORS: A59j: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. e4 Bxf1 8. Kxf1 g6 9. g3 Bg7 10. Kg2 O-O 11. Nf3 Nbd7
			variation => N__('Benko Gambit: 7. e4, Main Line, 11...Nbd7'),
			moves => {
				'h1e1' => 1,
				'h2h3' => 1,
			},
		},
		'r2q1rk1/3nppbp/3p1np1/2pP4/4P3/2N2NP1/PP3PKP/R1BQR3 b -' => {
			eco => 'A59k',
			# TRANSLATORS: A59k: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. e4 Bxf1 8. Kxf1 g6 9. g3 Bg7 10. Kg2 O-O 11. Nf3 Nbd7 12. Re1
			variation => N__('Benko Gambit: 7. e4, Main Line, 11...Nbd7 12. Re1'),
			moves => {
				'd8a5' => 1,
				'f6g4' => 1,
			},
		},
		'r4rk1/3nppbp/3p1np1/q1pP4/4P3/2N2NP1/PP3PKP/R1BQR3 w -' => {
			eco => 'A59l',
			# TRANSLATORS: A59l: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. e4 Bxf1 8. Kxf1 g6 9. g3 Bg7 10. Kg2 O-O 11. Nf3 Nbd7 12. Re1 Qa5
			variation => N__('Benko Gambit: 7. e4, Main Line, 11...Nbd7 12. Re1 Qa5'),
			moves => {
			},
		},
		'r2q1rk1/3nppbp/3p2p1/2pP4/4P1n1/2N2NP1/PP3PKP/R1BQR3 w -' => {
			eco => 'A59m',
			# TRANSLATORS: A59m: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. e4 Bxf1 8. Kxf1 g6 9. g3 Bg7 10. Kg2 O-O 11. Nf3 Nbd7 12. Re1 Ng4
			variation => N__('Benko Gambit: 7. e4, Main Line, 11...Nbd7 12. Re1 Ng4'),
			moves => {
			},
		},
		'r2q1rk1/3nppbp/3p1np1/2pP4/4P3/2N2NPP/PP3PK1/R1BQ3R b -' => {
			eco => 'A59n',
			# TRANSLATORS: A59n: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. e4 Bxf1 8. Kxf1 g6 9. g3 Bg7 10. Kg2 O-O 11. Nf3 Nbd7 12. h3
			variation => N__('Benko Gambit: 7. e4, Main Line, 11...Nbd7 12. h3'),
			moves => {
				'a8a6' => 1,
				'd8a5' => 1,
				'd8b6' => 1,
			},
		},
		'3q1rk1/3nppbp/r2p1np1/2pP4/4P3/2N2NPP/PP3PK1/R1BQ3R w -' => {
			eco => 'A59o',
			# TRANSLATORS: A59o: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. e4 Bxf1 8. Kxf1 g6 9. g3 Bg7 10. Kg2 O-O 11. Nf3 Nbd7 12. h3 Ra6
			variation => N__('Benko Gambit: 7. e4, Main Line, 11...Nbd7 12. h3 Ra6'),
			moves => {
				'h1e1' => 1,
			},
		},
		'3q1rk1/3nppbp/r2p1np1/2pP4/4P3/2N2NPP/PP3PK1/R1BQR3 b -' => {
			eco => 'A59o',
			# TRANSLATORS: A59o: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. e4 Bxf1 8. Kxf1 g6 9. g3 Bg7 10. Kg2 O-O 11. Nf3 Nbd7 12. h3 Ra6 13. Re1
			variation => N__('Benko Gambit: 7. e4, Main Line, 11...Nbd7 12. h3 Ra6 13. Re1'),
			moves => {
			},
		},
		'r4rk1/3nppbp/1q1p1np1/2pP4/4P3/2N2NPP/PP3PK1/R1BQ3R w -' => {
			eco => 'A59p',
			# TRANSLATORS: A59p: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. e4 Bxf1 8. Kxf1 g6 9. g3 Bg7 10. Kg2 O-O 11. Nf3 Nbd7 12. h3 Qb6
			variation => N__('Benko Gambit: 7. e4, Main Line, 11...Nbd7 12. h3 Qb6'),
			moves => {
				'h1e1' => 1,
			},
		},
		'r4rk1/3nppbp/1q1p1np1/2pP4/4P3/2N2NPP/PP3PK1/R1BQR3 b -' => {
			eco => 'A59p',
			# TRANSLATORS: A59p: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. e4 Bxf1 8. Kxf1 g6 9. g3 Bg7 10. Kg2 O-O 11. Nf3 Nbd7 12. h3 Qb6 13. Re1
			variation => N__('Benko Gambit: 7. e4, Main Line, 11...Nbd7 12. h3 Qb6 13. Re1'),
			moves => {
			},
		},
		'r4rk1/3nppbp/3p1np1/q1pP4/4P3/2N2NPP/PP3PK1/R1BQ3R w -' => {
			eco => 'A59q',
			# TRANSLATORS: A59q: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. e4 Bxf1 8. Kxf1 g6 9. g3 Bg7 10. Kg2 O-O 11. Nf3 Nbd7 12. h3 Qa5
			variation => N__('Benko Gambit: 7. e4, Main Line, 11...Nbd7 12. h3 Qa5'),
			moves => {
				'h1e1' => 1,
			},
		},
		'r4rk1/3nppbp/3p1np1/q1pP4/4P3/2N2NPP/PP3PK1/R1BQR3 b -' => {
			eco => 'A59q',
			# TRANSLATORS: A59q: 1. d4 Nf6 2. c4 c5 3. d5 b5 4. cxb5 a6 5. bxa6 Bxa6 6. Nc3 d6 7. e4 Bxf1 8. Kxf1 g6 9. g3 Bg7 10. Kg2 O-O 11. Nf3 Nbd7 12. h3 Qa5 13. Re1
			variation => N__('Benko Gambit: 7. e4, Main Line, 11...Nbd7 12. h3 Qa5 13. Re1'),
			moves => {
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/2pP4/2P5/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A60a',
			# TRANSLATORS: A60a: 1. d4 Nf6 2. c4 c5 3. d5 e6
			variation => N__('Benoni: 3. d5 e6'),
			moves => {
				'b1c3' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/pp1p1ppp/5n2/2pp4/2P5/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A60b',
			# TRANSLATORS: A60b: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nf3 exd5
			variation => N__('Benoni: 4. Nf3'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/2pP4/2P5/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'A60b',
			# TRANSLATORS: A60b: 1. d4 Nf6 2. c4 e6 3. Nf3 c5 4. d5
			variation => N__('Benoni: 4. Nf3'),
			moves => {
				'b7b5' => 1,
				'e6d5' => 1,
			},
		},
		'rnbqkb1r/pp1p1ppp/5n2/2pP4/8/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'A60c',
			# TRANSLATORS: A60c: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nf3 exd5 5. cxd5
			variation => N__('Benoni: 4. Nf3 exd5 5.cxd5'),
			moves => {
				'f8d6' => 1,
			},
		},
		'rnbqk2r/pp1p1ppp/3b1n2/2pP4/8/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A60d',
			# TRANSLATORS: A60d: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nf3 exd5 5. cxd5 Bd6
			variation => N__('Benoni: Snake Variation vs. 4. Nf3'),
			moves => {
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/2pP4/2P5/6P1/PP2PP1P/RNBQKBNR b KQkq' => {
			eco => 'A60e',
			# TRANSLATORS: A60e: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. g3
			variation => N__('Benoni: 4. g3'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rnbqkb1r/pp1p1ppp/5n2/2pp4/2P5/6P1/PP2PP1P/RNBQKBNR w KQkq' => {
			eco => 'A60e',
			# TRANSLATORS: A60e: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. g3 exd5
			variation => N__('Benoni: 4. g3'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rnbqkb1r/pp1p1ppp/5n2/2pP4/8/6P1/PP2PP1P/RNBQKBNR b KQkq' => {
			eco => 'A60e',
			# TRANSLATORS: A60e: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. g3 exd5 5. cxd5
			variation => N__('Benoni: 4. g3'),
			moves => {
				'b7b5' => 1,
			},
		},
		'rnbqkb1r/p2p1ppp/5n2/1ppP4/8/6P1/PP2PP1P/RNBQKBNR w KQkq' => {
			eco => 'A60f',
			# TRANSLATORS: A60f: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. g3 exd5 5. cxd5 b5
			variation => N__('Benoni: 4. g3 exd5 5.cxd5 b5'),
			moves => {
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/2pP4/2P5/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'A60g',
			# TRANSLATORS: A60g: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3
			variation => N__('Benoni: 4. Nc3'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rnbqkb1r/pp1p1ppp/5n2/2pp4/2P5/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'A60g',
			# TRANSLATORS: A60g: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5
			variation => N__('Benoni: 4. Nc3'),
			moves => {
				'c3d5' => 1,
				'c4d5' => 1,
			},
		},
		'rnbqkb1r/pp1p1ppp/5n2/2pN4/2P5/8/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'A60h',
			# TRANSLATORS: A60h: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. Nxd5
			variation => N__('Benoni: 4. Nc3 exd5 5.Nxd5'),
			moves => {
			},
		},
		'rnbqkb1r/pp1p1ppp/5n2/2pP4/8/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'A60i',
			# TRANSLATORS: A60i: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5
			variation => N__('Benoni: 4. Nc3 exd5 5.cxd5'),
			moves => {
				'd7d6' => 1,
				'f8d6' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqk2r/pp1p1ppp/3b1n2/2pP4/8/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'A60j',
			# TRANSLATORS: A60j: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 Bd6
			variation => N__('Benoni: Snake Variation'),
			moves => {
				'e2e4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqk2r/pp1p1ppp/3b1n2/2pP4/8/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'A60k',
			# TRANSLATORS: A60k: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 Bd6 6. Nf3
			variation => N__('Benoni: Snake, 6. Nf3'),
			moves => {
				'd6c7' => 1,
			},
		},
		'rnbqk2r/ppbp1ppp/5n2/2pP4/8/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'A60l',
			# TRANSLATORS: A60l: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 Bd6 6. Nf3 Bc7
			variation => N__('Benoni: Snake, 6. Nf3 Bc7'),
			moves => {
			},
		},
		'rnbqk2r/pp1p1ppp/3b1n2/2pP4/4P3/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'A60m',
			# TRANSLATORS: A60m: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 Bd6 6. e4
			variation => N__('Benoni: Snake, 6. e4'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/pp1p1ppp/3b1n2/2pP4/4P3/2N5/PP3PPP/R1BQKBNR w KQ' => {
			eco => 'A60m',
			# TRANSLATORS: A60m: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 Bd6 6. e4 O-O
			variation => N__('Benoni: Snake, 6. e4'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbq1rk1/pp1p1ppp/3b1n2/2pP4/4P3/2N2N2/PP3PPP/R1BQKB1R b KQ' => {
			eco => 'A60n',
			# TRANSLATORS: A60n: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 Bd6 6. e4 O-O 7. Nf3
			variation => N__('Benoni: Snake, 6. e4 O-O 7. Nf3'),
			moves => {
			},
		},
		'rnbqkb1r/pp1p1p1p/5np1/2pP4/8/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'A60o',
			# TRANSLATORS: A60o: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 g6
			variation => N__('Benoni: 4. Nc3 exd5 5.cxd5 g6'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/3p1n2/2pP4/8/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'A60p',
			# TRANSLATORS: A60p: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6
			variation => N__('Benoni: 4. Nc3 exd5 5.cxd5 d6'),
			moves => {
				'e2e4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/3p1n2/2pP4/8/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'A60q',
			# TRANSLATORS: A60q: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3
			variation => N__('Benoni: 4. Nc3 exd5 5.cxd5 d6 6. Nf3'),
			moves => {
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/pp3p1p/3p1np1/2pP4/8/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'A61',
			# TRANSLATORS: A61: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6
			variation => N__('Benoni: 6. Nf3 g6'),
			moves => {
				'c1f4' => 1,
				'c1g5' => 1,
				'f3d2' => 1,
				'g2g3' => 1,
				'h2h3' => 1,
			},
		},
		'rnbqkb1r/pp3p1p/3p1np1/2pP4/5B2/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'A61',
			# TRANSLATORS: A61: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. Bf4
			variation => N__('Benoni: 6. Nf3 g6 7. Bf4'),
			moves => {
				'a7a6' => 1,
				'f8g7' => 1,
			},
		},
		'rnbqkb1r/1p3p1p/p2p1np1/2pP4/5B2/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'A61',
			# TRANSLATORS: A61: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. Bf4 a6
			variation => N__('Benoni: 6. Nf3 g6 7. Bf4 a6'),
			moves => {
			},
		},
		'rnbqk2r/pp3pbp/3p1np1/2pP4/5B2/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'A61',
			# TRANSLATORS: A61: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. Bf4 Bg7
			variation => N__('Benoni: 6. Nf3 g6 7. Bf4 Bg7'),
			moves => {
				'd1a4' => 1,
				'f3d2' => 1,
			},
		},
		'rnbqk2r/pp3pbp/3p1np1/2pP4/Q4B2/2N2N2/PP2PPPP/R3KB1R b KQkq' => {
			eco => 'A61',
			# TRANSLATORS: A61: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. Bf4 Bg7 8. Qa4+
			variation => N__('Benoni: 6. Nf3 g6 7. Bf4 Bg7 8. Qa4+'),
			moves => {
			},
		},
		'rnbqk2r/pp3pbp/3p1np1/2pP4/5B2/2N5/PP1NPPPP/R2QKB1R b KQkq' => {
			eco => 'A61',
			# TRANSLATORS: A61: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. Bf4 Bg7 8. Nd2
			variation => N__('Benoni: 6. Nf3 g6 7. Bf4 Bg7 8. Nd2'),
			moves => {
			},
		},
		'rnbqkb1r/pp3p1p/3p1np1/2pP2B1/8/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'A61',
			# TRANSLATORS: A61: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. Bg5
			variation => N__('Benoni: Uhlmann Variation'),
			moves => {
				'f8g7' => 1,
				'h7h6' => 1,
			},
		},
		'rnbqk2r/pp3pbp/3p1np1/2pP2B1/8/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'A61',
			# TRANSLATORS: A61: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. Bg5 Bg7
			variation => N__('Benoni: Uhlmann, 7... Bg7'),
			moves => {
			},
		},
		'rnbqkb1r/pp3p2/3p1npp/2pP2B1/8/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'A61',
			# TRANSLATORS: A61: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. Bg5 h6
			variation => N__('Benoni: Uhlmann, 7... h6'),
			moves => {
			},
		},
		'rnbqkb1r/pp3p1p/3p1np1/2pP4/8/2N5/PP1NPPPP/R1BQKB1R b KQkq' => {
			eco => 'A61',
			# TRANSLATORS: A61: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. Nd2
			variation => N__('Benoni: Nimzowitsch Variation'),
			moves => {
				'b8d7' => 1,
				'f8g7' => 1,
			},
		},
		'r1bqkb1r/pp1n1p1p/3p1np1/2pP4/8/2N5/PP1NPPPP/R1BQKB1R w KQkq' => {
			eco => 'A61',
			# TRANSLATORS: A61: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. Nd2 Nbd7
			variation => N__('Benoni: Nimzowitsch, 7...Nbd7'),
			moves => {
			},
		},
		'rnbqk2r/pp3pbp/3p1np1/2pP4/8/2N5/PP1NPPPP/R1BQKB1R w KQkq' => {
			eco => 'A61',
			# TRANSLATORS: A61: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. Nd2 Bg7
			variation => N__('Benoni: Nimzowitsch, 7... Bg7'),
			moves => {
				'd2c4' => 1,
			},
		},
		'rnbqk2r/pp3pbp/3p1np1/2pP4/2N5/2N5/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'A61',
			# TRANSLATORS: A61: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. Nd2 Bg7 8. Nc4
			variation => N__('Benoni: Nimzowitsch, 7... Bg7'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2pP4/2N5/2N5/PP2PPPP/R1BQKB1R w KQ' => {
			eco => 'A61',
			# TRANSLATORS: A61: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. Nd2 Bg7 8. Nc4 O-O
			variation => N__('Benoni: Nimzowitsch, 7... Bg7'),
			moves => {
				'c1f4' => 1,
				'c1g5' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2pP4/2N2B2/2N5/PP2PPPP/R2QKB1R b KQ' => {
			eco => 'A61',
			# TRANSLATORS: A61: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. Nd2 Bg7 8. Nc4 O-O 9. Bf4
			variation => N__('Benoni: Nimzowitsch, 7... Bg7 8. Nc4 O-O 9. Bf4'),
			moves => {
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2pP2B1/2N5/2N5/PP2PPPP/R2QKB1R b KQ' => {
			eco => 'A61',
			# TRANSLATORS: A61: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. Nd2 Bg7 8. Nc4 O-O 9. Bg5
			variation => N__('Benoni: Nimzowitsch, 7... Bg7 8. Nc4 O-O 9. Bg5'),
			moves => {
			},
		},
		'rnbqkb1r/pp3p1p/3p1np1/2pP4/8/2N2NP1/PP2PP1P/R1BQKB1R b KQkq' => {
			eco => 'A61',
			# TRANSLATORS: A61: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. g3
			variation => N__('Benoni: Fianchetto Variation'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/pp3pbp/3p1np1/2pP4/8/2N2NP1/PP2PP1P/R1BQKB1R w KQkq' => {
			eco => 'A61',
			# TRANSLATORS: A61: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. g3 Bg7
			variation => N__('Benoni: Fianchetto Variation'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqk2r/pp3pbp/3p1np1/2pP4/8/2N2NP1/PP2PPBP/R1BQK2R b KQkq' => {
			eco => 'A61',
			# TRANSLATORS: A61: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. g3 Bg7 8. Bg2
			variation => N__('Benoni: Fianchetto Variation'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbqkb1r/pp3p1p/3p1np1/2pP4/8/2N2N1P/PP2PPP1/R1BQKB1R b KQkq' => {
			eco => 'A61',
			# TRANSLATORS: A61: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. h3
			variation => N__('Benoni: 6. Nf3 g6 7. h3'),
			moves => {
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2pP4/8/2N2NP1/PP2PPBP/R1BQK2R w KQ' => {
			eco => 'A62',
			# TRANSLATORS: A62: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. g3 Bg7 8. Bg2 O-O
			variation => N__('Benoni: Fianchetto, 8. Bg2 O-O'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2pP4/8/2N2NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'A62',
			# TRANSLATORS: A62: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. g3 Bg7 8. Bg2 O-O 9. O-O
			variation => N__('Benoni: Fianchetto, 9.O-O'),
			moves => {
				'a7a6' => 1,
				'b8a6' => 1,
				'b8d7' => 1,
				'f8e8' => 1,
			},
		},
		'rnbq1rk1/1p3pbp/p2p1np1/2pP4/8/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A62',
			# TRANSLATORS: A62: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. g3 Bg7 8. Bg2 O-O 9. O-O a6
			variation => N__('Benoni: Fianchetto, 9.O-O a6'),
			moves => {
				'a2a4' => 1,
			},
		},
		'rnbq1rk1/1p3pbp/p2p1np1/2pP4/P7/2N2NP1/1P2PPBP/R1BQ1RK1 b -' => {
			eco => 'A62',
			# TRANSLATORS: A62: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. g3 Bg7 8. Bg2 O-O 9. O-O a6 10. a4
			variation => N__('Benoni: Fianchetto, 9.O-O a6'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r1bq1rk1/pp3pbp/n2p1np1/2pP4/8/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A62',
			# TRANSLATORS: A62: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. g3 Bg7 8. Bg2 O-O 9. O-O Na6
			variation => N__('Benoni: Fianchetto, 9.O-O Na6'),
			moves => {
				'f3d2' => 1,
			},
		},
		'r1bq1rk1/pp3pbp/n2p1np1/2pP4/8/2N3P1/PP1NPPBP/R1BQ1RK1 b -' => {
			eco => 'A62',
			# TRANSLATORS: A62: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. g3 Bg7 8. Bg2 O-O 9. O-O Na6 10. Nd2
			variation => N__('Benoni: Fianchetto, 9.O-O Na6'),
			moves => {
				'a6c7' => 1,
			},
		},
		'r1bq1rk1/ppn2pbp/3p1np1/2pP4/8/2N3P1/PP1NPPBP/R1BQ1RK1 w -' => {
			eco => 'A62',
			# TRANSLATORS: A62: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. g3 Bg7 8. Bg2 O-O 9. O-O Na6 10. Nd2 Nc7
			variation => N__('Benoni: Fianchetto, 9.O-O Na6 10. Nd2 Nc7'),
			moves => {
			},
		},
		'rnbqr1k1/pp3pbp/3p1np1/2pP4/8/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A62',
			# TRANSLATORS: A62: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. g3 Bg7 8. Bg2 O-O 9. O-O Re8
			variation => N__('Benoni: Fianchetto, 9.O-O Re8'),
			moves => {
			},
		},
		'r1bq1rk1/1p1n1pbp/p2p1np1/2pP4/P7/2N2NP1/1P2PPBP/R1BQ1RK1 w -' => {
			eco => 'A63',
			# TRANSLATORS: A63: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. g3 Bg7 8. Bg2 O-O 9. O-O a6 10. a4 Nbd7
			variation => N__('Benoni: Fianchetto, 9... a6 10. a4 Nbd7'),
			moves => {
			},
		},
		'r1bq1rk1/pp1n1pbp/3p1np1/2pP4/8/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A63',
			# TRANSLATORS: A63: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. g3 Bg7 8. Bg2 O-O 9. O-O Nbd7
			variation => N__('Benoni: Fianchetto, 9...Nbd7'),
			moves => {
				'f3d2' => 1,
			},
		},
		'r1bq1rk1/pp1n1pbp/3p1np1/2pP4/8/2N3P1/PP1NPPBP/R1BQ1RK1 b -' => {
			eco => 'A63',
			# TRANSLATORS: A63: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. g3 Bg7 8. Bg2 O-O 9. O-O Nbd7 10. Nd2
			variation => N__('Benoni: Fianchetto, 9...Nbd7 10. Nd2'),
			moves => {
				'a7a6' => 1,
				'f8e8' => 1,
			},
		},
		'r1bq1rk1/1p1n1pbp/p2p1np1/2pP4/8/2N3P1/PP1NPPBP/R1BQ1RK1 w -' => {
			eco => 'A63',
			# TRANSLATORS: A63: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. g3 Bg7 8. Bg2 O-O 9. O-O Nbd7 10. Nd2 a6
			variation => N__('Benoni: Fianchetto, 9...Nbd7 10. Nd2 a6'),
			moves => {
				'a2a4' => 1,
			},
		},
		'r1bq1rk1/1p1n1pbp/p2p1np1/2pP4/P7/2N3P1/1P1NPPBP/R1BQ1RK1 b -' => {
			eco => 'A63',
			# TRANSLATORS: A63: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. g3 Bg7 8. Bg2 O-O 9. O-O Nbd7 10. Nd2 a6 11. a4
			variation => N__('Benoni: Fianchetto, 9...Nbd7 10. Nd2 a6 11. a4'),
			moves => {
				'f8e8' => 1,
			},
		},
		'r1bqr1k1/pp1n1pbp/3p1np1/2pP4/8/2N3P1/PP1NPPBP/R1BQ1RK1 w -' => {
			eco => 'A63',
			# TRANSLATORS: A63: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. g3 Bg7 8. Bg2 O-O 9. O-O Nbd7 10. Nd2 Re8
			variation => N__('Benoni: Fianchetto, 9...Nbd7 10. Nd2 Re8'),
			moves => {
			},
		},
		'r1bqr1k1/1p1n1pbp/p2p1np1/2pP4/P7/2N3P1/1P1NPPBP/R1BQ1RK1 w -' => {
			eco => 'A64',
			# TRANSLATORS: A64: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. g3 Bg7 8. Bg2 O-O 9. O-O Nbd7 10. Nd2 a6 11. a4 Re8
			variation => N__('Benoni: Fianchetto, 11... Re8'),
			moves => {
				'a4a5' => 1,
				'd2c4' => 1,
				'h2h3' => 1,
			},
		},
		'r1bqr1k1/1p1n1pbp/p2p1np1/P1pP4/8/2N3P1/1P1NPPBP/R1BQ1RK1 b -' => {
			eco => 'A64',
			# TRANSLATORS: A64: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. g3 Bg7 8. Bg2 O-O 9. O-O Nbd7 10. Nd2 a6 11. a4 Re8 12. a5
			variation => N__('Benoni: Fianchetto, 11... Re8 12. a5'),
			moves => {
			},
		},
		'r1bqr1k1/1p1n1pbp/p2p1np1/2pP4/P1N5/2N3P1/1P2PPBP/R1BQ1RK1 b -' => {
			eco => 'A64',
			# TRANSLATORS: A64: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. g3 Bg7 8. Bg2 O-O 9. O-O Nbd7 10. Nd2 a6 11. a4 Re8 12. Nc4
			variation => N__('Benoni: Fianchetto, 11... Re8 12. Nc4'),
			moves => {
				'd7e5' => 1,
			},
		},
		'r1bqr1k1/1p3pbp/p2p1np1/2pPn3/P1N5/2N3P1/1P2PPBP/R1BQ1RK1 w -' => {
			eco => 'A64',
			# TRANSLATORS: A64: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. g3 Bg7 8. Bg2 O-O 9. O-O Nbd7 10. Nd2 a6 11. a4 Re8 12. Nc4 Ne5
			variation => N__('Benoni: Fianchetto, 11... Re8 12. Nc4 Ne5'),
			moves => {
			},
		},
		'r1bqr1k1/1p1n1pbp/p2p1np1/2pP4/P7/2N3PP/1P1NPPB1/R1BQ1RK1 b -' => {
			eco => 'A64',
			# TRANSLATORS: A64: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. g3 Bg7 8. Bg2 O-O 9. O-O Nbd7 10. Nd2 a6 11. a4 Re8 12. h3
			variation => N__('Benoni: Fianchetto, 11... Re8 12. h3'),
			moves => {
				'a8b8' => 1,
			},
		},
		'1rbqr1k1/1p1n1pbp/p2p1np1/2pP4/P7/2N3PP/1P1NPPB1/R1BQ1RK1 w -' => {
			eco => 'A64',
			# TRANSLATORS: A64: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. g3 Bg7 8. Bg2 O-O 9. O-O Nbd7 10. Nd2 a6 11. a4 Re8 12. h3 Rb8
			variation => N__('Benoni: Fianchetto, 11... Re8 12. h3 Rb8'),
			moves => {
				'd2c4' => 1,
			},
		},
		'1rbqr1k1/1p1n1pbp/p2p1np1/2pP4/P1N5/2N3PP/1P2PPB1/R1BQ1RK1 b -' => {
			eco => 'A64',
			# TRANSLATORS: A64: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. g3 Bg7 8. Bg2 O-O 9. O-O Nbd7 10. Nd2 a6 11. a4 Re8 12. h3 Rb8 13. Nc4
			variation => N__('Benoni: Fianchetto, 11... Re8 12. h3 Rb8 13. Nc4'),
			moves => {
				'd7b6' => 1,
				'd7e5' => 1,
			},
		},
		'1rbqr1k1/1p3pbp/pn1p1np1/2pP4/P1N5/2N3PP/1P2PPB1/R1BQ1RK1 w -' => {
			eco => 'A64',
			# TRANSLATORS: A64: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. g3 Bg7 8. Bg2 O-O 9. O-O Nbd7 10. Nd2 a6 11. a4 Re8 12. h3 Rb8 13. Nc4 Nb6
			variation => N__('Benoni: Fianchetto, 11... Re8 12. h3 Rb8 13. Nc4 Nb6'),
			moves => {
			},
		},
		'1rbqr1k1/1p3pbp/p2p1np1/2pPn3/P1N5/2N3PP/1P2PPB1/R1BQ1RK1 w -' => {
			eco => 'A64',
			# TRANSLATORS: A64: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. Nf3 g6 7. g3 Bg7 8. Bg2 O-O 9. O-O Nbd7 10. Nd2 a6 11. a4 Re8 12. h3 Rb8 13. Nc4 Ne5
			variation => N__('Benoni: Fianchetto, 11... Re8 12. h3 Rb8 13. Nc4 Ne5'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/3p1n2/2pP4/4P3/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'A65a',
			# TRANSLATORS: A65a: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4
			variation => N__('Benoni: 6. e4'),
			moves => {
				'f8e7' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqk2r/pp2bppp/3p1n2/2pP4/4P3/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'A65a',
			# TRANSLATORS: A65a: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 Be7
			variation => N__('Benoni: 6. e4 Be7'),
			moves => {
			},
		},
		'rnbqkb1r/pp3p1p/3p1np1/2pP4/4P3/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'A65b',
			# TRANSLATORS: A65b: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6
			variation => N__('Benoni: 6. e4 g6'),
			moves => {
				'c1f4' => 1,
				'f1d3' => 1,
				'f2f3' => 1,
				'f2f4' => 1,
				'g1f3' => 1,
				'h2h3' => 1,
			},
		},
		'rnbqkb1r/pp3p1p/3p1np1/2pP4/4P3/2N4P/PP3PP1/R1BQKBNR b KQkq' => {
			eco => 'A65b',
			# TRANSLATORS: A65b: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. h3
			variation => N__('Benoni: 6. e4 g6 7. h3'),
			moves => {
			},
		},
		'rnbqkb1r/pp3p1p/3p1np1/2pP4/4PB2/2N5/PP3PPP/R2QKBNR b KQkq' => {
			eco => 'A65c',
			# TRANSLATORS: A65c: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Bf4
			variation => N__('Benoni: 6. e4 g6 7. Bf4'),
			moves => {
				'a7a6' => 1,
			},
		},
		'rnbqkb1r/1p3p1p/p2p1np1/2pP4/4PB2/2N5/PP3PPP/R2QKBNR w KQkq' => {
			eco => 'A65d',
			# TRANSLATORS: A65d: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Bf4 a6
			variation => N__('Benoni: 6. e4 g6 7. Bf4 a6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/1p3p1p/p2p1np1/2pP4/4PB2/2N2N2/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'A65d',
			# TRANSLATORS: A65d: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Bf4 a6 8. Nf3
			variation => N__('Benoni: 6. e4 g6 7. Bf4 a6'),
			moves => {
				'b7b5' => 1,
			},
		},
		'rnbqkb1r/5p1p/p2p1np1/1ppP4/4PB2/2N2N2/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'A65e',
			# TRANSLATORS: A65e: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Bf4 a6 8. Nf3 b5
			variation => N__('Benoni: 6. e4 g6 7. Bf4 a6 8. Nf3 b5'),
			moves => {
				'd1e2' => 1,
			},
		},
		'rnbqkb1r/5p1p/p2p1np1/1ppP4/4PB2/2N2N2/PP2QPPP/R3KB1R b KQkq' => {
			eco => 'A65e',
			# TRANSLATORS: A65e: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Bf4 a6 8. Nf3 b5 9. Qe2
			variation => N__('Benoni: 6. e4 g6 7. Bf4 a6 8. Nf3 b5 9. Qe2'),
			moves => {
			},
		},
		'rnbqkb1r/pp3p1p/3p1np1/2pP4/4P3/2NB4/PP3PPP/R1BQK1NR b KQkq' => {
			eco => 'A65f',
			# TRANSLATORS: A65f: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Bd3
			variation => N__('Benoni: 6. e4 g6 7. Bd3'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/pp3pbp/3p1np1/2pP4/4P3/2NB4/PP3PPP/R1BQK1NR w KQkq' => {
			eco => 'A65f',
			# TRANSLATORS: A65f: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Bd3 Bg7
			variation => N__('Benoni: 6. e4 g6 7. Bd3'),
			moves => {
				'g1e2' => 1,
				'h2h3' => 1,
			},
		},
		'rnbqk2r/pp3pbp/3p1np1/2pP4/4P3/2NB3P/PP3PP1/R1BQK1NR b KQkq' => {
			eco => 'A65f',
			# TRANSLATORS: A65f: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Bd3 Bg7 8. h3
			variation => N__('Benoni: 6. e4 g6 7. Bd3 Bg7 8. h3'),
			moves => {
			},
		},
		'rnbqk2r/pp3pbp/3p1np1/2pP4/4P3/2NB4/PP2NPPP/R1BQK2R b KQkq' => {
			eco => 'A65g',
			# TRANSLATORS: A65g: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Bd3 Bg7 8. Nge2
			variation => N__('Benoni: 6. e4 g6 7. Bd3 Bg7 8.Nge2'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2pP4/4P3/2NB4/PP2NPPP/R1BQK2R w KQ' => {
			eco => 'A65g',
			# TRANSLATORS: A65g: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Bd3 Bg7 8. Nge2 O-O
			variation => N__('Benoni: 6. e4 g6 7. Bd3 Bg7 8.Nge2 O-O'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2pP4/4P3/2NB4/PP2NPPP/R1BQ1RK1 b -' => {
			eco => 'A65g',
			# TRANSLATORS: A65g: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Bd3 Bg7 8. Nge2 O-O 9. O-O
			variation => N__('Benoni: 6. e4 g6 7. Bd3 Bg7 8.Nge2 O-O 9.O-O'),
			moves => {
				'a7a6' => 1,
				'b7b6' => 1,
				'b8a6' => 1,
			},
		},
		'rnbq1rk1/p4pbp/1p1p1np1/2pP4/4P3/2NB4/PP2NPPP/R1BQ1RK1 w -' => {
			eco => 'A65h',
			# TRANSLATORS: A65h: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Bd3 Bg7 8. Nge2 O-O 9. O-O b6
			variation => N__('Benoni: 6. e4 g6 7. Bd3 Bg7 8.Nge2 O-O 9.O-O b6'),
			moves => {
			},
		},
		'r1bq1rk1/pp3pbp/n2p1np1/2pP4/4P3/2NB4/PP2NPPP/R1BQ1RK1 w -' => {
			eco => 'A65i',
			# TRANSLATORS: A65i: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Bd3 Bg7 8. Nge2 O-O 9. O-O Na6
			variation => N__('Benoni: 6. e4 g6 7. Bd3 Bg7 8.Nge2 O-O 9.O-O Na6'),
			moves => {
			},
		},
		'rnbq1rk1/1p3pbp/p2p1np1/2pP4/4P3/2NB4/PP2NPPP/R1BQ1RK1 w -' => {
			eco => 'A65j',
			# TRANSLATORS: A65j: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Bd3 Bg7 8. Nge2 O-O 9. O-O a6
			variation => N__('Benoni: 6. e4 g6 7. Bd3 Bg7 8.Nge2 O-O 9.O-O a6'),
			moves => {
			},
		},
		'rnbqkb1r/pp3p1p/3p1np1/2pP4/4P3/2N2P2/PP4PP/R1BQKBNR b KQkq' => {
			eco => 'A65k',
			# TRANSLATORS: A65k: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f3
			variation => N__('Benoni: Sämisch (6. e4 g6 7. f3)'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/pp3pbp/3p1np1/2pP4/4P3/2N2P2/PP4PP/R1BQKBNR w KQkq' => {
			eco => 'A65k',
			# TRANSLATORS: A65k: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f3 Bg7
			variation => N__('Benoni: Sämisch, 7... Bg7'),
			moves => {
				'c1e3' => 1,
				'c1g5' => 1,
				'g1e2' => 1,
			},
		},
		'rnbqk2r/pp3pbp/3p1np1/2pP4/4P3/2N2P2/PP2N1PP/R1BQKB1R b KQkq' => {
			eco => 'A65l',
			# TRANSLATORS: A65l: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f3 Bg7 8. Nge2
			variation => N__('Benoni: Sämisch, 8.Nge2'),
			moves => {
			},
		},
		'rnbqk2r/pp3pbp/3p1np1/2pP4/4P3/2N1BP2/PP4PP/R2QKBNR b KQkq' => {
			eco => 'A65m',
			# TRANSLATORS: A65m: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f3 Bg7 8. Be3
			variation => N__('Benoni: Sämisch, 8. Be3'),
			moves => {
			},
		},
		'rnbqk2r/pp3pbp/3p1np1/2pP2B1/4P3/2N2P2/PP4PP/R2QKBNR b KQkq' => {
			eco => 'A65n',
			# TRANSLATORS: A65n: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f3 Bg7 8. Bg5
			variation => N__('Benoni: Sämisch, 8. Bg5'),
			moves => {
				'e8g8' => 1,
				'h7h6' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2pP2B1/4P3/2N2P2/PP4PP/R2QKBNR w KQ' => {
			eco => 'A65n',
			# TRANSLATORS: A65n: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f3 Bg7 8. Bg5 O-O
			variation => N__('Benoni: Sämisch, 8. Bg5 O-O'),
			moves => {
				'd1d2' => 1,
				'g1e2' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2pP2B1/4P3/2N2P2/PP2N1PP/R2QKB1R b KQ' => {
			eco => 'A65o',
			# TRANSLATORS: A65o: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f3 Bg7 8. Bg5 O-O 9. Nge2
			variation => N__('Benoni: Sämisch, 8. Bg5 O-O 9.Nge2'),
			moves => {
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2pP2B1/4P3/2N2P2/PP1Q2PP/R3KBNR b KQ' => {
			eco => 'A65p',
			# TRANSLATORS: A65p: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f3 Bg7 8. Bg5 O-O 9. Qd2
			variation => N__('Benoni: Sämisch, 8. Bg5 O-O 9. Qd2'),
			moves => {
				'a7a6' => 1,
			},
		},
		'rnbq1rk1/1p3pbp/p2p1np1/2pP2B1/4P3/2N2P2/PP1Q2PP/R3KBNR w KQ' => {
			eco => 'A65q',
			# TRANSLATORS: A65q: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f3 Bg7 8. Bg5 O-O 9. Qd2 a6
			variation => N__('Benoni: Sämisch, 8. Bg5 O-O 9. Qd2 a6'),
			moves => {
			},
		},
		'rnbqk2r/pp3pb1/3p1npp/2pP2B1/4P3/2N2P2/PP4PP/R2QKBNR w KQkq' => {
			eco => 'A65r',
			# TRANSLATORS: A65r: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f3 Bg7 8. Bg5 h6
			variation => N__('Benoni: Sämisch, 8. Bg5 h6'),
			moves => {
				'g5e3' => 1,
			},
		},
		'rnbqk2r/pp3pb1/3p1npp/2pP4/4P3/2N1BP2/PP4PP/R2QKBNR b KQkq' => {
			eco => 'A65r',
			# TRANSLATORS: A65r: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f3 Bg7 8. Bg5 h6 9. Be3
			variation => N__('Benoni: Sämisch, 8. Bg5 h6'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/pp3pb1/3p1npp/2pP4/4P3/2N1BP2/PP4PP/R2QKBNR w KQ' => {
			eco => 'A65r',
			# TRANSLATORS: A65r: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f3 Bg7 8. Bg5 h6 9. Be3 O-O
			variation => N__('Benoni: Sämisch, 8. Bg5 h6 9. Be3 O-O'),
			moves => {
				'd1d2' => 1,
				'g1e2' => 1,
			},
		},
		'rnbq1rk1/pp3pb1/3p1npp/2pP4/4P3/2N1BP2/PP2N1PP/R2QKB1R b KQ' => {
			eco => 'A65s',
			# TRANSLATORS: A65s: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f3 Bg7 8. Bg5 h6 9. Be3 O-O 10. Nge2
			variation => N__('Benoni: Sämisch, 8. Bg5 h6 9. Be3 O-O 10.Nge2'),
			moves => {
			},
		},
		'rnbq1rk1/pp3pb1/3p1npp/2pP4/4P3/2N1BP2/PP1Q2PP/R3KBNR b KQ' => {
			eco => 'A65t',
			# TRANSLATORS: A65t: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f3 Bg7 8. Bg5 h6 9. Be3 O-O 10. Qd2
			variation => N__('Benoni: Sämisch, 8. Bg5 h6 9. Be3 O-O 10. Qd2'),
			moves => {
				'a7a6' => 1,
				'f8e8' => 1,
			},
		},
		'rnbqr1k1/pp3pb1/3p1npp/2pP4/4P3/2N1BP2/PP1Q2PP/R3KBNR w KQ' => {
			eco => 'A65u',
			# TRANSLATORS: A65u: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f3 Bg7 8. Bg5 h6 9. Be3 O-O 10. Qd2 Re8
			variation => N__('Benoni: Sämisch, 8. Bg5 h6 9. Be3 O-O 10. Qd2 Re8'),
			moves => {
			},
		},
		'rnbq1rk1/1p3pb1/p2p1npp/2pP4/4P3/2N1BP2/PP1Q2PP/R3KBNR w KQ' => {
			eco => 'A65v',
			# TRANSLATORS: A65v: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f3 Bg7 8. Bg5 h6 9. Be3 O-O 10. Qd2 a6
			variation => N__('Benoni: Sämisch, 8. Bg5 h6 9. Be3 O-O 10. Qd2 a6'),
			moves => {
				'a2a4' => 1,
			},
		},
		'rnbq1rk1/1p3pb1/p2p1npp/2pP4/P3P3/2N1BP2/1P1Q2PP/R3KBNR b KQ' => {
			eco => 'A65v',
			# TRANSLATORS: A65v: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f3 Bg7 8. Bg5 h6 9. Be3 O-O 10. Qd2 a6 11. a4
			variation => N__('Benoni: Sämisch, 8. Bg5 h6 9. Be3 O-O 10. Qd2 a6 11. a4'),
			moves => {
				'b8d7' => 1,
				'f8e8' => 1,
				'h6h5' => 1,
			},
		},
		'rnbq1rk1/1p3pb1/p2p1np1/2pP3p/P3P3/2N1BP2/1P1Q2PP/R3KBNR w KQ' => {
			eco => 'A65w',
			# TRANSLATORS: A65w: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f3 Bg7 8. Bg5 h6 9. Be3 O-O 10. Qd2 a6 11. a4 h5
			variation => N__('Benoni: Sämisch, 8. Bg5 h6 9. Be3 O-O 10. Qd2 a6 11. a4 h5'),
			moves => {
			},
		},
		'r1bq1rk1/1p1n1pb1/p2p1npp/2pP4/P3P3/2N1BP2/1P1Q2PP/R3KBNR w KQ' => {
			eco => 'A65x',
			# TRANSLATORS: A65x: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f3 Bg7 8. Bg5 h6 9. Be3 O-O 10. Qd2 a6 11. a4 Nbd7
			variation => N__('Benoni: Sämisch, 8. Bg5 h6 9. Be3 O-O 10. Qd2 a6 11. a4 Nbd7'),
			moves => {
			},
		},
		'rnbqr1k1/1p3pb1/p2p1npp/2pP4/P3P3/2N1BP2/1P1Q2PP/R3KBNR w KQ' => {
			eco => 'A65y',
			# TRANSLATORS: A65y: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f3 Bg7 8. Bg5 h6 9. Be3 O-O 10. Qd2 a6 11. a4 Re8
			variation => N__('Benoni: Sämisch, 8. Bg5 h6 9. Be3 O-O 10. Qd2 a6 11. a4 Re8'),
			moves => {
				'g1e2' => 1,
			},
		},
		'rnbqr1k1/1p3pb1/p2p1npp/2pP4/P3P3/2N1BP2/1P1QN1PP/R3KB1R b KQ' => {
			eco => 'A65y',
			# TRANSLATORS: A65y: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f3 Bg7 8. Bg5 h6 9. Be3 O-O 10. Qd2 a6 11. a4 Re8 12. Nge2
			variation => N__('Benoni: Sämisch, 8. Bg5 h6 9. Be3 O-O 10. Qd2 a6 11. a4 Re8'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r1bqr1k1/1p1n1pb1/p2p1npp/2pP4/P3P3/2N1BP2/1P1QN1PP/R3KB1R w KQ' => {
			eco => 'A65y',
			# TRANSLATORS: A65y: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f3 Bg7 8. Bg5 h6 9. Be3 O-O 10. Qd2 a6 11. a4 Re8 12. Nge2 Nbd7
			variation => N__('Benoni: Sämisch, 8. Bg5 h6 9. Be3 O-O 10. Qd2 a6 11. a4 Re8 12.Nge2 Nbd7'),
			moves => {
			},
		},
		'rnbqkb1r/pp3p1p/3p1np1/2pP4/4PP2/2N5/PP4PP/R1BQKBNR b KQkq' => {
			eco => 'A66',
			# TRANSLATORS: A66: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4
			variation => N__('Benoni: Four Pawns Attack'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/pp3pbp/3p1np1/2pP4/4PP2/2N5/PP4PP/R1BQKBNR w KQkq' => {
			eco => 'A66',
			# TRANSLATORS: A66: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7
			variation => N__('Benoni: Four Pawns Attack'),
			moves => {
				'e4e5' => 1,
				'f1b5' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqk2r/pp3pbp/3p1np1/2pPP3/5P2/2N5/PP4PP/R1BQKBNR b KQkq' => {
			eco => 'A66',
			# TRANSLATORS: A66: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. e5
			variation => N__('Benoni: Four Pawns, Mikenas Attack'),
			moves => {
				'd6e5' => 1,
				'f6d7' => 1,
			},
		},
		'rnbqk2r/pp3pbp/5np1/2pPp3/5P2/2N5/PP4PP/R1BQKBNR w KQkq' => {
			eco => 'A66',
			# TRANSLATORS: A66: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. e5 dxe5
			variation => N__('Benoni: Mikenas Attack, 8...dxe5'),
			moves => {
			},
		},
		'rnbqk2r/pp1n1pbp/3p2p1/2pPP3/5P2/2N5/PP4PP/R1BQKBNR w KQkq' => {
			eco => 'A66',
			# TRANSLATORS: A66: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. e5 Nfd7
			variation => N__('Benoni: Mikenas Attack, 8...Nfd7'),
			moves => {
				'c3b5' => 1,
				'e5e6' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqk2r/pp1n1pbp/3p2p1/1NpPP3/5P2/8/PP4PP/R1BQKBNR b KQkq' => {
			eco => 'A66',
			# TRANSLATORS: A66: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. e5 Nfd7 9. Nb5
			variation => N__('Benoni: Mikenas Attack, 8...Nfd7 9. Nb5'),
			moves => {
				'd6e5' => 1,
			},
		},
		'rnbqk2r/pp1n1pbp/6p1/1NpPp3/5P2/8/PP4PP/R1BQKBNR w KQkq' => {
			eco => 'A66',
			# TRANSLATORS: A66: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. e5 Nfd7 9. Nb5 dxe5
			variation => N__('Benoni: Mikenas Attack, 8...Nfd7 9. Nb5'),
			moves => {
				'b5d6' => 1,
			},
		},
		'rnbqk2r/pp1n1pbp/3N2p1/2pPp3/5P2/8/PP4PP/R1BQKBNR b KQkq' => {
			eco => 'A66',
			# TRANSLATORS: A66: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. e5 Nfd7 9. Nb5 dxe5 10. Nd6+
			variation => N__('Benoni: Mikenas Attack, 9. Nb5 dxe5 10. Nd6+'),
			moves => {
				'e8e7' => 1,
			},
		},
		'rnbq3r/pp1nkpbp/3N2p1/2pPp3/5P2/8/PP4PP/R1BQKBNR w KQ' => {
			eco => 'A66',
			# TRANSLATORS: A66: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. e5 Nfd7 9. Nb5 dxe5 10. Nd6+ Ke7
			variation => N__('Benoni: Mikenas Attack, 9. Nb5 dxe5 10. Nd6+'),
			moves => {
				'd6c8' => 1,
			},
		},
		'rnNq3r/pp1nkpbp/6p1/2pPp3/5P2/8/PP4PP/R1BQKBNR b KQ' => {
			eco => 'A66',
			# TRANSLATORS: A66: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. e5 Nfd7 9. Nb5 dxe5 10. Nd6+ Ke7 11. Nxc8+
			variation => N__('Benoni: Mikenas Attack, 9. Nb5 dxe5 10. Nd6+ Ke7 11.Nxc8+'),
			moves => {
				'd8c8' => 1,
			},
		},
		'rnq4r/pp1nkpbp/6p1/2pPp3/5P2/8/PP4PP/R1BQKBNR w KQ' => {
			eco => 'A66',
			# TRANSLATORS: A66: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. e5 Nfd7 9. Nb5 dxe5 10. Nd6+ Ke7 11. Nxc8+ Qxc8
			variation => N__('Benoni: Mikenas Attack, 9. Nb5 dxe5 10. Nd6+ Ke7 11.Nxc8+'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnq4r/pp1nkpbp/6p1/2pPp3/5P2/5N2/PP4PP/R1BQKB1R b KQ' => {
			eco => 'A66',
			# TRANSLATORS: A66: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. e5 Nfd7 9. Nb5 dxe5 10. Nd6+ Ke7 11. Nxc8+ Qxc8 12. Nf3
			variation => N__('Benoni: Mikenas Attack, 9. Nb5 dxe5 10. Nd6+ Ke7 11.Nxc8+ Qxc8 12. Nf3'),
			moves => {
			},
		},
		'rnbqk2r/pp1n1pbp/3pP1p1/2pP4/5P2/2N5/PP4PP/R1BQKBNR b KQkq' => {
			eco => 'A66',
			# TRANSLATORS: A66: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. e5 Nfd7 9. e6
			variation => N__('Benoni: Mikenas Attack, 8...Nfd7 9. e6'),
			moves => {
			},
		},
		'rnbqk2r/pp1n1pbp/3p2p1/2pPP3/5P2/2N2N2/PP4PP/R1BQKB1R b KQkq' => {
			eco => 'A66',
			# TRANSLATORS: A66: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. e5 Nfd7 9. Nf3
			variation => N__('Benoni: Mikenas Attack, 8...Nfd7 9. Nf3'),
			moves => {
			},
		},
		'rnbqk2r/pp3pbp/3p1np1/1BpP4/4PP2/2N5/PP4PP/R1BQK1NR b KQkq' => {
			eco => 'A67a',
			# TRANSLATORS: A67a: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Bb5+
			variation => N__('Benoni: Four Pawns, Taimanov (Alatortsev) Variation'),
			moves => {
				'b8d7' => 1,
				'f6d7' => 1,
			},
		},
		'r1bqk2r/pp1n1pbp/3p1np1/1BpP4/4PP2/2N5/PP4PP/R1BQK1NR w KQkq' => {
			eco => 'A67b',
			# TRANSLATORS: A67b: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Bb5+ Nbd7
			variation => N__('Benoni: Four Pawns, Taimanov, 8...Nbd7'),
			moves => {
				'e4e5' => 1,
			},
		},
		'r1bqk2r/pp1n1pbp/3p1np1/1BpPP3/5P2/2N5/PP4PP/R1BQK1NR b KQkq' => {
			eco => 'A67b',
			# TRANSLATORS: A67b: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Bb5+ Nbd7 9. e5
			variation => N__('Benoni: Four Pawns, Taimanov, 8...Nbd7'),
			moves => {
				'd6e5' => 1,
			},
		},
		'r1bqk2r/pp1n1pbp/5np1/1BpPp3/5P2/2N5/PP4PP/R1BQK1NR w KQkq' => {
			eco => 'A67b',
			# TRANSLATORS: A67b: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Bb5+ Nbd7 9. e5 dxe5
			variation => N__('Benoni: Four Pawns, Taimanov, 8...Nbd7'),
			moves => {
				'f4e5' => 1,
			},
		},
		'r1bqk2r/pp1n1pbp/5np1/1BpPP3/8/2N5/PP4PP/R1BQK1NR b KQkq' => {
			eco => 'A67b',
			# TRANSLATORS: A67b: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Bb5+ Nbd7 9. e5 dxe5 10. fxe5
			variation => N__('Benoni: Four Pawns, Taimanov, 8...Nbd7'),
			moves => {
				'f6h5' => 1,
			},
		},
		'r1bqk2r/pp1n1pbp/6p1/1BpPP2n/8/2N5/PP4PP/R1BQK1NR w KQkq' => {
			eco => 'A67b',
			# TRANSLATORS: A67b: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Bb5+ Nbd7 9. e5 dxe5 10. fxe5 Nh5
			variation => N__('Benoni: Four Pawns, Taimanov, 8...Nbd7'),
			moves => {
				'e5e6' => 1,
			},
		},
		'r1bqk2r/pp1n1pbp/4P1p1/1BpP3n/8/2N5/PP4PP/R1BQK1NR b KQkq' => {
			eco => 'A67c',
			# TRANSLATORS: A67c: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Bb5+ Nbd7 9. e5 dxe5 10. fxe5 Nh5 11. e6
			variation => N__('Benoni: Four Pawns, Taimanov, 8...Nbd7 9. e5 dxe5 10.fxe5 Nh5 11. e6'),
			moves => {
			},
		},
		'rnbqk2r/pp1n1pbp/3p2p1/1BpP4/4PP2/2N5/PP4PP/R1BQK1NR w KQkq' => {
			eco => 'A67d',
			# TRANSLATORS: A67d: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Bb5+ Nfd7
			variation => N__('Benoni: Four Pawns, Taimanov, 8...Nfd7'),
			moves => {
				'a2a4' => 1,
				'b5d3' => 1,
			},
		},
		'rnbqk2r/pp1n1pbp/3p2p1/2pP4/4PP2/2NB4/PP4PP/R1BQK1NR b KQkq' => {
			eco => 'A67e',
			# TRANSLATORS: A67e: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Bb5+ Nfd7 9. Bd3
			variation => N__('Benoni: Four Pawns, Taimanov, 9. Bd3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/pp1n1pbp/3p2p1/2pP4/4PP2/2NB4/PP4PP/R1BQK1NR w KQ' => {
			eco => 'A67f',
			# TRANSLATORS: A67f: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Bb5+ Nfd7 9. Bd3 O-O
			variation => N__('Benoni: Four Pawns, Taimanov, 9. Bd3 O-O'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbq1rk1/pp1n1pbp/3p2p1/2pP4/4PP2/2NB1N2/PP4PP/R1BQK2R b KQ' => {
			eco => 'A67g',
			# TRANSLATORS: A67g: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Bb5+ Nfd7 9. Bd3 O-O 10. Nf3
			variation => N__('Benoni: Four Pawns, Taimanov, 9. Bd3 O-O 10. Nf3'),
			moves => {
				'a7a6' => 1,
				'b8a6' => 1,
			},
		},
		'rnbq1rk1/1p1n1pbp/p2p2p1/2pP4/4PP2/2NB1N2/PP4PP/R1BQK2R w KQ' => {
			eco => 'A67h',
			# TRANSLATORS: A67h: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Bb5+ Nfd7 9. Bd3 O-O 10. Nf3 a6
			variation => N__('Benoni: Four Pawns, Taimanov, 9. Bd3 O-O 10. Nf3 a6'),
			moves => {
				'a2a4' => 1,
			},
		},
		'rnbq1rk1/1p1n1pbp/p2p2p1/2pP4/P3PP2/2NB1N2/1P4PP/R1BQK2R b KQ' => {
			eco => 'A67i',
			# TRANSLATORS: A67i: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Bb5+ Nfd7 9. Bd3 O-O 10. Nf3 a6 11. a4
			variation => N__('Benoni: Four Pawns, Taimanov, 9. Bd3 O-O 10. Nf3 a6'),
			moves => {
			},
		},
		'r1bq1rk1/pp1n1pbp/n2p2p1/2pP4/4PP2/2NB1N2/PP4PP/R1BQK2R w KQ' => {
			eco => 'A67j',
			# TRANSLATORS: A67j: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Bb5+ Nfd7 9. Bd3 O-O 10. Nf3 Na6
			variation => N__('Benoni: Four Pawns, Taimanov, 9. Bd3 O-O 10. Nf3 Na6'),
			moves => {
			},
		},
		'rnbqk2r/pp1n1pbp/3p2p1/1BpP4/P3PP2/2N5/1P4PP/R1BQK1NR b KQkq' => {
			eco => 'A67k',
			# TRANSLATORS: A67k: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Bb5+ Nfd7 9. a4
			variation => N__('Benoni: Four Pawns, Taimanov, 9. a4 (Zaitsev)'),
			moves => {
				'a7a6' => 1,
				'd8h4' => 1,
				'e8g8' => 1,
			},
		},
		'rnb1k2r/pp1n1pbp/3p2p1/1BpP4/P3PP1q/2N5/1P4PP/R1BQK1NR w KQkq' => {
			eco => 'A67l',
			# TRANSLATORS: A67l: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Bb5+ Nfd7 9. a4 Qh4+
			variation => N__('Benoni: Four Pawns, Taimanov, 9. a4 Qh4+'),
			moves => {
			},
		},
		'rnbqk2r/1p1n1pbp/p2p2p1/1BpP4/P3PP2/2N5/1P4PP/R1BQK1NR w KQkq' => {
			eco => 'A67m',
			# TRANSLATORS: A67m: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Bb5+ Nfd7 9. a4 a6
			variation => N__('Benoni: Four Pawns, Taimanov, 9. a4 a6'),
			moves => {
				'b5d3' => 1,
				'b5e2' => 1,
			},
		},
		'rnbqk2r/1p1n1pbp/p2p2p1/2pP4/P3PP2/2NB4/1P4PP/R1BQK1NR b KQkq' => {
			eco => 'A67n',
			# TRANSLATORS: A67n: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Bb5+ Nfd7 9. a4 a6 10. Bd3
			variation => N__('Benoni: Four Pawns, Taimanov, 9. a4 a6 10. Bd3'),
			moves => {
			},
		},
		'rnbqk2r/1p1n1pbp/p2p2p1/2pP4/P3PP2/2N5/1P2B1PP/R1BQK1NR b KQkq' => {
			eco => 'A67o',
			# TRANSLATORS: A67o: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Bb5+ Nfd7 9. a4 a6 10. Be2
			variation => N__('Benoni: Four Pawns, Taimanov, 9. a4 a6 10. Be2'),
			moves => {
			},
		},
		'rnbq1rk1/pp1n1pbp/3p2p1/1BpP4/P3PP2/2N5/1P4PP/R1BQK1NR w KQ' => {
			eco => 'A67p',
			# TRANSLATORS: A67p: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Bb5+ Nfd7 9. a4 O-O
			variation => N__('Benoni: Four Pawns, Taimanov, 9. a4 O-O'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbq1rk1/pp1n1pbp/3p2p1/1BpP4/P3PP2/2N2N2/1P4PP/R1BQK2R b KQ' => {
			eco => 'A67q',
			# TRANSLATORS: A67q: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Bb5+ Nfd7 9. a4 O-O 10. Nf3
			variation => N__('Benoni: Four Pawns, Taimanov, 9. a4 O-O 10. Nf3'),
			moves => {
				'b8a6' => 1,
			},
		},
		'r1bq1rk1/pp1n1pbp/n2p2p1/1BpP4/P3PP2/2N2N2/1P4PP/R1BQK2R w KQ' => {
			eco => 'A67r',
			# TRANSLATORS: A67r: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Bb5+ Nfd7 9. a4 O-O 10. Nf3 Na6
			variation => N__('Benoni: Four Pawns, Taimanov, 9. a4 O-O 10. Nf3 Na6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bq1rk1/pp1n1pbp/n2p2p1/1BpP4/P3PP2/2N2N2/1P4PP/R1BQ1RK1 b -' => {
			eco => 'A67r',
			# TRANSLATORS: A67r: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Bb5+ Nfd7 9. a4 O-O 10. Nf3 Na6 11. O-O
			variation => N__('Benoni: Four Pawns, Taimanov, 9. a4 O-O 10. Nf3 Na6'),
			moves => {
				'a6c7' => 1,
			},
		},
		'r1bq1rk1/ppnn1pbp/3p2p1/1BpP4/P3PP2/2N2N2/1P4PP/R1BQ1RK1 w -' => {
			eco => 'A67s',
			# TRANSLATORS: A67s: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Bb5+ Nfd7 9. a4 O-O 10. Nf3 Na6 11. O-O Nc7
			variation => N__('Benoni: Four Pawns, Taimanov, 9. a4 O-O 10. Nf3 Na6 11.O-O Nc7'),
			moves => {
			},
		},
		'rnbqk2r/pp3pbp/3p1np1/2pP4/4PP2/2N2N2/PP4PP/R1BQKB1R b KQkq' => {
			eco => 'A68a',
			# TRANSLATORS: A68a: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3
			variation => N__('Benoni: Four Pawns, 8. Nf3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2pP4/4PP2/2N2N2/PP4PP/R1BQKB1R w KQ' => {
			eco => 'A68a',
			# TRANSLATORS: A68a: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O
			variation => N__('Benoni: Four Pawns, 8. Nf3 O-O'),
			moves => {
				'f1d3' => 1,
				'f1e2' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2pP4/4PP2/2NB1N2/PP4PP/R1BQK2R b KQ' => {
			eco => 'A68b',
			# TRANSLATORS: A68b: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O 9. Bd3
			variation => N__('Benoni: Four Pawns, 9. Bd3'),
			moves => {
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2pP4/4PP2/2N2N2/PP2B1PP/R1BQK2R b KQ' => {
			eco => 'A68c',
			# TRANSLATORS: A68c: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O 9. Be2
			variation => N__('Benoni: Four Pawns, 9. Be2'),
			moves => {
				'b7b5' => 1,
				'c8g4' => 1,
				'f8e8' => 1,
			},
		},
		'rnbq1rk1/p4pbp/3p1np1/1ppP4/4PP2/2N2N2/PP2B1PP/R1BQK2R w KQ' => {
			eco => 'A68d',
			# TRANSLATORS: A68d: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O 9. Be2 b5
			variation => N__('Benoni: Four Pawns, 9. Be2 b5'),
			moves => {
				'e4e5' => 1,
			},
		},
		'rnbq1rk1/p4pbp/3p1np1/1ppPP3/5P2/2N2N2/PP2B1PP/R1BQK2R b KQ' => {
			eco => 'A68e',
			# TRANSLATORS: A68e: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O 9. Be2 b5 10. e5
			variation => N__('Benoni: Four Pawns, 9. Be2 b5 10. e5'),
			moves => {
				'd6e5' => 1,
			},
		},
		'rnbq1rk1/p4pbp/5np1/1ppPp3/5P2/2N2N2/PP2B1PP/R1BQK2R w KQ' => {
			eco => 'A68f',
			# TRANSLATORS: A68f: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O 9. Be2 b5 10. e5 dxe5
			variation => N__('Benoni: Four Pawns, 9. Be2 b5 10. e5 dxe5'),
			moves => {
				'f4e5' => 1,
			},
		},
		'rnbq1rk1/p4pbp/5np1/1ppPP3/8/2N2N2/PP2B1PP/R1BQK2R b KQ' => {
			eco => 'A68f',
			# TRANSLATORS: A68f: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O 9. Be2 b5 10. e5 dxe5 11. fxe5
			variation => N__('Benoni: Four Pawns, 9. Be2 b5 10. e5 dxe5'),
			moves => {
				'f6g4' => 1,
			},
		},
		'rnbq1rk1/p4pbp/6p1/1ppPP3/6n1/2N2N2/PP2B1PP/R1BQK2R w KQ' => {
			eco => 'A68f',
			# TRANSLATORS: A68f: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O 9. Be2 b5 10. e5 dxe5 11. fxe5 Ng4
			variation => N__('Benoni: Four Pawns, 9. Be2 b5 10. e5 dxe5'),
			moves => {
				'c1g5' => 1,
			},
		},
		'rnbq1rk1/p4pbp/6p1/1ppPP1B1/6n1/2N2N2/PP2B1PP/R2QK2R b KQ' => {
			eco => 'A68g',
			# TRANSLATORS: A68g: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O 9. Be2 b5 10. e5 dxe5 11. fxe5 Ng4 12. Bg5
			variation => N__('Benoni: Four Pawns, 9. Be2 b5 10. e5 dxe5 11.fxe5 Ng4 12. Bg5'),
			moves => {
			},
		},
		'rn1q1rk1/pp3pbp/3p1np1/2pP4/4PPb1/2N2N2/PP2B1PP/R1BQK2R w KQ' => {
			eco => 'A68h',
			# TRANSLATORS: A68h: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O 9. Be2 Bg4
			variation => N__('Benoni: Four Pawns, 9. Be2 Bg4'),
			moves => {
				'e1g1' => 1,
				'e4e5' => 1,
			},
		},
		'rn1q1rk1/pp3pbp/3p1np1/2pPP3/5Pb1/2N2N2/PP2B1PP/R1BQK2R b KQ' => {
			eco => 'A68i',
			# TRANSLATORS: A68i: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O 9. Be2 Bg4 10. e5
			variation => N__('Benoni: Four Pawns, 9. Be2 Bg4 10. e5'),
			moves => {
			},
		},
		'rn1q1rk1/pp3pbp/3p1np1/2pP4/4PPb1/2N2N2/PP2B1PP/R1BQ1RK1 b -' => {
			eco => 'A68j',
			# TRANSLATORS: A68j: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O 9. Be2 Bg4 10. O-O
			variation => N__('Benoni: Four Pawns, 9. Be2 Bg4 10.O-O'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r2q1rk1/pp1n1pbp/3p1np1/2pP4/4PPb1/2N2N2/PP2B1PP/R1BQ1RK1 w -' => {
			eco => 'A68k',
			# TRANSLATORS: A68k: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O 9. Be2 Bg4 10. O-O Nbd7
			variation => N__('Benoni: Four Pawns, 9. Be2 Bg4 10.O-O Nbd7'),
			moves => {
				'h2h3' => 1,
			},
		},
		'r2q1rk1/pp1n1pbp/3p1np1/2pP4/4PPb1/2N2N1P/PP2B1P1/R1BQ1RK1 b -' => {
			eco => 'A68l',
			# TRANSLATORS: A68l: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O 9. Be2 Bg4 10. O-O Nbd7 11. h3
			variation => N__('Benoni: Four Pawns, 9. Be2 Bg4 10.O-O Nbd7 11. h3'),
			moves => {
				'g4f3' => 1,
			},
		},
		'r2q1rk1/pp1n1pbp/3p1np1/2pP4/4PP2/2N2b1P/PP2B1P1/R1BQ1RK1 w -' => {
			eco => 'A68l',
			# TRANSLATORS: A68l: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O 9. Be2 Bg4 10. O-O Nbd7 11. h3 Bxf3
			variation => N__('Benoni: Four Pawns, 9. Be2 Bg4 10.O-O Nbd7 11. h3'),
			moves => {
				'e2f3' => 1,
			},
		},
		'r2q1rk1/pp1n1pbp/3p1np1/2pP4/4PP2/2N2B1P/PP4P1/R1BQ1RK1 b -' => {
			eco => 'A68l',
			# TRANSLATORS: A68l: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O 9. Be2 Bg4 10. O-O Nbd7 11. h3 Bxf3 12. Bxf3
			variation => N__('Benoni: Four Pawns, 9. Be2 Bg4 10.O-O Nbd7 11. h3'),
			moves => {
				'f8e8' => 1,
			},
		},
		'r2qr1k1/pp1n1pbp/3p1np1/2pP4/4PP2/2N2B1P/PP4P1/R1BQ1RK1 w -' => {
			eco => 'A68m',
			# TRANSLATORS: A68m: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O 9. Be2 Bg4 10. O-O Nbd7 11. h3 Bxf3 12. Bxf3 Re8
			variation => N__('Benoni: Four Pawns, 9. Be2 Bg4 10.O-O Nbd7 11. h3 Bxf3 12.Bxf3 Re8'),
			moves => {
				'f1e1' => 1,
			},
		},
		'r2qr1k1/pp1n1pbp/3p1np1/2pP4/4PP2/2N2B1P/PP4P1/R1BQR1K1 b -' => {
			eco => 'A68n',
			# TRANSLATORS: A68n: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O 9. Be2 Bg4 10. O-O Nbd7 11. h3 Bxf3 12. Bxf3 Re8 13. Re1
			variation => N__('Benoni: Four Pawns, 9. Be2 Bg4 10.O-O Nbd7 11. h3 Bxf3 12.Bxf3 Re8 13. Re1'),
			moves => {
			},
		},
		'rnbqr1k1/pp3pbp/3p1np1/2pP4/4PP2/2N2N2/PP2B1PP/R1BQK2R w KQ' => {
			eco => 'A69a',
			# TRANSLATORS: A69a: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O 9. Be2 Re8
			variation => N__('Benoni: Four Pawns, Main Line'),
			moves => {
				'e1g1' => 1,
				'e4e5' => 1,
				'f3d2' => 1,
			},
		},
		'rnbqr1k1/pp3pbp/3p1np1/2pP4/4PP2/2N2N2/PP2B1PP/R1BQ1RK1 b -' => {
			eco => 'A69b',
			# TRANSLATORS: A69b: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O 9. Be2 Re8 10. O-O
			variation => N__('Benoni: Four Pawns, Main Line, 10.O-O'),
			moves => {
			},
		},
		'rnbqr1k1/pp3pbp/3p1np1/2pP4/4PP2/2N5/PP1NB1PP/R1BQK2R b KQ' => {
			eco => 'A69c',
			# TRANSLATORS: A69c: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O 9. Be2 Re8 10. Nd2
			variation => N__('Benoni: Four Pawns, Main Line, 10. Nd2'),
			moves => {
				'a7a6' => 1,
				'b8d7' => 1,
			},
		},
		'rnbqr1k1/1p3pbp/p2p1np1/2pP4/4PP2/2N5/PP1NB1PP/R1BQK2R w KQ' => {
			eco => 'A69d',
			# TRANSLATORS: A69d: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O 9. Be2 Re8 10. Nd2 a6
			variation => N__('Benoni: Four Pawns, Main Line, 10. Nd2 a6'),
			moves => {
			},
		},
		'r1bqr1k1/pp1n1pbp/3p1np1/2pP4/4PP2/2N5/PP1NB1PP/R1BQK2R w KQ' => {
			eco => 'A69e',
			# TRANSLATORS: A69e: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O 9. Be2 Re8 10. Nd2 Nbd7
			variation => N__('Benoni: Four Pawns, Main Line, 10. Nd2 Nbd7'),
			moves => {
			},
		},
		'rnbqr1k1/pp3pbp/3p1np1/2pPP3/5P2/2N2N2/PP2B1PP/R1BQK2R b KQ' => {
			eco => 'A69f',
			# TRANSLATORS: A69f: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O 9. Be2 Re8 10. e5
			variation => N__('Benoni: Four Pawns, Main Line, 10. e5'),
			moves => {
				'd6e5' => 1,
			},
		},
		'rnbqr1k1/pp3pbp/5np1/2pPp3/5P2/2N2N2/PP2B1PP/R1BQK2R w KQ' => {
			eco => 'A69f',
			# TRANSLATORS: A69f: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O 9. Be2 Re8 10. e5 dxe5
			variation => N__('Benoni: Four Pawns, Main Line, 10. e5'),
			moves => {
				'f4e5' => 1,
			},
		},
		'rnbqr1k1/pp3pbp/5np1/2pPP3/8/2N2N2/PP2B1PP/R1BQK2R b KQ' => {
			eco => 'A69f',
			# TRANSLATORS: A69f: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O 9. Be2 Re8 10. e5 dxe5 11. fxe5
			variation => N__('Benoni: Four Pawns, Main Line, 10. e5'),
			moves => {
				'f6g4' => 1,
			},
		},
		'rnbqr1k1/pp3pbp/6p1/2pPP3/6n1/2N2N2/PP2B1PP/R1BQK2R w KQ' => {
			eco => 'A69f',
			# TRANSLATORS: A69f: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O 9. Be2 Re8 10. e5 dxe5 11. fxe5 Ng4
			variation => N__('Benoni: Four Pawns, Main Line, 10. e5'),
			moves => {
				'c1g5' => 1,
				'e1g1' => 1,
				'e5e6' => 1,
			},
		},
		'rnbqr1k1/pp3pbp/6p1/2pPP3/6n1/2N2N2/PP2B1PP/R1BQ1RK1 b -' => {
			eco => 'A69g',
			# TRANSLATORS: A69g: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O 9. Be2 Re8 10. e5 dxe5 11. fxe5 Ng4 12. O-O
			variation => N__('Benoni: Four Pawns, Main Line, 10. e5: 12.O-O'),
			moves => {
			},
		},
		'rnbqr1k1/pp3pbp/4P1p1/2pP4/6n1/2N2N2/PP2B1PP/R1BQK2R b KQ' => {
			eco => 'A69h',
			# TRANSLATORS: A69h: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O 9. Be2 Re8 10. e5 dxe5 11. fxe5 Ng4 12. e6
			variation => N__('Benoni: Four Pawns, Main Line, 10. e5: 12. e6'),
			moves => {
			},
		},
		'rnbqr1k1/pp3pbp/6p1/2pPP1B1/6n1/2N2N2/PP2B1PP/R2QK2R b KQ' => {
			eco => 'A69i',
			# TRANSLATORS: A69i: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O 9. Be2 Re8 10. e5 dxe5 11. fxe5 Ng4 12. Bg5
			variation => N__('Benoni: Four Pawns, Main Line, 10. e5: 12. Bg5'),
			moves => {
				'd8b6' => 1,
				'f7f6' => 1,
			},
		},
		'rnbqr1k1/pp4bp/5pp1/2pPP1B1/6n1/2N2N2/PP2B1PP/R2QK2R w KQ' => {
			eco => 'A69j',
			# TRANSLATORS: A69j: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O 9. Be2 Re8 10. e5 dxe5 11. fxe5 Ng4 12. Bg5 f6
			variation => N__('Benoni: Four Pawns, Main Line, 10. e5: 12. Bg5 f6'),
			moves => {
			},
		},
		'rnb1r1k1/pp3pbp/1q4p1/2pPP1B1/6n1/2N2N2/PP2B1PP/R2QK2R w KQ' => {
			eco => 'A69k',
			# TRANSLATORS: A69k: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O 9. Be2 Re8 10. e5 dxe5 11. fxe5 Ng4 12. Bg5 Qb6
			variation => N__('Benoni: Four Pawns, Main Line, 10. e5: 12. Bg5 Qb6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnb1r1k1/pp3pbp/1q4p1/2pPP1B1/6n1/2N2N2/PP2B1PP/R2Q1RK1 b -' => {
			eco => 'A69k',
			# TRANSLATORS: A69k: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O 9. Be2 Re8 10. e5 dxe5 11. fxe5 Ng4 12. Bg5 Qb6 13. O-O
			variation => N__('Benoni: Four Pawns, Main Line, 10. e5: 12. Bg5 Qb6'),
			moves => {
				'g4e5' => 1,
			},
		},
		'rnb1r1k1/pp3pbp/1q4p1/2pPn1B1/8/2N2N2/PP2B1PP/R2Q1RK1 w -' => {
			eco => 'A69k',
			# TRANSLATORS: A69k: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O 9. Be2 Re8 10. e5 dxe5 11. fxe5 Ng4 12. Bg5 Qb6 13. O-O Nxe5
			variation => N__('Benoni: Four Pawns, Main Line, 10. e5: 12. Bg5 Qb6'),
			moves => {
				'd5d6' => 1,
				'f3e5' => 1,
			},
		},
		'rnb1r1k1/pp3pbp/1q4p1/2pPN1B1/8/2N5/PP2B1PP/R2Q1RK1 b -' => {
			eco => 'A69l',
			# TRANSLATORS: A69l: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O 9. Be2 Re8 10. e5 dxe5 11. fxe5 Ng4 12. Bg5 Qb6 13. O-O Nxe5 14. Nxe5
			variation => N__('Benoni: Four Pawns, Main Line, 10. e5: 12. Bg5 Qb6 13.O-O Nxe5 14.Nxe5'),
			moves => {
			},
		},
		'rnb1r1k1/pp3pbp/1q1P2p1/2p1n1B1/8/2N2N2/PP2B1PP/R2Q1RK1 b -' => {
			eco => 'A69m',
			# TRANSLATORS: A69m: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. f4 Bg7 8. Nf3 O-O 9. Be2 Re8 10. e5 dxe5 11. fxe5 Ng4 12. Bg5 Qb6 13. O-O Nxe5 14. d6
			variation => N__('Benoni: Four Pawns, Main Line, 10. e5: 12. Bg5 Qb6 13.O-O Nxe5 14. d6'),
			moves => {
			},
		},
		'rnbqkb1r/pp3p1p/3p1np1/2pP4/4P3/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'A70a',
			# TRANSLATORS: A70a: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3
			variation => N__('Benoni: Classical'),
			moves => {
				'a7a6' => 1,
				'f8g7' => 1,
			},
		},
		'rnbqkb1r/1p3p1p/p2p1np1/2pP4/4P3/2N2N2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'A70b',
			# TRANSLATORS: A70b: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 a6
			variation => N__('Benoni: Classical, 7... a6'),
			moves => {
				'a2a4' => 1,
			},
		},
		'rnbqkb1r/1p3p1p/p2p1np1/2pP4/P3P3/2N2N2/1P3PPP/R1BQKB1R b KQkq' => {
			eco => 'A70b',
			# TRANSLATORS: A70b: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 a6 8. a4
			variation => N__('Benoni: Classical, 7... a6 8. a4'),
			moves => {
				'c8g4' => 1,
			},
		},
		'rn1qkb1r/1p3p1p/p2p1np1/2pP4/P3P1b1/2N2N2/1P3PPP/R1BQKB1R w KQkq' => {
			eco => 'A70b',
			# TRANSLATORS: A70b: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 a6 8. a4 Bg4
			variation => N__('Benoni: Classical, 7... a6 8. a4 Bg4'),
			moves => {
				'f1e2' => 1,
			},
		},
		'rn1qkb1r/1p3p1p/p2p1np1/2pP4/P3P1b1/2N2N2/1P2BPPP/R1BQK2R b KQkq' => {
			eco => 'A70c',
			# TRANSLATORS: A70c: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 a6 8. a4 Bg4 9. Be2
			variation => N__('Benoni: Classical, 7... a6 8. a4 Bg4 9. Be2'),
			moves => {
			},
		},
		'rnbqk2r/pp3pbp/3p1np1/2pP4/4P3/2N2N2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'A70d',
			# TRANSLATORS: A70d: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7
			variation => N__('Benoni: Classical, 7... Bg7'),
			moves => {
				'c1f4' => 1,
				'c1g5' => 1,
				'd1a4' => 1,
				'f1d3' => 1,
				'f1e2' => 1,
				'h2h3' => 1,
			},
		},
		'rnbqk2r/pp3pbp/3p1np1/2pP4/4P3/2N2N2/PP2BPPP/R1BQK2R b KQkq' => {
			eco => 'A70e',
			# TRANSLATORS: A70e: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2
			variation => N__('Benoni: Classical, 8. Be2'),
			moves => {
				'a7a6' => 1,
				'e8g8' => 1,
			},
		},
		'rnbqk2r/1p3pbp/p2p1np1/2pP4/4P3/2N2N2/PP2BPPP/R1BQK2R w KQkq' => {
			eco => 'A70e',
			# TRANSLATORS: A70e: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 a6
			variation => N__('Benoni: Classical, 8. Be2 a6'),
			moves => {
			},
		},
		'rnbqk2r/pp3pbp/3p1np1/2pP4/Q3P3/2N2N2/PP3PPP/R1B1KB1R b KQkq' => {
			eco => 'A70f',
			# TRANSLATORS: A70f: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Qa4+
			variation => N__('Benoni: Classical, 8. Qa4+'),
			moves => {
				'c8d7' => 1,
			},
		},
		'rn1qk2r/pp1b1pbp/3p1np1/2pP4/Q3P3/2N2N2/PP3PPP/R1B1KB1R w KQkq' => {
			eco => 'A70f',
			# TRANSLATORS: A70f: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Qa4+ Bd7
			variation => N__('Benoni: Classical, 8. Qa4+'),
			moves => {
				'a4b3' => 1,
			},
		},
		'rn1qk2r/pp1b1pbp/3p1np1/2pP4/4P3/1QN2N2/PP3PPP/R1B1KB1R b KQkq' => {
			eco => 'A70f',
			# TRANSLATORS: A70f: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Qa4+ Bd7 9. Qb3
			variation => N__('Benoni: Classical, 8. Qa4+'),
			moves => {
				'd8c7' => 1,
			},
		},
		'rn2k2r/ppqb1pbp/3p1np1/2pP4/4P3/1QN2N2/PP3PPP/R1B1KB1R w KQkq' => {
			eco => 'A70f',
			# TRANSLATORS: A70f: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Qa4+ Bd7 9. Qb3 Qc7
			variation => N__('Benoni: Classical, 8. Qa4+ Bd7 9. Qb3 Qc7'),
			moves => {
			},
		},
		'rnbqk2r/pp3pbp/3p1np1/2pP4/4PB2/2N2N2/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'A70g',
			# TRANSLATORS: A70g: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Bf4
			variation => N__('Benoni: Classical, 8. Bf4'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2pP4/4PB2/2N2N2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'A70g',
			# TRANSLATORS: A70g: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Bf4 O-O
			variation => N__('Benoni: Classical, 8. Bf4'),
			moves => {
				'f3d2' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2pP4/4PB2/2N5/PP1N1PPP/R2QKB1R b KQ' => {
			eco => 'A70g',
			# TRANSLATORS: A70g: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Bf4 O-O 9. Nd2
			variation => N__('Benoni: Classical, 8. Bf4 O-O 9. Nd2'),
			moves => {
			},
		},
		'rnbqk2r/pp3pbp/3p1np1/2pP4/4P3/2NB1N2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'A70h',
			# TRANSLATORS: A70h: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Bd3
			variation => N__('Benoni: Classical, 8. Bd3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2pP4/4P3/2NB1N2/PP3PPP/R1BQK2R w KQ' => {
			eco => 'A70h',
			# TRANSLATORS: A70h: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Bd3 O-O
			variation => N__('Benoni: Classical, 8. Bd3'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2pP4/4P3/2NB1N2/PP3PPP/R1BQ1RK1 b -' => {
			eco => 'A70i',
			# TRANSLATORS: A70i: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Bd3 O-O 9. O-O
			variation => N__('Benoni: Classical, 8. Bd3 O-O 9.O-O'),
			moves => {
			},
		},
		'rnbqk2r/pp3pbp/3p1np1/2pP4/4P3/2N2N1P/PP3PP1/R1BQKB1R b KQkq' => {
			eco => 'A70j',
			# TRANSLATORS: A70j: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. h3
			variation => N__('Benoni: Classical, 8. h3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2pP4/4P3/2N2N1P/PP3PP1/R1BQKB1R w KQ' => {
			eco => 'A70j',
			# TRANSLATORS: A70j: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. h3 O-O
			variation => N__('Benoni: Classical, 8. h3'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2pP4/4P3/2NB1N1P/PP3PP1/R1BQK2R b KQ' => {
			eco => 'A70k',
			# TRANSLATORS: A70k: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. h3 O-O 9. Bd3
			variation => N__('Benoni: Classical, 8. h3 O-O 9. Bd3'),
			moves => {
				'a7a6' => 1,
				'b7b5' => 1,
				'b8a6' => 1,
				'c8d7' => 1,
				'f8e8' => 1,
			},
		},
		'rn1q1rk1/pp1b1pbp/3p1np1/2pP4/4P3/2NB1N1P/PP3PP1/R1BQK2R w KQ' => {
			eco => 'A70l',
			# TRANSLATORS: A70l: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. h3 O-O 9. Bd3 Bd7
			variation => N__('Benoni: Classical, 8. h3 O-O 9. Bd3 Bd7'),
			moves => {
			},
		},
		'r1bq1rk1/pp3pbp/n2p1np1/2pP4/4P3/2NB1N1P/PP3PP1/R1BQK2R w KQ' => {
			eco => 'A70m',
			# TRANSLATORS: A70m: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. h3 O-O 9. Bd3 Na6
			variation => N__('Benoni: Classical, 8. h3 O-O 9. Bd3 Na6'),
			moves => {
			},
		},
		'rnbqr1k1/pp3pbp/3p1np1/2pP4/4P3/2NB1N1P/PP3PP1/R1BQK2R w KQ' => {
			eco => 'A70n',
			# TRANSLATORS: A70n: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. h3 O-O 9. Bd3 Re8
			variation => N__('Benoni: Classical, 8. h3 O-O 9. Bd3 Re8'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbqr1k1/pp3pbp/3p1np1/2pP4/4P3/2NB1N1P/PP3PP1/R1BQ1RK1 b -' => {
			eco => 'A70n',
			# TRANSLATORS: A70n: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. h3 O-O 9. Bd3 Re8 10. O-O
			variation => N__('Benoni: Classical, 8. h3 O-O 9. Bd3 Re8'),
			moves => {
				'c5c4' => 1,
			},
		},
		'rnbqr1k1/pp3pbp/3p1np1/3P4/2p1P3/2NB1N1P/PP3PP1/R1BQ1RK1 w -' => {
			eco => 'A70o',
			# TRANSLATORS: A70o: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. h3 O-O 9. Bd3 Re8 10. O-O c4
			variation => N__('Benoni: Classical, 8. h3 O-O 9. Bd3 Re8 10.O-O c4'),
			moves => {
			},
		},
		'rnbq1rk1/1p3pbp/p2p1np1/2pP4/4P3/2NB1N1P/PP3PP1/R1BQK2R w KQ' => {
			eco => 'A70p',
			# TRANSLATORS: A70p: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. h3 O-O 9. Bd3 a6
			variation => N__('Benoni: Classical, 8. h3 O-O 9. Bd3 a6'),
			moves => {
				'a2a4' => 1,
				'e1g1' => 1,
			},
		},
		'rnbq1rk1/1p3pbp/p2p1np1/2pP4/4P3/2NB1N1P/PP3PP1/R1BQ1RK1 b -' => {
			eco => 'A70p',
			# TRANSLATORS: A70p: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. h3 O-O 9. Bd3 a6 10. O-O
			variation => N__('Benoni: Classical, 8. h3 O-O 9. Bd3 a6'),
			moves => {
				'b7b5' => 1,
			},
		},
		'rnbq1rk1/5pbp/p2p1np1/1ppP4/4P3/2NB1N1P/PP3PP1/R1BQ1RK1 w -' => {
			eco => 'A70q',
			# TRANSLATORS: A70q: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. h3 O-O 9. Bd3 a6 10. O-O b5
			variation => N__('Benoni: Classical, 8. h3 O-O 9. Bd3 a6 10.O-O b5'),
			moves => {
			},
		},
		'rnbq1rk1/1p3pbp/p2p1np1/2pP4/P3P3/2NB1N1P/1P3PP1/R1BQK2R b KQ' => {
			eco => 'A70r',
			# TRANSLATORS: A70r: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. h3 O-O 9. Bd3 a6 10. a4
			variation => N__('Benoni: Classical, 8. h3 O-O 9. Bd3 a6 10. a4'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r1bq1rk1/1p1n1pbp/p2p1np1/2pP4/P3P3/2NB1N1P/1P3PP1/R1BQK2R w KQ' => {
			eco => 'A70s',
			# TRANSLATORS: A70s: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. h3 O-O 9. Bd3 a6 10. a4 Nbd7
			variation => N__('Benoni: Classical, 8. h3 O-O 9. Bd3 a6 10. a4 Nbd7'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bq1rk1/1p1n1pbp/p2p1np1/2pP4/P3P3/2NB1N1P/1P3PP1/R1BQ1RK1 b -' => {
			eco => 'A70s',
			# TRANSLATORS: A70s: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. h3 O-O 9. Bd3 a6 10. a4 Nbd7 11. O-O
			variation => N__('Benoni: Classical, 8. h3 O-O 9. Bd3 a6 10. a4 Nbd7'),
			moves => {
				'f8e8' => 1,
			},
		},
		'r1bqr1k1/1p1n1pbp/p2p1np1/2pP4/P3P3/2NB1N1P/1P3PP1/R1BQ1RK1 w -' => {
			eco => 'A70t',
			# TRANSLATORS: A70t: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. h3 O-O 9. Bd3 a6 10. a4 Nbd7 11. O-O Re8
			variation => N__('Benoni: Classical, 8. h3 O-O 9. Bd3 a6 10. a4 Nbd7 11.O-O Re8'),
			moves => {
			},
		},
		'rnbq1rk1/p4pbp/3p1np1/1ppP4/4P3/2NB1N1P/PP3PP1/R1BQK2R w KQ' => {
			eco => 'A70u',
			# TRANSLATORS: A70u: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. h3 O-O 9. Bd3 b5
			variation => N__('Benoni: Classical, 8. h3 O-O 9. Bd3 b5'),
			moves => {
				'c3b5' => 1,
				'd3b5' => 1,
			},
		},
		'rnbq1rk1/p4pbp/3p1np1/1BpP4/4P3/2N2N1P/PP3PP1/R1BQK2R b KQ' => {
			eco => 'A70v',
			# TRANSLATORS: A70v: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. h3 O-O 9. Bd3 b5 10. Bxb5
			variation => N__('Benoni: Classical, 8. h3 O-O 9. Bd3 b5 10.Bxb5'),
			moves => {
			},
		},
		'rnbq1rk1/p4pbp/3p1np1/1NpP4/4P3/3B1N1P/PP3PP1/R1BQK2R b KQ' => {
			eco => 'A70w',
			# TRANSLATORS: A70w: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. h3 O-O 9. Bd3 b5 10. Nxb5
			variation => N__('Benoni: Classical, 8. h3 O-O 9. Bd3 b5 10.Nxb5'),
			moves => {
				'f6e4' => 1,
				'f8e8' => 1,
			},
		},
		'rnbq1rk1/p4pbp/3p2p1/1NpP4/4n3/3B1N1P/PP3PP1/R1BQK2R w KQ' => {
			eco => 'A70w',
			# TRANSLATORS: A70w: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. h3 O-O 9. Bd3 b5 10. Nxb5 Nxe4
			variation => N__('Benoni: Classical, 8. h3 O-O 9. Bd3 b5 10.Nxb5 Nxe4'),
			moves => {
			},
		},
		'rnbqr1k1/p4pbp/3p1np1/1NpP4/4P3/3B1N1P/PP3PP1/R1BQK2R w KQ' => {
			eco => 'A70x',
			# TRANSLATORS: A70x: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. h3 O-O 9. Bd3 b5 10. Nxb5 Re8
			variation => N__('Benoni: Classical, 8. h3 O-O 9. Bd3 b5 10.Nxb5 Re8'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbqr1k1/p4pbp/3p1np1/1NpP4/4P3/3B1N1P/PP3PP1/R1BQ1RK1 b -' => {
			eco => 'A70x',
			# TRANSLATORS: A70x: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. h3 O-O 9. Bd3 b5 10. Nxb5 Re8 11. O-O
			variation => N__('Benoni: Classical, 8. h3 O-O 9. Bd3 b5 10.Nxb5 Re8'),
			moves => {
				'f6e4' => 1,
			},
		},
		'rnbqr1k1/p4pbp/3p2p1/1NpP4/4n3/3B1N1P/PP3PP1/R1BQ1RK1 w -' => {
			eco => 'A70y',
			# TRANSLATORS: A70y: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. h3 O-O 9. Bd3 b5 10. Nxb5 Re8 11. O-O Nxe4
			variation => N__('Benoni: Classical, 8. h3 O-O 9. Bd3 b5 10.Nxb5 Re8 11.O-O Nxe4'),
			moves => {
			},
		},
		'rnbqk2r/pp3pbp/3p1np1/2pP2B1/4P3/2N2N2/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'A71',
			# TRANSLATORS: A71: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Bg5
			variation => N__('Benoni: Classical, 8. Bg5'),
			moves => {
				'h7h6' => 1,
			},
		},
		'rnbqk2r/pp3pb1/3p1npp/2pP2B1/4P3/2N2N2/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'A71',
			# TRANSLATORS: A71: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Bg5 h6
			variation => N__('Benoni: Classical, 8. Bg5'),
			moves => {
				'g5h4' => 1,
			},
		},
		'rnbqk2r/pp3pb1/3p1npp/2pP4/4P2B/2N2N2/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'A71',
			# TRANSLATORS: A71: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Bg5 h6 9. Bh4
			variation => N__('Benoni: Classical, 8. Bg5'),
			moves => {
				'a7a6' => 1,
				'g6g5' => 1,
			},
		},
		'rnbqk2r/1p3pb1/p2p1npp/2pP4/4P2B/2N2N2/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'A71',
			# TRANSLATORS: A71: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Bg5 h6 9. Bh4 a6
			variation => N__('Benoni: Classical, 8. Bg5 h6 9. Bh4 a6'),
			moves => {
				'f3d2' => 1,
			},
		},
		'rnbqk2r/1p3pb1/p2p1npp/2pP4/4P2B/2N5/PP1N1PPP/R2QKB1R b KQkq' => {
			eco => 'A71',
			# TRANSLATORS: A71: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Bg5 h6 9. Bh4 a6 10. Nd2
			variation => N__('Benoni: Classical, 8. Bg5 h6 9. Bh4 a6 10. Nd2'),
			moves => {
				'b7b5' => 1,
			},
		},
		'rnbqk2r/5pb1/p2p1npp/1ppP4/4P2B/2N5/PP1N1PPP/R2QKB1R w KQkq' => {
			eco => 'A71',
			# TRANSLATORS: A71: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Bg5 h6 9. Bh4 a6 10. Nd2 b5
			variation => N__('Benoni: Classical, 8. Bg5 h6 9. Bh4 a6 10. Nd2'),
			moves => {
				'f1e2' => 1,
			},
		},
		'rnbqk2r/5pb1/p2p1npp/1ppP4/4P2B/2N5/PP1NBPPP/R2QK2R b KQkq' => {
			eco => 'A71',
			# TRANSLATORS: A71: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Bg5 h6 9. Bh4 a6 10. Nd2 b5 11. Be2
			variation => N__('Benoni: Classical, 8. Bg5 h6 9. Bh4 a6 10. Nd2 b5 11. Be2'),
			moves => {
			},
		},
		'rnbqk2r/pp3pb1/3p1n1p/2pP2p1/4P2B/2N2N2/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'A71',
			# TRANSLATORS: A71: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Bg5 h6 9. Bh4 g5
			variation => N__('Benoni: Classical, 8. Bg5 h6 9. Bh4 g5'),
			moves => {
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2pP4/4P3/2N2N2/PP2BPPP/R1BQK2R w KQ' => {
			eco => 'A72',
			# TRANSLATORS: A72: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O
			variation => N__('Benoni: Classical, 8. Be2 O-O'),
			moves => {
				'c1f4' => 1,
				'c1g5' => 1,
				'e1g1' => 1,
				'f3d2' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2pP4/4PB2/2N2N2/PP2BPPP/R2QK2R b KQ' => {
			eco => 'A72',
			# TRANSLATORS: A72: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. Bf4
			variation => N__('Benoni: Classical, 8. Be2 O-O 9. Bf4'),
			moves => {
				'a7a6' => 1,
				'b7b5' => 1,
			},
		},
		'rnbq1rk1/1p3pbp/p2p1np1/2pP4/4PB2/2N2N2/PP2BPPP/R2QK2R w KQ' => {
			eco => 'A72',
			# TRANSLATORS: A72: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. Bf4 a6
			variation => N__('Benoni: Classical, 8. Be2 O-O 9. Bf4 a6'),
			moves => {
			},
		},
		'rnbq1rk1/p4pbp/3p1np1/1ppP4/4PB2/2N2N2/PP2BPPP/R2QK2R w KQ' => {
			eco => 'A72',
			# TRANSLATORS: A72: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. Bf4 b5
			variation => N__('Benoni: Classical, 8. Be2 O-O 9. Bf4 b5'),
			moves => {
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2pP2B1/4P3/2N2N2/PP2BPPP/R2QK2R b KQ' => {
			eco => 'A72',
			# TRANSLATORS: A72: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. Bg5
			variation => N__('Benoni: Classical, 8. Be2 O-O 9. Bg5'),
			moves => {
				'h7h6' => 1,
			},
		},
		'rnbq1rk1/pp3pb1/3p1npp/2pP2B1/4P3/2N2N2/PP2BPPP/R2QK2R w KQ' => {
			eco => 'A72',
			# TRANSLATORS: A72: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. Bg5 h6
			variation => N__('Benoni: Classical, 8. Be2 O-O 9. Bg5'),
			moves => {
				'g5h4' => 1,
			},
		},
		'rnbq1rk1/pp3pb1/3p3p/2pP2pn/4P3/2N3B1/PP1NBPPP/R2QK2R b KQ' => {
			eco => 'A72',
			# TRANSLATORS: A72: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. Bg5 h6 10. Bh4 g5 11. Bg3 Nh5 12. Nd2
			variation => N__('Benoni: Classical, 8. Be2 O-O 9. Bg5 h6 10. Bh4 g5 11. Bg3 Nh5 12. Nd2'),
			moves => {
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2pP4/4P3/2N5/PP1NBPPP/R1BQK2R b KQ' => {
			eco => 'A72',
			# TRANSLATORS: A72: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. Nd2
			variation => N__('Benoni: Classical, 8. Be2 O-O 9. Nd2'),
			moves => {
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2pP4/4P3/2N2N2/PP2BPPP/R1BQ1RK1 b -' => {
			eco => 'A73',
			# TRANSLATORS: A73: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O
			variation => N__('Benoni: Classical, 9.O-O'),
			moves => {
				'a7a6' => 1,
				'b8a6' => 1,
				'b8d7' => 1,
				'c8g4' => 1,
				'f8e8' => 1,
			},
		},
		'rnbq1rk1/1p3pbp/p2p1np1/2pP4/4P3/2N2N2/PP2BPPP/R1BQ1RK1 w -' => {
			eco => 'A73',
			# TRANSLATORS: A73: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O a6
			variation => N__('Benoni: Classical, 9.O-O a6'),
			moves => {
				'a2a4' => 1,
			},
		},
		'r1bq1rk1/pp3pbp/n2p1np1/2pP4/4P3/2N2N2/PP2BPPP/R1BQ1RK1 w -' => {
			eco => 'A73',
			# TRANSLATORS: A73: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Na6
			variation => N__('Benoni: Classical, 9.O-O Na6'),
			moves => {
				'f3d2' => 1,
			},
		},
		'r1bq1rk1/pp3pbp/n2p1np1/2pP4/4P3/2N5/PP1NBPPP/R1BQ1RK1 b -' => {
			eco => 'A73',
			# TRANSLATORS: A73: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Na6 10. Nd2
			variation => N__('Benoni: Classical, 9.O-O Na6 10. Nd2'),
			moves => {
				'a6c7' => 1,
			},
		},
		'r1bq1rk1/ppn2pbp/3p1np1/2pP4/4P3/2N5/PP1NBPPP/R1BQ1RK1 w -' => {
			eco => 'A73',
			# TRANSLATORS: A73: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Na6 10. Nd2 Nc7
			variation => N__('Benoni: Classical, 9.O-O Na6 10. Nd2 Nc7'),
			moves => {
			},
		},
		'r1bq1rk1/pp1n1pbp/3p1np1/2pP4/4P3/2N2N2/PP2BPPP/R1BQ1RK1 w -' => {
			eco => 'A73',
			# TRANSLATORS: A73: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Nbd7
			variation => N__('Benoni: Classical, 9.O-O Nbd7'),
			moves => {
			},
		},
		'rn1q1rk1/pp3pbp/3p1np1/2pP4/4P1b1/2N2N2/PP2BPPP/R1BQ1RK1 w -' => {
			eco => 'A73',
			# TRANSLATORS: A73: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Bg4
			variation => N__('Benoni: Classical, 9.O-O Bg4'),
			moves => {
				'c1f4' => 1,
				'c1g5' => 1,
				'h2h3' => 1,
			},
		},
		'rn1q1rk1/pp3pbp/3p1np1/2pP4/4PBb1/2N2N2/PP2BPPP/R2Q1RK1 b -' => {
			eco => 'A73',
			# TRANSLATORS: A73: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Bg4 10. Bf4
			variation => N__('Benoni: Classical, 9.O-O Bg4 10. Bf4'),
			moves => {
			},
		},
		'rn1q1rk1/pp3pbp/3p1np1/2pP2B1/4P1b1/2N2N2/PP2BPPP/R2Q1RK1 b -' => {
			eco => 'A73',
			# TRANSLATORS: A73: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Bg4 10. Bg5
			variation => N__('Benoni: Classical, 9.O-O Bg4 10. Bg5'),
			moves => {
			},
		},
		'rn1q1rk1/pp3pbp/3p1np1/2pP4/4P1b1/2N2N1P/PP2BPP1/R1BQ1RK1 b -' => {
			eco => 'A73',
			# TRANSLATORS: A73: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Bg4 10. h3
			variation => N__('Benoni: Classical, 9.O-O Bg4 10. h3'),
			moves => {
			},
		},
		'rnbq1rk1/1p3pbp/p2p1np1/2pP4/P3P3/2N2N2/1P2BPPP/R1BQ1RK1 b -' => {
			eco => 'A74',
			# TRANSLATORS: A74: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O a6 10. a4
			variation => N__('Benoni: Classical, 9.O-O a6 10. a4'),
			moves => {
				'b8d7' => 1,
				'c8g4' => 1,
			},
		},
		'r1bq1rk1/1p1n1pbp/p2p1np1/2pP4/P3P3/2N2N2/1P2BPPP/R1BQ1RK1 w -' => {
			eco => 'A74',
			# TRANSLATORS: A74: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O a6 10. a4 Nbd7
			variation => N__('Benoni: Classical, 9.O-O a6 10. a4 Nbd7'),
			moves => {
				'c1f4' => 1,
				'c1g5' => 1,
				'f3d2' => 1,
			},
		},
		'r1bq1rk1/1p1n1pbp/p2p1np1/2pP4/P3PB2/2N2N2/1P2BPPP/R2Q1RK1 b -' => {
			eco => 'A74',
			# TRANSLATORS: A74: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O a6 10. a4 Nbd7 11. Bf4
			variation => N__('Benoni: Classical, 9.O-O a6 10. a4 Nbd7 11. Bf4'),
			moves => {
				'd8e7' => 1,
			},
		},
		'r1b2rk1/1p1nqpbp/p2p1np1/2pP4/P3PB2/2N2N2/1P2BPPP/R2Q1RK1 w -' => {
			eco => 'A74',
			# TRANSLATORS: A74: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O a6 10. a4 Nbd7 11. Bf4 Qe7
			variation => N__('Benoni: Classical, 9.O-O a6 10. a4 Nbd7 11. Bf4 Qe7'),
			moves => {
			},
		},
		'r1bq1rk1/1p1n1pbp/p2p1np1/2pP2B1/P3P3/2N2N2/1P2BPPP/R2Q1RK1 b -' => {
			eco => 'A74',
			# TRANSLATORS: A74: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O a6 10. a4 Nbd7 11. Bg5
			variation => N__('Benoni: Classical, 9.O-O a6 10. a4 Nbd7 11. Bg5'),
			moves => {
			},
		},
		'r1bq1rk1/1p1n1pbp/p2p1np1/2pP4/P3P3/2N5/1P1NBPPP/R1BQ1RK1 b -' => {
			eco => 'A74',
			# TRANSLATORS: A74: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O a6 10. a4 Nbd7 11. Nd2
			variation => N__('Benoni: Classical, 9.O-O a6 10. a4 Nbd7 11. Nd2'),
			moves => {
			},
		},
		'rn1q1rk1/1p3pbp/p2p1np1/2pP4/P3P1b1/2N2N2/1P2BPPP/R1BQ1RK1 w -' => {
			eco => 'A75',
			# TRANSLATORS: A75: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O a6 10. a4 Bg4
			variation => N__('Benoni: Classical, 9.O-O a6 10. a4 Bg4'),
			moves => {
				'c1f4' => 1,
				'c1g5' => 1,
				'f3d2' => 1,
				'h2h3' => 1,
			},
		},
		'rn1q1rk1/1p3pbp/p2p1np1/2pP4/P3PBb1/2N2N2/1P2BPPP/R2Q1RK1 b -' => {
			eco => 'A75',
			# TRANSLATORS: A75: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O a6 10. a4 Bg4 11. Bf4
			variation => N__('Benoni: Classical, 9.O-O a6 10. a4 Bg4 11. Bf4'),
			moves => {
				'd8e7' => 1,
				'f8e8' => 1,
				'g4f3' => 1,
			},
		},
		'rn3rk1/1p2qpbp/p2p1np1/2pP4/P3PBb1/2N2N2/1P2BPPP/R2Q1RK1 w -' => {
			eco => 'A75',
			# TRANSLATORS: A75: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O a6 10. a4 Bg4 11. Bf4 Qe7
			variation => N__('Benoni: Classical, 9.O-O a6 10. a4 Bg4 11. Bf4 Qe7'),
			moves => {
			},
		},
		'rn1qr1k1/1p3pbp/p2p1np1/2pP4/P3PBb1/2N2N2/1P2BPPP/R2Q1RK1 w -' => {
			eco => 'A75',
			# TRANSLATORS: A75: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O a6 10. a4 Bg4 11. Bf4 Re8
			variation => N__('Benoni: Classical, 9.O-O a6 10. a4 Bg4 11. Bf4 Re8'),
			moves => {
				'f3d2' => 1,
			},
		},
		'rn1qr1k1/1p3pbp/p2p1np1/2pP4/P3PBb1/2N5/1P1NBPPP/R2Q1RK1 b -' => {
			eco => 'A75',
			# TRANSLATORS: A75: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O a6 10. a4 Bg4 11. Bf4 Re8 12. Nd2
			variation => N__('Benoni: Classical, 9.O-O a6 10. a4 Bg4 11. Bf4 Re8'),
			moves => {
				'g4e2' => 1,
			},
		},
		'rn1qr1k1/1p3pbp/p2p1np1/2pP4/P3PB2/2N5/1P1NbPPP/R2Q1RK1 w -' => {
			eco => 'A75',
			# TRANSLATORS: A75: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O a6 10. a4 Bg4 11. Bf4 Re8 12. Nd2 Bxe2
			variation => N__('Benoni: Classical, 9.O-O a6 10. a4 Bg4 11. Bf4 Re8'),
			moves => {
				'd1e2' => 1,
			},
		},
		'rn1qr1k1/1p3pbp/p2p1np1/2pP4/P3PB2/2N5/1P1NQPPP/R4RK1 b -' => {
			eco => 'A75',
			# TRANSLATORS: A75: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O a6 10. a4 Bg4 11. Bf4 Re8 12. Nd2 Bxe2 13. Qxe2
			variation => N__('Benoni: Classical, 9.O-O a6 10. a4 Bg4 11. Bf4 Re8'),
			moves => {
				'f6h5' => 1,
			},
		},
		'rn1qr1k1/1p3pbp/p2p2p1/2pP3n/P3PB2/2N5/1P1NQPPP/R4RK1 w -' => {
			eco => 'A75',
			# TRANSLATORS: A75: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O a6 10. a4 Bg4 11. Bf4 Re8 12. Nd2 Bxe2 13. Qxe2 Nh5
			variation => N__('Benoni: Classical, 9.O-O a6 10. a4 Bg4 11. Bf4 Re8 12. Nd2 Bxe2 13.Qxe2 Nh5'),
			moves => {
			},
		},
		'rn1q1rk1/1p3pbp/p2p1np1/2pP4/P3PB2/2N2b2/1P2BPPP/R2Q1RK1 w -' => {
			eco => 'A75',
			# TRANSLATORS: A75: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O a6 10. a4 Bg4 11. Bf4 Bxf3
			variation => N__('Benoni: Classical, 9.O-O a6 10. a4 Bg4 11. Bf4 Bxf3'),
			moves => {
				'e2f3' => 1,
			},
		},
		'rn1q1rk1/1p3pbp/p2p1np1/2pP4/P3PB2/2N2B2/1P3PPP/R2Q1RK1 b -' => {
			eco => 'A75',
			# TRANSLATORS: A75: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O a6 10. a4 Bg4 11. Bf4 Bxf3 12. Bxf3
			variation => N__('Benoni: Classical, 9.O-O a6 10. a4 Bg4 11. Bf4 Bxf3'),
			moves => {
				'd8e7' => 1,
			},
		},
		'rn3rk1/1p2qpbp/p2p1np1/2pP4/P3PB2/2N2B2/1P3PPP/R2Q1RK1 w -' => {
			eco => 'A75',
			# TRANSLATORS: A75: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O a6 10. a4 Bg4 11. Bf4 Bxf3 12. Bxf3 Qe7
			variation => N__('Benoni: Classical, 9.O-O a6 10. a4 Bg4 11. Bf4 Bxf3 12.Bxf3 Qe7'),
			moves => {
				'f1e1' => 1,
			},
		},
		'rn3rk1/1p2qpbp/p2p1np1/2pP4/P3PB2/2N2B2/1P3PPP/R2QR1K1 b -' => {
			eco => 'A75',
			# TRANSLATORS: A75: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O a6 10. a4 Bg4 11. Bf4 Bxf3 12. Bxf3 Qe7 13. Re1
			variation => N__('Benoni: Classical, 9.O-O a6 10. a4 Bg4 11. Bf4 Bxf3 12.Bxf3 Qe7 13. Re1'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r4rk1/1p1nqpbp/p2p1np1/2pP4/P3PB2/2N2B2/1P3PPP/R2QR1K1 w -' => {
			eco => 'A75',
			# TRANSLATORS: A75: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O a6 10. a4 Bg4 11. Bf4 Bxf3 12. Bxf3 Qe7 13. Re1 Nbd7
			variation => N__('Benoni: Classical, 9.O-O a6 10. a4 Bg4 11. Bf4 Bxf3 12.Bxf3 Qe7 13. Re1'),
			moves => {
				'a4a5' => 1,
			},
		},
		'r4rk1/1p1nqpbp/p2p1np1/P1pP4/4PB2/2N2B2/1P3PPP/R2QR1K1 b -' => {
			eco => 'A75',
			# TRANSLATORS: A75: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O a6 10. a4 Bg4 11. Bf4 Bxf3 12. Bxf3 Qe7 13. Re1 Nbd7 14. a5
			variation => N__('Benoni: Classical, 9.O-O a6 10. a4 Bg4 11. Bf4 Bxf3 12.Bxf3 Qe7 with 14. a5'),
			moves => {
			},
		},
		'rn1q1rk1/1p3pbp/p2p1np1/2pP2B1/P3P1b1/2N2N2/1P2BPPP/R2Q1RK1 b -' => {
			eco => 'A75',
			# TRANSLATORS: A75: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O a6 10. a4 Bg4 11. Bg5
			variation => N__('Benoni: Classical, 9.O-O a6 10. a4 Bg4 11. Bg5'),
			moves => {
				'h7h6' => 1,
			},
		},
		'rn1q1rk1/1p3pb1/p2p1npp/2pP2B1/P3P1b1/2N2N2/1P2BPPP/R2Q1RK1 w -' => {
			eco => 'A75',
			# TRANSLATORS: A75: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O a6 10. a4 Bg4 11. Bg5 h6
			variation => N__('Benoni: Classical, 9.O-O a6 10. a4 Bg4 11. Bg5 h6'),
			moves => {
			},
		},
		'rn1q1rk1/1p3pbp/p2p1np1/2pP4/P3P1b1/2N5/1P1NBPPP/R1BQ1RK1 b -' => {
			eco => 'A75',
			# TRANSLATORS: A75: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O a6 10. a4 Bg4 11. Nd2
			variation => N__('Benoni: Classical, 9.O-O a6 10. a4 Bg4 11. Nd2'),
			moves => {
			},
		},
		'rn1q1rk1/1p3pbp/p2p1np1/2pP4/P3P1b1/2N2N1P/1P2BPP1/R1BQ1RK1 b -' => {
			eco => 'A75',
			# TRANSLATORS: A75: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O a6 10. a4 Bg4 11. h3
			variation => N__('Benoni: Classical, 9.O-O a6 10. a4 Bg4 11. h3'),
			moves => {
			},
		},
		'rnbqr1k1/pp3pbp/3p1np1/2pP4/4P3/2N2N2/PP2BPPP/R1BQ1RK1 w -' => {
			eco => 'A76',
			# TRANSLATORS: A76: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Re8
			variation => N__('Benoni: Classical, Main Line'),
			moves => {
				'd1c2' => 1,
				'f3d2' => 1,
			},
		},
		'rnbqr1k1/pp3pbp/3p1np1/2pP4/4P3/2N2N2/PPQ1BPPP/R1B2RK1 b -' => {
			eco => 'A76',
			# TRANSLATORS: A76: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Re8 10. Qc2
			variation => N__('Benoni: Classical, Main Line, 10. Qc2'),
			moves => {
				'b8a6' => 1,
				'c8g4' => 1,
			},
		},
		'r1bqr1k1/pp3pbp/n2p1np1/2pP4/4P3/2N2N2/PPQ1BPPP/R1B2RK1 w -' => {
			eco => 'A76',
			# TRANSLATORS: A76: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Re8 10. Qc2 Na6
			variation => N__('Benoni: Classical, Main Line, 10. Qc2 Na6'),
			moves => {
				'c1f4' => 1,
				'f1e1' => 1,
			},
		},
		'r1bqr1k1/pp3pbp/n2p1np1/2pP4/4PB2/2N2N2/PPQ1BPPP/R4RK1 b -' => {
			eco => 'A76',
			# TRANSLATORS: A76: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Re8 10. Qc2 Na6 11. Bf4
			variation => N__('Benoni: Classical, Main Line, 10. Qc2 Na6 11. Bf4'),
			moves => {
			},
		},
		'r1bqr1k1/pp3pbp/n2p1np1/2pP4/4P3/2N2N2/PPQ1BPPP/R1B1R1K1 b -' => {
			eco => 'A76',
			# TRANSLATORS: A76: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Re8 10. Qc2 Na6 11. Re1
			variation => N__('Benoni: Classical, Main Line, 10. Qc2 Na6 11. Re1'),
			moves => {
				'c8g4' => 1,
			},
		},
		'r2qr1k1/pp3pbp/n2p1np1/2pP4/4P1b1/2N2N2/PPQ1BPPP/R1B1R1K1 w -' => {
			eco => 'A76',
			# TRANSLATORS: A76: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Re8 10. Qc2 Na6 11. Re1 Bg4
			variation => N__('Benoni: Classical, Main Line, 10. Qc2 Na6 11. Re1 Bg4'),
			moves => {
			},
		},
		'rn1qr1k1/pp3pbp/3p1np1/2pP4/4P1b1/2N2N2/PPQ1BPPP/R1B2RK1 w -' => {
			eco => 'A76',
			# TRANSLATORS: A76: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Re8 10. Qc2 Bg4
			variation => N__('Benoni: Classical, Main Line, 10. Qc2 Bg4'),
			moves => {
			},
		},
		'rnbqr1k1/pp3pbp/3p1np1/2pP4/4P3/2N5/PP1NBPPP/R1BQ1RK1 b -' => {
			eco => 'A77',
			# TRANSLATORS: A77: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Re8 10. Nd2
			variation => N__('Benoni: Classical, Main Line, 10. Nd2'),
			moves => {
				'a7a6' => 1,
				'b8a6' => 1,
				'b8d7' => 1,
			},
		},
		'rnbqr1k1/1p3pbp/p2p1np1/2pP4/4P3/2N5/PP1NBPPP/R1BQ1RK1 w -' => {
			eco => 'A77',
			# TRANSLATORS: A77: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Re8 10. Nd2 a6
			variation => N__('Benoni: Classical, Main Line, 10. Nd2 a6'),
			moves => {
			},
		},
		'r1bqr1k1/pp1n1pbp/3p1np1/2pP4/4P3/2N5/PP1NBPPP/R1BQ1RK1 w -' => {
			eco => 'A77',
			# TRANSLATORS: A77: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Re8 10. Nd2 Nbd7
			variation => N__('Benoni: Classical, Main Line, 10. Nd2 Nbd7'),
			moves => {
				'a2a4' => 1,
			},
		},
		'r1bqr1k1/pp1n1pbp/3p1np1/2pP4/P3P3/2N5/1P1NBPPP/R1BQ1RK1 b -' => {
			eco => 'A77',
			# TRANSLATORS: A77: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Re8 10. Nd2 Nbd7 11. a4
			variation => N__('Benoni: Classical, Main Line, 10. Nd2 Nbd7 11. a4'),
			moves => {
				'a7a6' => 1,
				'd7e5' => 1,
			},
		},
		'r1bqr1k1/1p1n1pbp/p2p1np1/2pP4/P3P3/2N5/1P1NBPPP/R1BQ1RK1 w -' => {
			eco => 'A77',
			# TRANSLATORS: A77: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Re8 10. Nd2 Nbd7 11. a4 a6
			variation => N__('Benoni: Classical, Main Line, 10. Nd2 Nbd7 11. a4 a6'),
			moves => {
				'a1a3' => 1,
				'd1c2' => 1,
				'h2h3' => 1,
			},
		},
		'r1bqr1k1/1p1n1pbp/p2p1np1/2pP4/P3P3/R1N5/1P1NBPPP/2BQ1RK1 b -' => {
			eco => 'A77',
			# TRANSLATORS: A77: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Re8 10. Nd2 Nbd7 11. a4 a6 12. Ra3
			variation => N__('Benoni: Classical, Main Line, 10. Nd2 Nbd7 11. a4 a6 12. Ra3'),
			moves => {
			},
		},
		'r1bqr1k1/1p1n1pbp/p2p1np1/2pP4/P3P3/2N5/1PQNBPPP/R1B2RK1 b -' => {
			eco => 'A77',
			# TRANSLATORS: A77: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Re8 10. Nd2 Nbd7 11. a4 a6 12. Qc2
			variation => N__('Benoni: Classical, Main Line, 10. Nd2 Nbd7 11. a4 a6 12. Qc2'),
			moves => {
			},
		},
		'r1bqr1k1/1p1n1pbp/p2p1np1/2pP4/P3P3/2N4P/1P1NBPP1/R1BQ1RK1 b -' => {
			eco => 'A77',
			# TRANSLATORS: A77: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Re8 10. Nd2 Nbd7 11. a4 a6 12. h3
			variation => N__('Benoni: Classical, Main Line, 10. Nd2 Nbd7 11. a4 a6 12. h3'),
			moves => {
			},
		},
		'r1bqr1k1/pp3pbp/3p1np1/2pPn3/P3P3/2N5/1P1NBPPP/R1BQ1RK1 w -' => {
			eco => 'A77',
			# TRANSLATORS: A77: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Re8 10. Nd2 Nbd7 11. a4 Ne5
			variation => N__('Benoni: Classical, Main Line, 10. Nd2 Nbd7 11. a4 Ne5'),
			moves => {
				'a1a3' => 1,
				'd1c2' => 1,
				'd2b1' => 1,
				'f1e1' => 1,
			},
		},
		'r1bqr1k1/pp3pbp/3p1np1/2pPn3/P3P3/R1N5/1P1NBPPP/2BQ1RK1 b -' => {
			eco => 'A77',
			# TRANSLATORS: A77: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Re8 10. Nd2 Nbd7 11. a4 Ne5 12. Ra3
			variation => N__('Benoni: Classical, Main Line, 10. Nd2 Nbd7 11. a4 Ne5 12. Ra3'),
			moves => {
			},
		},
		'r1bqr1k1/pp3pbp/3p1np1/2pPn3/P3P3/2N5/1PQNBPPP/R1B2RK1 b -' => {
			eco => 'A77',
			# TRANSLATORS: A77: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Re8 10. Nd2 Nbd7 11. a4 Ne5 12. Qc2
			variation => N__('Benoni: Classical, Main Line, 10. Nd2 Nbd7 11. a4 Ne5 12. Qc2'),
			moves => {
			},
		},
		'r1bqr1k1/pp3pbp/3p1np1/2pPn3/P3P3/2N5/1P2BPPP/RNBQ1RK1 b -' => {
			eco => 'A77',
			# TRANSLATORS: A77: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Re8 10. Nd2 Nbd7 11. a4 Ne5 12. Ndb1
			variation => N__('Benoni: Classical, Main Line, 10. Nd2 Nbd7 11. a4 Ne5 12.Ndb1'),
			moves => {
			},
		},
		'r1bqr1k1/pp3pbp/3p1np1/2pPn3/P3P3/2N5/1P1NBPPP/R1BQR1K1 b -' => {
			eco => 'A77',
			# TRANSLATORS: A77: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Re8 10. Nd2 Nbd7 11. a4 Ne5 12. Re1
			variation => N__('Benoni: Classical, Main Line, 10. Nd2 Nbd7 11. a4 Ne5 12. Re1'),
			moves => {
			},
		},
		'r1bqr1k1/pp3pbp/n2p1np1/2pP4/4P3/2N5/PP1NBPPP/R1BQ1RK1 w -' => {
			eco => 'A78',
			# TRANSLATORS: A78: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Re8 10. Nd2 Na6
			variation => N__('Benoni: Classical, Main Line, 10. Nd2 Na6'),
			moves => {
				'a1b1' => 1,
				'f1e1' => 1,
				'f2f3' => 1,
				'f2f4' => 1,
				'g1h1' => 1,
			},
		},
		'r1bqr1k1/pp3pbp/n2p1np1/2pP4/4P3/2N5/PP1NBPPP/1RBQ1RK1 b -' => {
			eco => 'A78',
			# TRANSLATORS: A78: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Re8 10. Nd2 Na6 11. Rb1
			variation => N__('Benoni: Classical, Main Line, 10. Nd2 Na6 11. Rb1'),
			moves => {
			},
		},
		'r1bqr1k1/pp3pbp/n2p1np1/2pP4/4P3/2N5/PP1NBPPP/R1BQR1K1 b -' => {
			eco => 'A78',
			# TRANSLATORS: A78: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Re8 10. Nd2 Na6 11. Re1
			variation => N__('Benoni: Classical, Main Line, 10. Nd2 Na6 11. Re1'),
			moves => {
			},
		},
		'r1bqr1k1/pp3pbp/n2p1np1/2pP4/4PP2/2N5/PP1NB1PP/R1BQ1RK1 b -' => {
			eco => 'A78',
			# TRANSLATORS: A78: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Re8 10. Nd2 Na6 11. f4
			variation => N__('Benoni: Classical, Main Line, 10. Nd2 Na6 11. f4'),
			moves => {
				'a6c7' => 1,
			},
		},
		'r1bqr1k1/ppn2pbp/3p1np1/2pP4/4PP2/2N5/PP1NB1PP/R1BQ1RK1 w -' => {
			eco => 'A78',
			# TRANSLATORS: A78: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Re8 10. Nd2 Na6 11. f4 Nc7
			variation => N__('Benoni: Classical, Main Line, 10. Nd2 Na6 11. f4 Nc7'),
			moves => {
			},
		},
		'r1bqr1k1/pp3pbp/n2p1np1/2pP4/4P3/2N5/PP1NBPPP/R1BQ1R1K b -' => {
			eco => 'A78',
			# TRANSLATORS: A78: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Re8 10. Nd2 Na6 11. Kh1
			variation => N__('Benoni: Classical, Main Line, 10. Nd2 Na6 11. Kh1'),
			moves => {
			},
		},
		'r1bqr1k1/pp3pbp/n2p1np1/2pP4/4P3/2N2P2/PP1NB1PP/R1BQ1RK1 b -' => {
			eco => 'A79',
			# TRANSLATORS: A79: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Re8 10. Nd2 Na6 11. f3
			variation => N__('Benoni: Classical, Main Line, 10. Nd2 Na6 11. f3'),
			moves => {
				'a6c7' => 1,
			},
		},
		'r1bqr1k1/ppn2pbp/3p1np1/2pP4/4P3/2N2P2/PP1NB1PP/R1BQ1RK1 w -' => {
			eco => 'A79',
			# TRANSLATORS: A79: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Re8 10. Nd2 Na6 11. f3 Nc7
			variation => N__('Benoni: Classical, Main Line, 10. Nd2 Na6 11. f3 Nc7'),
			moves => {
				'a2a4' => 1,
			},
		},
		'r1bqr1k1/ppn2pbp/3p1np1/2pP4/P3P3/2N2P2/1P1NB1PP/R1BQ1RK1 b -' => {
			eco => 'A79',
			# TRANSLATORS: A79: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Re8 10. Nd2 Na6 11. f3 Nc7 12. a4
			variation => N__('Benoni: Classical, Main Line, 10. Nd2 Na6 11. f3 Nc7 12. a4'),
			moves => {
				'b7b6' => 1,
				'f6d7' => 1,
			},
		},
		'r1bqr1k1/p1n2pbp/1p1p1np1/2pP4/P3P3/2N2P2/1P1NB1PP/R1BQ1RK1 w -' => {
			eco => 'A79',
			# TRANSLATORS: A79: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Re8 10. Nd2 Na6 11. f3 Nc7 12. a4 b6
			variation => N__('Benoni: Classical, Main Line, 10. Nd2 Na6 11. f3 Nc7 12. a4 b6'),
			moves => {
				'd2c4' => 1,
				'g1h1' => 1,
			},
		},
		'r1bqr1k1/p1n2pbp/1p1p1np1/2pP4/P1N1P3/2N2P2/1P2B1PP/R1BQ1RK1 b -' => {
			eco => 'A79',
			# TRANSLATORS: A79: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Re8 10. Nd2 Na6 11. f3 Nc7 12. a4 b6 13. Nc4
			variation => N__('Benoni: Classical, Main Line, 10. Nd2 Na6 11. f3 Nc7 12. a4 b6 13. Nc4'),
			moves => {
			},
		},
		'r1bqr1k1/p1n2pbp/1p1p1np1/2pP4/P3P3/2N2P2/1P1NB1PP/R1BQ1R1K b -' => {
			eco => 'A79',
			# TRANSLATORS: A79: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Re8 10. Nd2 Na6 11. f3 Nc7 12. a4 b6 13. Kh1
			variation => N__('Benoni: Classical, Main Line, 10. Nd2 Na6 11. f3 Nc7 12. a4 b6 13. Kh1'),
			moves => {
			},
		},
		'r1bqr1k1/ppnn1pbp/3p2p1/2pP4/P3P3/2N2P2/1P1NB1PP/R1BQ1RK1 w -' => {
			eco => 'A79',
			# TRANSLATORS: A79: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. O-O Re8 10. Nd2 Na6 11. f3 Nc7 12. a4 Nd7
			variation => N__('Benoni: Classical, Main Line, 10. Nd2 Na6 11. f3 Nc7 12. a4 Nd7'),
			moves => {
			},
		},
		'rnbqkbnr/ppppp1pp/8/5p2/3P4/8/PPP1PPPP/RNBQKBNR w KQkq' => {
			eco => 'A80a',
			# TRANSLATORS: A80a: 1. d4 f5
			variation => N__('Dutch'),
			moves => {
				'b1c3' => 1,
				'c1g5' => 1,
				'c2c4' => 1,
				'd1d3' => 1,
				'e2e4' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
				'g2g4' => 1,
				'h2h3' => 1,
			},
		},
		'rnbqkbnr/ppppp1pp/8/5p2/3P2P1/8/PPP1PP1P/RNBQKBNR b KQkq' => {
			eco => 'A80b',
			# TRANSLATORS: A80b: 1. d4 f5 2. g4
			variation => N__('Dutch: Krejcik Gambit'),
			moves => {
				'f5g4' => 1,
			},
		},
		'rnbqkbnr/ppppp1pp/8/8/3P2p1/8/PPP1PP1P/RNBQKBNR w KQkq' => {
			eco => 'A80b',
			# TRANSLATORS: A80b: 1. d4 f5 2. g4 fxg4
			variation => N__('Dutch: Krejcik Gambit Accepted'),
			moves => {
			},
		},
		'rnbqkbnr/ppppp1pp/8/5p2/3P4/7P/PPP1PPP1/RNBQKBNR b KQkq' => {
			eco => 'A80c',
			# TRANSLATORS: A80c: 1. d4 f5 2. h3
			variation => N__('Dutch: Korchnoi Attack'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/5p2/3P4/7P/PPP1PPP1/RNBQKBNR w KQkq' => {
			eco => 'A80c',
			# TRANSLATORS: A80c: 1. d4 f5 2. h3 Nf6
			variation => N__('Dutch: Korchnoi Attack'),
			moves => {
				'g2g4' => 1,
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/5p2/3P2P1/7P/PPP1PP2/RNBQKBNR b KQkq' => {
			eco => 'A80c',
			# TRANSLATORS: A80c: 1. d4 f5 2. h3 Nf6 3. g4
			variation => N__('Dutch: Korchnoi, Janzen Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/ppppp1pp/8/5pB1/3P4/8/PPP1PPPP/RN1QKBNR b KQkq' => {
			eco => 'A80d',
			# TRANSLATORS: A80d: 1. d4 f5 2. Bg5
			variation => N__('Dutch: 2. Bg5'),
			moves => {
				'c7c6' => 1,
				'd7d5' => 1,
				'g7g6' => 1,
				'g8f6' => 1,
				'h7h6' => 1,
			},
		},
		'rnbqkbnr/pp1pp1pp/2p5/5pB1/3P4/8/PPP1PPPP/RN1QKBNR w KQkq' => {
			eco => 'A80d',
			# TRANSLATORS: A80d: 1. d4 f5 2. Bg5 c6
			variation => N__('Dutch: 2. Bg5 c6'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1p1pp/8/3p1pB1/3P4/8/PPP1PPPP/RN1QKBNR w KQkq' => {
			eco => 'A80d',
			# TRANSLATORS: A80d: 1. d4 f5 2. Bg5 d5
			variation => N__('Dutch: 2. Bg5 d5'),
			moves => {
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/5pB1/3P4/8/PPP1PPPP/RN1QKBNR w KQkq' => {
			eco => 'A80e',
			# TRANSLATORS: A80e: 1. d4 f5 2. Bg5 Nf6
			variation => N__('Dutch: 2. Bg5 Nf6'),
			moves => {
			},
		},
		'rnbqkbnr/ppppp1p1/7p/5pB1/3P4/8/PPP1PPPP/RN1QKBNR w KQkq' => {
			eco => 'A80f',
			# TRANSLATORS: A80f: 1. d4 f5 2. Bg5 h6
			variation => N__('Dutch: 2. Bg5 h6'),
			moves => {
			},
		},
		'rnbqkbnr/ppppp2p/6p1/5pB1/3P4/8/PPP1PPPP/RN1QKBNR w KQkq' => {
			eco => 'A80g',
			# TRANSLATORS: A80g: 1. d4 f5 2. Bg5 g6
			variation => N__('Dutch: 2. Bg5 g6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkbnr/ppppp2p/6p1/5pB1/3P4/2N5/PPP1PPPP/R2QKBNR b KQkq' => {
			eco => 'A80h',
			# TRANSLATORS: A80h: 1. d4 f5 2. Bg5 g6 3. Nc3
			variation => N__('Dutch: 2. Bg5 g6 3. Nc3'),
			moves => {
			},
		},
		'rnbqkbnr/ppppp1pp/8/5p2/3P4/3Q4/PPP1PPPP/RNB1KBNR b KQkq' => {
			eco => 'A80i',
			# TRANSLATORS: A80i: 1. d4 f5 2. Qd3
			variation => N__('Dutch: Alapin'),
			moves => {
				'd7d6' => 1,
				'e7e6' => 1,
			},
		},
		'rnbqkbnr/ppp1p1pp/3p4/5p2/3P4/3Q4/PPP1PPPP/RNB1KBNR w KQkq' => {
			eco => 'A80i',
			# TRANSLATORS: A80i: 1. d4 f5 2. Qd3 d6
			variation => N__('Dutch: Alapin'),
			moves => {
				'g2g4' => 1,
			},
		},
		'rnbqkbnr/ppp1p1pp/3p4/5p2/3P2P1/3Q4/PPP1PP1P/RNB1KBNR b KQkq' => {
			eco => 'A80i',
			# TRANSLATORS: A80i: 1. d4 f5 2. Qd3 d6 3. g4
			variation => N__('Dutch: Alapin, Manhattan Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pppp2pp/4p3/5p2/3P4/3Q4/PPP1PPPP/RNB1KBNR w KQkq' => {
			eco => 'A80i',
			# TRANSLATORS: A80i: 1. d4 f5 2. Qd3 e6
			variation => N__('Dutch: Alapin'),
			moves => {
				'g2g4' => 1,
			},
		},
		'rnbqkbnr/pppp2pp/4p3/5p2/3P2P1/3Q4/PPP1PP1P/RNB1KBNR b KQkq' => {
			eco => 'A80i',
			# TRANSLATORS: A80i: 1. d4 f5 2. Qd3 e6 3. g4
			variation => N__('Dutch: Von Pretzel Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/ppppp1pp/8/5p2/3P4/2N5/PPP1PPPP/R1BQKBNR b KQkq' => {
			eco => 'A80j',
			# TRANSLATORS: A80j: 1. d4 f5 2. Nc3
			variation => N__('Dutch: 2. Nc3'),
			moves => {
				'd7d5' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/ppp1p1pp/8/3p1p2/3P4/2N5/PPP1PPPP/R1BQKBNR w KQkq' => {
			eco => 'A80k',
			# TRANSLATORS: A80k: 1. d4 f5 2. Nc3 d5
			variation => N__('Dutch: 2. Nc3 d5'),
			moves => {
				'c1g5' => 1,
				'e2e4' => 1,
			},
		},
		'rnbqkbnr/ppp1p1pp/8/3p1p2/3PP3/2N5/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'A80k',
			# TRANSLATORS: A80k: 1. d4 f5 2. Nc3 d5 3. e4
			variation => N__('Dutch: 2. Nc3 d5, Euwe Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1p1pp/8/3p1pB1/3P4/2N5/PPP1PPPP/R2QKBNR b KQkq' => {
			eco => 'A80l',
			# TRANSLATORS: A80l: 1. d4 f5 2. Nc3 d5 3. Bg5
			variation => N__('Dutch: 2. Nc3 d5 3. Bg5'),
			moves => {
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/5p2/3P4/2N5/PPP1PPPP/R1BQKBNR w KQkq' => {
			eco => 'A80m',
			# TRANSLATORS: A80m: 1. d4 f5 2. Nc3 Nf6
			variation => N__('Dutch: 2. Nc3 Nf6'),
			moves => {
				'c1g5' => 1,
				'g2g4' => 1,
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/5p2/3P2P1/2N5/PPP1PP1P/R1BQKBNR b KQkq' => {
			eco => 'A80m',
			# TRANSLATORS: A80m: 1. d4 f5 2. Nc3 Nf6 3. g4
			variation => N__('Dutch: Spielmann Gambit'),
			moves => {
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/5pB1/3P4/2N5/PPP1PPPP/R2QKBNR b KQkq' => {
			eco => 'A80n',
			# TRANSLATORS: A80n: 1. d4 f5 2. Nc3 Nf6 3. Bg5
			variation => N__('Dutch: 2. Nc3 Nf6 3. Bg5'),
			moves => {
				'd7d5' => 1,
				'e7e6' => 1,
			},
		},
		'rnbqkb1r/pppp2pp/4pn2/5pB1/3P4/2N5/PPP1PPPP/R2QKBNR w KQkq' => {
			eco => 'A80n',
			# TRANSLATORS: A80n: 1. d4 f5 2. Nc3 Nf6 3. Bg5 e6
			variation => N__('Dutch: 2. Nc3 Nf6 3. Bg5 e6'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1p1pp/5n2/3p1pB1/3P4/2N5/PPP1PPPP/R2QKBNR w KQkq' => {
			eco => 'A80o',
			# TRANSLATORS: A80o: 1. d4 f5 2. Nc3 Nf6 3. Bg5 d5
			variation => N__('Dutch: 2. Nc3 Nf6 3. Bg5 d5'),
			moves => {
				'g5f6' => 1,
			},
		},
		'rnbqkb1r/ppp1p1pp/5B2/3p1p2/3P4/2N5/PPP1PPPP/R2QKBNR b KQkq' => {
			eco => 'A80o',
			# TRANSLATORS: A80o: 1. d4 f5 2. Nc3 Nf6 3. Bg5 d5 4. Bxf6
			variation => N__('Dutch: 2. Nc3 Nf6 3. Bg5 d5'),
			moves => {
				'e7f6' => 1,
			},
		},
		'rnbqkb1r/ppp3pp/5p2/3p1p2/3P4/2N5/PPP1PPPP/R2QKBNR w KQkq' => {
			eco => 'A80p',
			# TRANSLATORS: A80p: 1. d4 f5 2. Nc3 Nf6 3. Bg5 d5 4. Bxf6 exf6
			variation => N__('Dutch: 2. Nc3 Nf6 3. Bg5 d5 4.Bxf6 exf6'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbqkb1r/ppp3pp/5p2/3p1p2/3P4/2N1P3/PPP2PPP/R2QKBNR b KQkq' => {
			eco => 'A80p',
			# TRANSLATORS: A80p: 1. d4 f5 2. Nc3 Nf6 3. Bg5 d5 4. Bxf6 exf6 5. e3
			variation => N__('Dutch: 2. Nc3 Nf6 3. Bg5 d5 4.Bxf6 exf6 5. e3'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rnbqkb1r/pp4pp/2p2p2/3p1p2/3P4/2N1P3/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'A80p',
			# TRANSLATORS: A80p: 1. d4 f5 2. Nc3 Nf6 3. Bg5 d5 4. Bxf6 exf6 5. e3 c6
			variation => N__('Dutch: 2. Nc3 Nf6 3. Bg5 d5 4.Bxf6 exf6 5. e3 c6'),
			moves => {
			},
		},
		'rnbqkbnr/ppppp1pp/8/5p2/3P4/5N2/PPP1PPPP/RNBQKB1R b KQkq' => {
			eco => 'A80q',
			# TRANSLATORS: A80q: 1. d4 f5 2. Nf3
			variation => N__('Dutch: 2. Nf3'),
			moves => {
				'e7e6' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/pppp2pp/4p3/5p2/3P4/5N2/PPP1PPPP/RNBQKB1R w KQkq' => {
			eco => 'A80r',
			# TRANSLATORS: A80r: 1. d4 f5 2. Nf3 e6
			variation => N__('Dutch: 2. Nf3 e6'),
			moves => {
				'd4d5' => 1,
			},
		},
		'rnbqkbnr/pppp2pp/4p3/3P1p2/8/5N2/PPP1PPPP/RNBQKB1R b KQkq' => {
			eco => 'A80s',
			# TRANSLATORS: A80s: 1. d4 f5 2. Nf3 e6 3. d5
			variation => N__('Dutch: 2. Nf3 e6 3. d5'),
			moves => {
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/5p2/3P4/5N2/PPP1PPPP/RNBQKB1R w KQkq' => {
			eco => 'A80t',
			# TRANSLATORS: A80t: 1. d4 f5 2. Nf3 Nf6
			variation => N__('Dutch: 2. Nf3 Nf6'),
			moves => {
				'c1g5' => 1,
				'c2c3' => 1,
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/5p2/3P4/2P2N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'A80u',
			# TRANSLATORS: A80u: 1. d4 f5 2. Nf3 Nf6 3. c3
			variation => N__('Dutch: Barcza System'),
			moves => {
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/5pB1/3P4/5N2/PPP1PPPP/RN1QKB1R b KQkq' => {
			eco => 'A80v',
			# TRANSLATORS: A80v: 1. d4 f5 2. Nf3 Nf6 3. Bg5
			variation => N__('Dutch: 2. Nf3 Nf6 3. Bg5'),
			moves => {
			},
		},
		'rnbqkbnr/ppppp1pp/8/5p2/3P4/6P1/PPP1PP1P/RNBQKBNR b KQkq' => {
			eco => 'A81',
			# TRANSLATORS: A81: 1. d4 f5 2. g3
			variation => N__('Dutch: 2. g3'),
			moves => {
				'e7e6' => 1,
				'g7g6' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/pppp2pp/4p3/5p2/3P4/6P1/PPP1PP1P/RNBQKBNR w KQkq' => {
			eco => 'A81',
			# TRANSLATORS: A81: 1. d4 f5 2. g3 e6
			variation => N__('Dutch: 2. g3 e6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pppp2pp/4p3/5p2/3P4/5NP1/PPP1PP1P/RNBQKB1R b KQkq' => {
			eco => 'A81',
			# TRANSLATORS: A81: 1. d4 f5 2. g3 e6 3. Nf3
			variation => N__('Dutch: 2. g3 e6 3. Nf3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/pppp2pp/4pn2/5p2/3P4/5NP1/PPP1PP1P/RNBQKB1R w KQkq' => {
			eco => 'A81',
			# TRANSLATORS: A81: 1. d4 f5 2. g3 e6 3. Nf3 Nf6
			variation => N__('Dutch: 2. g3 e6 3. Nf3 Nf6'),
			moves => {
			},
		},
		'rnbqkbnr/ppppp2p/6p1/5p2/3P4/6P1/PPP1PP1P/RNBQKBNR w KQkq' => {
			eco => 'A81',
			# TRANSLATORS: A81: 1. d4 f5 2. g3 g6
			variation => N__('Dutch: 2. g3'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkbnr/ppppp2p/6p1/5p2/3P4/6P1/PPP1PPBP/RNBQK1NR b KQkq' => {
			eco => 'A81',
			# TRANSLATORS: A81: 1. d4 f5 2. g3 g6 3. Bg2
			variation => N__('Dutch: 2. g3'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk1nr/ppppp1bp/6p1/5p2/3P4/6P1/PPP1PPBP/RNBQK1NR w KQkq' => {
			eco => 'A81',
			# TRANSLATORS: A81: 1. d4 f5 2. g3 g6 3. Bg2 Bg7
			variation => N__('Dutch: 2. g3'),
			moves => {
				'g1f3' => 1,
				'g1h3' => 1,
			},
		},
		'rnbqk1nr/ppppp1bp/6p1/5p2/3P4/5NP1/PPP1PPBP/RNBQK2R b KQkq' => {
			eco => 'A81',
			# TRANSLATORS: A81: 1. d4 f5 2. g3 g6 3. Bg2 Bg7 4. Nf3
			variation => N__('Dutch: 2. g3'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rnbqk1nr/pp1pp1bp/2p3p1/5p2/3P4/5NP1/PPP1PPBP/RNBQK2R w KQkq' => {
			eco => 'A81',
			# TRANSLATORS: A81: 1. d4 f5 2. g3 g6 3. Bg2 Bg7 4. Nf3 c6
			variation => N__('Dutch: 2. g3'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbqk1nr/pp1pp1bp/2p3p1/5p2/3P4/5NP1/PPP1PPBP/RNBQ1RK1 b kq' => {
			eco => 'A81',
			# TRANSLATORS: A81: 1. d4 f5 2. g3 g6 3. Bg2 Bg7 4. Nf3 c6 5. O-O
			variation => N__('Dutch: 2. g3'),
			moves => {
				'g8h6' => 1,
			},
		},
		'rnbqk2r/pp1pp1bp/2p3pn/5p2/3P4/5NP1/PPP1PPBP/RNBQ1RK1 w kq' => {
			eco => 'A81',
			# TRANSLATORS: A81: 1. d4 f5 2. g3 g6 3. Bg2 Bg7 4. Nf3 c6 5. O-O Nh6
			variation => N__('Dutch: Leningrad, Basman Variation'),
			moves => {
			},
		},
		'rnbqk1nr/ppppp1bp/6p1/5p2/3P4/6PN/PPP1PPBP/RNBQK2R b KQkq' => {
			eco => 'A81',
			# TRANSLATORS: A81: 1. d4 f5 2. g3 g6 3. Bg2 Bg7 4. Nh3
			variation => N__('Dutch: Leningrad, Carlsbad Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/5p2/3P4/6P1/PPP1PP1P/RNBQKBNR w KQkq' => {
			eco => 'A81',
			# TRANSLATORS: A81: 1. d4 f5 2. g3 Nf6
			variation => N__('Dutch: 2. g3 Nf6'),
			moves => {
				'f1g2' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/5p2/3P4/6P1/PPP1PPBP/RNBQK1NR b KQkq' => {
			eco => 'A81',
			# TRANSLATORS: A81: 1. d4 f5 2. g3 Nf6 3. Bg2
			variation => N__('Dutch: 2. g3 Nf6 3. Bg2'),
			moves => {
				'e7e6' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/pppp2pp/4pn2/5p2/3P4/6P1/PPP1PPBP/RNBQK1NR w KQkq' => {
			eco => 'A81',
			# TRANSLATORS: A81: 1. d4 f5 2. g3 Nf6 3. Bg2 e6
			variation => N__('Dutch: 2. g3 Nf6 3. Bg2 e6'),
			moves => {
				'g1h3' => 1,
			},
		},
		'rnbqkb1r/pppp2pp/4pn2/5p2/3P4/6PN/PPP1PPBP/RNBQK2R b KQkq' => {
			eco => 'A81',
			# TRANSLATORS: A81: 1. d4 f5 2. g3 Nf6 3. Bg2 e6 4. Nh3
			variation => N__('Dutch: Blackburne Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppppp2p/5np1/5p2/3P4/6P1/PPP1PPBP/RNBQK1NR w KQkq' => {
			eco => 'A81',
			# TRANSLATORS: A81: 1. d4 f5 2. g3 Nf6 3. Bg2 g6
			variation => N__('Dutch: 2. g3 Nf6 3. Bg2 g6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/ppppp2p/5np1/5p2/3P4/5NP1/PPP1PPBP/RNBQK2R b KQkq' => {
			eco => 'A81',
			# TRANSLATORS: A81: 1. d4 f5 2. g3 Nf6 3. Bg2 g6 4. Nf3
			variation => N__('Dutch: 2. g3 Nf6 3. Bg2 g6 4. Nf3'),
			moves => {
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/5p2/3P4/5NP1/PPP1PP1P/RNBQKB1R b KQkq' => {
			eco => 'A81',
			# TRANSLATORS: A81: 1. d4 f5 2. g3 Nf6 3. Nf3
			variation => N__('Dutch: 2. g3 Nf6 3. Nf3'),
			moves => {
			},
		},
		'rnbqkbnr/ppppp1pp/8/5p2/3PP3/8/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'A82',
			# TRANSLATORS: A82: 1. d4 f5 2. e4
			variation => N__('Dutch: Staunton Gambit'),
			moves => {
				'd7d6' => 1,
				'f5e4' => 1,
			},
		},
		'rnbqkbnr/ppp1p1pp/3p4/5p2/3PP3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'A82',
			# TRANSLATORS: A82: 1. d4 f5 2. e4 d6
			variation => N__('Dutch: Staunton Gambit, Balogh Defence'),
			moves => {
			},
		},
		'rnbqkbnr/ppppp1pp/8/8/3Pp3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'A82',
			# TRANSLATORS: A82: 1. d4 f5 2. e4 fxe4
			variation => N__('Dutch: Staunton Gambit Accepted'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkbnr/ppppp1pp/8/8/3Pp3/2N5/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'A82',
			# TRANSLATORS: A82: 1. d4 f5 2. e4 fxe4 3. Nc3
			variation => N__('Dutch: Staunton Gambit, 3. Nc3'),
			moves => {
				'e7e6' => 1,
				'g7g6' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/pppp2pp/4p3/8/3Pp3/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'A82',
			# TRANSLATORS: A82: 1. d4 f5 2. e4 fxe4 3. Nc3 e6
			variation => N__('Dutch: Staunton Gambit, 3. Nc3 e6'),
			moves => {
			},
		},
		'rnbqkbnr/ppppp2p/6p1/8/3Pp3/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'A82',
			# TRANSLATORS: A82: 1. d4 f5 2. e4 fxe4 3. Nc3 g6
			variation => N__('Dutch: Staunton Gambit, 3. Nc3 g6'),
			moves => {
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/8/3Pp3/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'A82',
			# TRANSLATORS: A82: 1. d4 f5 2. e4 fxe4 3. Nc3 Nf6
			variation => N__('Dutch: Staunton Gambit, 3. Nc3 Nf6'),
			moves => {
				'c1g5' => 1,
				'f2f3' => 1,
				'g2g4' => 1,
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/8/3Pp3/2N2P2/PPP3PP/R1BQKBNR b KQkq' => {
			eco => 'A82',
			# TRANSLATORS: A82: 1. d4 f5 2. e4 fxe4 3. Nc3 Nf6 4. f3
			variation => N__('Dutch: Staunton Gambit, 4. f3'),
			moves => {
				'b8c6' => 1,
				'd7d5' => 1,
				'e4f3' => 1,
				'e7e6' => 1,
			},
		},
		'r1bqkb1r/ppppp1pp/2n2n2/8/3Pp3/2N2P2/PPP3PP/R1BQKBNR w KQkq' => {
			eco => 'A82',
			# TRANSLATORS: A82: 1. d4 f5 2. e4 fxe4 3. Nc3 Nf6 4. f3 Nc6
			variation => N__('Dutch: Staunton Gambit, 4. f3 Nc6'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1p1pp/5n2/3p4/3Pp3/2N2P2/PPP3PP/R1BQKBNR w KQkq' => {
			eco => 'A82',
			# TRANSLATORS: A82: 1. d4 f5 2. e4 fxe4 3. Nc3 Nf6 4. f3 d5
			variation => N__('Dutch: Staunton Gambit, 4. f3 d5'),
			moves => {
				'f3e4' => 1,
			},
		},
		'rnbqkb1r/ppp1p1pp/5n2/3p4/3PP3/2N5/PPP3PP/R1BQKBNR b KQkq' => {
			eco => 'A82',
			# TRANSLATORS: A82: 1. d4 f5 2. e4 fxe4 3. Nc3 Nf6 4. f3 d5 5. fxe4
			variation => N__('Dutch: Staunton Gambit, 4. f3 d5 5.fxe4'),
			moves => {
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/8/3P4/2N2p2/PPP3PP/R1BQKBNR w KQkq' => {
			eco => 'A82',
			# TRANSLATORS: A82: 1. d4 f5 2. e4 fxe4 3. Nc3 Nf6 4. f3 exf3
			variation => N__('Dutch: Staunton Gambit, 4. f3 exf3'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/8/3P4/2N2N2/PPP3PP/R1BQKB1R b KQkq' => {
			eco => 'A82',
			# TRANSLATORS: A82: 1. d4 f5 2. e4 fxe4 3. Nc3 Nf6 4. f3 exf3 5. Nxf3
			variation => N__('Dutch: Staunton Gambit, 4. f3 exf3 5.Nxf3'),
			moves => {
			},
		},
		'rnbqkb1r/pppp2pp/4pn2/8/3Pp3/2N2P2/PPP3PP/R1BQKBNR w KQkq' => {
			eco => 'A82',
			# TRANSLATORS: A82: 1. d4 f5 2. e4 fxe4 3. Nc3 Nf6 4. f3 e6
			variation => N__('Dutch: Staunton Gambit, 4. f3 e6'),
			moves => {
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/8/3Pp1P1/2N5/PPP2P1P/R1BQKBNR b KQkq' => {
			eco => 'A82',
			# TRANSLATORS: A82: 1. d4 f5 2. e4 fxe4 3. Nc3 Nf6 4. g4
			variation => N__('Dutch: Staunton Gambit, Tartakower Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/6B1/3Pp3/2N5/PPP2PPP/R2QKBNR b KQkq' => {
			eco => 'A83a',
			# TRANSLATORS: A83a: 1. d4 f5 2. e4 fxe4 3. Nc3 Nf6 4. Bg5
			variation => N__('Dutch: Staunton Gambit, Staunton Variation'),
			moves => {
				'b7b6' => 1,
				'b8c6' => 1,
				'c7c6' => 1,
				'e7e6' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/p1ppp1pp/1p3n2/6B1/3Pp3/2N5/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'A83b',
			# TRANSLATORS: A83b: 1. d4 f5 2. e4 fxe4 3. Nc3 Nf6 4. Bg5 b6
			variation => N__('Dutch: Staunton Gambit, Nimzowitsch Variation'),
			moves => {
			},
		},
		'rnbqkb1r/pp1pp1pp/2p2n2/6B1/3Pp3/2N5/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'A83c',
			# TRANSLATORS: A83c: 1. d4 f5 2. e4 fxe4 3. Nc3 Nf6 4. Bg5 c6
			variation => N__('Dutch: Staunton Gambit, Chigorin Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppppp2p/5np1/6B1/3Pp3/2N5/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'A83d',
			# TRANSLATORS: A83d: 1. d4 f5 2. e4 fxe4 3. Nc3 Nf6 4. Bg5 g6
			variation => N__('Dutch: Staunton Gambit, 4. Bg5 g6'),
			moves => {
				'f2f3' => 1,
				'h2h4' => 1,
			},
		},
		'rnbqkb1r/ppppp2p/5np1/6B1/3Pp2P/2N5/PPP2PP1/R2QKBNR b KQkq' => {
			eco => 'A83e',
			# TRANSLATORS: A83e: 1. d4 f5 2. e4 fxe4 3. Nc3 Nf6 4. Bg5 g6 5. h4
			variation => N__('Dutch: Staunton Gambit, Alekhine Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppppp2p/5np1/6B1/3Pp3/2N2P2/PPP3PP/R2QKBNR b KQkq' => {
			eco => 'A83f',
			# TRANSLATORS: A83f: 1. d4 f5 2. e4 fxe4 3. Nc3 Nf6 4. Bg5 g6 5. f3
			variation => N__('Dutch: Staunton Gambit, Lasker Variation'),
			moves => {
			},
		},
		'rnbqkb1r/pppp2pp/4pn2/6B1/3Pp3/2N5/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'A83g',
			# TRANSLATORS: A83g: 1. d4 f5 2. e4 fxe4 3. Nc3 Nf6 4. Bg5 e6
			variation => N__('Dutch: Staunton Gambit, 4. Bg5 e6'),
			moves => {
				'c3e4' => 1,
			},
		},
		'rnbqkb1r/pppp2pp/4pn2/6B1/3PN3/8/PPP2PPP/R2QKBNR b KQkq' => {
			eco => 'A83h',
			# TRANSLATORS: A83h: 1. d4 f5 2. e4 fxe4 3. Nc3 Nf6 4. Bg5 e6 5. Nxe4
			variation => N__('Dutch: Staunton Gambit, 4. Bg5 e6 5.Nxe4'),
			moves => {
				'f8e7' => 1,
			},
		},
		'rnbqk2r/ppppb1pp/4pn2/6B1/3PN3/8/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'A83h',
			# TRANSLATORS: A83h: 1. d4 f5 2. e4 fxe4 3. Nc3 Nf6 4. Bg5 e6 5. Nxe4 Be7
			variation => N__('Dutch: Staunton Gambit, 4. Bg5 e6 5.Nxe4'),
			moves => {
				'g5f6' => 1,
			},
		},
		'rnbqk2r/ppppb1pp/4pB2/8/3PN3/8/PPP2PPP/R2QKBNR b KQkq' => {
			eco => 'A83h',
			# TRANSLATORS: A83h: 1. d4 f5 2. e4 fxe4 3. Nc3 Nf6 4. Bg5 e6 5. Nxe4 Be7 6. Bxf6
			variation => N__('Dutch: Staunton Gambit, 4. Bg5 e6 5.Nxe4'),
			moves => {
				'e7f6' => 1,
			},
		},
		'rnbqk2r/pppp2pp/4pb2/8/3PN3/8/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'A83h',
			# TRANSLATORS: A83h: 1. d4 f5 2. e4 fxe4 3. Nc3 Nf6 4. Bg5 e6 5. Nxe4 Be7 6. Bxf6 Bxf6
			variation => N__('Dutch: Staunton Gambit, 4. Bg5 e6 5.Nxe4'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqk2r/pppp2pp/4pb2/8/3PN3/5N2/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'A83i',
			# TRANSLATORS: A83i: 1. d4 f5 2. e4 fxe4 3. Nc3 Nf6 4. Bg5 e6 5. Nxe4 Be7 6. Bxf6 Bxf6 7. Nf3
			variation => N__('Dutch: Staunton Gambit, 4. Bg5 e6 5.Nxe4'),
			moves => {
			},
		},
		'r1bqkb1r/ppppp1pp/2n2n2/6B1/3Pp3/2N5/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'A83j',
			# TRANSLATORS: A83j: 1. d4 f5 2. e4 fxe4 3. Nc3 Nf6 4. Bg5 Nc6
			variation => N__('Dutch: Staunton Gambit, 4. Bg5 Nc6'),
			moves => {
				'd4d5' => 1,
				'f2f3' => 1,
			},
		},
		'r1bqkb1r/ppppp1pp/2n2n2/6B1/3Pp3/2N2P2/PPP3PP/R2QKBNR b KQkq' => {
			eco => 'A83k',
			# TRANSLATORS: A83k: 1. d4 f5 2. e4 fxe4 3. Nc3 Nf6 4. Bg5 Nc6 5. f3
			variation => N__('Dutch: Staunton Gambit, 4. Bg5 Nc6 5. f3'),
			moves => {
			},
		},
		'r1bqkb1r/ppppp1pp/2n2n2/3P2B1/4p3/2N5/PPP2PPP/R2QKBNR b KQkq' => {
			eco => 'A83l',
			# TRANSLATORS: A83l: 1. d4 f5 2. e4 fxe4 3. Nc3 Nf6 4. Bg5 Nc6 5. d5
			variation => N__('Dutch: Staunton Gambit, 4. Bg5 Nc6 5. d5'),
			moves => {
				'c6e5' => 1,
			},
		},
		'r1bqkb1r/ppppp1pp/5n2/3Pn1B1/4p3/2N5/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'A83l',
			# TRANSLATORS: A83l: 1. d4 f5 2. e4 fxe4 3. Nc3 Nf6 4. Bg5 Nc6 5. d5 Ne5
			variation => N__('Dutch: Staunton Gambit, 4. Bg5 Nc6 5. d5'),
			moves => {
				'd1d4' => 1,
			},
		},
		'r1bqkb1r/ppppp1pp/5n2/3Pn1B1/3Qp3/2N5/PPP2PPP/R3KBNR b KQkq' => {
			eco => 'A83m',
			# TRANSLATORS: A83m: 1. d4 f5 2. e4 fxe4 3. Nc3 Nf6 4. Bg5 Nc6 5. d5 Ne5 6. Qd4
			variation => N__('Dutch: Staunton Gambit, 4. Bg5 Nc6 5. d5 Ne5 6. Qd4'),
			moves => {
			},
		},
		'rnbqkbnr/ppppp1pp/8/5p2/2PP4/8/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'A84',
			# TRANSLATORS: A84: 1. d4 f5 2. c4
			variation => N__('Dutch: 2. c4'),
			moves => {
				'd7d6' => 1,
				'e7e6' => 1,
				'g7g6' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/ppp1p1pp/3p4/5p2/2PP4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A84',
			# TRANSLATORS: A84: 1. d4 f5 2. c4 d6
			variation => N__('Dutch: 2. c4 d6'),
			moves => {
			},
		},
		'rnbqkbnr/pppp2pp/4p3/5p2/2PP4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A84',
			# TRANSLATORS: A84: 1. d4 f5 2. c4 e6
			variation => N__('Dutch: 2. c4 e6'),
			moves => {
				'b1c3' => 1,
				'e2e4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pppp2pp/4p3/5p2/2PP4/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'A84',
			# TRANSLATORS: A84: 1. d4 f5 2. c4 e6 3. Nc3
			variation => N__('Dutch: Rubinstein Variation'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqkbnr/ppp3pp/4p3/3p1p2/2PP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'A84',
			# TRANSLATORS: A84: 1. d4 f5 2. c4 e6 3. Nc3 d5
			variation => N__('Dutch: Rubinstein, 3... d5'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbqkbnr/ppp3pp/4p3/3p1p2/2PP4/2N1P3/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'A84',
			# TRANSLATORS: A84: 1. d4 f5 2. c4 e6 3. Nc3 d5 4. e3
			variation => N__('Dutch: Rubinstein, 3... d5'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rnbqkbnr/pp4pp/2p1p3/3p1p2/2PP4/2N1P3/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'A84',
			# TRANSLATORS: A84: 1. d4 f5 2. c4 e6 3. Nc3 d5 4. e3 c6
			variation => N__('Dutch: Rubinstein, 3... d5 4. e3 c6'),
			moves => {
			},
		},
		'rnbqkbnr/pppp2pp/4p3/5p2/2PPP3/8/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'A84',
			# TRANSLATORS: A84: 1. d4 f5 2. c4 e6 3. e4
			variation => N__('Dutch: Staunton Gambit Deferred'),
			moves => {
			},
		},
		'rnbqkbnr/pppp2pp/4p3/5p2/2PP4/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'A84',
			# TRANSLATORS: A84: 1. d4 f5 2. c4 e6 3. Nf3
			variation => N__('Dutch: 2. c4 e6 3. Nf3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/pppp2pp/4pn2/5p2/2PP4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'A84',
			# TRANSLATORS: A84: 1. d4 f5 2. c4 e6 3. Nf3 Nf6
			variation => N__('Dutch: 2. c4 e6 3. Nf3 Nf6'),
			moves => {
			},
		},
		'rnbqkbnr/ppppp2p/6p1/5p2/2PP4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A84',
			# TRANSLATORS: A84: 1. d4 f5 2. c4 g6
			variation => N__('Dutch: 2. c4 g6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkbnr/ppppp2p/6p1/5p2/2PP4/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'A84',
			# TRANSLATORS: A84: 1. d4 f5 2. c4 g6 3. Nc3
			variation => N__('Dutch: 2. c4 g6'),
			moves => {
				'g8h6' => 1,
			},
		},
		'rnbqkb1r/ppppp2p/6pn/5p2/2PP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'A84',
			# TRANSLATORS: A84: 1. d4 f5 2. c4 g6 3. Nc3 Nh6
			variation => N__('Dutch: Bladel Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/5p2/2PP4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'A84',
			# TRANSLATORS: A84: 1. d4 f5 2. c4 Nf6
			variation => N__('Dutch: 2. c4 Nf6'),
			moves => {
				'b1c3' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/5p2/2PP4/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'A84',
			# TRANSLATORS: A84: 1. d4 f5 2. c4 Nf6 3. Nf3
			variation => N__('Dutch: 2. c4 Nf6'),
			moves => {
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/5p2/2PP4/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'A85',
			# TRANSLATORS: A85: 1. d4 f5 2. c4 Nf6 3. Nc3
			variation => N__('Dutch: 2. c4 Nf6 3. Nc3'),
			moves => {
				'd7d6' => 1,
				'e7e6' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/ppp1p1pp/3p1n2/5p2/2PP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'A85',
			# TRANSLATORS: A85: 1. d4 f5 2. c4 Nf6 3. Nc3 d6
			variation => N__('Dutch: 2. c4 Nf6 3. Nc3 d6'),
			moves => {
			},
		},
		'rnbqkb1r/pppp2pp/4pn2/5p2/2PP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'A85',
			# TRANSLATORS: A85: 1. d4 f5 2. c4 Nf6 3. Nc3 e6
			variation => N__('Dutch: 2. c4 Nf6 3. Nc3 e6'),
			moves => {
				'a2a3' => 1,
				'c1g5' => 1,
				'd1c2' => 1,
				'e2e3' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/pppp2pp/4pn2/5p2/2PP4/P1N5/1P2PPPP/R1BQKBNR b KQkq' => {
			eco => 'A85',
			# TRANSLATORS: A85: 1. d4 f5 2. c4 Nf6 3. Nc3 e6 4. a3
			variation => N__('Dutch: 2. c4 Nf6 3. Nc3 e6 4. a3'),
			moves => {
			},
		},
		'rnbqkb1r/pppp2pp/4pn2/5pB1/2PP4/2N5/PP2PPPP/R2QKBNR b KQkq' => {
			eco => 'A85',
			# TRANSLATORS: A85: 1. d4 f5 2. c4 Nf6 3. Nc3 e6 4. Bg5
			variation => N__('Dutch: 2. c4 Nf6 3. Nc3 e6 4. Bg5'),
			moves => {
			},
		},
		'rnbqkb1r/pppp2pp/4pn2/5p2/2PP4/2N5/PPQ1PPPP/R1B1KBNR b KQkq' => {
			eco => 'A85',
			# TRANSLATORS: A85: 1. d4 f5 2. c4 Nf6 3. Nc3 e6 4. Qc2
			variation => N__('Dutch: 2. c4 Nf6 3. Nc3 e6 4. Qc2'),
			moves => {
			},
		},
		'rnbqkb1r/pppp2pp/4pn2/5p2/2PP4/2N1P3/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'A85',
			# TRANSLATORS: A85: 1. d4 f5 2. c4 Nf6 3. Nc3 e6 4. e3
			variation => N__('Dutch: 2. c4 Nf6 3. Nc3 e6 4. e3'),
			moves => {
				'd7d5' => 1,
				'f8b4' => 1,
			},
		},
		'rnbqkb1r/ppp3pp/4pn2/3p1p2/2PP4/2N1P3/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'A85',
			# TRANSLATORS: A85: 1. d4 f5 2. c4 Nf6 3. Nc3 e6 4. e3 d5
			variation => N__('Dutch: 2. c4 Nf6 3. Nc3 e6 4. e3 d5'),
			moves => {
			},
		},
		'rnbqk2r/pppp2pp/4pn2/5p2/1bPP4/2N1P3/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'A85',
			# TRANSLATORS: A85: 1. d4 f5 2. c4 Nf6 3. Nc3 e6 4. e3 Bb4
			variation => N__('Dutch: 2. c4 Nf6 3. Nc3 e6 4. e3 Bb4'),
			moves => {
			},
		},
		'rnbqkb1r/pppp2pp/4pn2/5p2/2PP4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'A85',
			# TRANSLATORS: A85: 1. d4 f5 2. c4 Nf6 3. Nc3 e6 4. Nf3
			variation => N__('Dutch: 2. c4 Nf6 3. Nc3 e6 4. Nf3'),
			moves => {
			},
		},
		'rnbqkb1r/ppppp2p/5np1/5p2/2PP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'A85',
			# TRANSLATORS: A85: 1. d4 f5 2. c4 Nf6 3. Nc3 g6
			variation => N__('Dutch: 2. c4 Nf6 3. Nc3 g6'),
			moves => {
				'c1g5' => 1,
				'f2f3' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/ppppp2p/5np1/5pB1/2PP4/2N5/PP2PPPP/R2QKBNR b KQkq' => {
			eco => 'A85',
			# TRANSLATORS: A85: 1. d4 f5 2. c4 Nf6 3. Nc3 g6 4. Bg5
			variation => N__('Dutch: 2. c4 Nf6 3. Nc3 g6 4. Bg5'),
			moves => {
			},
		},
		'rnbqkb1r/ppppp2p/5np1/5p2/2PP4/2N2P2/PP2P1PP/R1BQKBNR b KQkq' => {
			eco => 'A85',
			# TRANSLATORS: A85: 1. d4 f5 2. c4 Nf6 3. Nc3 g6 4. f3
			variation => N__('Dutch: 2. c4 Nf6 3. Nc3 g6 4. f3'),
			moves => {
			},
		},
		'rnbqkb1r/ppppp2p/5np1/5p2/2PP4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'A85',
			# TRANSLATORS: A85: 1. d4 f5 2. c4 Nf6 3. Nc3 g6 4. Nf3
			variation => N__('Dutch: 2. c4 Nf6 3. Nc3 g6 4. Nf3'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppppp1bp/5np1/5p2/2PP4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'A85',
			# TRANSLATORS: A85: 1. d4 f5 2. c4 Nf6 3. Nc3 g6 4. Nf3 Bg7
			variation => N__('Dutch: 2. c4 Nf6 3. Nc3 g6 4. Nf3 Bg7'),
			moves => {
				'c1f4' => 1,
				'c1g5' => 1,
				'e2e3' => 1,
			},
		},
		'rnbqk2r/ppppp1bp/5np1/5p2/2PP1B2/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'A85',
			# TRANSLATORS: A85: 1. d4 f5 2. c4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. Bf4
			variation => N__('Dutch: 2. c4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. Bf4'),
			moves => {
			},
		},
		'rnbqk2r/ppppp1bp/5np1/5pB1/2PP4/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'A85',
			# TRANSLATORS: A85: 1. d4 f5 2. c4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. Bg5
			variation => N__('Dutch: 2. c4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. Bg5'),
			moves => {
			},
		},
		'rnbqk2r/ppppp1bp/5np1/5p2/2PP4/2N1PN2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'A85',
			# TRANSLATORS: A85: 1. d4 f5 2. c4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. e3
			variation => N__('Dutch: 2. c4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. e3'),
			moves => {
			},
		},
		'rnbqkb1r/ppppp1pp/5n2/5p2/2PP4/6P1/PP2PP1P/RNBQKBNR b KQkq' => {
			eco => 'A86',
			# TRANSLATORS: A86: 1. d4 f5 2. c4 Nf6 3. g3
			variation => N__('Dutch: 2. c4 Nf6 3. g3'),
			moves => {
				'd7d6' => 1,
				'e7e6' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/ppp1p1pp/3p1n2/5p2/2PP4/6P1/PP2PP1P/RNBQKBNR w KQkq' => {
			eco => 'A86',
			# TRANSLATORS: A86: 1. d4 f5 2. c4 Nf6 3. g3 d6
			variation => N__('Dutch: 2. c4 Nf6 3. g3 d6'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkb1r/ppp1p1pp/3p1n2/5p2/2PP4/6P1/PP2PPBP/RNBQK1NR b KQkq' => {
			eco => 'A86',
			# TRANSLATORS: A86: 1. d4 f5 2. c4 Nf6 3. g3 d6 4. Bg2
			variation => N__('Dutch: 2. c4 Nf6 3. g3 d6'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rnbqkb1r/pp2p1pp/2pp1n2/5p2/2PP4/6P1/PP2PPBP/RNBQK1NR w KQkq' => {
			eco => 'A86',
			# TRANSLATORS: A86: 1. d4 f5 2. c4 Nf6 3. g3 d6 4. Bg2 c6
			variation => N__('Dutch: 2. c4 Nf6 3. g3 d6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkb1r/pp2p1pp/2pp1n2/5p2/2PP4/2N3P1/PP2PPBP/R1BQK1NR b KQkq' => {
			eco => 'A86',
			# TRANSLATORS: A86: 1. d4 f5 2. c4 Nf6 3. g3 d6 4. Bg2 c6 5. Nc3
			variation => N__('Dutch: 2. c4 Nf6 3. g3 d6'),
			moves => {
				'd8c7' => 1,
			},
		},
		'rnb1kb1r/ppq1p1pp/2pp1n2/5p2/2PP4/2N3P1/PP2PPBP/R1BQK1NR w KQkq' => {
			eco => 'A86',
			# TRANSLATORS: A86: 1. d4 f5 2. c4 Nf6 3. g3 d6 4. Bg2 c6 5. Nc3 Qc7
			variation => N__('Dutch: Hort-Antoshin System'),
			moves => {
			},
		},
		'rnbqkb1r/ppppp2p/5np1/5p2/2PP4/6P1/PP2PP1P/RNBQKBNR w KQkq' => {
			eco => 'A86',
			# TRANSLATORS: A86: 1. d4 f5 2. c4 Nf6 3. g3 g6
			variation => N__('Dutch: Leningrad Variation'),
			moves => {
				'b1c3' => 1,
				'f1g2' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/ppppp2p/5np1/5p2/2PP4/2N3P1/PP2PP1P/R1BQKBNR b KQkq' => {
			eco => 'A86',
			# TRANSLATORS: A86: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Nc3
			variation => N__('Dutch: Leningrad, 4. Nc3'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppppp1bp/5np1/5p2/2PP4/2N3P1/PP2PP1P/R1BQKBNR w KQkq' => {
			eco => 'A86',
			# TRANSLATORS: A86: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Nc3 Bg7
			variation => N__('Dutch: Leningrad, 4. Nc3 Bg7'),
			moves => {
			},
		},
		'rnbqkb1r/ppppp2p/5np1/5p2/2PP4/6P1/PP2PPBP/RNBQK1NR b KQkq' => {
			eco => 'A86',
			# TRANSLATORS: A86: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2
			variation => N__('Dutch: Leningrad, 4. Bg2'),
			moves => {
				'd7d6' => 1,
				'f8g7' => 1,
			},
		},
		'rnbqkb1r/ppp1p2p/3p1np1/5p2/2PP4/6P1/PP2PPBP/RNBQK1NR w KQkq' => {
			eco => 'A86',
			# TRANSLATORS: A86: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 d6
			variation => N__('Dutch: Leningrad, 4. Bg2 d6'),
			moves => {
			},
		},
		'rnbqk2r/ppppp1bp/5np1/5p2/2PP4/6P1/PP2PPBP/RNBQK1NR w KQkq' => {
			eco => 'A86',
			# TRANSLATORS: A86: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7
			variation => N__('Dutch: Leningrad, 4. Bg2 Bg7'),
			moves => {
				'b1c3' => 1,
				'g1f3' => 1,
				'g1h3' => 1,
			},
		},
		'rnbqk2r/ppppp1bp/5np1/5p2/2PP4/2N3P1/PP2PPBP/R1BQK1NR b KQkq' => {
			eco => 'A86',
			# TRANSLATORS: A86: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nc3
			variation => N__('Dutch: Leningrad, 4. Bg2 Bg7 5. Nc3'),
			moves => {
				'd7d6' => 1,
				'e8g8' => 1,
			},
		},
		'rnbqk2r/ppp1p1bp/3p1np1/5p2/2PP4/2N3P1/PP2PPBP/R1BQK1NR w KQkq' => {
			eco => 'A86',
			# TRANSLATORS: A86: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nc3 d6
			variation => N__('Dutch: Leningrad, 4. Bg2 Bg7 5. Nc3 d6'),
			moves => {
				'd4d5' => 1,
				'g1h3' => 1,
			},
		},
		'rnbqk2r/ppp1p1bp/3p1np1/3P1p2/2P5/2N3P1/PP2PPBP/R1BQK1NR b KQkq' => {
			eco => 'A86',
			# TRANSLATORS: A86: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nc3 d6 6. d5
			variation => N__('Dutch: Leningrad, 4. Bg2 Bg7 5. Nc3 d6 6. d5'),
			moves => {
			},
		},
		'rnbqk2r/ppp1p1bp/3p1np1/5p2/2PP4/2N3PN/PP2PPBP/R1BQK2R b KQkq' => {
			eco => 'A86',
			# TRANSLATORS: A86: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nc3 d6 6. Nh3
			variation => N__('Dutch: Leningrad, 4. Bg2 Bg7 5. Nc3 d6 6. Nh3'),
			moves => {
			},
		},
		'rnbq1rk1/ppppp1bp/5np1/5p2/2PP4/2N3P1/PP2PPBP/R1BQK1NR w KQ' => {
			eco => 'A86',
			# TRANSLATORS: A86: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nc3 O-O
			variation => N__('Dutch: Leningrad, 4. Bg2 Bg7 5. Nc3 O-O'),
			moves => {
				'g1h3' => 1,
			},
		},
		'rnbq1rk1/ppppp1bp/5np1/5p2/2PP4/2N3PN/PP2PPBP/R1BQK2R b KQ' => {
			eco => 'A86',
			# TRANSLATORS: A86: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nc3 O-O 6. Nh3
			variation => N__('Dutch: Leningrad, 4. Bg2 Bg7 5. Nc3 O-O 6. Nh3'),
			moves => {
			},
		},
		'rnbqk2r/ppppp1bp/5np1/5p2/2PP4/6PN/PP2PPBP/RNBQK2R b KQkq' => {
			eco => 'A86',
			# TRANSLATORS: A86: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nh3
			variation => N__('Dutch: Leningrad, 4. Bg2 Bg7 5. Nh3'),
			moves => {
			},
		},
		'rnbqkb1r/ppppp2p/5np1/5p2/2PP4/5NP1/PP2PP1P/RNBQKB1R b KQkq' => {
			eco => 'A86',
			# TRANSLATORS: A86: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Nf3
			variation => N__('Dutch: Leningrad, 4. Nf3'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppppp1bp/5np1/5p2/2PP4/5NP1/PP2PP1P/RNBQKB1R w KQkq' => {
			eco => 'A86',
			# TRANSLATORS: A86: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Nf3 Bg7
			variation => N__('Dutch: Leningrad, 4. Nf3 Bg7'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqk2r/ppppp1bp/5np1/5p2/2PP4/2N2NP1/PP2PP1P/R1BQKB1R b KQkq' => {
			eco => 'A86',
			# TRANSLATORS: A86: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Nf3 Bg7 5. Nc3
			variation => N__('Dutch: Leningrad, 4. Nf3 Bg7 5. Nc3'),
			moves => {
			},
		},
		'rnbqk2r/ppppp1bp/5np1/5p2/2PP4/5NP1/PP2PPBP/RNBQK2R b KQkq' => {
			eco => 'A87',
			# TRANSLATORS: A87: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3
			variation => N__('Dutch: Leningrad, Main Line'),
			moves => {
				'd7d6' => 1,
				'e8g8' => 1,
			},
		},
		'rnbqk2r/ppp1p1bp/3p1np1/5p2/2PP4/5NP1/PP2PPBP/RNBQK2R w KQkq' => {
			eco => 'A87',
			# TRANSLATORS: A87: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 d6
			variation => N__('Dutch: Leningrad, Main Line, 5... d6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqk2r/ppp1p1bp/3p1np1/5p2/2PP4/2N2NP1/PP2PPBP/R1BQK2R b KQkq' => {
			eco => 'A87',
			# TRANSLATORS: A87: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 d6 6. Nc3
			variation => N__('Dutch: Leningrad, Main Line, 5... d6 6. Nc3'),
			moves => {
			},
		},
		'rnbq1rk1/ppppp1bp/5np1/5p2/2PP4/5NP1/PP2PPBP/RNBQK2R w KQ' => {
			eco => 'A87',
			# TRANSLATORS: A87: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O
			variation => N__('Dutch: Leningrad, Main Line, 5...O-O'),
			moves => {
				'b1c3' => 1,
				'e1g1' => 1,
			},
		},
		'rnbq1rk1/ppppp1bp/5np1/5p2/2PP4/2N2NP1/PP2PPBP/R1BQK2R b KQ' => {
			eco => 'A87',
			# TRANSLATORS: A87: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. Nc3
			variation => N__('Dutch: Leningrad, Main Line, 6. Nc3'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rnbq1rk1/ppp1p1bp/3p1np1/5p2/2PP4/2N2NP1/PP2PPBP/R1BQK2R w KQ' => {
			eco => 'A87',
			# TRANSLATORS: A87: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. Nc3 d6
			variation => N__('Dutch: Leningrad, Main Line, 6. Nc3 d6'),
			moves => {
			},
		},
		'rnbq1rk1/ppppp1bp/5np1/5p2/2PP4/5NP1/PP2PPBP/RNBQ1RK1 b -' => {
			eco => 'A87',
			# TRANSLATORS: A87: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O
			variation => N__('Dutch: Leningrad, Main Line, 6.O-O'),
			moves => {
				'c7c6' => 1,
				'd7d6' => 1,
			},
		},
		'rnbq1rk1/pp1pp1bp/2p2np1/5p2/2PP4/5NP1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'A87',
			# TRANSLATORS: A87: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6
			variation => N__('Dutch: Leningrad, Main Line, 6... c6'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1p1bp/3p1np1/5p2/2PP4/5NP1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'A87',
			# TRANSLATORS: A87: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6
			variation => N__('Dutch: Leningrad, Main Line, 6... d6'),
			moves => {
				'b1c3' => 1,
				'b2b3' => 1,
				'd4d5' => 1,
			},
		},
		'rnbq1rk1/ppp1p1bp/3p1np1/5p2/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'A87',
			# TRANSLATORS: A87: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3'),
			moves => {
				'b8a6' => 1,
				'b8c6' => 1,
				'c7c6' => 1,
				'd8e8' => 1,
				'e7e6' => 1,
			},
		},
		'r1bq1rk1/ppp1p1bp/n2p1np1/5p2/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A87',
			# TRANSLATORS: A87: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 Na6
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 Na6'),
			moves => {
			},
		},
		'rnb1qrk1/ppp1p1bp/3p1np1/5p2/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A87',
			# TRANSLATORS: A87: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 Qe8
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 Qe8'),
			moves => {
				'b2b3' => 1,
				'c3d5' => 1,
				'd4d5' => 1,
				'f1e1' => 1,
			},
		},
		'rnb1qrk1/ppp1p1bp/3p1np1/5p2/2PP4/1PN2NP1/P3PPBP/R1BQ1RK1 b -' => {
			eco => 'A87',
			# TRANSLATORS: A87: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 Qe8 8. b3
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 Qe8 8. b3'),
			moves => {
			},
		},
		'rnb1qrk1/ppp1p1bp/3p1np1/3N1p2/2PP4/5NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'A87',
			# TRANSLATORS: A87: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 Qe8 8. Nd5
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 Qe8 8. Nd5'),
			moves => {
			},
		},
		'rnb1qrk1/ppp1p1bp/3p1np1/3P1p2/2P5/2N2NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'A87',
			# TRANSLATORS: A87: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 Qe8 8. d5
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 Qe8 8. d5'),
			moves => {
				'a7a5' => 1,
				'b8a6' => 1,
			},
		},
		'rnb1qrk1/1pp1p1bp/3p1np1/p2P1p2/2P5/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A87',
			# TRANSLATORS: A87: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 Qe8 8. d5 a5
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 Qe8 8. d5 a5'),
			moves => {
			},
		},
		'r1b1qrk1/ppp1p1bp/n2p1np1/3P1p2/2P5/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A87',
			# TRANSLATORS: A87: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 Qe8 8. d5 Na6
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 Qe8 8. d5 Na6'),
			moves => {
				'a1b1' => 1,
			},
		},
		'r1b1qrk1/ppp1p1bp/n2p1np1/3P1p2/2P5/2N2NP1/PP2PPBP/1RBQ1RK1 b -' => {
			eco => 'A87',
			# TRANSLATORS: A87: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 Qe8 8. d5 Na6 9. Rb1
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 Qe8 8. d5 Na6 9. Rb1'),
			moves => {
			},
		},
		'rnb1qrk1/ppp1p1bp/3p1np1/5p2/2PP4/2N2NP1/PP2PPBP/R1BQR1K1 b -' => {
			eco => 'A87',
			# TRANSLATORS: A87: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 Qe8 8. Re1
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 Qe8 8. Re1'),
			moves => {
			},
		},
		'rnbq1rk1/ppp3bp/3ppnp1/5p2/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A87',
			# TRANSLATORS: A87: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 e6
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 e6'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1p1bp/3p1np1/5p2/2PP4/1P3NP1/P3PPBP/RNBQ1RK1 b -' => {
			eco => 'A87',
			# TRANSLATORS: A87: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. b3
			variation => N__('Dutch: Leningrad, Main Line, 7. b3'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rnbq1rk1/pp2p1bp/2pp1np1/5p2/2PP4/1P3NP1/P3PPBP/RNBQ1RK1 w -' => {
			eco => 'A87',
			# TRANSLATORS: A87: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. b3 c6
			variation => N__('Dutch: Leningrad, Main Line, 7. b3 c6'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1p1bp/3p1np1/3P1p2/2P5/5NP1/PP2PPBP/RNBQ1RK1 b -' => {
			eco => 'A87',
			# TRANSLATORS: A87: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. d5
			variation => N__('Dutch: Leningrad, Main Line, 7. d5'),
			moves => {
				'c7c5' => 1,
				'c7c6' => 1,
			},
		},
		'rnbq1rk1/pp2p1bp/3p1np1/2pP1p2/2P5/5NP1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'A87',
			# TRANSLATORS: A87: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. d5 c5
			variation => N__('Dutch: Leningrad, Main Line, 7. d5 c5'),
			moves => {
			},
		},
		'rnbq1rk1/pp2p1bp/2pp1np1/3P1p2/2P5/5NP1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'A87',
			# TRANSLATORS: A87: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. d5 c6
			variation => N__('Dutch: Leningrad, Main Line, 7. d5 c6'),
			moves => {
			},
		},
		'rnbq1rk1/pp2p1bp/2pp1np1/5p2/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A88',
			# TRANSLATORS: A88: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 c6
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 c6'),
			moves => {
				'b2b3' => 1,
				'd1c2' => 1,
				'd4d5' => 1,
				'f1e1' => 1,
			},
		},
		'rnbq1rk1/pp2p1bp/2pp1np1/5p2/2PP4/1PN2NP1/P3PPBP/R1BQ1RK1 b -' => {
			eco => 'A88',
			# TRANSLATORS: A88: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 c6 8. b3
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 c6 8. b3'),
			moves => {
				'b8a6' => 1,
				'd8a5' => 1,
				'd8e8' => 1,
			},
		},
		'r1bq1rk1/pp2p1bp/n1pp1np1/5p2/2PP4/1PN2NP1/P3PPBP/R1BQ1RK1 w -' => {
			eco => 'A88',
			# TRANSLATORS: A88: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 c6 8. b3 Na6
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 c6 8. b3 Na6'),
			moves => {
			},
		},
		'rnb2rk1/pp2p1bp/2pp1np1/q4p2/2PP4/1PN2NP1/P3PPBP/R1BQ1RK1 w -' => {
			eco => 'A88',
			# TRANSLATORS: A88: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 c6 8. b3 Qa5
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 c6 8. b3 Qa5'),
			moves => {
			},
		},
		'rnb1qrk1/pp2p1bp/2pp1np1/5p2/2PP4/1PN2NP1/P3PPBP/R1BQ1RK1 w -' => {
			eco => 'A88',
			# TRANSLATORS: A88: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 c6 8. b3 Qe8
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 c6 8. b3 Qe8'),
			moves => {
			},
		},
		'rnbq1rk1/pp2p1bp/2pp1np1/5p2/2PP4/2N2NP1/PPQ1PPBP/R1B2RK1 b -' => {
			eco => 'A88',
			# TRANSLATORS: A88: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 c6 8. Qc2
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 c6 8. Qc2'),
			moves => {
			},
		},
		'rnbq1rk1/pp2p1bp/2pp1np1/3P1p2/2P5/2N2NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'A88',
			# TRANSLATORS: A88: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 c6 8. d5
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 c6 8. d5'),
			moves => {
				'c6d5' => 1,
				'c8d7' => 1,
				'd8a5' => 1,
				'd8e8' => 1,
				'e7e5' => 1,
			},
		},
		'rnbq1rk1/pp2p1bp/3p1np1/3p1p2/2P5/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A88',
			# TRANSLATORS: A88: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 c6 8. d5 cxd5
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 c6 8. d5 cxd5'),
			moves => {
			},
		},
		'rn1q1rk1/pp1bp1bp/2pp1np1/3P1p2/2P5/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A88',
			# TRANSLATORS: A88: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 c6 8. d5 Bd7
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 c6 8. d5 Bd7'),
			moves => {
			},
		},
		'rnb2rk1/pp2p1bp/2pp1np1/q2P1p2/2P5/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A88',
			# TRANSLATORS: A88: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 c6 8. d5 Qa5
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 c6 8. d5 Qa5'),
			moves => {
			},
		},
		'rnb1qrk1/pp2p1bp/2pp1np1/3P1p2/2P5/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A88',
			# TRANSLATORS: A88: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 c6 8. d5 Qe8
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 c6 8. d5 Qe8'),
			moves => {
			},
		},
		'rnbq1rk1/pp4bp/2pp1np1/3Ppp2/2P5/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A88',
			# TRANSLATORS: A88: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 c6 8. d5 e5
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 c6 8. d5 e5'),
			moves => {
				'd5e6' => 1,
			},
		},
		'rnbq1rk1/pp4bp/2ppPnp1/5p2/2P5/2N2NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'A88',
			# TRANSLATORS: A88: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 c6 8. d5 e5 9. dxe6
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 c6 8. d5 e5'),
			moves => {
				'c8e6' => 1,
			},
		},
		'rn1q1rk1/pp4bp/2ppbnp1/5p2/2P5/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A88',
			# TRANSLATORS: A88: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 c6 8. d5 e5 9. dxe6 Bxe6
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 c6 8. d5 e5'),
			moves => {
				'b2b3' => 1,
				'd1d3' => 1,
			},
		},
		'rn1q1rk1/pp4bp/2ppbnp1/5p2/2P5/1PN2NP1/P3PPBP/R1BQ1RK1 b -' => {
			eco => 'A88',
			# TRANSLATORS: A88: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 c6 8. d5 e5 9. dxe6 Bxe6 10. b3
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 c6 8. d5 e5 9.dxe6 Bxe6 10. b3'),
			moves => {
			},
		},
		'rn1q1rk1/pp4bp/2ppbnp1/5p2/2P5/2NQ1NP1/PP2PPBP/R1B2RK1 b -' => {
			eco => 'A88',
			# TRANSLATORS: A88: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 c6 8. d5 e5 9. dxe6 Bxe6 10. Qd3
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 c6 8. d5 e5 9.dxe6 Bxe6 10. Qd3'),
			moves => {
			},
		},
		'rnbq1rk1/pp2p1bp/2pp1np1/5p2/2PP4/2N2NP1/PP2PPBP/R1BQR1K1 b -' => {
			eco => 'A88',
			# TRANSLATORS: A88: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 c6 8. Re1
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 c6 8. Re1'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1p1bp/2np1np1/5p2/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A89',
			# TRANSLATORS: A89: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 Nc6
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 Nc6'),
			moves => {
				'b2b3' => 1,
				'd4d5' => 1,
			},
		},
		'r1bq1rk1/ppp1p1bp/2np1np1/5p2/2PP4/1PN2NP1/P3PPBP/R1BQ1RK1 b -' => {
			eco => 'A89',
			# TRANSLATORS: A89: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 Nc6 8. b3
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 Nc6 8. b3'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1p1bp/2np1np1/3P1p2/2P5/2N2NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'A89',
			# TRANSLATORS: A89: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 Nc6 8. d5
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 Nc6 8. d5'),
			moves => {
				'c6a5' => 1,
				'c6e5' => 1,
			},
		},
		'r1bq1rk1/ppp1p1bp/3p1np1/n2P1p2/2P5/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A89',
			# TRANSLATORS: A89: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 Nc6 8. d5 Na5
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 Nc6 8. d5 Na5'),
			moves => {
				'd1d3' => 1,
				'f3d2' => 1,
			},
		},
		'r1bq1rk1/ppp1p1bp/3p1np1/n2P1p2/2P5/2NQ1NP1/PP2PPBP/R1B2RK1 b -' => {
			eco => 'A89',
			# TRANSLATORS: A89: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 Nc6 8. d5 Na5 9. Qd3
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 Nc6 8. d5 Na5 9. Qd3'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1p1bp/3p1np1/n2P1p2/2P5/2N3P1/PP1NPPBP/R1BQ1RK1 b -' => {
			eco => 'A89',
			# TRANSLATORS: A89: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 Nc6 8. d5 Na5 9. Nd2
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 Nc6 8. d5 Na5 9. Nd2'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1p1bp/3p1np1/3Pnp2/2P5/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A89',
			# TRANSLATORS: A89: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 Nc6 8. d5 Ne5
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 Nc6 8. d5 Ne5'),
			moves => {
				'f3e5' => 1,
			},
		},
		'r1bq1rk1/ppp1p1bp/3p1np1/3PNp2/2P5/2N3P1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'A89',
			# TRANSLATORS: A89: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 Nc6 8. d5 Ne5 9. Nxe5
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 Nc6 8. d5 Ne5 9.Nxe5'),
			moves => {
				'd6e5' => 1,
			},
		},
		'r1bq1rk1/ppp1p1bp/5np1/3Ppp2/2P5/2N3P1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A89',
			# TRANSLATORS: A89: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 Nc6 8. d5 Ne5 9. Nxe5 dxe5
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 Nc6 8. d5 Ne5 9.Nxe5'),
			moves => {
				'd1b3' => 1,
				'e2e4' => 1,
			},
		},
		'r1bq1rk1/ppp1p1bp/5np1/3Ppp2/2P5/1QN3P1/PP2PPBP/R1B2RK1 b -' => {
			eco => 'A89',
			# TRANSLATORS: A89: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 Nc6 8. d5 Ne5 9. Nxe5 dxe5 10. Qb3
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 Nc6 8. d5 Ne5 9.Nxe5 dxe5 10. Qb3'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1p1bp/5np1/3Ppp2/2P1P3/2N3P1/PP3PBP/R1BQ1RK1 b -' => {
			eco => 'A89',
			# TRANSLATORS: A89: 1. d4 f5 2. c4 Nf6 3. g3 g6 4. Bg2 Bg7 5. Nf3 O-O 6. O-O d6 7. Nc3 Nc6 8. d5 Ne5 9. Nxe5 dxe5 10. e4
			variation => N__('Dutch: Leningrad, Main Line, 7. Nc3 Nc6 8. d5 Ne5 9.Nxe5 dxe5 10. e4'),
			moves => {
			},
		},
		'rnbqkb1r/pppp2pp/4pn2/5p2/2PP4/6P1/PP2PP1P/RNBQKBNR w KQkq' => {
			eco => 'A90',
			# TRANSLATORS: A90: 1. d4 f5 2. c4 Nf6 3. g3 e6
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6'),
			moves => {
				'b1c3' => 1,
				'f1g2' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/pppp2pp/4pn2/5p2/2PP4/2N3P1/PP2PP1P/R1BQKBNR b KQkq' => {
			eco => 'A90',
			# TRANSLATORS: A90: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Nc3
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Nc3'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqkb1r/ppp3pp/4pn2/3p1p2/2PP4/2N3P1/PP2PP1P/R1BQKBNR w KQkq' => {
			eco => 'A90',
			# TRANSLATORS: A90: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Nc3 d5
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Nc3 d5'),
			moves => {
			},
		},
		'rnbqkb1r/pppp2pp/4pn2/5p2/2PP4/6P1/PP2PPBP/RNBQK1NR b KQkq' => {
			eco => 'A90',
			# TRANSLATORS: A90: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Bg2'),
			moves => {
				'c7c6' => 1,
				'd7d5' => 1,
				'f8b4' => 1,
				'f8e7' => 1,
			},
		},
		'rnbqkb1r/pp1p2pp/2p1pn2/5p2/2PP4/6P1/PP2PPBP/RNBQK1NR w KQkq' => {
			eco => 'A90',
			# TRANSLATORS: A90: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 c6
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Bg2 c6'),
			moves => {
				'g1f3' => 1,
				'g1h3' => 1,
			},
		},
		'rnbqkb1r/pp1p2pp/2p1pn2/5p2/2PP4/5NP1/PP2PPBP/RNBQK2R b KQkq' => {
			eco => 'A90',
			# TRANSLATORS: A90: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 c6 5. Nf3
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Bg2 c6 5. Nf3'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqkb1r/pp4pp/2p1pn2/3p1p2/2PP4/5NP1/PP2PPBP/RNBQK2R w KQkq' => {
			eco => 'A90',
			# TRANSLATORS: A90: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 c6 5. Nf3 d5
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Bg2 c6 5. Nf3 d5'),
			moves => {
				'b1c3' => 1,
				'd1c2' => 1,
				'e1g1' => 1,
			},
		},
		'rnbqkb1r/pp4pp/2p1pn2/3p1p2/2PP4/2N2NP1/PP2PPBP/R1BQK2R b KQkq' => {
			eco => 'A90',
			# TRANSLATORS: A90: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 c6 5. Nf3 d5 6. Nc3
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 5. Nf3 d5 6. Nc3'),
			moves => {
			},
		},
		'rnbqkb1r/pp4pp/2p1pn2/3p1p2/2PP4/5NP1/PPQ1PPBP/RNB1K2R b KQkq' => {
			eco => 'A90',
			# TRANSLATORS: A90: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 c6 5. Nf3 d5 6. Qc2
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 5. Nf3 d5 6. Qc2'),
			moves => {
				'f8d6' => 1,
			},
		},
		'rnbqk2r/pp4pp/2pbpn2/3p1p2/2PP4/5NP1/PPQ1PPBP/RNB1K2R w KQkq' => {
			eco => 'A90',
			# TRANSLATORS: A90: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 c6 5. Nf3 d5 6. Qc2 Bd6
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 5. Nf3 d5 6. Qc2 Bd6'),
			moves => {
			},
		},
		'rnbqkb1r/pp4pp/2p1pn2/3p1p2/2PP4/5NP1/PP2PPBP/RNBQ1RK1 b kq' => {
			eco => 'A90',
			# TRANSLATORS: A90: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 c6 5. Nf3 d5 6. O-O
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 5. Nf3 d5 6.O-O'),
			moves => {
				'f8d6' => 1,
			},
		},
		'rnbqk2r/pp4pp/2pbpn2/3p1p2/2PP4/5NP1/PP2PPBP/RNBQ1RK1 w kq' => {
			eco => 'A90',
			# TRANSLATORS: A90: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 c6 5. Nf3 d5 6. O-O Bd6
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 5. Nf3 d5 6.O-O Bd6'),
			moves => {
				'b2b3' => 1,
			},
		},
		'rnbqk2r/pp4pp/2pbpn2/3p1p2/2PP4/1P3NP1/P3PPBP/RNBQ1RK1 b kq' => {
			eco => 'A90',
			# TRANSLATORS: A90: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 c6 5. Nf3 d5 6. O-O Bd6 7. b3
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 5. Nf3 d5 6.O-O Bd6 7. b3'),
			moves => {
			},
		},
		'rnbqkb1r/pp1p2pp/2p1pn2/5p2/2PP4/6PN/PP2PPBP/RNBQK2R b KQkq' => {
			eco => 'A90',
			# TRANSLATORS: A90: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 c6 5. Nh3
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Bg2 c6 5. Nh3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp3pp/4pn2/3p1p2/2PP4/6P1/PP2PPBP/RNBQK1NR w KQkq' => {
			eco => 'A90',
			# TRANSLATORS: A90: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 d5
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Bg2 d5'),
			moves => {
				'g1f3' => 1,
				'g1h3' => 1,
			},
		},
		'rnbqkb1r/ppp3pp/4pn2/3p1p2/2PP4/5NP1/PP2PPBP/RNBQK2R b KQkq' => {
			eco => 'A90',
			# TRANSLATORS: A90: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 d5 5. Nf3
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Bg2 d5 5. Nf3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp3pp/4pn2/3p1p2/2PP4/6PN/PP2PPBP/RNBQK2R b KQkq' => {
			eco => 'A90',
			# TRANSLATORS: A90: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 d5 5. Nh3
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Bg2 d5 5. Nh3'),
			moves => {
			},
		},
		'rnbqk2r/pppp2pp/4pn2/5p2/1bPP4/6P1/PP2PPBP/RNBQK1NR w KQkq' => {
			eco => 'A90',
			# TRANSLATORS: A90: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Bb4+
			variation => N__('Dutch: Dutch-Indian (Nimzo-Dutch) Variation'),
			moves => {
				'b1c3' => 1,
				'b1d2' => 1,
				'c1d2' => 1,
			},
		},
		'rnbqk2r/pppp2pp/4pn2/5p2/1bPP4/2N3P1/PP2PPBP/R1BQK1NR b KQkq' => {
			eco => 'A90',
			# TRANSLATORS: A90: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Bb4+ 5. Nc3
			variation => N__('Dutch: Dutch-Indian, 5. Nc3'),
			moves => {
			},
		},
		'rnbqk2r/pppp2pp/4pn2/5p2/1bPP4/6P1/PP1NPPBP/R1BQK1NR b KQkq' => {
			eco => 'A90',
			# TRANSLATORS: A90: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Bb4+ 5. Nd2
			variation => N__('Dutch: Dutch-Indian, 5. Nd2'),
			moves => {
			},
		},
		'rnbqk2r/pppp2pp/4pn2/5p2/1bPP4/6P1/PP1BPPBP/RN1QK1NR b KQkq' => {
			eco => 'A90',
			# TRANSLATORS: A90: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Bb4+ 5. Bd2
			variation => N__('Dutch: Dutch-Indian, 5. Bd2'),
			moves => {
				'b4e7' => 1,
			},
		},
		'rnbqk2r/ppppb1pp/4pn2/5p2/2PP4/6P1/PP1BPPBP/RN1QK1NR w KQkq' => {
			eco => 'A90',
			# TRANSLATORS: A90: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Bb4+ 5. Bd2 Be7
			variation => N__('Dutch: Dutch-Indian, Alekhine Variation'),
			moves => {
			},
		},
		'rnbqkb1r/pppp2pp/4pn2/5p2/2PP4/5NP1/PP2PP1P/RNBQKB1R b KQkq' => {
			eco => 'A90',
			# TRANSLATORS: A90: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Nf3
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Nf3'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqkb1r/ppp3pp/4pn2/3p1p2/2PP4/5NP1/PP2PP1P/RNBQKB1R w KQkq' => {
			eco => 'A90',
			# TRANSLATORS: A90: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Nf3 d5
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Nf3 d5'),
			moves => {
			},
		},
		'rnbqk2r/ppppb1pp/4pn2/5p2/2PP4/6P1/PP2PPBP/RNBQK1NR w KQkq' => {
			eco => 'A91',
			# TRANSLATORS: A91: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Bg2 Be7'),
			moves => {
				'b1c3' => 1,
				'g1f3' => 1,
				'g1h3' => 1,
			},
		},
		'rnbqk2r/ppppb1pp/4pn2/5p2/2PP4/2N3P1/PP2PPBP/R1BQK1NR b KQkq' => {
			eco => 'A91',
			# TRANSLATORS: A91: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nc3
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nc3'),
			moves => {
				'd7d5' => 1,
				'e8g8' => 1,
			},
		},
		'rnbqk2r/ppp1b1pp/4pn2/3p1p2/2PP4/2N3P1/PP2PPBP/R1BQK1NR w KQkq' => {
			eco => 'A91',
			# TRANSLATORS: A91: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nc3 d5
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nc3 d5'),
			moves => {
			},
		},
		'rnbq1rk1/ppppb1pp/4pn2/5p2/2PP4/2N3P1/PP2PPBP/R1BQK1NR w KQ' => {
			eco => 'A91',
			# TRANSLATORS: A91: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nc3 O-O
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nc3 O-O'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbq1rk1/ppppb1pp/4pn2/5p2/2PP4/2N1P1P1/PP3PBP/R1BQK1NR b KQ' => {
			eco => 'A91',
			# TRANSLATORS: A91: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nc3 O-O 6. e3
			variation => N__('Dutch: Botvinnik-Bronstein Variation'),
			moves => {
			},
		},
		'rnbqk2r/ppppb1pp/4pn2/5p2/2PP4/5NP1/PP2PPBP/RNBQK2R b KQkq' => {
			eco => 'A91',
			# TRANSLATORS: A91: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3'),
			moves => {
				'd7d5' => 1,
				'd7d6' => 1,
				'e8g8' => 1,
			},
		},
		'rnbqk2r/ppp1b1pp/4pn2/3p1p2/2PP4/5NP1/PP2PPBP/RNBQK2R w KQkq' => {
			eco => 'A91',
			# TRANSLATORS: A91: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 d5
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 d5'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbqk2r/ppp1b1pp/4pn2/3p1p2/2PP4/5NP1/PP2PPBP/RNBQ1RK1 b kq' => {
			eco => 'A91',
			# TRANSLATORS: A91: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 d5 6. O-O
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 d5 6.O-O'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rnbqk2r/pp2b1pp/2p1pn2/3p1p2/2PP4/5NP1/PP2PPBP/RNBQ1RK1 w kq' => {
			eco => 'A91',
			# TRANSLATORS: A91: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 d5 6. O-O c6
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 d5 6.O-O c6'),
			moves => {
			},
		},
		'rnbqk2r/ppp1b1pp/3ppn2/5p2/2PP4/5NP1/PP2PPBP/RNBQK2R w KQkq' => {
			eco => 'A91',
			# TRANSLATORS: A91: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 d6
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 d6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqk2r/ppp1b1pp/3ppn2/5p2/2PP4/2N2NP1/PP2PPBP/R1BQK2R b KQkq' => {
			eco => 'A91',
			# TRANSLATORS: A91: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 d6 6. Nc3
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 d6 6. Nc3'),
			moves => {
			},
		},
		'rnbqk2r/ppppb1pp/4pn2/5p2/2PP4/6PN/PP2PPBP/RNBQK2R b KQkq' => {
			eco => 'A91',
			# TRANSLATORS: A91: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nh3
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nh3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppppb1pp/4pn2/5p2/2PP4/6PN/PP2PPBP/RNBQK2R w KQ' => {
			eco => 'A91',
			# TRANSLATORS: A91: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nh3 O-O
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nh3'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbq1rk1/ppppb1pp/4pn2/5p2/2PP4/6PN/PP2PPBP/RNBQ1RK1 b -' => {
			eco => 'A91',
			# TRANSLATORS: A91: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nh3 O-O 6. O-O
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nh3 O-O 6.O-O'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rnbq1rk1/ppp1b1pp/3ppn2/5p2/2PP4/6PN/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'A91',
			# TRANSLATORS: A91: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nh3 O-O 6. O-O d6
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nh3 O-O 6.O-O d6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbq1rk1/ppp1b1pp/3ppn2/5p2/2PP4/2N3PN/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'A91',
			# TRANSLATORS: A91: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nh3 O-O 6. O-O d6 7. Nc3
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nh3 O-O 6.O-O d6 7. Nc3'),
			moves => {
				'c7c6' => 1,
				'd8e8' => 1,
			},
		},
		'rnbq1rk1/pp2b1pp/2pppn2/5p2/2PP4/2N3PN/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A91',
			# TRANSLATORS: A91: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nh3 O-O 6. O-O d6 7. Nc3 c6
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nh3 O-O 6.O-O d6 7. Nc3 c6'),
			moves => {
			},
		},
		'rnb1qrk1/ppp1b1pp/3ppn2/5p2/2PP4/2N3PN/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A91',
			# TRANSLATORS: A91: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nh3 O-O 6. O-O d6 7. Nc3 Qe8
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nh3 O-O 6.O-O d6 7. Nc3 Qe8'),
			moves => {
			},
		},
		'rnbq1rk1/ppppb1pp/4pn2/5p2/2PP4/5NP1/PP2PPBP/RNBQK2R w KQ' => {
			eco => 'A92',
			# TRANSLATORS: A92: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O'),
			moves => {
				'b1c3' => 1,
				'd4d5' => 1,
				'e1g1' => 1,
			},
		},
		'rnbq1rk1/ppppb1pp/4pn2/5p2/2PP4/2N2NP1/PP2PPBP/R1BQK2R b KQ' => {
			eco => 'A92',
			# TRANSLATORS: A92: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. Nc3
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. Nc3'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rnbq1rk1/ppp1b1pp/3ppn2/5p2/2PP4/2N2NP1/PP2PPBP/R1BQK2R w KQ' => {
			eco => 'A92',
			# TRANSLATORS: A92: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. Nc3 d6
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. Nc3 d6'),
			moves => {
			},
		},
		'rnbq1rk1/ppppb1pp/4pn2/3P1p2/2P5/5NP1/PP2PPBP/RNBQK2R b KQ' => {
			eco => 'A92',
			# TRANSLATORS: A92: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. d5
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. d5'),
			moves => {
			},
		},
		'rnbq1rk1/ppppb1pp/4pn2/5p2/2PP4/5NP1/PP2PPBP/RNBQ1RK1 b -' => {
			eco => 'A92',
			# TRANSLATORS: A92: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6.O-O'),
			moves => {
				'c7c6' => 1,
				'd7d5' => 1,
				'd7d6' => 1,
				'f6e4' => 1,
			},
		},
		'rnbq1rk1/pp1pb1pp/2p1pn2/5p2/2PP4/5NP1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'A92',
			# TRANSLATORS: A92: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O c6
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6.O-O c6'),
			moves => {
				'b2b3' => 1,
			},
		},
		'rnbq1rk1/pp1pb1pp/2p1pn2/5p2/2PP4/1P3NP1/P3PPBP/RNBQ1RK1 b -' => {
			eco => 'A92',
			# TRANSLATORS: A92: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O c6 7. b3
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6.O-O c6 7. b3'),
			moves => {
				'a7a5' => 1,
			},
		},
		'rnbq1rk1/1p1pb1pp/2p1pn2/p4p2/2PP4/1P3NP1/P3PPBP/RNBQ1RK1 w -' => {
			eco => 'A92',
			# TRANSLATORS: A92: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O c6 7. b3 a5
			variation => N__('Dutch: 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6.O-O c6 7. b3 a5'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1b1pp/4pn2/3p1p2/2PP4/5NP1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'A92',
			# TRANSLATORS: A92: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d5
			variation => N__('Dutch: Stonewall Variation'),
			moves => {
				'b1c3' => 1,
				'b1d2' => 1,
				'b2b3' => 1,
				'd1c2' => 1,
			},
		},
		'rnbq1rk1/ppp1b1pp/4pn2/3p1p2/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'A92',
			# TRANSLATORS: A92: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d5 7. Nc3
			variation => N__('Dutch: Stonewall, 7. Nc3'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rnbq1rk1/ppp1b1pp/4pn2/3p1p2/2PP4/5NP1/PP1NPPBP/R1BQ1RK1 b -' => {
			eco => 'A92',
			# TRANSLATORS: A92: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d5 7. Nbd2
			variation => N__('Dutch: Stonewall, 7.Nbd2'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rnbq1rk1/pp2b1pp/2p1pn2/3p1p2/2PP4/5NP1/PP1NPPBP/R1BQ1RK1 w -' => {
			eco => 'A92',
			# TRANSLATORS: A92: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d5 7. Nbd2 c6
			variation => N__('Dutch: Stonewall, 7.Nbd2 c6'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1b1pp/4pn2/3p1p2/2PP4/5NP1/PPQ1PPBP/RNB2RK1 b -' => {
			eco => 'A92',
			# TRANSLATORS: A92: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d5 7. Qc2
			variation => N__('Dutch: Stonewall, 7. Qc2'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rnbq1rk1/pp2b1pp/2p1pn2/3p1p2/2PP4/5NP1/PPQ1PPBP/RNB2RK1 w -' => {
			eco => 'A92',
			# TRANSLATORS: A92: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d5 7. Qc2 c6
			variation => N__('Dutch: Stonewall, 7. Qc2 c6'),
			moves => {
				'b1d2' => 1,
			},
		},
		'rnbq1rk1/pp2b1pp/2p1pn2/3p1p2/2PP4/5NP1/PPQNPPBP/R1B2RK1 b -' => {
			eco => 'A92',
			# TRANSLATORS: A92: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d5 7. Qc2 c6 8. Nbd2
			variation => N__('Dutch: Stonewall, 7. Qc2 c6 8.Nbd2'),
			moves => {
			},
		},
		'rnbq1rk1/ppppb1pp/4p3/5p2/2PPn3/5NP1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'A92',
			# TRANSLATORS: A92: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O Ne4
			variation => N__('Dutch: Alekhine Variation'),
			moves => {
				'b1d2' => 1,
				'd4d5' => 1,
			},
		},
		'rnbq1rk1/ppppb1pp/4p3/5p2/2PPn3/5NP1/PP1NPPBP/R1BQ1RK1 b -' => {
			eco => 'A92',
			# TRANSLATORS: A92: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O Ne4 7. Nbd2
			variation => N__('Dutch: Alekhine, 7.Nbd2'),
			moves => {
			},
		},
		'rnbq1rk1/ppppb1pp/4p3/3P1p2/2P1n3/5NP1/PP2PPBP/RNBQ1RK1 b -' => {
			eco => 'A92',
			# TRANSLATORS: A92: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O Ne4 7. d5
			variation => N__('Dutch: Alekhine, 7. d5'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1b1pp/4pn2/3p1p2/2PP4/1P3NP1/P3PPBP/RNBQ1RK1 b -' => {
			eco => 'A93',
			# TRANSLATORS: A93: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d5 7. b3
			variation => N__('Dutch: Stonewall, Botvinnik Variation'),
			moves => {
				'b7b6' => 1,
				'b8c6' => 1,
				'c7c6' => 1,
			},
		},
		'rnbq1rk1/p1p1b1pp/1p2pn2/3p1p2/2PP4/1P3NP1/P3PPBP/RNBQ1RK1 w -' => {
			eco => 'A93',
			# TRANSLATORS: A93: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d5 7. b3 b6
			variation => N__('Dutch: Stonewall, Botvinnik, 7... b6'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1b1pp/2n1pn2/3p1p2/2PP4/1P3NP1/P3PPBP/RNBQ1RK1 w -' => {
			eco => 'A93',
			# TRANSLATORS: A93: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d5 7. b3 Nc6
			variation => N__('Dutch: Stonewall, Botvinnik, 7... Nc6'),
			moves => {
			},
		},
		'rnbq1rk1/pp2b1pp/2p1pn2/3p1p2/2PP4/1P3NP1/P3PPBP/RNBQ1RK1 w -' => {
			eco => 'A93',
			# TRANSLATORS: A93: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d5 7. b3 c6
			variation => N__('Dutch: Stonewall, Botvinnik, 7... c6'),
			moves => {
				'c1a3' => 1,
				'c1b2' => 1,
				'd1c2' => 1,
			},
		},
		'rnbq1rk1/pp2b1pp/2p1pn2/3p1p2/2PP4/1P3NP1/PB2PPBP/RN1Q1RK1 b -' => {
			eco => 'A93',
			# TRANSLATORS: A93: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d5 7. b3 c6 8. Bb2
			variation => N__('Dutch: Stonewall, Botvinnik, 8. Bb2'),
			moves => {
			},
		},
		'rnbq1rk1/pp2b1pp/2p1pn2/3p1p2/2PP4/1P3NP1/P1Q1PPBP/RNB2RK1 b -' => {
			eco => 'A93',
			# TRANSLATORS: A93: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d5 7. b3 c6 8. Qc2
			variation => N__('Dutch: Stonewall, Botvinnik, 8. Qc2'),
			moves => {
				'f6e4' => 1,
			},
		},
		'rnbq1rk1/pp2b1pp/2p1p3/3p1p2/2PPn3/1P3NP1/P1Q1PPBP/RNB2RK1 w -' => {
			eco => 'A93',
			# TRANSLATORS: A93: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d5 7. b3 c6 8. Qc2 Ne4
			variation => N__('Dutch: Stonewall, Botvinnik, 8. Qc2 Ne4'),
			moves => {
			},
		},
		'rnbq1rk1/pp2b1pp/2p1pn2/3p1p2/2PP4/BP3NP1/P3PPBP/RN1Q1RK1 b -' => {
			eco => 'A94',
			# TRANSLATORS: A94: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d5 7. b3 c6 8. Ba3
			variation => N__('Dutch: Stonewall, Botvinnik, 8. Ba3'),
			moves => {
				'b8d7' => 1,
				'c8d7' => 1,
				'e7a3' => 1,
			},
		},
		'r1bq1rk1/pp1nb1pp/2p1pn2/3p1p2/2PP4/BP3NP1/P3PPBP/RN1Q1RK1 w -' => {
			eco => 'A94',
			# TRANSLATORS: A94: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d5 7. b3 c6 8. Ba3 Nbd7
			variation => N__('Dutch: Stonewall, Botvinnik, 8. Ba3 Nbd7'),
			moves => {
				'a3e7' => 1,
			},
		},
		'r1bq1rk1/pp1nB1pp/2p1pn2/3p1p2/2PP4/1P3NP1/P3PPBP/RN1Q1RK1 b -' => {
			eco => 'A94',
			# TRANSLATORS: A94: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d5 7. b3 c6 8. Ba3 Nbd7 9. Bxe7
			variation => N__('Dutch: Stonewall, Botvinnik, 8. Ba3 Nbd7 9.Bxe7'),
			moves => {
			},
		},
		'rn1q1rk1/pp1bb1pp/2p1pn2/3p1p2/2PP4/BP3NP1/P3PPBP/RN1Q1RK1 w -' => {
			eco => 'A94',
			# TRANSLATORS: A94: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d5 7. b3 c6 8. Ba3 Bd7
			variation => N__('Dutch: Stonewall, Botvinnik, 8. Ba3 Bd7'),
			moves => {
			},
		},
		'rnbq1rk1/pp4pp/2p1pn2/3p1p2/2PP4/bP3NP1/P3PPBP/RN1Q1RK1 w -' => {
			eco => 'A94',
			# TRANSLATORS: A94: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d5 7. b3 c6 8. Ba3 Bxa3
			variation => N__('Dutch: Stonewall, Botvinnik, 8. Ba3 Bxa3'),
			moves => {
				'b1a3' => 1,
			},
		},
		'rnbq1rk1/pp4pp/2p1pn2/3p1p2/2PP4/NP3NP1/P3PPBP/R2Q1RK1 b -' => {
			eco => 'A94',
			# TRANSLATORS: A94: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d5 7. b3 c6 8. Ba3 Bxa3 9. Nxa3
			variation => N__('Dutch: Stonewall, Botvinnik, 8. Ba3 Bxa3 9.Nxa3'),
			moves => {
				'b8d7' => 1,
				'd8e7' => 1,
			},
		},
		'r1bq1rk1/pp1n2pp/2p1pn2/3p1p2/2PP4/NP3NP1/P3PPBP/R2Q1RK1 w -' => {
			eco => 'A94',
			# TRANSLATORS: A94: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d5 7. b3 c6 8. Ba3 Bxa3 9. Nxa3 Nbd7
			variation => N__('Dutch: Stonewall, Botvinnik, 8. Ba3 Bxa3 9.Nxa3 Nbd7'),
			moves => {
			},
		},
		'rnb2rk1/pp2q1pp/2p1pn2/3p1p2/2PP4/NP3NP1/P3PPBP/R2Q1RK1 w -' => {
			eco => 'A94',
			# TRANSLATORS: A94: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d5 7. b3 c6 8. Ba3 Bxa3 9. Nxa3 Qe7
			variation => N__('Dutch: Stonewall, Botvinnik, 8. Ba3 Bxa3 9.Nxa3 Qe7'),
			moves => {
				'd1c1' => 1,
			},
		},
		'rnb2rk1/pp2q1pp/2p1pn2/3p1p2/2PP4/NP3NP1/P3PPBP/R1Q2RK1 b -' => {
			eco => 'A94',
			# TRANSLATORS: A94: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d5 7. b3 c6 8. Ba3 Bxa3 9. Nxa3 Qe7 10. Qc1
			variation => N__('Dutch: Stonewall, Botvinnik, 8. Ba3 Bxa3 9.Nxa3 Qe7 10. Qc1'),
			moves => {
			},
		},
		'rnbq1rk1/pp2b1pp/2p1pn2/3p1p2/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A95',
			# TRANSLATORS: A95: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d5 7. Nc3 c6
			variation => N__('Dutch: Stonewall, 7. Nc3 c6'),
			moves => {
				'b2b3' => 1,
				'c1f4' => 1,
				'c1g5' => 1,
				'd1c2' => 1,
				'f3e5' => 1,
			},
		},
		'rnbq1rk1/pp2b1pp/2p1pn2/3p1p2/2PP4/1PN2NP1/P3PPBP/R1BQ1RK1 b -' => {
			eco => 'A95',
			# TRANSLATORS: A95: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d5 7. Nc3 c6 8. b3
			variation => N__('Dutch: Stonewall, 7. Nc3 c6 8. b3'),
			moves => {
				'd8e8' => 1,
			},
		},
		'rnb1qrk1/pp2b1pp/2p1pn2/3p1p2/2PP4/1PN2NP1/P3PPBP/R1BQ1RK1 w -' => {
			eco => 'A95',
			# TRANSLATORS: A95: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d5 7. Nc3 c6 8. b3 Qe8
			variation => N__('Dutch: Stonewall, 7. Nc3 c6 8. b3 Qe8'),
			moves => {
			},
		},
		'rnbq1rk1/pp2b1pp/2p1pn2/3p1p2/2PP1B2/2N2NP1/PP2PPBP/R2Q1RK1 b -' => {
			eco => 'A95',
			# TRANSLATORS: A95: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d5 7. Nc3 c6 8. Bf4
			variation => N__('Dutch: Stonewall, 7. Nc3 c6 8. Bf4'),
			moves => {
			},
		},
		'rnbq1rk1/pp2b1pp/2p1pn2/3p1pB1/2PP4/2N2NP1/PP2PPBP/R2Q1RK1 b -' => {
			eco => 'A95',
			# TRANSLATORS: A95: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d5 7. Nc3 c6 8. Bg5
			variation => N__('Dutch: Stonewall, 7. Nc3 c6 8. Bg5'),
			moves => {
			},
		},
		'rnbq1rk1/pp2b1pp/2p1pn2/3p1p2/2PP4/2N2NP1/PPQ1PPBP/R1B2RK1 b -' => {
			eco => 'A95',
			# TRANSLATORS: A95: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d5 7. Nc3 c6 8. Qc2
			variation => N__('Dutch: Stonewall, 7. Nc3 c6 8. Qc2'),
			moves => {
				'd8e8' => 1,
			},
		},
		'rnb1qrk1/pp2b1pp/2p1pn2/3p1p2/2PP4/2N2NP1/PPQ1PPBP/R1B2RK1 w -' => {
			eco => 'A95',
			# TRANSLATORS: A95: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d5 7. Nc3 c6 8. Qc2 Qe8
			variation => N__('Dutch: Stonewall, 7. Nc3 c6 8. Qc2'),
			moves => {
				'c1g5' => 1,
			},
		},
		'rnb1qrk1/pp2b1pp/2p1pn2/3p1pB1/2PP4/2N2NP1/PPQ1PPBP/R4RK1 b -' => {
			eco => 'A95',
			# TRANSLATORS: A95: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d5 7. Nc3 c6 8. Qc2 Qe8 9. Bg5
			variation => N__('Dutch: Stonewall: Chekhover Variation'),
			moves => {
			},
		},
		'rnbq1rk1/pp2b1pp/2p1pn2/3pNp2/2PP4/2N3P1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'A95',
			# TRANSLATORS: A95: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d5 7. Nc3 c6 8. Ne5
			variation => N__('Dutch: Stonewall, 7. Nc3 c6 8. Ne5'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1b1pp/3ppn2/5p2/2PP4/5NP1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'A96',
			# TRANSLATORS: A96: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6
			variation => N__('Dutch: Classical'),
			moves => {
				'b1c3' => 1,
				'b2b3' => 1,
			},
		},
		'rnbq1rk1/ppp1b1pp/3ppn2/5p2/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'A96',
			# TRANSLATORS: A96: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6 7. Nc3
			variation => N__('Dutch: Classical, 7. Nc3'),
			moves => {
				'a7a5' => 1,
				'd8e8' => 1,
			},
		},
		'rnbq1rk1/1pp1b1pp/3ppn2/p4p2/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A96',
			# TRANSLATORS: A96: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6 7. Nc3 a5
			variation => N__('Dutch: Classical, 7. Nc3 a5'),
			moves => {
				'b2b3' => 1,
				'd1c2' => 1,
				'f1e1' => 1,
			},
		},
		'rnbq1rk1/1pp1b1pp/3ppn2/p4p2/2PP4/1PN2NP1/P3PPBP/R1BQ1RK1 b -' => {
			eco => 'A96',
			# TRANSLATORS: A96: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6 7. Nc3 a5 8. b3
			variation => N__('Dutch: Classical, 7. Nc3 a5 8. b3'),
			moves => {
			},
		},
		'rnbq1rk1/1pp1b1pp/3ppn2/p4p2/2PP4/2N2NP1/PPQ1PPBP/R1B2RK1 b -' => {
			eco => 'A96',
			# TRANSLATORS: A96: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6 7. Nc3 a5 8. Qc2
			variation => N__('Dutch: Classical, 7. Nc3 a5 8. Qc2'),
			moves => {
			},
		},
		'rnbq1rk1/1pp1b1pp/3ppn2/p4p2/2PP4/2N2NP1/PP2PPBP/R1BQR1K1 b -' => {
			eco => 'A96',
			# TRANSLATORS: A96: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6 7. Nc3 a5 8. Re1
			variation => N__('Dutch: Classical, 7. Nc3 a5 8. Re1'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1b1pp/3ppn2/5p2/2PP4/1P3NP1/P3PPBP/RNBQ1RK1 b -' => {
			eco => 'A96',
			# TRANSLATORS: A96: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6 7. b3
			variation => N__('Dutch: Classical, 7. b3'),
			moves => {
				'a7a5' => 1,
				'd8e8' => 1,
			},
		},
		'rnbq1rk1/1pp1b1pp/3ppn2/p4p2/2PP4/1P3NP1/P3PPBP/RNBQ1RK1 w -' => {
			eco => 'A96',
			# TRANSLATORS: A96: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6 7. b3 a5
			variation => N__('Dutch: Classical, 7. b3 a5'),
			moves => {
				'c1b2' => 1,
			},
		},
		'rnbq1rk1/1pp1b1pp/3ppn2/p4p2/2PP4/1P3NP1/PB2PPBP/RN1Q1RK1 b -' => {
			eco => 'A96',
			# TRANSLATORS: A96: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6 7. b3 a5 8. Bb2
			variation => N__('Dutch: Classical, 7. b3 a5 8. Bb2'),
			moves => {
			},
		},
		'rnb1qrk1/ppp1b1pp/3ppn2/5p2/2PP4/1P3NP1/P3PPBP/RNBQ1RK1 w -' => {
			eco => 'A96',
			# TRANSLATORS: A96: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6 7. b3 Qe8
			variation => N__('Dutch: Classical, 7. b3 Qe8'),
			moves => {
				'c1b2' => 1,
			},
		},
		'rnb1qrk1/ppp1b1pp/3ppn2/5p2/2PP4/1P3NP1/PB2PPBP/RN1Q1RK1 b -' => {
			eco => 'A96',
			# TRANSLATORS: A96: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6 7. b3 Qe8 8. Bb2
			variation => N__('Dutch: Classical, 7. b3 Qe8 8. Bb2'),
			moves => {
			},
		},
		'rnb1qrk1/ppp1b1pp/3ppn2/5p2/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'A97',
			# TRANSLATORS: A97: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6 7. Nc3 Qe8
			variation => N__('Dutch: Ilyin-Zhenevsky Variation'),
			moves => {
				'b2b3' => 1,
				'b2b4' => 1,
				'd1c2' => 1,
				'f1e1' => 1,
			},
		},
		'rnb1qrk1/ppp1b1pp/3ppn2/5p2/1PPP4/2N2NP1/P3PPBP/R1BQ1RK1 b -' => {
			eco => 'A97',
			# TRANSLATORS: A97: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6 7. Nc3 Qe8 8. b4
			variation => N__('Dutch: Ilyin-Zhenevsky, 8. b4'),
			moves => {
			},
		},
		'rnb1qrk1/ppp1b1pp/3ppn2/5p2/2PP4/2N2NP1/PP2PPBP/R1BQR1K1 b -' => {
			eco => 'A97',
			# TRANSLATORS: A97: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6 7. Nc3 Qe8 8. Re1
			variation => N__('Dutch: Ilyin-Zhenevsky, Winter Variation'),
			moves => {
				'e8g6' => 1,
				'e8h5' => 1,
				'f6e4' => 1,
			},
		},
		'rnb2rk1/ppp1b1pp/3ppnq1/5p2/2PP4/2N2NP1/PP2PPBP/R1BQR1K1 w -' => {
			eco => 'A97',
			# TRANSLATORS: A97: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6 7. Nc3 Qe8 8. Re1 Qg6
			variation => N__('Dutch: Ilyin-Zhenevsky, Winter, 8... Qg6'),
			moves => {
				'e2e4' => 1,
			},
		},
		'rnb2rk1/ppp1b1pp/3ppnq1/5p2/2PPP3/2N2NP1/PP3PBP/R1BQR1K1 b -' => {
			eco => 'A97',
			# TRANSLATORS: A97: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6 7. Nc3 Qe8 8. Re1 Qg6 9. e4
			variation => N__('Dutch: Ilyin-Zhenevsky, Winter, 8... Qg6 9. e4'),
			moves => {
				'f5e4' => 1,
			},
		},
		'rnb2rk1/ppp1b1pp/3ppnq1/8/2PPp3/2N2NP1/PP3PBP/R1BQR1K1 w -' => {
			eco => 'A97',
			# TRANSLATORS: A97: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6 7. Nc3 Qe8 8. Re1 Qg6 9. e4 fxe4
			variation => N__('Dutch: Ilyin-Zhenevsky, Winter, 8... Qg6 9. e4 fxe4'),
			moves => {
			},
		},
		'rnb2rk1/ppp1b1pp/3ppn2/5p1q/2PP4/2N2NP1/PP2PPBP/R1BQR1K1 w -' => {
			eco => 'A97',
			# TRANSLATORS: A97: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6 7. Nc3 Qe8 8. Re1 Qh5
			variation => N__('Dutch: Ilyin-Zhenevsky, Winter, 8... Qh5'),
			moves => {
			},
		},
		'rnb1qrk1/ppp1b1pp/3pp3/5p2/2PPn3/2N2NP1/PP2PPBP/R1BQR1K1 w -' => {
			eco => 'A97',
			# TRANSLATORS: A97: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6 7. Nc3 Qe8 8. Re1 Ne4
			variation => N__('Dutch: Ilyin-Zhenevsky, Winter, 8... Ne4'),
			moves => {
			},
		},
		'rnb1qrk1/ppp1b1pp/3ppn2/5p2/2PP4/2N2NP1/PPQ1PPBP/R1B2RK1 b -' => {
			eco => 'A98',
			# TRANSLATORS: A98: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6 7. Nc3 Qe8 8. Qc2
			variation => N__('Dutch: Ilyin-Zhenevsky, 8. Qc2'),
			moves => {
				'b8c6' => 1,
				'e8h5' => 1,
			},
		},
		'r1b1qrk1/ppp1b1pp/2nppn2/5p2/2PP4/2N2NP1/PPQ1PPBP/R1B2RK1 w -' => {
			eco => 'A98',
			# TRANSLATORS: A98: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6 7. Nc3 Qe8 8. Qc2 Nc6
			variation => N__('Dutch: Ilyin-Zhenevsky, 8. Qc2 Nc6'),
			moves => {
			},
		},
		'rnb2rk1/ppp1b1pp/3ppn2/5p1q/2PP4/2N2NP1/PPQ1PPBP/R1B2RK1 w -' => {
			eco => 'A98',
			# TRANSLATORS: A98: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6 7. Nc3 Qe8 8. Qc2 Qh5
			variation => N__('Dutch: Ilyin-Zhenevsky, 8. Qc2 Qh5'),
			moves => {
			},
		},
		'rnb1qrk1/ppp1b1pp/3ppn2/5p2/2PP4/1PN2NP1/P3PPBP/R1BQ1RK1 b -' => {
			eco => 'A99',
			# TRANSLATORS: A99: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6 7. Nc3 Qe8 8. b3
			variation => N__('Dutch: Ilyin-Zhenevsky, 8. b3'),
			moves => {
				'a7a5' => 1,
				'b8c6' => 1,
				'b8d7' => 1,
				'c7c6' => 1,
				'e8h5' => 1,
			},
		},
		'rnb1qrk1/1pp1b1pp/3ppn2/p4p2/2PP4/1PN2NP1/P3PPBP/R1BQ1RK1 w -' => {
			eco => 'A99',
			# TRANSLATORS: A99: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6 7. Nc3 Qe8 8. b3 a5
			variation => N__('Dutch: Ilyin-Zhenevsky, 8. b3 a5'),
			moves => {
				'c1a3' => 1,
				'c1b2' => 1,
				'd1c2' => 1,
			},
		},
		'rnb1qrk1/1pp1b1pp/3ppn2/p4p2/2PP4/BPN2NP1/P3PPBP/R2Q1RK1 b -' => {
			eco => 'A99',
			# TRANSLATORS: A99: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6 7. Nc3 Qe8 8. b3 a5 9. Ba3
			variation => N__('Dutch: Ilyin-Zhenevsky, 8. b3 a5 9. Ba3'),
			moves => {
			},
		},
		'rnb1qrk1/1pp1b1pp/3ppn2/p4p2/2PP4/1PN2NP1/PB2PPBP/R2Q1RK1 b -' => {
			eco => 'A99',
			# TRANSLATORS: A99: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6 7. Nc3 Qe8 8. b3 a5 9. Bb2
			variation => N__('Dutch: Ilyin-Zhenevsky, 8. b3 a5 9. Bb2'),
			moves => {
				'b8a6' => 1,
				'c7c6' => 1,
				'e8h5' => 1,
			},
		},
		'r1b1qrk1/1pp1b1pp/n2ppn2/p4p2/2PP4/1PN2NP1/PB2PPBP/R2Q1RK1 w -' => {
			eco => 'A99',
			# TRANSLATORS: A99: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6 7. Nc3 Qe8 8. b3 a5 9. Bb2 Na6
			variation => N__('Dutch: Ilyin-Zhenevsky, 8. b3 a5 9. Bb2 Na6'),
			moves => {
			},
		},
		'rnb1qrk1/1p2b1pp/2pppn2/p4p2/2PP4/1PN2NP1/PB2PPBP/R2Q1RK1 w -' => {
			eco => 'A99',
			# TRANSLATORS: A99: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6 7. Nc3 Qe8 8. b3 a5 9. Bb2 c6
			variation => N__('Dutch: Ilyin-Zhenevsky, 8. b3 a5 9. Bb2 c6'),
			moves => {
			},
		},
		'rnb2rk1/1pp1b1pp/3ppn2/p4p1q/2PP4/1PN2NP1/PB2PPBP/R2Q1RK1 w -' => {
			eco => 'A99',
			# TRANSLATORS: A99: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6 7. Nc3 Qe8 8. b3 a5 9. Bb2 Qh5
			variation => N__('Dutch: Ilyin-Zhenevsky, 8. b3 a5 9. Bb2 Qh5'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnb2rk1/1pp1b1pp/3ppn2/p4p1q/2PP4/1PN1PNP1/PB3PBP/R2Q1RK1 b -' => {
			eco => 'A99',
			# TRANSLATORS: A99: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6 7. Nc3 Qe8 8. b3 a5 9. Bb2 Qh5 10. e3
			variation => N__('Dutch: Ilyin-Zhenevsky, 8. b3 a5 9. Bb2 Qh5 10. e3'),
			moves => {
			},
		},
		'rnb1qrk1/1pp1b1pp/3ppn2/p4p2/2PP4/1PN2NP1/P1Q1PPBP/R1B2RK1 b -' => {
			eco => 'A99',
			# TRANSLATORS: A99: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6 7. Nc3 Qe8 8. b3 a5 9. Qc2
			variation => N__('Dutch: Ilyin-Zhenevsky, 8. b3 a5 9. Qc2'),
			moves => {
			},
		},
		'r1b1qrk1/ppp1b1pp/2nppn2/5p2/2PP4/1PN2NP1/P3PPBP/R1BQ1RK1 w -' => {
			eco => 'A99',
			# TRANSLATORS: A99: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6 7. Nc3 Qe8 8. b3 Nc6
			variation => N__('Dutch: Ilyin-Zhenevsky, 8. b3 Nc6'),
			moves => {
			},
		},
		'r1b1qrk1/pppnb1pp/3ppn2/5p2/2PP4/1PN2NP1/P3PPBP/R1BQ1RK1 w -' => {
			eco => 'A99',
			# TRANSLATORS: A99: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6 7. Nc3 Qe8 8. b3 Nbd7
			variation => N__('Dutch: Ilyin-Zhenevsky, 8. b3 Nbd7'),
			moves => {
			},
		},
		'rnb1qrk1/pp2b1pp/2pppn2/5p2/2PP4/1PN2NP1/P3PPBP/R1BQ1RK1 w -' => {
			eco => 'A99',
			# TRANSLATORS: A99: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6 7. Nc3 Qe8 8. b3 c6
			variation => N__('Dutch: Ilyin-Zhenevsky, 8. b3 c6'),
			moves => {
			},
		},
		'rnb2rk1/ppp1b1pp/3ppn2/5p1q/2PP4/1PN2NP1/P3PPBP/R1BQ1RK1 w -' => {
			eco => 'A99',
			# TRANSLATORS: A99: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6 7. Nc3 Qe8 8. b3 Qh5
			variation => N__('Dutch: Ilyin-Zhenevsky, 8. b3 Qh5'),
			moves => {
				'c1b2' => 1,
			},
		},
		'rnb2rk1/ppp1b1pp/3ppn2/5p1q/2PP4/1PN2NP1/PB2PPBP/R2Q1RK1 b -' => {
			eco => 'A99',
			# TRANSLATORS: A99: 1. d4 f5 2. c4 Nf6 3. g3 e6 4. Bg2 Be7 5. Nf3 O-O 6. O-O d6 7. Nc3 Qe8 8. b3 Qh5 9. Bb2
			variation => N__('Dutch: Ilyin-Zhenevsky, 8. b3 Qh5 9. Bb2'),
			moves => {
			},
		},
		'rnbqkbnr/pppppppp/8/8/4P3/8/PPPP1PPP/RNBQKBNR b KQkq' => {
			eco => 'B00a',
			# TRANSLATORS: B00a: 1. e4
			variation => N__('King\'s Pawn'),
			moves => {
				'a7a6' => 1,
				'b7b6' => 1,
				'b8c6' => 1,
				'c7c5' => 1,
				'c7c6' => 1,
				'd7d5' => 1,
				'd7d6' => 1,
				'e7e5' => 1,
				'e7e6' => 1,
				'f7f5' => 1,
				'g7g5' => 1,
				'g7g6' => 1,
				'g8f6' => 1,
				'g8h6' => 1,
			},
		},
		'rnbqkbnr/ppppp1pp/8/5p2/4P3/8/PPPP1PPP/RNBQKBNR w KQkq' => {
			eco => 'B00a',
			# TRANSLATORS: B00a: 1. e4 f5
			variation => N__('King\'s Pawn: Fred'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/7n/8/4P3/8/PPPP1PPP/RNBQKBNR w KQkq' => {
			eco => 'B00a',
			# TRANSLATORS: B00a: 1. e4 Nh6
			variation => N__('King\'s Pawn'),
			moves => {
				'd2d4' => 1,
			},
		},
		'rnbqkb1r/pppppppp/7n/8/3PP3/8/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'B00a',
			# TRANSLATORS: B00a: 1. e4 Nh6 2. d4
			variation => N__('King\'s Pawn'),
			moves => {
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/pppppp1p/6pn/8/3PP3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B00a',
			# TRANSLATORS: B00a: 1. e4 Nh6 2. d4 g6
			variation => N__('King\'s Pawn'),
			moves => {
				'c2c4' => 1,
			},
		},
		'rnbqkb1r/pppppp1p/6pn/8/2PPP3/8/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'B00a',
			# TRANSLATORS: B00a: 1. e4 Nh6 2. d4 g6 3. c4
			variation => N__('King\'s Pawn'),
			moves => {
				'f7f6' => 1,
			},
		},
		'rnbqkb1r/ppppp2p/5ppn/8/2PPP3/8/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'B00a',
			# TRANSLATORS: B00a: 1. e4 Nh6 2. d4 g6 3. c4 f6
			variation => N__('King\'s Pawn: Hippopotamus Defence'),
			moves => {
			},
		},
		'rnbqkbnr/pppppp1p/8/6p1/4P3/8/PPPP1PPP/RNBQKBNR w KQkq' => {
			eco => 'B00b',
			# TRANSLATORS: B00b: 1. e4 g5
			variation => N__('Reversed Grob (Borg/Basman Defence)'),
			moves => {
				'd2d4' => 1,
			},
		},
		'rnbqkbnr/pppppp1p/8/6p1/3PP3/8/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'B00b',
			# TRANSLATORS: B00b: 1. e4 g5 2. d4
			variation => N__('Reversed Grob (Borg/Basman Defence)'),
			moves => {
			},
		},
		'rnbqkbnr/1ppppppp/p7/8/4P3/8/PPPP1PPP/RNBQKBNR w KQkq' => {
			eco => 'B00c',
			# TRANSLATORS: B00c: 1. e4 a6
			variation => N__('St. George Defence'),
			moves => {
				'd2d4' => 1,
			},
		},
		'rnbqkbnr/1ppppppp/p7/8/3PP3/8/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'B00c',
			# TRANSLATORS: B00c: 1. e4 a6 2. d4
			variation => N__('St. George Defence'),
			moves => {
				'h7h6' => 1,
			},
		},
		'rnbqkbnr/1pppppp1/p6p/8/3PP3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B00c',
			# TRANSLATORS: B00c: 1. e4 a6 2. d4 h6
			variation => N__('Basman\'s Creepy-Crawly System (as Black)'),
			moves => {
			},
		},
		'rnbqkbnr/p1pppppp/1p6/8/4P3/8/PPPP1PPP/RNBQKBNR w KQkq' => {
			eco => 'B00d',
			# TRANSLATORS: B00d: 1. e4 b6
			variation => N__('Owen Defence'),
			moves => {
				'd2d4' => 1,
			},
		},
		'rnbqkbnr/p1pppppp/1p6/8/3PP3/8/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'B00d',
			# TRANSLATORS: B00d: 1. e4 b6 2. d4
			variation => N__('Owen Defence'),
			moves => {
				'c8b7' => 1,
				'e7e6' => 1,
			},
		},
		'rnbqkbnr/p1pp1ppp/1p2p3/8/3PP3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B00e',
			# TRANSLATORS: B00e: 1. e4 b6 2. d4 e6
			variation => N__('Owen Defence: French'),
			moves => {
			},
		},
		'rn1qkbnr/pbpppppp/1p6/8/3PP3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B00f',
			# TRANSLATORS: B00f: 1. e4 b6 2. d4 Bb7
			variation => N__('Owen Defence: 2. d4 Bb7'),
			moves => {
				'c1g5' => 1,
				'f1d3' => 1,
				'g1f3' => 1,
			},
		},
		'rn1qkbnr/pbpppppp/1p6/6B1/3PP3/8/PPP2PPP/RN1QKBNR b KQkq' => {
			eco => 'B00f',
			# TRANSLATORS: B00f: 1. e4 b6 2. d4 Bb7 3. Bg5
			variation => N__('Owen Defence: Naselwaus Gambit'),
			moves => {
			},
		},
		'rn1qkbnr/pbpppppp/1p6/8/3PP3/5N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B00f',
			# TRANSLATORS: B00f: 1. e4 b6 2. d4 Bb7 3. Nf3
			variation => N__('Owen Defence: Smith Gambit'),
			moves => {
			},
		},
		'rn1qkbnr/pbpppppp/1p6/8/3PP3/3B4/PPP2PPP/RNBQK1NR b KQkq' => {
			eco => 'B00g',
			# TRANSLATORS: B00g: 1. e4 b6 2. d4 Bb7 3. Bd3
			variation => N__('Owen Defence: 3. Bd3'),
			moves => {
				'e7e6' => 1,
				'f7f5' => 1,
				'g8f6' => 1,
			},
		},
		'rn1qkbnr/pbppp1pp/1p6/5p2/3PP3/3B4/PPP2PPP/RNBQK1NR w KQkq' => {
			eco => 'B00g',
			# TRANSLATORS: B00g: 1. e4 b6 2. d4 Bb7 3. Bd3 f5
			variation => N__('Owen Defence: Matinovsky Gambit'),
			moves => {
			},
		},
		'rn1qkb1r/pbpppppp/1p3n2/8/3PP3/3B4/PPP2PPP/RNBQK1NR w KQkq' => {
			eco => 'B00h',
			# TRANSLATORS: B00h: 1. e4 b6 2. d4 Bb7 3. Bd3 Nf6
			variation => N__('Owen Defence: 3. Bd3 Nf6'),
			moves => {
			},
		},
		'rn1qkbnr/pbpp1ppp/1p2p3/8/3PP3/3B4/PPP2PPP/RNBQK1NR w KQkq' => {
			eco => 'B00i',
			# TRANSLATORS: B00i: 1. e4 b6 2. d4 Bb7 3. Bd3 e6
			variation => N__('Owen Defence: 3. Bd3 e6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rn1qkbnr/pbpp1ppp/1p2p3/8/3PP3/3B1N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'B00j',
			# TRANSLATORS: B00j: 1. e4 b6 2. d4 Bb7 3. Bd3 e6 4. Nf3
			variation => N__('Owen Defence: 3. Bd3 e6 4. Nf3'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rn1qkbnr/pb1p1ppp/1p2p3/2p5/3PP3/3B1N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'B00k',
			# TRANSLATORS: B00k: 1. e4 b6 2. d4 Bb7 3. Bd3 e6 4. Nf3 c5
			variation => N__('Owen Defence: 3. Bd3 e6 4. Nf3 c5'),
			moves => {
				'c2c3' => 1,
			},
		},
		'rn1qkbnr/pb1p1ppp/1p2p3/2p5/3PP3/2PB1N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'B00k',
			# TRANSLATORS: B00k: 1. e4 b6 2. d4 Bb7 3. Bd3 e6 4. Nf3 c5 5. c3
			variation => N__('Owen Defence: 3. Bd3 e6 4. Nf3 c5 5. c3'),
			moves => {
			},
		},
		'r1bqkbnr/pppppppp/2n5/8/4P3/8/PPPP1PPP/RNBQKBNR w KQkq' => {
			eco => 'B00l',
			# TRANSLATORS: B00l: 1. e4 Nc6
			variation => N__('Nimzowitsch Defence'),
			moves => {
				'b1c3' => 1,
				'b2b4' => 1,
				'd2d4' => 1,
				'g1f3' => 1,
			},
		},
		'r1bqkbnr/pppppppp/2n5/8/1P2P3/8/P1PP1PPP/RNBQKBNR b KQkq' => {
			eco => 'B00l',
			# TRANSLATORS: B00l: 1. e4 Nc6 2. b4
			variation => N__('Nimzowitsch Defence: Wheeler Gambit'),
			moves => {
			},
		},
		'r1bqkbnr/pppppppp/2n5/8/4P3/2N5/PPPP1PPP/R1BQKBNR b KQkq' => {
			eco => 'B00m',
			# TRANSLATORS: B00m: 1. e4 Nc6 2. Nc3
			variation => N__('Nimzowitsch Defence: 2. Nc3'),
			moves => {
				'e7e6' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/2n1p3/8/4P3/2N5/PPPP1PPP/R1BQKBNR w KQkq' => {
			eco => 'B00m',
			# TRANSLATORS: B00m: 1. e4 Nc6 2. Nc3 e6
			variation => N__('Nimzowitsch Defence: 2. Nc3 e6'),
			moves => {
			},
		},
		'r1bqkb1r/pppppppp/2n2n2/8/4P3/2N5/PPPP1PPP/R1BQKBNR w KQkq' => {
			eco => 'B00m',
			# TRANSLATORS: B00m: 1. e4 Nc6 2. Nc3 Nf6
			variation => N__('Nimzowitsch Defence: 2. Nc3 Nf6'),
			moves => {
			},
		},
		'r1bqkbnr/pppppppp/2n5/8/4P3/5N2/PPPP1PPP/RNBQKB1R b KQkq' => {
			eco => 'B00n',
			# TRANSLATORS: B00n: 1. e4 Nc6 2. Nf3
			variation => N__('Nimzowitsch Defence: 2. Nf3'),
			moves => {
				'd7d6' => 1,
				'f7f5' => 1,
			},
		},
		'r1bqkbnr/ppppp1pp/2n5/5p2/4P3/5N2/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'B00n',
			# TRANSLATORS: B00n: 1. e4 Nc6 2. Nf3 f5
			variation => N__('Nimzowitsch Defence: Colorado Counter'),
			moves => {
			},
		},
		'r1bqkbnr/ppp1pppp/2np4/8/4P3/5N2/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'B00o',
			# TRANSLATORS: B00o: 1. e4 Nc6 2. Nf3 d6
			variation => N__('Nimzowitsch Defence: 2. Nf3 d6'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bqkbnr/ppp1pppp/2np4/8/3PP3/5N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B00o',
			# TRANSLATORS: B00o: 1. e4 Nc6 2. Nf3 d6 3. d4
			variation => N__('Nimzowitsch Defence: 2. Nf3 d6 3. d4'),
			moves => {
				'c8g4' => 1,
				'g8f6' => 1,
			},
		},
		'r2qkbnr/ppp1pppp/2np4/8/3PP1b1/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B00o',
			# TRANSLATORS: B00o: 1. e4 Nc6 2. Nf3 d6 3. d4 Bg4
			variation => N__('Nimzowitsch Defence: 2. Nf3 d6 3. d4 Bg4'),
			moves => {
			},
		},
		'r1bqkb1r/ppp1pppp/2np1n2/8/3PP3/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B00p',
			# TRANSLATORS: B00p: 1. e4 Nc6 2. Nf3 d6 3. d4 Nf6
			variation => N__('Nimzowitsch Defence: 2. Nf3 d6 3. d4 Nf6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r1bqkb1r/ppp1pppp/2np1n2/8/3PP3/2N2N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B00q',
			# TRANSLATORS: B00q: 1. e4 Nc6 2. Nf3 d6 3. d4 Nf6 4. Nc3
			variation => N__('Nimzowitsch Defence: 2. Nf3 d6 3. d4 Nf6 4. Nc3'),
			moves => {
				'c8g4' => 1,
				'g7g6' => 1,
			},
		},
		'r1bqkb1r/ppp1pp1p/2np1np1/8/3PP3/2N2N2/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B00q',
			# TRANSLATORS: B00q: 1. e4 Nc6 2. Nf3 d6 3. d4 Nf6 4. Nc3 g6
			variation => N__('Nimzowitsch Defence: 2. Nf3 d6 3. d4 Nf6 4. Nc3 g6'),
			moves => {
			},
		},
		'r2qkb1r/ppp1pppp/2np1n2/8/3PP1b1/2N2N2/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B00r',
			# TRANSLATORS: B00r: 1. e4 Nc6 2. Nf3 d6 3. d4 Nf6 4. Nc3 Bg4
			variation => N__('Nimzowitsch Defence: 2. Nf3 d6 3. d4 Nf6 4. Nc3 Bg4'),
			moves => {
				'c1e3' => 1,
				'd4d5' => 1,
				'f1b5' => 1,
				'f1e2' => 1,
			},
		},
		'r2qkb1r/ppp1pppp/2np1n2/3P4/4P1b1/2N2N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B00r',
			# TRANSLATORS: B00r: 1. e4 Nc6 2. Nf3 d6 3. d4 Nf6 4. Nc3 Bg4 5. d5
			variation => N__('Nimzowitsch Defence: 2. Nf3 d6 3. d4 Nf6 4. Nc3 Bg4 5. d5'),
			moves => {
			},
		},
		'r2qkb1r/ppp1pppp/2np1n2/1B6/3PP1b1/2N2N2/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'B00r',
			# TRANSLATORS: B00r: 1. e4 Nc6 2. Nf3 d6 3. d4 Nf6 4. Nc3 Bg4 5. Bb5
			variation => N__('Nimzowitsch Defence: 2. Nf3 d6 3. d4 Nf6 4. Nc3 Bg4 5. Bb5'),
			moves => {
			},
		},
		'r2qkb1r/ppp1pppp/2np1n2/8/3PP1b1/2N2N2/PPP1BPPP/R1BQK2R b KQkq' => {
			eco => 'B00r',
			# TRANSLATORS: B00r: 1. e4 Nc6 2. Nf3 d6 3. d4 Nf6 4. Nc3 Bg4 5. Be2
			variation => N__('Nimzowitsch Defence: 2. Nf3 d6 3. d4 Nf6 4. Nc3 Bg4 5. Be2'),
			moves => {
			},
		},
		'r2qkb1r/ppp1pppp/2np1n2/8/3PP1b1/2N1BN2/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'B00s',
			# TRANSLATORS: B00s: 1. e4 Nc6 2. Nf3 d6 3. d4 Nf6 4. Nc3 Bg4 5. Be3
			variation => N__('Nimzowitsch Defence: 2. Nf3 d6 3. d4 Nf6 4. Nc3 Bg4 5. Be3'),
			moves => {
			},
		},
		'r1bqkbnr/pppppppp/2n5/8/3PP3/8/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'B00t',
			# TRANSLATORS: B00t: 1. e4 Nc6 2. d4
			variation => N__('Nimzowitsch Defence: 2. d4'),
			moves => {
				'd7d5' => 1,
				'd7d6' => 1,
				'e7e5' => 1,
			},
		},
		'r1bqkbnr/ppp1pppp/2np4/8/3PP3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B00t',
			# TRANSLATORS: B00t: 1. e4 Nc6 2. d4 d6
			variation => N__('Nimzowitsch Defence: 2. d4 d6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r1bqkbnr/ppp1pppp/2np4/8/3PP3/2N5/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'B00t',
			# TRANSLATORS: B00t: 1. e4 Nc6 2. d4 d6 3. Nc3
			variation => N__('Nimzowitsch Defence: 2. d4 d6 3. Nc3'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4p3/3PP3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B00u',
			# TRANSLATORS: B00u: 1. e4 Nc6 2. d4 e5
			variation => N__('Nimzowitsch Defence: 2. d4 e5'),
			moves => {
				'd4d5' => 1,
				'd4e5' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/3Pp3/4P3/8/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'B00u',
			# TRANSLATORS: B00u: 1. e4 Nc6 2. d4 e5 3. d5
			variation => N__('Nimzowitsch Defence: 2. d4 e5 3. d5'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4P3/4P3/8/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'B00u',
			# TRANSLATORS: B00u: 1. e4 Nc6 2. d4 e5 3. dxe5
			variation => N__('Nimzowitsch Defence: 2. d4 e5 3.dxe5'),
			moves => {
				'f8c5' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/2b1P3/4P3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B00u',
			# TRANSLATORS: B00u: 1. e4 Nc6 2. d4 e5 3. dxe5 Bc5
			variation => N__('Nimzowitsch Defence: Bielefelder Gambit'),
			moves => {
			},
		},
		'r1bqkbnr/ppp1pppp/2n5/3p4/3PP3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B00v',
			# TRANSLATORS: B00v: 1. e4 Nc6 2. d4 d5
			variation => N__('Nimzowitsch Defence: 2. d4 d5'),
			moves => {
				'b1c3' => 1,
				'e4d5' => 1,
				'e4e5' => 1,
			},
		},
		'r1bqkbnr/ppp1pppp/2n5/3P4/3P4/8/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'B00v',
			# TRANSLATORS: B00v: 1. e4 Nc6 2. d4 d5 3. exd5
			variation => N__('Nimzowitsch Defence: 2. d4 d5 3.exd5'),
			moves => {
				'c6b4' => 1,
				'd8d5' => 1,
			},
		},
		'r1bqkbnr/ppp1pppp/8/3P4/1n1P4/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B00v',
			# TRANSLATORS: B00v: 1. e4 Nc6 2. d4 d5 3. exd5 Nb4
			variation => N__('Nimzowitsch Defence: Aachen Gambit'),
			moves => {
			},
		},
		'r1b1kbnr/ppp1pppp/2n5/3q4/3P4/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B00v',
			# TRANSLATORS: B00v: 1. e4 Nc6 2. d4 d5 3. exd5 Qxd5
			variation => N__('Nimzowitsch Defence: 2. d4 d5 3.exd5 Qxd5'),
			moves => {
				'b1c3' => 1,
				'g1f3' => 1,
			},
		},
		'r1b1kbnr/ppp1pppp/2n5/3q4/3P4/2N5/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'B00v',
			# TRANSLATORS: B00v: 1. e4 Nc6 2. d4 d5 3. exd5 Qxd5 4. Nc3
			variation => N__('Nimzowitsch Defence: Marshall Gambit'),
			moves => {
			},
		},
		'r1b1kbnr/ppp1pppp/2n5/3q4/3P4/5N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B00v',
			# TRANSLATORS: B00v: 1. e4 Nc6 2. d4 d5 3. exd5 Qxd5 4. Nf3
			variation => N__('Nimzowitsch Defence: 2. d4 d5 3.exd5 Qxd5 4. Nf3'),
			moves => {
			},
		},
		'r1bqkbnr/ppp1pppp/2n5/3p4/3PP3/2N5/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'B00w',
			# TRANSLATORS: B00w: 1. e4 Nc6 2. d4 d5 3. Nc3
			variation => N__('Nimzowitsch Defence: Bogoljubow Variation'),
			moves => {
				'd5e4' => 1,
				'e7e5' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkbnr/ppp1pppp/2n5/8/3Pp3/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'B00w',
			# TRANSLATORS: B00w: 1. e4 Nc6 2. d4 d5 3. Nc3 dxe4
			variation => N__('Nimzowitsch Defence: Bogoljubow, 3...dxe4'),
			moves => {
			},
		},
		'r1bqkbnr/ppp2ppp/2n5/3pp3/3PP3/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'B00w',
			# TRANSLATORS: B00w: 1. e4 Nc6 2. d4 d5 3. Nc3 e5
			variation => N__('Nimzowitsch Defence: Bogoljubow, 3... e5'),
			moves => {
			},
		},
		'r1bqkb1r/ppp1pppp/2n2n2/3p4/3PP3/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'B00w',
			# TRANSLATORS: B00w: 1. e4 Nc6 2. d4 d5 3. Nc3 Nf6
			variation => N__('Nimzowitsch Defence: Bogoljubow, 3... Nf6'),
			moves => {
			},
		},
		'r1bqkbnr/ppp1pppp/2n5/3pP3/3P4/8/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'B00x',
			# TRANSLATORS: B00x: 1. e4 Nc6 2. d4 d5 3. e5
			variation => N__('Nimzowitsch Defence: 2. d4 d5 3. e5'),
			moves => {
				'c8f5' => 1,
			},
		},
		'r2qkbnr/ppp1pppp/2n5/3pPb2/3P4/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B00x',
			# TRANSLATORS: B00x: 1. e4 Nc6 2. d4 d5 3. e5 Bf5
			variation => N__('Nimzowitsch Defence: 2. d4 d5 3. e5 Bf5'),
			moves => {
				'c2c3' => 1,
			},
		},
		'r2qkbnr/ppp1pppp/2n5/3pPb2/3P4/2P5/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'B00x',
			# TRANSLATORS: B00x: 1. e4 Nc6 2. d4 d5 3. e5 Bf5 4. c3
			variation => N__('Nimzowitsch Defence: 2. d4 d5 3. e5 Bf5 4. c3'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/4P3/8/PPPP1PPP/RNBQKBNR w KQkq' => {
			eco => 'B01a',
			# TRANSLATORS: B01a: 1. e4 d5
			variation => N__('Scandinavian (Centre Counter)'),
			moves => {
				'd2d3' => 1,
				'e4d5' => 1,
				'e4e5' => 1,
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/4P3/3P4/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'B01a',
			# TRANSLATORS: B01a: 1. e4 d5 2. d3
			variation => N__('Scandinavian: 2. d3'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/3P4/8/8/PPPP1PPP/RNBQKBNR b KQkq' => {
			eco => 'B01a',
			# TRANSLATORS: B01a: 1. e4 d5 2. exd5
			variation => N__('Scandinavian: 2.exd5'),
			moves => {
				'd8d5' => 1,
				'e7e5' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/8/3Pp3/8/8/PPPP1PPP/RNBQKBNR w KQkq' => {
			eco => 'B01a',
			# TRANSLATORS: B01a: 1. e4 d5 2. exd5 e5
			variation => N__('Scandinavian: Böhnke Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/3pP3/8/8/PPPP1PPP/RNBQKBNR b KQkq' => {
			eco => 'B01a',
			# TRANSLATORS: B01a: 1. e4 d5 2. e5
			variation => N__('Scandinavian: 2. e5'),
			moves => {
			},
		},
		'rnb1kbnr/ppp1pppp/8/3q4/8/8/PPPP1PPP/RNBQKBNR w KQkq' => {
			eco => 'B01b',
			# TRANSLATORS: B01b: 1. e4 d5 2. exd5 Qxd5
			variation => N__('Scandinavian: 2...Qxd5'),
			moves => {
				'b1c3' => 1,
				'd2d4' => 1,
				'g1f3' => 1,
			},
		},
		'rnb1kbnr/ppp1pppp/8/3q4/8/2N5/PPPP1PPP/R1BQKBNR b KQkq' => {
			eco => 'B01b',
			# TRANSLATORS: B01b: 1. e4 d5 2. exd5 Qxd5 3. Nc3
			variation => N__('Scandinavian: 2...Qxd5 3. Nc3'),
			moves => {
				'd5a5' => 1,
				'd5d6' => 1,
				'd5d8' => 1,
			},
		},
		'rnb1kbnr/ppp1pppp/8/3q4/3P4/8/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'B01b',
			# TRANSLATORS: B01b: 1. e4 d5 2. exd5 Qxd5 3. d4
			variation => N__('Scandinavian: 2...Qxd5 3. d4'),
			moves => {
				'e7e5' => 1,
				'g8f6' => 1,
			},
		},
		'rnb1kbnr/ppp2ppp/8/3qp3/3P4/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B01b',
			# TRANSLATORS: B01b: 1. e4 d5 2. exd5 Qxd5 3. d4 e5
			variation => N__('Scandinavian: 2...Qxd5 3. d4 e5'),
			moves => {
			},
		},
		'rnb1kb1r/ppp1pppp/5n2/3q4/3P4/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B01b',
			# TRANSLATORS: B01b: 1. e4 d5 2. exd5 Qxd5 3. d4 Nf6
			variation => N__('Scandinavian: 2...Qxd5 3. d4 Nf6'),
			moves => {
			},
		},
		'rnb1kbnr/ppp1pppp/8/3q4/8/5N2/PPPP1PPP/RNBQKB1R b KQkq' => {
			eco => 'B01b',
			# TRANSLATORS: B01b: 1. e4 d5 2. exd5 Qxd5 3. Nf3
			variation => N__('Scandinavian: 2...Qxd5 3. Nf3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnb1kb1r/ppp1pppp/5n2/3q4/8/5N2/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'B01b',
			# TRANSLATORS: B01b: 1. e4 d5 2. exd5 Qxd5 3. Nf3 Nf6
			variation => N__('Scandinavian: 2...Qxd5 3. Nf3 Nf6'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/8/8/2N5/PPPP1PPP/R1BQKBNR w KQkq' => {
			eco => 'B01c',
			# TRANSLATORS: B01c: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qd8
			variation => N__('Scandinavian: 2...Qxd5 3. Nc3 Qd8'),
			moves => {
			},
		},
		'rnb1kbnr/ppp1pppp/3q4/8/8/2N5/PPPP1PPP/R1BQKBNR w KQkq' => {
			eco => 'B01d',
			# TRANSLATORS: B01d: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qd6
			variation => N__('Scandinavian: Schiller Defence'),
			moves => {
				'd2d4' => 1,
			},
		},
		'rnb1kbnr/ppp1pppp/3q4/8/3P4/2N5/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'B01d',
			# TRANSLATORS: B01d: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qd6 4. d4
			variation => N__('Scandinavian: Schiller Defence'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnb1kb1r/ppp1pppp/3q1n2/8/3P4/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'B01d',
			# TRANSLATORS: B01d: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qd6 4. d4 Nf6
			variation => N__('Scandinavian: Schiller, 4. d4 Nf6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnb1kb1r/ppp1pppp/3q1n2/8/3P4/2N2N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B01d',
			# TRANSLATORS: B01d: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qd6 4. d4 Nf6 5. Nf3
			variation => N__('Scandinavian: Schiller, 4. d4 Nf6'),
			moves => {
				'a7a6' => 1,
			},
		},
		'rnb1kb1r/1pp1pppp/p2q1n2/8/3P4/2N2N2/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B01d',
			# TRANSLATORS: B01d: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qd6 4. d4 Nf6 5. Nf3 a6
			variation => N__('Scandinavian: Schiller, Bronstein Variation'),
			moves => {
			},
		},
		'rnb1kbnr/ppp1pppp/8/q7/8/2N5/PPPP1PPP/R1BQKBNR w KQkq' => {
			eco => 'B01e',
			# TRANSLATORS: B01e: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5
			variation => N__('Scandinavian: 2...Qxd5 3. Nc3 Qa5'),
			moves => {
				'b2b4' => 1,
				'd2d4' => 1,
				'f1c4' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
			},
		},
		'rnb1kbnr/ppp1pppp/8/q7/1P6/2N5/P1PP1PPP/R1BQKBNR b KQkq' => {
			eco => 'B01e',
			# TRANSLATORS: B01e: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. b4
			variation => N__('Scandinavian, Mieses Gambit'),
			moves => {
			},
		},
		'rnb1kbnr/ppp1pppp/8/q7/2B5/2N5/PPPP1PPP/R1BQK1NR b KQkq' => {
			eco => 'B01e',
			# TRANSLATORS: B01e: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. Bc4
			variation => N__('Scandinavian: 2...Qxd5 3. Nc3 Qa5 4. Bc4'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnb1kb1r/ppp1pppp/5n2/q7/2B5/2N5/PPPP1PPP/R1BQK1NR w KQkq' => {
			eco => 'B01e',
			# TRANSLATORS: B01e: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. Bc4 Nf6
			variation => N__('Scandinavian: 2...Qxd5 3. Nc3 Qa5 4. Bc4 Nf6'),
			moves => {
			},
		},
		'rnb1kbnr/ppp1pppp/8/q7/8/2N3P1/PPPP1P1P/R1BQKBNR b KQkq' => {
			eco => 'B01e',
			# TRANSLATORS: B01e: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. g3
			variation => N__('Scandinavian: 2...Qxd5 3. Nc3 Qa5 4. g3'),
			moves => {
			},
		},
		'rnb1kbnr/ppp1pppp/8/q7/8/2N2N2/PPPP1PPP/R1BQKB1R b KQkq' => {
			eco => 'B01f',
			# TRANSLATORS: B01f: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. Nf3
			variation => N__('Scandinavian: 2...Qxd5 3. Nc3 Qa5 4. Nf3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnb1kb1r/ppp1pppp/5n2/q7/8/2N2N2/PPPP1PPP/R1BQKB1R w KQkq' => {
			eco => 'B01f',
			# TRANSLATORS: B01f: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. Nf3 Nf6
			variation => N__('Scandinavian: 2...Qxd5 3. Nc3 Qa5 4. Nf3 Nf6'),
			moves => {
				'f1e2' => 1,
			},
		},
		'rnb1kb1r/ppp1pppp/5n2/q7/8/2N2N2/PPPPBPPP/R1BQK2R b KQkq' => {
			eco => 'B01f',
			# TRANSLATORS: B01f: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. Nf3 Nf6 5. Be2
			variation => N__('Scandinavian: 2...Qxd5 3. Nc3 Qa5 4. Nf3 Nf6 5. Be2'),
			moves => {
			},
		},
		'rnb1kbnr/ppp1pppp/8/q7/3P4/2N5/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'B01g',
			# TRANSLATORS: B01g: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. d4
			variation => N__('Scandinavian: 2...Qxd5 3. Nc3 Qa5 4. d4'),
			moves => {
				'c7c6' => 1,
				'e7e5' => 1,
				'g8f6' => 1,
			},
		},
		'rnb1kbnr/ppp2ppp/8/q3p3/3P4/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'B01g',
			# TRANSLATORS: B01g: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. d4 e5
			variation => N__('Scandinavian: Anderssen Counterattack'),
			moves => {
				'd4e5' => 1,
				'g1f3' => 1,
			},
		},
		'rnb1kbnr/ppp2ppp/8/q3P3/8/2N5/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'B01g',
			# TRANSLATORS: B01g: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. d4 e5 5. dxe5
			variation => N__('Scandinavian: Anderssen Counterattack, 5.dxe5'),
			moves => {
			},
		},
		'rnb1kbnr/ppp2ppp/8/q3p3/3P4/2N2N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B01g',
			# TRANSLATORS: B01g: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. d4 e5 5. Nf3
			variation => N__('Scandinavian: Anderssen Counterattack, Goteborg Variation'),
			moves => {
				'c8g4' => 1,
			},
		},
		'rn2kbnr/ppp2ppp/8/q3p3/3P2b1/2N2N2/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B01g',
			# TRANSLATORS: B01g: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. d4 e5 5. Nf3 Bg4
			variation => N__('Scandinavian: Anderssen Counterattack, Collijn Variation'),
			moves => {
			},
		},
		'rnb1kbnr/pp2pppp/2p5/q7/3P4/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'B01h',
			# TRANSLATORS: B01h: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. d4 c6
			variation => N__('Scandinavian: 2...Qxd5 3. Nc3 Qa5 4. d4 c6'),
			moves => {
				'f1c4' => 1,
				'g1f3' => 1,
			},
		},
		'rnb1kbnr/pp2pppp/2p5/q7/2BP4/2N5/PPP2PPP/R1BQK1NR b KQkq' => {
			eco => 'B01h',
			# TRANSLATORS: B01h: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. d4 c6 5. Bc4
			variation => N__('Scandinavian: 2...Qxd5 3. Nc3 Qa5 4. d4 c6 5. Bc4'),
			moves => {
			},
		},
		'rnb1kbnr/pp2pppp/2p5/q7/3P4/2N2N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B01h',
			# TRANSLATORS: B01h: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. d4 c6 5. Nf3
			variation => N__('Scandinavian: 2...Qxd5 3. Nc3 Qa5 4. d4 c6 5. Nf3'),
			moves => {
			},
		},
		'rnb1kb1r/ppp1pppp/5n2/q7/3P4/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'B01i',
			# TRANSLATORS: B01i: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. d4 Nf6
			variation => N__('Scandinavian: 2...Qxd5 3. Nc3 Qa5 4. d4 Nf6'),
			moves => {
				'c1d2' => 1,
				'f1c4' => 1,
				'g1f3' => 1,
			},
		},
		'rnb1kb1r/ppp1pppp/5n2/q7/3P4/2N5/PPPB1PPP/R2QKBNR b KQkq' => {
			eco => 'B01i',
			# TRANSLATORS: B01i: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. d4 Nf6 5. Bd2
			variation => N__('Scandinavian: 2...Qxd5, 5. Bd2'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rnb1kb1r/pp2pppp/2p2n2/q7/3P4/2N5/PPPB1PPP/R2QKBNR w KQkq' => {
			eco => 'B01i',
			# TRANSLATORS: B01i: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. d4 Nf6 5. Bd2 c6
			variation => N__('Scandinavian: 2...Qxd5, 5. Bd2 c6'),
			moves => {
			},
		},
		'rnb1kb1r/ppp1pppp/5n2/q7/2BP4/2N5/PPP2PPP/R1BQK1NR b KQkq' => {
			eco => 'B01i',
			# TRANSLATORS: B01i: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. d4 Nf6 5. Bc4
			variation => N__('Scandinavian: 2...Qxd5, 5. Bc4'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rnb1kb1r/pp2pppp/2p2n2/q7/2BP4/2N5/PPP2PPP/R1BQK1NR w KQkq' => {
			eco => 'B01i',
			# TRANSLATORS: B01i: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. d4 Nf6 5. Bc4 c6
			variation => N__('Scandinavian: 2...Qxd5, 5. Bc4 c6'),
			moves => {
			},
		},
		'rnb1kb1r/ppp1pppp/5n2/q7/3P4/2N2N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B01j',
			# TRANSLATORS: B01j: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. d4 Nf6 5. Nf3
			variation => N__('Scandinavian: 2...Qxd5, 5. Nf3'),
			moves => {
				'c7c6' => 1,
				'c8f5' => 1,
				'c8g4' => 1,
			},
		},
		'rn2kb1r/ppp1pppp/5n2/q7/3P2b1/2N2N2/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B01j',
			# TRANSLATORS: B01j: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. d4 Nf6 5. Nf3 Bg4
			variation => N__('Scandinavian: 2...Qxd5, 5. Nf3 Bg4'),
			moves => {
				'h2h3' => 1,
			},
		},
		'rn2kb1r/ppp1pppp/5n2/q7/3P2b1/2N2N1P/PPP2PP1/R1BQKB1R b KQkq' => {
			eco => 'B01k',
			# TRANSLATORS: B01k: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. d4 Nf6 5. Nf3 Bg4 6. h3
			variation => N__('Scandinavian: Lasker Variation'),
			moves => {
			},
		},
		'rn2kb1r/ppp1pppp/5n2/q4b2/3P4/2N2N2/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B01l',
			# TRANSLATORS: B01l: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. d4 Nf6 5. Nf3 Bf5
			variation => N__('Scandinavian: 2...Qxd5, 5. Nf3 Bf5'),
			moves => {
				'f1c4' => 1,
				'f3e5' => 1,
			},
		},
		'rn2kb1r/ppp1pppp/5n2/q4b2/2BP4/2N2N2/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'B01l',
			# TRANSLATORS: B01l: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. d4 Nf6 5. Nf3 Bf5 6. Bc4
			variation => N__('Scandinavian: 2...Qxd5, 5. Nf3 Bf5 6. Bc4'),
			moves => {
			},
		},
		'rn2kb1r/ppp1pppp/5n2/q3Nb2/3P4/2N5/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B01l',
			# TRANSLATORS: B01l: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. d4 Nf6 5. Nf3 Bf5 6. Ne5
			variation => N__('Scandinavian: 2...Qxd5, 5. Nf3 Bf5'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rn2kb1r/pp2pppp/2p2n2/q3Nb2/3P4/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B01l',
			# TRANSLATORS: B01l: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. d4 Nf6 5. Nf3 Bf5 6. Ne5 c6
			variation => N__('Scandinavian: 2...Qxd5, 5. Nf3 Bf5'),
			moves => {
				'g2g4' => 1,
			},
		},
		'rn2kb1r/pp2pppp/2p2n2/q3Nb2/3P2P1/2N5/PPP2P1P/R1BQKB1R b KQkq' => {
			eco => 'B01l',
			# TRANSLATORS: B01l: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. d4 Nf6 5. Nf3 Bf5 6. Ne5 c6 7. g4
			variation => N__('Scandinavian: Grünfeld Variation'),
			moves => {
			},
		},
		'rnb1kb1r/pp2pppp/2p2n2/q7/3P4/2N2N2/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B01m',
			# TRANSLATORS: B01m: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. d4 Nf6 5. Nf3 c6
			variation => N__('Scandinavian: 2...Qxd5, Main Line'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnb1kb1r/pp2pppp/2p2n2/q7/2BP4/2N2N2/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'B01n',
			# TRANSLATORS: B01n: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. d4 Nf6 5. Nf3 c6 6. Bc4
			variation => N__('Scandinavian: 2...Qxd5, Main Line, 6. Bc4'),
			moves => {
				'c8f5' => 1,
				'c8g4' => 1,
			},
		},
		'rn2kb1r/pp2pppp/2p2n2/q7/2BP2b1/2N2N2/PPP2PPP/R1BQK2R w KQkq' => {
			eco => 'B01n',
			# TRANSLATORS: B01n: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. d4 Nf6 5. Nf3 c6 6. Bc4 Bg4
			variation => N__('Scandinavian: 2...Qxd5, Main Line, 6. Bc4 Bg4'),
			moves => {
			},
		},
		'rn2kb1r/pp2pppp/2p2n2/q4b2/2BP4/2N2N2/PPP2PPP/R1BQK2R w KQkq' => {
			eco => 'B01o',
			# TRANSLATORS: B01o: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. d4 Nf6 5. Nf3 c6 6. Bc4 Bf5
			variation => N__('Scandinavian: 2...Qxd5, Main Line, 6. Bc4 Bf5'),
			moves => {
				'c1d2' => 1,
			},
		},
		'rn2kb1r/pp2pppp/2p2n2/q4b2/2BP4/2N2N2/PPPB1PPP/R2QK2R b KQkq' => {
			eco => 'B01p',
			# TRANSLATORS: B01p: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. d4 Nf6 5. Nf3 c6 6. Bc4 Bf5 7. Bd2
			variation => N__('Scandinavian: 2...Qxd5, Main Line, 6. Bc4 Bf5 7. Bd2'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rn2kb1r/pp3ppp/2p1pn2/q4b2/2BP4/2N2N2/PPPB1PPP/R2QK2R w KQkq' => {
			eco => 'B01p',
			# TRANSLATORS: B01p: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. d4 Nf6 5. Nf3 c6 6. Bc4 Bf5 7. Bd2 e6
			variation => N__('Scandinavian: 2...Qxd5, Main Line, 6. Bc4 Bf5 7. Bd2 e6'),
			moves => {
				'c3d5' => 1,
				'd1e2' => 1,
			},
		},
		'rn2kb1r/pp3ppp/2p1pn2/q2N1b2/2BP4/5N2/PPPB1PPP/R2QK2R b KQkq' => {
			eco => 'B01p',
			# TRANSLATORS: B01p: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. d4 Nf6 5. Nf3 c6 6. Bc4 Bf5 7. Bd2 e6 8. Nd5
			variation => N__('Scandinavian: 2...Qxd5, Main Line, 8. Nd5'),
			moves => {
			},
		},
		'rn2kb1r/pp3ppp/2p1pn2/q4b2/2BP4/2N2N2/PPPBQPPP/R3K2R b KQkq' => {
			eco => 'B01q',
			# TRANSLATORS: B01q: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. d4 Nf6 5. Nf3 c6 6. Bc4 Bf5 7. Bd2 e6 8. Qe2
			variation => N__('Scandinavian: 2...Qxd5, Main Line, 8. Qe2'),
			moves => {
				'f8b4' => 1,
			},
		},
		'rn2k2r/pp3ppp/2p1pn2/q4b2/1bBP4/2N2N2/PPPBQPPP/R3K2R w KQkq' => {
			eco => 'B01q',
			# TRANSLATORS: B01q: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. d4 Nf6 5. Nf3 c6 6. Bc4 Bf5 7. Bd2 e6 8. Qe2 Bb4
			variation => N__('Scandinavian: 2...Qxd5, Main Line, 8. Qe2 Bb4'),
			moves => {
				'a2a3' => 1,
				'e1c1' => 1,
			},
		},
		'rn2k2r/pp3ppp/2p1pn2/q4b2/1bBP4/P1N2N2/1PPBQPPP/R3K2R b KQkq' => {
			eco => 'B01q',
			# TRANSLATORS: B01q: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. d4 Nf6 5. Nf3 c6 6. Bc4 Bf5 7. Bd2 e6 8. Qe2 Bb4 9. a3
			variation => N__('Scandinavian: 2...Qxd5, Main Line, 8. Qe2 Bb4 9. a3'),
			moves => {
			},
		},
		'rn2k2r/pp3ppp/2p1pn2/q4b2/1bBP4/2N2N2/PPPBQPPP/2KR3R b kq' => {
			eco => 'B01q',
			# TRANSLATORS: B01q: 1. e4 d5 2. exd5 Qxd5 3. Nc3 Qa5 4. d4 Nf6 5. Nf3 c6 6. Bc4 Bf5 7. Bd2 e6 8. Qe2 Bb4 9. O-O-O
			variation => N__('Scandinavian: 2...Qxd5, Main Line, 8. Qe2 Bb4 9.O-O-O'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3P4/8/8/PPPP1PPP/RNBQKBNR w KQkq' => {
			eco => 'B01r',
			# TRANSLATORS: B01r: 1. e4 d5 2. exd5 Nf6
			variation => N__('Scandinavian: 2... Nf6'),
			moves => {
				'c2c4' => 1,
				'd2d4' => 1,
				'f1b5' => 1,
				'f1c4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3P4/2B5/8/PPPP1PPP/RNBQK1NR b KQkq' => {
			eco => 'B01r',
			# TRANSLATORS: B01r: 1. e4 d5 2. exd5 Nf6 3. Bc4
			variation => N__('Scandinavian: 2... Nf6 3. Bc4'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3P4/8/5N2/PPPP1PPP/RNBQKB1R b KQkq' => {
			eco => 'B01r',
			# TRANSLATORS: B01r: 1. e4 d5 2. exd5 Nf6 3. Nf3
			variation => N__('Scandinavian: 2... Nf6 3. Nf3'),
			moves => {
				'f6d5' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/8/3n4/8/5N2/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'B01r',
			# TRANSLATORS: B01r: 1. e4 d5 2. exd5 Nf6 3. Nf3 Nxd5
			variation => N__('Scandinavian: 2... Nf6 3. Nf3 Nxd5'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/1B1P4/8/8/PPPP1PPP/RNBQK1NR b KQkq' => {
			eco => 'B01s',
			# TRANSLATORS: B01s: 1. e4 d5 2. exd5 Nf6 3. Bb5+
			variation => N__('Scandinavian: 2... Nf6 3. Bb5+'),
			moves => {
				'b8d7' => 1,
				'c8d7' => 1,
			},
		},
		'r1bqkb1r/pppnpppp/5n2/1B1P4/8/8/PPPP1PPP/RNBQK1NR w KQkq' => {
			eco => 'B01s',
			# TRANSLATORS: B01s: 1. e4 d5 2. exd5 Nf6 3. Bb5+ Nbd7
			variation => N__('Scandinavian: 2... Nf6 3. Bb5+ Nbd7'),
			moves => {
			},
		},
		'rn1qkb1r/pppbpppp/5n2/1B1P4/8/8/PPPP1PPP/RNBQK1NR w KQkq' => {
			eco => 'B01s',
			# TRANSLATORS: B01s: 1. e4 d5 2. exd5 Nf6 3. Bb5+ Bd7
			variation => N__('Scandinavian: 2... Nf6 3. Bb5+ Bd7'),
			moves => {
				'b5c4' => 1,
				'b5e2' => 1,
			},
		},
		'rn1qkb1r/pppbpppp/5n2/3P4/2B5/8/PPPP1PPP/RNBQK1NR b KQkq' => {
			eco => 'B01s',
			# TRANSLATORS: B01s: 1. e4 d5 2. exd5 Nf6 3. Bb5+ Bd7 4. Bc4
			variation => N__('Scandinavian: 2... Nf6 3. Bb5+ Bd7 4. Bc4'),
			moves => {
				'd7g4' => 1,
			},
		},
		'rn1qkb1r/ppp1pppp/5n2/3P4/2B3b1/8/PPPP1PPP/RNBQK1NR w KQkq' => {
			eco => 'B01s',
			# TRANSLATORS: B01s: 1. e4 d5 2. exd5 Nf6 3. Bb5+ Bd7 4. Bc4 Bg4
			variation => N__('Scandinavian: 2... Nf6 3. Bb5+ Bd7 4. Bc4 Bg4'),
			moves => {
			},
		},
		'rn1qkb1r/pppbpppp/5n2/3P4/8/8/PPPPBPPP/RNBQK1NR b KQkq' => {
			eco => 'B01s',
			# TRANSLATORS: B01s: 1. e4 d5 2. exd5 Nf6 3. Bb5+ Bd7 4. Be2
			variation => N__('Scandinavian: 2... Nf6 3. Bb5+ Bd7 4. Be2'),
			moves => {
				'f6d5' => 1,
			},
		},
		'rn1qkb1r/pppbpppp/8/3n4/8/8/PPPPBPPP/RNBQK1NR w KQkq' => {
			eco => 'B01s',
			# TRANSLATORS: B01s: 1. e4 d5 2. exd5 Nf6 3. Bb5+ Bd7 4. Be2 Nxd5
			variation => N__('Scandinavian: 2... Nf6 3. Bb5+ Bd7 4. Be2'),
			moves => {
				'd2d4' => 1,
			},
		},
		'rn1qkb1r/pppbpppp/8/3n4/3P4/8/PPP1BPPP/RNBQK1NR b KQkq' => {
			eco => 'B01s',
			# TRANSLATORS: B01s: 1. e4 d5 2. exd5 Nf6 3. Bb5+ Bd7 4. Be2 Nxd5 5. d4
			variation => N__('Scandinavian: 2... Nf6 3. Bb5+ Bd7 4. Be2'),
			moves => {
				'd7f5' => 1,
			},
		},
		'rn1qkb1r/ppp1pppp/8/3n1b2/3P4/8/PPP1BPPP/RNBQK1NR w KQkq' => {
			eco => 'B01s',
			# TRANSLATORS: B01s: 1. e4 d5 2. exd5 Nf6 3. Bb5+ Bd7 4. Be2 Nxd5 5. d4 Bf5
			variation => N__('Scandinavian: 2... Nf6 3. Bb5+ Bd7 4. Be2 Nxd5 5. d4 Bf5'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3P4/2P5/8/PP1P1PPP/RNBQKBNR b KQkq' => {
			eco => 'B01t',
			# TRANSLATORS: B01t: 1. e4 d5 2. exd5 Nf6 3. c4
			variation => N__('Scandinavian: 2... Nf6 3. c4'),
			moves => {
				'c7c6' => 1,
				'e7e6' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/3P4/2P5/8/PP1P1PPP/RNBQKBNR w KQkq' => {
			eco => 'B01t',
			# TRANSLATORS: B01t: 1. e4 d5 2. exd5 Nf6 3. c4 c6
			variation => N__('Scandinavian: Scandinavian Gambit'),
			moves => {
				'd5c6' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/2P2n2/8/2P5/8/PP1P1PPP/RNBQKBNR b KQkq' => {
			eco => 'B01t',
			# TRANSLATORS: B01t: 1. e4 d5 2. exd5 Nf6 3. c4 c6 4. dxc6
			variation => N__('Scandinavian: Scandinavian Gambit Accepted'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3P4/2P5/8/PP1P1PPP/RNBQKBNR w KQkq' => {
			eco => 'B01t',
			# TRANSLATORS: B01t: 1. e4 d5 2. exd5 Nf6 3. c4 e6
			variation => N__('Scandinavian: Icelandic Gambit'),
			moves => {
				'd5e6' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4Pn2/8/2P5/8/PP1P1PPP/RNBQKBNR b KQkq' => {
			eco => 'B01t',
			# TRANSLATORS: B01t: 1. e4 d5 2. exd5 Nf6 3. c4 e6 4. dxe6
			variation => N__('Scandinavian: Icelandic Gambit Accepted'),
			moves => {
				'c8e6' => 1,
			},
		},
		'rn1qkb1r/ppp2ppp/4bn2/8/2P5/8/PP1P1PPP/RNBQKBNR w KQkq' => {
			eco => 'B01t',
			# TRANSLATORS: B01t: 1. e4 d5 2. exd5 Nf6 3. c4 e6 4. dxe6 Bxe6
			variation => N__('Scandinavian: Icelandic Gambit Accepted'),
			moves => {
				'd2d4' => 1,
				'g1f3' => 1,
			},
		},
		'rn1qkb1r/ppp2ppp/4bn2/8/2PP4/8/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'B01t',
			# TRANSLATORS: B01t: 1. e4 d5 2. exd5 Nf6 3. c4 e6 4. dxe6 Bxe6 5. d4
			variation => N__('Scandinavian: Icelandic Gambit, 5. d4'),
			moves => {
			},
		},
		'rn1qkb1r/ppp2ppp/4bn2/8/2P5/5N2/PP1P1PPP/RNBQKB1R b KQkq' => {
			eco => 'B01t',
			# TRANSLATORS: B01t: 1. e4 d5 2. exd5 Nf6 3. c4 e6 4. dxe6 Bxe6 5. Nf3
			variation => N__('Scandinavian: Icelandic Gambit, 5. Nf3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3P4/3P4/8/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'B01u',
			# TRANSLATORS: B01u: 1. e4 d5 2. exd5 Nf6 3. d4
			variation => N__('Scandinavian: 2... Nf6 3. d4'),
			moves => {
				'c8g4' => 1,
				'f6d5' => 1,
				'g7g6' => 1,
			},
		},
		'rn1qkb1r/ppp1pppp/5n2/3P4/3P2b1/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B01u',
			# TRANSLATORS: B01u: 1. e4 d5 2. exd5 Nf6 3. d4 Bg4
			variation => N__('Scandinavian: Portuguese Variation'),
			moves => {
				'f1b5' => 1,
				'f1e2' => 1,
				'f2f3' => 1,
				'g1f3' => 1,
			},
		},
		'rn1qkb1r/ppp1pppp/5n2/1B1P4/3P2b1/8/PPP2PPP/RNBQK1NR b KQkq' => {
			eco => 'B01u',
			# TRANSLATORS: B01u: 1. e4 d5 2. exd5 Nf6 3. d4 Bg4 4. Bb5+
			variation => N__('Scandinavian: Portuguese, 4. Bb5+'),
			moves => {
			},
		},
		'rn1qkb1r/ppp1pppp/5n2/3P4/3P2b1/8/PPP1BPPP/RNBQK1NR b KQkq' => {
			eco => 'B01u',
			# TRANSLATORS: B01u: 1. e4 d5 2. exd5 Nf6 3. d4 Bg4 4. Be2
			variation => N__('Scandinavian: Portuguese, 4. Be2'),
			moves => {
				'g4e2' => 1,
			},
		},
		'rn1qkb1r/ppp1pppp/5n2/3P4/3P4/8/PPP1bPPP/RNBQK1NR w KQkq' => {
			eco => 'B01u',
			# TRANSLATORS: B01u: 1. e4 d5 2. exd5 Nf6 3. d4 Bg4 4. Be2 Bxe2
			variation => N__('Scandinavian: Portuguese, 4. Be2 Bxe2'),
			moves => {
			},
		},
		'rn1qkb1r/ppp1pppp/5n2/3P4/3P2b1/5N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B01u',
			# TRANSLATORS: B01u: 1. e4 d5 2. exd5 Nf6 3. d4 Bg4 4. Nf3
			variation => N__('Scandinavian: Portuguese, 4. Nf3'),
			moves => {
				'd8d5' => 1,
			},
		},
		'rn2kb1r/ppp1pppp/5n2/3q4/3P2b1/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B01u',
			# TRANSLATORS: B01u: 1. e4 d5 2. exd5 Nf6 3. d4 Bg4 4. Nf3 Qxd5
			variation => N__('Scandinavian: Portuguese, 4. Nf3 Qxd5'),
			moves => {
				'f1e2' => 1,
			},
		},
		'rn2kb1r/ppp1pppp/5n2/3q4/3P2b1/5N2/PPP1BPPP/RNBQK2R b KQkq' => {
			eco => 'B01u',
			# TRANSLATORS: B01u: 1. e4 d5 2. exd5 Nf6 3. d4 Bg4 4. Nf3 Qxd5 5. Be2
			variation => N__('Scandinavian: Portuguese, 4. Nf3 Qxd5 5. Be2'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r3kb1r/ppp1pppp/2n2n2/3q4/3P2b1/5N2/PPP1BPPP/RNBQK2R w KQkq' => {
			eco => 'B01u',
			# TRANSLATORS: B01u: 1. e4 d5 2. exd5 Nf6 3. d4 Bg4 4. Nf3 Qxd5 5. Be2 Nc6
			variation => N__('Scandinavian: Portuguese, 4. Nf3 Qxd5 5. Be2 Nc6'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/3P4/3P4/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B01u',
			# TRANSLATORS: B01u: 1. e4 d5 2. exd5 Nf6 3. d4 g6
			variation => N__('Scandinavian: Richter Variation'),
			moves => {
			},
		},
		'rn1qkb1r/ppp1pppp/5n2/3P4/3P2b1/5P2/PPP3PP/RNBQKBNR b KQkq' => {
			eco => 'B01v',
			# TRANSLATORS: B01v: 1. e4 d5 2. exd5 Nf6 3. d4 Bg4 4. f3
			variation => N__('Scandinavian: Portuguese, 4. f3'),
			moves => {
				'g4f5' => 1,
			},
		},
		'rn1qkb1r/ppp1pppp/5n2/3P1b2/3P4/5P2/PPP3PP/RNBQKBNR w KQkq' => {
			eco => 'B01v',
			# TRANSLATORS: B01v: 1. e4 d5 2. exd5 Nf6 3. d4 Bg4 4. f3 Bf5
			variation => N__('Scandinavian: Portuguese, 4. f3 Bf5'),
			moves => {
				'c2c4' => 1,
				'f1b5' => 1,
			},
		},
		'rn1qkb1r/ppp1pppp/5n2/3P1b2/2PP4/5P2/PP4PP/RNBQKBNR b KQkq' => {
			eco => 'B01v',
			# TRANSLATORS: B01v: 1. e4 d5 2. exd5 Nf6 3. d4 Bg4 4. f3 Bf5 5. c4
			variation => N__('Scandinavian: Portuguese, 4. f3 Bf5 5. c4'),
			moves => {
			},
		},
		'rn1qkb1r/ppp1pppp/5n2/1B1P1b2/3P4/5P2/PPP3PP/RNBQK1NR b KQkq' => {
			eco => 'B01v',
			# TRANSLATORS: B01v: 1. e4 d5 2. exd5 Nf6 3. d4 Bg4 4. f3 Bf5 5. Bb5+
			variation => N__('Scandinavian: Portuguese, 4. f3 Bf5 5. Bb5+'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r2qkb1r/pppnpppp/5n2/1B1P1b2/3P4/5P2/PPP3PP/RNBQK1NR w KQkq' => {
			eco => 'B01v',
			# TRANSLATORS: B01v: 1. e4 d5 2. exd5 Nf6 3. d4 Bg4 4. f3 Bf5 5. Bb5+ Nbd7
			variation => N__('Scandinavian: Portuguese, 4. f3 Bf5 5. Bb5+ Nbd7'),
			moves => {
				'c2c4' => 1,
			},
		},
		'r2qkb1r/pppnpppp/5n2/1B1P1b2/2PP4/5P2/PP4PP/RNBQK1NR b KQkq' => {
			eco => 'B01v',
			# TRANSLATORS: B01v: 1. e4 d5 2. exd5 Nf6 3. d4 Bg4 4. f3 Bf5 5. Bb5+ Nbd7 6. c4
			variation => N__('Scandinavian: Portuguese, 4. f3 Bf5 5. Bb5+ Nbd7 6. c4'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/8/3n4/3P4/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B01w',
			# TRANSLATORS: B01w: 1. e4 d5 2. exd5 Nf6 3. d4 Nxd5
			variation => N__('Scandinavian: Marshall Variation'),
			moves => {
				'c2c4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/8/3n4/3P4/5N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B01w',
			# TRANSLATORS: B01w: 1. e4 d5 2. exd5 Nf6 3. d4 Nxd5 4. Nf3
			variation => N__('Scandinavian: Marshall, 4. Nf3'),
			moves => {
				'c8f5' => 1,
				'c8g4' => 1,
				'g7g6' => 1,
			},
		},
		'rn1qkb1r/ppp1pppp/8/3n1b2/3P4/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B01w',
			# TRANSLATORS: B01w: 1. e4 d5 2. exd5 Nf6 3. d4 Nxd5 4. Nf3 Bf5
			variation => N__('Scandinavian: Marshall, 4. Nf3 Bf5'),
			moves => {
			},
		},
		'rn1qkb1r/ppp1pppp/8/3n4/3P2b1/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B01w',
			# TRANSLATORS: B01w: 1. e4 d5 2. exd5 Nf6 3. d4 Nxd5 4. Nf3 Bg4
			variation => N__('Scandinavian: Marshall, 4. Nf3 Bg4'),
			moves => {
				'f1e2' => 1,
			},
		},
		'rn1qkb1r/ppp1pppp/8/3n4/3P2b1/5N2/PPP1BPPP/RNBQK2R b KQkq' => {
			eco => 'B01w',
			# TRANSLATORS: B01w: 1. e4 d5 2. exd5 Nf6 3. d4 Nxd5 4. Nf3 Bg4 5. Be2
			variation => N__('Scandinavian: Marshall, 4. Nf3 Bg4 5. Be2'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rn1qkb1r/ppp2ppp/4p3/3n4/3P2b1/5N2/PPP1BPPP/RNBQK2R w KQkq' => {
			eco => 'B01w',
			# TRANSLATORS: B01w: 1. e4 d5 2. exd5 Nf6 3. d4 Nxd5 4. Nf3 Bg4 5. Be2 e6
			variation => N__('Scandinavian: Marshall, 4. Nf3 Bg4 5. Be2 e6'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/6p1/3n4/3P4/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B01x',
			# TRANSLATORS: B01x: 1. e4 d5 2. exd5 Nf6 3. d4 Nxd5 4. Nf3 g6
			variation => N__('Scandinavian: Marshall, 4. Nf3 g6'),
			moves => {
				'f1e2' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/6p1/3n4/3P4/5N2/PPP1BPPP/RNBQK2R b KQkq' => {
			eco => 'B01x',
			# TRANSLATORS: B01x: 1. e4 d5 2. exd5 Nf6 3. d4 Nxd5 4. Nf3 g6 5. Be2
			variation => N__('Scandinavian: Marshall, 4. Nf3 g6 5. Be2'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/6p1/3n4/3P4/5N2/PPP1BPPP/RNBQK2R w KQkq' => {
			eco => 'B01x',
			# TRANSLATORS: B01x: 1. e4 d5 2. exd5 Nf6 3. d4 Nxd5 4. Nf3 g6 5. Be2 Bg7
			variation => N__('Scandinavian: Marshall, 4. Nf3 g6 5. Be2 Bg7'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/8/3n4/2PP4/8/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'B01y',
			# TRANSLATORS: B01y: 1. e4 d5 2. exd5 Nf6 3. d4 Nxd5 4. c4
			variation => N__('Scandinavian: Marshall, 4. c4'),
			moves => {
				'd5b6' => 1,
				'd5f6' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/1n6/8/2PP4/8/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'B01y',
			# TRANSLATORS: B01y: 1. e4 d5 2. exd5 Nf6 3. d4 Nxd5 4. c4 Nb6
			variation => N__('Scandinavian: Marshall, 4. c4 Nb6'),
			moves => {
				'b1c3' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/1n6/8/2PP4/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'B01y',
			# TRANSLATORS: B01y: 1. e4 d5 2. exd5 Nf6 3. d4 Nxd5 4. c4 Nb6 5. Nc3
			variation => N__('Scandinavian: Marshall, 4. c4 Nb6 5. Nc3'),
			moves => {
				'e7e5' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/1n6/4p3/2PP4/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'B01y',
			# TRANSLATORS: B01y: 1. e4 d5 2. exd5 Nf6 3. d4 Nxd5 4. c4 Nb6 5. Nc3 e5
			variation => N__('Scandinavian: Marshall, 4. c4 Nb6 5. Nc3 e5'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/8/2PP4/8/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'B01y',
			# TRANSLATORS: B01y: 1. e4 d5 2. exd5 Nf6 3. d4 Nxd5 4. c4 Nf6
			variation => N__('Scandinavian: Marshall, 4. c4 Nf6'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/1n6/8/2PP4/5N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'B01z',
			# TRANSLATORS: B01z: 1. e4 d5 2. exd5 Nf6 3. d4 Nxd5 4. c4 Nb6 5. Nf3
			variation => N__('Scandinavian: Marshall, 4. c4 Nb6 5. Nf3'),
			moves => {
				'c8g4' => 1,
				'g7g6' => 1,
			},
		},
		'rn1qkb1r/ppp1pppp/1n6/8/2PP2b1/5N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'B01z',
			# TRANSLATORS: B01z: 1. e4 d5 2. exd5 Nf6 3. d4 Nxd5 4. c4 Nb6 5. Nf3 Bg4
			variation => N__('Scandinavian: Marshall, 4. c4 Nb6 5. Nf3 Bg4'),
			moves => {
				'c4c5' => 1,
				'f1e2' => 1,
			},
		},
		'rn1qkb1r/ppp1pppp/1n6/2P5/3P2b1/5N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'B01z',
			# TRANSLATORS: B01z: 1. e4 d5 2. exd5 Nf6 3. d4 Nxd5 4. c4 Nb6 5. Nf3 Bg4 6. c5
			variation => N__('Scandinavian: Marshall, 4. c4 Nb6 5. Nf3 Bg4 6. c5'),
			moves => {
			},
		},
		'rn1qkb1r/ppp1pppp/1n6/8/2PP2b1/5N2/PP2BPPP/RNBQK2R b KQkq' => {
			eco => 'B01z',
			# TRANSLATORS: B01z: 1. e4 d5 2. exd5 Nf6 3. d4 Nxd5 4. c4 Nb6 5. Nf3 Bg4 6. Be2
			variation => N__('Scandinavian: Marshall, 4. c4 Nb6 5. Nf3 Bg4'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rn1qkb1r/ppp2ppp/1n2p3/8/2PP2b1/5N2/PP2BPPP/RNBQK2R w KQkq' => {
			eco => 'B01z',
			# TRANSLATORS: B01z: 1. e4 d5 2. exd5 Nf6 3. d4 Nxd5 4. c4 Nb6 5. Nf3 Bg4 6. Be2 e6
			variation => N__('Scandinavian: Marshall, 4. c4 Nb6 5. Nf3 Bg4 6. Be2 e6'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/1n4p1/8/2PP4/5N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'B01z',
			# TRANSLATORS: B01z: 1. e4 d5 2. exd5 Nf6 3. d4 Nxd5 4. c4 Nb6 5. Nf3 g6
			variation => N__('Scandinavian: Marshall, 4. c4 Nb6 5. Nf3 g6'),
			moves => {
				'b1c3' => 1,
				'f1e2' => 1,
				'h2h3' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/1n4p1/8/2PP4/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'B01z',
			# TRANSLATORS: B01z: 1. e4 d5 2. exd5 Nf6 3. d4 Nxd5 4. c4 Nb6 5. Nf3 g6 6. Nc3
			variation => N__('Scandinavian: Marshall, 4. c4 Nb6 5. Nf3 g6 6. Nc3'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/1n4p1/8/2PP4/2N2N2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'B01z',
			# TRANSLATORS: B01z: 1. e4 d5 2. exd5 Nf6 3. d4 Nxd5 4. c4 Nb6 5. Nf3 g6 6. Nc3 Bg7
			variation => N__('Scandinavian: Marshall, 4. c4 Nb6 5. Nf3 g6 6. Nc3 Bg7'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/1n4p1/8/2PP4/5N2/PP2BPPP/RNBQK2R b KQkq' => {
			eco => 'B01z',
			# TRANSLATORS: B01z: 1. e4 d5 2. exd5 Nf6 3. d4 Nxd5 4. c4 Nb6 5. Nf3 g6 6. Be2
			variation => N__('Scandinavian: Marshall, 4. c4 Nb6 5. Nf3 g6 6. Be2'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/1n4p1/8/2PP4/5N2/PP2BPPP/RNBQK2R w KQkq' => {
			eco => 'B01z',
			# TRANSLATORS: B01z: 1. e4 d5 2. exd5 Nf6 3. d4 Nxd5 4. c4 Nb6 5. Nf3 g6 6. Be2 Bg7
			variation => N__('Scandinavian: Marshall, 4. c4 Nb6 5. Nf3 g6 6. Be2 Bg7'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/1n4p1/8/2PP4/5N1P/PP3PP1/RNBQKB1R b KQkq' => {
			eco => 'B01z',
			# TRANSLATORS: B01z: 1. e4 d5 2. exd5 Nf6 3. d4 Nxd5 4. c4 Nb6 5. Nf3 g6 6. h3
			variation => N__('Scandinavian: Marshall, 4. c4 Nb6 5. Nf3 g6 6. h3'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/1n4p1/8/2PP4/5N1P/PP3PP1/RNBQKB1R w KQkq' => {
			eco => 'B01z',
			# TRANSLATORS: B01z: 1. e4 d5 2. exd5 Nf6 3. d4 Nxd5 4. c4 Nb6 5. Nf3 g6 6. h3 Bg7
			variation => N__('Scandinavian: Marshall, 4. c4 Nb6 5. Nf3 g6 6. h3 Bg7'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/4P3/8/PPPP1PPP/RNBQKBNR w KQkq' => {
			eco => 'B02a',
			# TRANSLATORS: B02a: 1. e4 Nf6
			variation => N__('Alekhine Defence'),
			moves => {
				'b1c3' => 1,
				'd2d3' => 1,
				'e4e5' => 1,
				'f1c4' => 1,
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/2B1P3/8/PPPP1PPP/RNBQK1NR b KQkq' => {
			eco => 'B02a',
			# TRANSLATORS: B02a: 1. e4 Nf6 2. Bc4
			variation => N__('Alekhine: Krejcik Variation'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/4P3/3P4/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'B02b',
			# TRANSLATORS: B02b: 1. e4 Nf6 2. d3
			variation => N__('Alekhine: Maroczy Variation'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/5n2/8/4P3/2N5/PPPP1PPP/R1BQKBNR b KQkq' => {
			eco => 'B02c',
			# TRANSLATORS: B02c: 1. e4 Nf6 2. Nc3
			variation => N__('Alekhine: Scandinavian Variation'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/4P3/2N5/PPPP1PPP/R1BQKBNR w KQkq' => {
			eco => 'B02c',
			# TRANSLATORS: B02c: 1. e4 Nf6 2. Nc3 d5
			variation => N__('Alekhine: Scandinavian Variation'),
			moves => {
				'e4d5' => 1,
				'e4e5' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3pP3/8/2N5/PPPP1PPP/R1BQKBNR b KQkq' => {
			eco => 'B02d',
			# TRANSLATORS: B02d: 1. e4 Nf6 2. Nc3 d5 3. e5
			variation => N__('Alekhine: Scandinavian, 3. e5'),
			moves => {
				'f6d7' => 1,
				'f6e4' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/8/3pP3/4n3/2N5/PPPP1PPP/R1BQKBNR w KQkq' => {
			eco => 'B02e',
			# TRANSLATORS: B02e: 1. e4 Nf6 2. Nc3 d5 3. e5 Ne4
			variation => N__('Alekhine: Scandinavian, 3. e5 Ne4'),
			moves => {
			},
		},
		'rnbqkb1r/pppnpppp/8/3pP3/8/2N5/PPPP1PPP/R1BQKBNR w KQkq' => {
			eco => 'B02f',
			# TRANSLATORS: B02f: 1. e4 Nf6 2. Nc3 d5 3. e5 Nfd7
			variation => N__('Alekhine: Scandinavian, 3. e5 Nfd7'),
			moves => {
				'e5e6' => 1,
			},
		},
		'rnbqkb1r/pppnpppp/4P3/3p4/8/2N5/PPPP1PPP/R1BQKBNR b KQkq' => {
			eco => 'B02f',
			# TRANSLATORS: B02f: 1. e4 Nf6 2. Nc3 d5 3. e5 Nfd7 4. e6
			variation => N__('Alekhine: Spielmann Gambit'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3P4/8/2N5/PPPP1PPP/R1BQKBNR b KQkq' => {
			eco => 'B02g',
			# TRANSLATORS: B02g: 1. e4 Nf6 2. Nc3 d5 3. exd5
			variation => N__('Alekhine: Scandinavian, Exchange'),
			moves => {
				'c7c6' => 1,
				'f6d5' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/3P4/8/2N5/PPPP1PPP/R1BQKBNR w KQkq' => {
			eco => 'B02g',
			# TRANSLATORS: B02g: 1. e4 Nf6 2. Nc3 d5 3. exd5 c6
			variation => N__('Alekhine: Scandinavian, Geschev Gambit'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/8/3n4/8/2N5/PPPP1PPP/R1BQKBNR w KQkq' => {
			eco => 'B02g',
			# TRANSLATORS: B02g: 1. e4 Nf6 2. Nc3 d5 3. exd5 Nxd5
			variation => N__('Alekhine: Scandinavian, Exchange'),
			moves => {
				'c3d5' => 1,
				'f1c4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/8/3n4/8/2N2N2/PPPP1PPP/R1BQKB1R b KQkq' => {
			eco => 'B02g',
			# TRANSLATORS: B02g: 1. e4 Nf6 2. Nc3 d5 3. exd5 Nxd5 4. Nf3
			variation => N__('Alekhine: Scandinavian, Exchange, 4. Nf3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/8/3N4/8/8/PPPP1PPP/R1BQKBNR b KQkq' => {
			eco => 'B02h',
			# TRANSLATORS: B02h: 1. e4 Nf6 2. Nc3 d5 3. exd5 Nxd5 4. Nxd5
			variation => N__('Alekhine: Scandinavian, Exchange, 4.Nxd5'),
			moves => {
				'd8d5' => 1,
			},
		},
		'rnb1kb1r/ppp1pppp/8/3q4/8/8/PPPP1PPP/R1BQKBNR w KQkq' => {
			eco => 'B02h',
			# TRANSLATORS: B02h: 1. e4 Nf6 2. Nc3 d5 3. exd5 Nxd5 4. Nxd5 Qxd5
			variation => N__('Alekhine: Scandinavian, Exchange, 4.Nxd5'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/8/3n4/2B5/2N5/PPPP1PPP/R1BQK1NR b KQkq' => {
			eco => 'B02i',
			# TRANSLATORS: B02i: 1. e4 Nf6 2. Nc3 d5 3. exd5 Nxd5 4. Bc4
			variation => N__('Alekhine: Scandinavian, Exchange, 4. Bc4'),
			moves => {
				'd5b6' => 1,
				'e7e6' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4p3/3n4/2B5/2N5/PPPP1PPP/R1BQK1NR w KQkq' => {
			eco => 'B02j',
			# TRANSLATORS: B02j: 1. e4 Nf6 2. Nc3 d5 3. exd5 Nxd5 4. Bc4 e6
			variation => N__('Alekhine: Scandinavian, Exchange, 4. Bc4 e6'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/1n6/8/2B5/2N5/PPPP1PPP/R1BQK1NR w KQkq' => {
			eco => 'B02k',
			# TRANSLATORS: B02k: 1. e4 Nf6 2. Nc3 d5 3. exd5 Nxd5 4. Bc4 Nb6
			variation => N__('Alekhine: Scandinavian, Exchange, 4. Bc4 Nb6'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/5n2/4P3/8/8/PPPP1PPP/RNBQKBNR b KQkq' => {
			eco => 'B02l',
			# TRANSLATORS: B02l: 1. e4 Nf6 2. e5
			variation => N__('Alekhine: 2. e5'),
			moves => {
				'f6d5' => 1,
				'f6e4' => 1,
				'f6g8' => 1,
			},
		},
		'rnbqkb1r/pppppppp/8/4P3/4n3/8/PPPP1PPP/RNBQKBNR w KQkq' => {
			eco => 'B02l',
			# TRANSLATORS: B02l: 1. e4 Nf6 2. e5 Ne4
			variation => N__('Alekhine: Mokele Mbembe (Bücker) Variation'),
			moves => {
			},
		},
		'rnbqkbnr/pppppppp/8/4P3/8/8/PPPP1PPP/RNBQKBNR w KQkq' => {
			eco => 'B02l',
			# TRANSLATORS: B02l: 1. e4 Nf6 2. e5 Ng8
			variation => N__('Alekhine: Brooklyn Defence (Retreat Variation)'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/8/3nP3/8/8/PPPP1PPP/RNBQKBNR w KQkq' => {
			eco => 'B02m',
			# TRANSLATORS: B02m: 1. e4 Nf6 2. e5 Nd5
			variation => N__('Alekhine: 2. e5 Nd5'),
			moves => {
				'b1c3' => 1,
				'b2b3' => 1,
				'c2c4' => 1,
				'd2d4' => 1,
				'f1c4' => 1,
			},
		},
		'rnbqkb1r/pppppppp/8/3nP3/8/1P6/P1PP1PPP/RNBQKBNR b KQkq' => {
			eco => 'B02m',
			# TRANSLATORS: B02m: 1. e4 Nf6 2. e5 Nd5 3. b3
			variation => N__('Alekhine: Welling Variation'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/8/3nP3/2B5/8/PPPP1PPP/RNBQK1NR b KQkq' => {
			eco => 'B02n',
			# TRANSLATORS: B02n: 1. e4 Nf6 2. e5 Nd5 3. Bc4
			variation => N__('Alekhine: 3. Bc4'),
			moves => {
				'd5b6' => 1,
			},
		},
		'rnbqkb1r/pppppppp/1n6/4P3/2B5/8/PPPP1PPP/RNBQK1NR w KQkq' => {
			eco => 'B02n',
			# TRANSLATORS: B02n: 1. e4 Nf6 2. e5 Nd5 3. Bc4 Nb6
			variation => N__('Alekhine: 3. Bc4'),
			moves => {
				'c4b3' => 1,
			},
		},
		'rnbqkb1r/pppppppp/1n6/4P3/8/1B6/PPPP1PPP/RNBQK1NR b KQkq' => {
			eco => 'B02n',
			# TRANSLATORS: B02n: 1. e4 Nf6 2. e5 Nd5 3. Bc4 Nb6 4. Bb3
			variation => N__('Alekhine: 3. Bc4'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqkb1r/pp1ppppp/1n6/2p1P3/8/1B6/PPPP1PPP/RNBQK1NR w KQkq' => {
			eco => 'B02n',
			# TRANSLATORS: B02n: 1. e4 Nf6 2. e5 Nd5 3. Bc4 Nb6 4. Bb3 c5
			variation => N__('Alekhine: 3. Bc4'),
			moves => {
				'd2d3' => 1,
			},
		},
		'rnbqkb1r/pp1ppppp/1n6/2p1P3/8/1B1P4/PPP2PPP/RNBQK1NR b KQkq' => {
			eco => 'B02n',
			# TRANSLATORS: B02n: 1. e4 Nf6 2. e5 Nd5 3. Bc4 Nb6 4. Bb3 c5 5. d3
			variation => N__('Alekhine: Kmoch Variation'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/8/3nP3/8/2N5/PPPP1PPP/R1BQKBNR b KQkq' => {
			eco => 'B02o',
			# TRANSLATORS: B02o: 1. e4 Nf6 2. e5 Nd5 3. Nc3
			variation => N__('Alekhine: Sämisch Attack'),
			moves => {
				'd5c3' => 1,
			},
		},
		'rnbqkb1r/pppppppp/8/4P3/8/2n5/PPPP1PPP/R1BQKBNR w KQkq' => {
			eco => 'B02p',
			# TRANSLATORS: B02p: 1. e4 Nf6 2. e5 Nd5 3. Nc3 Nxc3
			variation => N__('Alekhine: Sämisch Attack, 3...Nxc3'),
			moves => {
				'd2c3' => 1,
			},
		},
		'rnbqkb1r/pppppppp/8/4P3/8/2P5/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'B02q',
			# TRANSLATORS: B02q: 1. e4 Nf6 2. e5 Nd5 3. Nc3 Nxc3 4. dxc3
			variation => N__('Alekhine: Sämisch Attack, 3...Nxc3 4.dxc3'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/8/3nP3/2P5/8/PP1P1PPP/RNBQKBNR b KQkq' => {
			eco => 'B02r',
			# TRANSLATORS: B02r: 1. e4 Nf6 2. e5 Nd5 3. c4
			variation => N__('Alekhine: Chase Variation'),
			moves => {
				'd5b6' => 1,
			},
		},
		'rnbqkb1r/pppppppp/1n6/4P3/2P5/8/PP1P1PPP/RNBQKBNR w KQkq' => {
			eco => 'B02r',
			# TRANSLATORS: B02r: 1. e4 Nf6 2. e5 Nd5 3. c4 Nb6
			variation => N__('Alekhine: Chase Variation'),
			moves => {
				'b2b3' => 1,
				'c4c5' => 1,
			},
		},
		'rnbqkb1r/pppppppp/1n6/4P3/2P5/1P6/P2P1PPP/RNBQKBNR b KQkq' => {
			eco => 'B02r',
			# TRANSLATORS: B02r: 1. e4 Nf6 2. e5 Nd5 3. c4 Nb6 4. b3
			variation => N__('Alekhine: Chase, Steiner Variation'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/1n6/2P1P3/8/8/PP1P1PPP/RNBQKBNR b KQkq' => {
			eco => 'B02s',
			# TRANSLATORS: B02s: 1. e4 Nf6 2. e5 Nd5 3. c4 Nb6 4. c5
			variation => N__('Alekhine: Two Pawns (Lasker) Attack'),
			moves => {
				'b6d5' => 1,
			},
		},
		'rnbqkb1r/pppppppp/8/2PnP3/8/8/PP1P1PPP/RNBQKBNR w KQkq' => {
			eco => 'B02s',
			# TRANSLATORS: B02s: 1. e4 Nf6 2. e5 Nd5 3. c4 Nb6 4. c5 Nd5
			variation => N__('Alekhine: Two Pawns (Lasker) Attack'),
			moves => {
				'b1c3' => 1,
				'f1c4' => 1,
			},
		},
		'rnbqkb1r/pppppppp/8/2PnP3/8/2N5/PP1P1PPP/R1BQKBNR b KQkq' => {
			eco => 'B02t',
			# TRANSLATORS: B02t: 1. e4 Nf6 2. e5 Nd5 3. c4 Nb6 4. c5 Nd5 5. Nc3
			variation => N__('Alekhine: Two Pawns Attack, 5. Nc3'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/8/2PnP3/2B5/8/PP1P1PPP/RNBQK1NR b KQkq' => {
			eco => 'B02u',
			# TRANSLATORS: B02u: 1. e4 Nf6 2. e5 Nd5 3. c4 Nb6 4. c5 Nd5 5. Bc4
			variation => N__('Alekhine: Two Pawns Attack, 5. Bc4'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/4p3/2PnP3/2B5/8/PP1P1PPP/RNBQK1NR w KQkq' => {
			eco => 'B02u',
			# TRANSLATORS: B02u: 1. e4 Nf6 2. e5 Nd5 3. c4 Nb6 4. c5 Nd5 5. Bc4 e6
			variation => N__('Alekhine: Two Pawns Attack, 5. Bc4'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/4p3/2PnP3/2B5/2N5/PP1P1PPP/R1BQK1NR b KQkq' => {
			eco => 'B02u',
			# TRANSLATORS: B02u: 1. e4 Nf6 2. e5 Nd5 3. c4 Nb6 4. c5 Nd5 5. Bc4 e6 6. Nc3
			variation => N__('Alekhine: Two Pawns Attack, 5. Bc4'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/3pp3/2PnP3/2B5/2N5/PP1P1PPP/R1BQK1NR w KQkq' => {
			eco => 'B02u',
			# TRANSLATORS: B02u: 1. e4 Nf6 2. e5 Nd5 3. c4 Nb6 4. c5 Nd5 5. Bc4 e6 6. Nc3 d6
			variation => N__('Alekhine: Two Pawns Attack, Mikenas Variation'),
			moves => {
			},
		},
		'rnbqkb1r/pppppppp/8/3nP3/3P4/8/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'B03a',
			# TRANSLATORS: B03a: 1. e4 Nf6 2. e5 Nd5 3. d4
			variation => N__('Alekhine: 3. d4'),
			moves => {
				'b7b5' => 1,
				'd7d6' => 1,
			},
		},
		'rnbqkb1r/p1pppppp/8/1p1nP3/3P4/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B03a',
			# TRANSLATORS: B03a: 1. e4 Nf6 2. e5 Nd5 3. d4 b5
			variation => N__('Alekhine: O\'Sullivan Gambit'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/3p4/3nP3/3P4/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B03b',
			# TRANSLATORS: B03b: 1. e4 Nf6 2. e5 Nd5 3. d4 d6
			variation => N__('Alekhine: 3. d4 d6'),
			moves => {
				'c2c4' => 1,
				'e5d6' => 1,
				'f1c4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/3P4/3n4/3P4/8/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'B03c',
			# TRANSLATORS: B03c: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. exd6
			variation => N__('Alekhine: 3. d4 d6 4.exd6'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/3p4/3nP3/2BP4/8/PPP2PPP/RNBQK1NR b KQkq' => {
			eco => 'B03d',
			# TRANSLATORS: B03d: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Bc4
			variation => N__('Alekhine: Balogh Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/3p4/3nP3/2PP4/8/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'B03e',
			# TRANSLATORS: B03e: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4
			variation => N__('Alekhine: 4. c4'),
			moves => {
				'd5b6' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/1n1p4/4P3/2PP4/8/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'B03e',
			# TRANSLATORS: B03e: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4 Nb6
			variation => N__('Alekhine: 4. c4 Nb6'),
			moves => {
				'e5d6' => 1,
				'f2f4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/1n1p4/4P3/2PP4/5N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'B03f',
			# TRANSLATORS: B03f: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4 Nb6 5. Nf3
			variation => N__('Alekhine: 4. c4 Nb6 5. Nf3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/1n1p4/4P3/2PP1P2/8/PP4PP/RNBQKBNR b KQkq' => {
			eco => 'B03g',
			# TRANSLATORS: B03g: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4 Nb6 5. f4
			variation => N__('Alekhine: Four Pawns Attack'),
			moves => {
				'c8f5' => 1,
				'd6e5' => 1,
				'g7g5' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/1n1p4/4P1p1/2PP1P2/8/PP4PP/RNBQKBNR w KQkq' => {
			eco => 'B03g',
			# TRANSLATORS: B03g: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4 Nb6 5. f4 g5
			variation => N__('Alekhine: Four Pawns Attack, Planinc Variation'),
			moves => {
			},
		},
		'rn1qkb1r/ppp1pppp/1n1p4/4Pb2/2PP1P2/8/PP4PP/RNBQKBNR w KQkq' => {
			eco => 'B03h',
			# TRANSLATORS: B03h: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4 Nb6 5. f4 Bf5
			variation => N__('Alekhine: Four Pawns Attack, Trifunovic Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/1n1p2p1/4P3/2PP1P2/8/PP4PP/RNBQKBNR w KQkq' => {
			eco => 'B03i',
			# TRANSLATORS: B03i: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4 Nb6 5. f4 g6
			variation => N__('Alekhine: Four Pawns Attack, Fianchetto Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/1n6/4p3/2PP1P2/8/PP4PP/RNBQKBNR w KQkq' => {
			eco => 'B03j',
			# TRANSLATORS: B03j: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4 Nb6 5. f4 dxe5
			variation => N__('Alekhine: Four Pawns Attack, 5...dxe5'),
			moves => {
				'f4e5' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/1n6/4P3/2PP4/8/PP4PP/RNBQKBNR b KQkq' => {
			eco => 'B03j',
			# TRANSLATORS: B03j: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4 Nb6 5. f4 dxe5 6. fxe5
			variation => N__('Alekhine: Four Pawns Attack, 5...dxe5'),
			moves => {
				'b8c6' => 1,
				'c7c5' => 1,
				'c8f5' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/1n6/2p1P3/2PP4/8/PP4PP/RNBQKBNR w KQkq' => {
			eco => 'B03k',
			# TRANSLATORS: B03k: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4 Nb6 5. f4 dxe5 6. fxe5 c5
			variation => N__('Alekhine: Four Pawns Attack, 6... c5'),
			moves => {
			},
		},
		'rn1qkb1r/ppp1pppp/1n6/4Pb2/2PP4/8/PP4PP/RNBQKBNR w KQkq' => {
			eco => 'B03l',
			# TRANSLATORS: B03l: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4 Nb6 5. f4 dxe5 6. fxe5 Bf5
			variation => N__('Alekhine: Four Pawns Attack, 6... Bf5'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rn1qkb1r/ppp1pppp/1n6/4Pb2/2PP4/2N5/PP4PP/R1BQKBNR b KQkq' => {
			eco => 'B03l',
			# TRANSLATORS: B03l: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4 Nb6 5. f4 dxe5 6. fxe5 Bf5 7. Nc3
			variation => N__('Alekhine: Four Pawns Attack, 6... Bf5'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rn1qkb1r/ppp2ppp/1n2p3/4Pb2/2PP4/2N5/PP4PP/R1BQKBNR w KQkq' => {
			eco => 'B03l',
			# TRANSLATORS: B03l: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4 Nb6 5. f4 dxe5 6. fxe5 Bf5 7. Nc3 e6
			variation => N__('Alekhine: Four Pawns Attack, 6... Bf5'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rn1qkb1r/ppp2ppp/1n2p3/4Pb2/2PP4/2N2N2/PP4PP/R1BQKB1R b KQkq' => {
			eco => 'B03l',
			# TRANSLATORS: B03l: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4 Nb6 5. f4 dxe5 6. fxe5 Bf5 7. Nc3 e6 8. Nf3
			variation => N__('Alekhine: Four Pawns Attack, 6... Bf5'),
			moves => {
				'f8b4' => 1,
				'f8e7' => 1,
			},
		},
		'rn1qk2r/ppp2ppp/1n2p3/4Pb2/1bPP4/2N2N2/PP4PP/R1BQKB1R w KQkq' => {
			eco => 'B03l',
			# TRANSLATORS: B03l: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4 Nb6 5. f4 dxe5 6. fxe5 Bf5 7. Nc3 e6 8. Nf3 Bb4
			variation => N__('Alekhine: Four Pawns Attack, 6... Bf5'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rn1qk2r/ppp2ppp/1n2p3/4Pb2/1bPP4/2NB1N2/PP4PP/R1BQK2R b KQkq' => {
			eco => 'B03l',
			# TRANSLATORS: B03l: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4 Nb6 5. f4 dxe5 6. fxe5 Bf5 7. Nc3 e6 8. Nf3 Bb4 9. Bd3
			variation => N__('Alekhine: Four Pawns Attack, Fahrni Variation'),
			moves => {
			},
		},
		'rn1qk2r/ppp1bppp/1n2p3/4Pb2/2PP4/2N2N2/PP4PP/R1BQKB1R w KQkq' => {
			eco => 'B03l',
			# TRANSLATORS: B03l: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4 Nb6 5. f4 dxe5 6. fxe5 Bf5 7. Nc3 e6 8. Nf3 Be7
			variation => N__('Alekhine: Four Pawns Attack, 6... Bf5'),
			moves => {
				'f1e2' => 1,
			},
		},
		'rn1qk2r/ppp1bppp/1n2p3/4Pb2/2PP4/2N2N2/PP2B1PP/R1BQK2R b KQkq' => {
			eco => 'B03l',
			# TRANSLATORS: B03l: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4 Nb6 5. f4 dxe5 6. fxe5 Bf5 7. Nc3 e6 8. Nf3 Be7 9. Be2
			variation => N__('Alekhine: Four Pawns Attack, 6... Bf5'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rn1q1rk1/ppp1bppp/1n2p3/4Pb2/2PP4/2N2N2/PP2B1PP/R1BQK2R w KQ' => {
			eco => 'B03l',
			# TRANSLATORS: B03l: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4 Nb6 5. f4 dxe5 6. fxe5 Bf5 7. Nc3 e6 8. Nf3 Be7 9. Be2 O-O
			variation => N__('Alekhine: Four Pawns Attack, 6... Bf5'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rn1q1rk1/ppp1bppp/1n2p3/4Pb2/2PP4/2N2N2/PP2B1PP/R1BQ1RK1 b -' => {
			eco => 'B03l',
			# TRANSLATORS: B03l: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4 Nb6 5. f4 dxe5 6. fxe5 Bf5 7. Nc3 e6 8. Nf3 Be7 9. Be2 O-O 10. O-O
			variation => N__('Alekhine: Four Pawns Attack, 6... Bf5'),
			moves => {
				'f7f6' => 1,
			},
		},
		'rn1q1rk1/ppp1b1pp/1n2pp2/4Pb2/2PP4/2N2N2/PP2B1PP/R1BQ1RK1 w -' => {
			eco => 'B03l',
			# TRANSLATORS: B03l: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4 Nb6 5. f4 dxe5 6. fxe5 Bf5 7. Nc3 e6 8. Nf3 Be7 9. Be2 O-O 10. O-O f6
			variation => N__('Alekhine: Four Pawns Attack, Korchnoi Variation'),
			moves => {
			},
		},
		'r1bqkb1r/ppp1pppp/1nn5/4P3/2PP4/8/PP4PP/RNBQKBNR w KQkq' => {
			eco => 'B03m',
			# TRANSLATORS: B03m: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4 Nb6 5. f4 dxe5 6. fxe5 Nc6
			variation => N__('Alekhine: Four Pawns Attack, 6... Nc6'),
			moves => {
				'c1e3' => 1,
				'g1f3' => 1,
			},
		},
		'r1bqkb1r/ppp1pppp/1nn5/4P3/2PP4/5N2/PP4PP/RNBQKB1R b KQkq' => {
			eco => 'B03m',
			# TRANSLATORS: B03m: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4 Nb6 5. f4 dxe5 6. fxe5 Nc6 7. Nf3
			variation => N__('Alekhine: Four Pawns Attack, 6... Nc6'),
			moves => {
				'c8g4' => 1,
			},
		},
		'r2qkb1r/ppp1pppp/1nn5/4P3/2PP2b1/5N2/PP4PP/RNBQKB1R w KQkq' => {
			eco => 'B03m',
			# TRANSLATORS: B03m: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4 Nb6 5. f4 dxe5 6. fxe5 Nc6 7. Nf3 Bg4
			variation => N__('Alekhine: Four Pawns Attack, 6... Nc6'),
			moves => {
				'e5e6' => 1,
			},
		},
		'r2qkb1r/ppp1pppp/1nn1P3/8/2PP2b1/5N2/PP4PP/RNBQKB1R b KQkq' => {
			eco => 'B03m',
			# TRANSLATORS: B03m: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4 Nb6 5. f4 dxe5 6. fxe5 Nc6 7. Nf3 Bg4 8. e6
			variation => N__('Alekhine: Four Pawns Attack, 6... Nc6'),
			moves => {
				'f7e6' => 1,
			},
		},
		'r2qkb1r/ppp1p1pp/1nn1p3/8/2PP2b1/5N2/PP4PP/RNBQKB1R w KQkq' => {
			eco => 'B03m',
			# TRANSLATORS: B03m: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4 Nb6 5. f4 dxe5 6. fxe5 Nc6 7. Nf3 Bg4 8. e6 fxe6
			variation => N__('Alekhine: Four Pawns Attack, 6... Nc6'),
			moves => {
				'c4c5' => 1,
			},
		},
		'r2qkb1r/ppp1p1pp/1nn1p3/2P5/3P2b1/5N2/PP4PP/RNBQKB1R b KQkq' => {
			eco => 'B03m',
			# TRANSLATORS: B03m: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4 Nb6 5. f4 dxe5 6. fxe5 Nc6 7. Nf3 Bg4 8. e6 fxe6 9. c5
			variation => N__('Alekhine: Four Pawns Attack, Ilyin-Zhenevsky Variation'),
			moves => {
			},
		},
		'r1bqkb1r/ppp1pppp/1nn5/4P3/2PP4/4B3/PP4PP/RN1QKBNR b KQkq' => {
			eco => 'B03n',
			# TRANSLATORS: B03n: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4 Nb6 5. f4 dxe5 6. fxe5 Nc6 7. Be3
			variation => N__('Alekhine: Four Pawns Attack, 7. Be3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/1n1P4/8/2PP4/8/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'B03o',
			# TRANSLATORS: B03o: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4 Nb6 5. exd6
			variation => N__('Alekhine: Exchange Variation'),
			moves => {
				'c7d6' => 1,
				'e7d6' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/1n1p4/8/2PP4/8/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'B03o',
			# TRANSLATORS: B03o: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4 Nb6 5. exd6 exd6
			variation => N__('Alekhine: Exchange, 5...exd6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/1n1p4/8/2PP4/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'B03p',
			# TRANSLATORS: B03p: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4 Nb6 5. exd6 exd6 6. Nc3
			variation => N__('Alekhine: Exchange, 5...exd6 6. Nc3'),
			moves => {
				'f8e7' => 1,
			},
		},
		'rnbqk2r/ppp1bppp/1n1p4/8/2PP4/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'B03q',
			# TRANSLATORS: B03q: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4 Nb6 5. exd6 exd6 6. Nc3 Be7
			variation => N__('Alekhine: Exchange, 5...exd6 6. Nc3 Be7'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/1n1p4/8/2PP4/8/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'B03r',
			# TRANSLATORS: B03r: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4 Nb6 5. exd6 cxd6
			variation => N__('Alekhine: Exchange, 5...cxd6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/1n1p4/8/2PP4/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'B03s',
			# TRANSLATORS: B03s: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4 Nb6 5. exd6 cxd6 6. Nc3
			variation => N__('Alekhine: Exchange, 5...cxd6 6. Nc3'),
			moves => {
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/pp2pp1p/1n1p2p1/8/2PP4/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'B03s',
			# TRANSLATORS: B03s: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4 Nb6 5. exd6 cxd6 6. Nc3 g6
			variation => N__('Alekhine: Exchange, 5...cxd6 6. Nc3'),
			moves => {
				'c1e3' => 1,
			},
		},
		'rnbqkb1r/pp2pp1p/1n1p2p1/8/2PP4/2N1B3/PP3PPP/R2QKBNR b KQkq' => {
			eco => 'B03t',
			# TRANSLATORS: B03t: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. c4 Nb6 5. exd6 cxd6 6. Nc3 g6 7. Be3
			variation => N__('Alekhine: Exchange, 5...cxd6 6. Nc3 g6 7. Be3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/3p4/3nP3/3P4/5N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B04a',
			# TRANSLATORS: B04a: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3
			variation => N__('Alekhine: Modern Variation'),
			moves => {
				'b8c6' => 1,
				'c7c6' => 1,
				'c8g4' => 1,
				'd5b6' => 1,
				'd6e5' => 1,
				'g7g6' => 1,
			},
		},
		'r1bqkb1r/ppp1pppp/2np4/3nP3/3P4/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B04b',
			# TRANSLATORS: B04b: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 Nc6
			variation => N__('Alekhine: Modern, 4... Nc6'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/2pp4/3nP3/3P4/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B04c',
			# TRANSLATORS: B04c: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 c6
			variation => N__('Alekhine: Modern, 4... c6'),
			moves => {
				'c2c4' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/2pp4/3nP3/2PP4/5N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'B04d',
			# TRANSLATORS: B04d: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 c6 5. c4
			variation => N__('Alekhine: Modern, 4... c6 5. c4'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/1n1p4/4P3/3P4/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B04e',
			# TRANSLATORS: B04e: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 Nb6
			variation => N__('Alekhine: Modern, Schmid Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/8/3np3/3P4/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B04f',
			# TRANSLATORS: B04f: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 dxe5
			variation => N__('Alekhine: Modern, Larsen Variation'),
			moves => {
				'f3e5' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/8/3nN3/3P4/8/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B04f',
			# TRANSLATORS: B04f: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 dxe5 5. Nxe5
			variation => N__('Alekhine: Modern, Larsen Variation'),
			moves => {
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/6p1/3nN3/3P4/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B04g',
			# TRANSLATORS: B04g: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 dxe5 5. Nxe5 g6
			variation => N__('Alekhine: Modern, Larsen, 5.Nxe5 g6'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/6p1/3nN3/2BP4/8/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'B04h',
			# TRANSLATORS: B04h: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 dxe5 5. Nxe5 g6 6. Bc4
			variation => N__('Alekhine: Modern, Larsen, 5.Nxe5 g6 6. Bc4'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rnbqkb1r/pp2pp1p/2p3p1/3nN3/2BP4/8/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'B04h',
			# TRANSLATORS: B04h: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 dxe5 5. Nxe5 g6 6. Bc4 c6
			variation => N__('Alekhine: Modern, Larsen, 5.Nxe5 g6 6. Bc4'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbqkb1r/pp2pp1p/2p3p1/3nN3/2BP4/8/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'B04i',
			# TRANSLATORS: B04i: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 dxe5 5. Nxe5 g6 6. Bc4 c6 7. O-O
			variation => N__('Alekhine: Modern, Larsen, 5.Nxe5 g6 6. Bc4 c6 7.O-O'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/3p2p1/3nP3/3P4/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B04j',
			# TRANSLATORS: B04j: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 g6
			variation => N__('Alekhine: Modern, Fianchetto Variation'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/3p2p1/3nP3/2BP4/5N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'B04k',
			# TRANSLATORS: B04k: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 g6 5. Bc4
			variation => N__('Alekhine: Modern, Fianchetto, 5. Bc4'),
			moves => {
				'd5b6' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/1n1p2p1/4P3/2BP4/5N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'B04l',
			# TRANSLATORS: B04l: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 g6 5. Bc4 Nb6
			variation => N__('Alekhine: Modern, Fianchetto, 5. Bc4 Nb6'),
			moves => {
				'c4b3' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/1n1p2p1/4P3/3P4/1B3N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'B04l',
			# TRANSLATORS: B04l: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 g6 5. Bc4 Nb6 6. Bb3
			variation => N__('Alekhine: Modern, Fianchetto, 5. Bc4 Nb6'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/1n1p2p1/4P3/3P4/1B3N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'B04m',
			# TRANSLATORS: B04m: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 g6 5. Bc4 Nb6 6. Bb3 Bg7
			variation => N__('Alekhine: Modern, Fianchetto, 5. Bc4 Nb6 6. Bb3 Bg7'),
			moves => {
				'a2a4' => 1,
				'f3g5' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/1n1p2p1/4P3/P2P4/1B3N2/1PP2PPP/RNBQK2R b KQkq' => {
			eco => 'B04n',
			# TRANSLATORS: B04n: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 g6 5. Bc4 Nb6 6. Bb3 Bg7 7. a4
			variation => N__('Alekhine: Modern, Fianchetto, Keres Variation'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/1n1p2p1/4P1N1/3P4/1B6/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'B04o',
			# TRANSLATORS: B04o: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 g6 5. Bc4 Nb6 6. Bb3 Bg7 7. Ng5
			variation => N__('Alekhine: Modern, Fianchetto, 5. Bc4 Nb6 6. Bb3 Bg7 7. Ng5'),
			moves => {
			},
		},
		'rn1qkb1r/ppp1pppp/3p4/3nP3/3P2b1/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B05a',
			# TRANSLATORS: B05a: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 Bg4
			variation => N__('Alekhine: Modern, 4... Bg4'),
			moves => {
				'c2c4' => 1,
				'f1e2' => 1,
				'h2h3' => 1,
			},
		},
		'rn1qkb1r/ppp1pppp/3p4/3nP3/3P2b1/5N1P/PPP2PP1/RNBQKB1R b KQkq' => {
			eco => 'B05b',
			# TRANSLATORS: B05b: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 Bg4 5. h3
			variation => N__('Alekhine: Modern, Panov Variation'),
			moves => {
			},
		},
		'rn1qkb1r/ppp1pppp/3p4/3nP3/2PP2b1/5N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'B05c',
			# TRANSLATORS: B05c: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 Bg4 5. c4
			variation => N__('Alekhine: Modern, Alekhine Variation'),
			moves => {
				'd5b6' => 1,
			},
		},
		'rn1qkb1r/ppp1pppp/1n1p4/4P3/2PP2b1/5N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'B05c',
			# TRANSLATORS: B05c: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 Bg4 5. c4 Nb6
			variation => N__('Alekhine: Modern, Alekhine Variation'),
			moves => {
				'e5d6' => 1,
			},
		},
		'rn1qkb1r/ppp1pppp/1n1P4/8/2PP2b1/5N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'B05d',
			# TRANSLATORS: B05d: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 Bg4 5. c4 Nb6 6. exd6
			variation => N__('Alekhine: Modern, Alekhine Variation, 6.exd6'),
			moves => {
				'c7d6' => 1,
				'e7d6' => 1,
			},
		},
		'rn1qkb1r/pp2pppp/1n1p4/8/2PP2b1/5N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'B05d',
			# TRANSLATORS: B05d: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 Bg4 5. c4 Nb6 6. exd6 cxd6
			variation => N__('Alekhine: Modern, Alekhine Variation, 6.exd6 cxd6'),
			moves => {
			},
		},
		'rn1qkb1r/ppp2ppp/1n1p4/8/2PP2b1/5N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'B05e',
			# TRANSLATORS: B05e: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 Bg4 5. c4 Nb6 6. exd6 exd6
			variation => N__('Alekhine: Modern, Alekhine Variation, 6.exd6 exd6'),
			moves => {
			},
		},
		'rn1qkb1r/ppp1pppp/3p4/3nP3/3P2b1/5N2/PPP1BPPP/RNBQK2R b KQkq' => {
			eco => 'B05f',
			# TRANSLATORS: B05f: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 Bg4 5. Be2
			variation => N__('Alekhine: Modern, 5. Be2'),
			moves => {
				'b8c6' => 1,
				'c7c6' => 1,
				'e7e6' => 1,
			},
		},
		'r2qkb1r/ppp1pppp/2np4/3nP3/3P2b1/5N2/PPP1BPPP/RNBQK2R w KQkq' => {
			eco => 'B05g',
			# TRANSLATORS: B05g: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 Bg4 5. Be2 Nc6
			variation => N__('Alekhine: Modern, 5. Be2 Nc6'),
			moves => {
			},
		},
		'rn1qkb1r/pp2pppp/2pp4/3nP3/3P2b1/5N2/PPP1BPPP/RNBQK2R w KQkq' => {
			eco => 'B05h',
			# TRANSLATORS: B05h: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 Bg4 5. Be2 c6
			variation => N__('Alekhine: Modern, Flohr Variation'),
			moves => {
				'c2c4' => 1,
				'e1g1' => 1,
			},
		},
		'rn1qkb1r/pp2pppp/2pp4/3nP3/2PP2b1/5N2/PP2BPPP/RNBQK2R b KQkq' => {
			eco => 'B05i',
			# TRANSLATORS: B05i: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 Bg4 5. Be2 c6 6. c4
			variation => N__('Alekhine: Modern, Flohr, 6. c4'),
			moves => {
			},
		},
		'rn1qkb1r/pp2pppp/2pp4/3nP3/3P2b1/5N2/PPP1BPPP/RNBQ1RK1 b kq' => {
			eco => 'B05j',
			# TRANSLATORS: B05j: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 Bg4 5. Be2 c6 6. O-O
			variation => N__('Alekhine: Modern, Flohr, 6.O-O'),
			moves => {
			},
		},
		'rn1qkb1r/ppp2ppp/3pp3/3nP3/3P2b1/5N2/PPP1BPPP/RNBQK2R w KQkq' => {
			eco => 'B05k',
			# TRANSLATORS: B05k: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 Bg4 5. Be2 e6
			variation => N__('Alekhine: Modern, 5. Be2 e6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rn1qkb1r/ppp2ppp/3pp3/3nP3/3P2b1/5N2/PPP1BPPP/RNBQ1RK1 b kq' => {
			eco => 'B05l',
			# TRANSLATORS: B05l: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 Bg4 5. Be2 e6 6. O-O
			variation => N__('Alekhine: Modern, 5. Be2 e6 6.O-O'),
			moves => {
				'f8e7' => 1,
			},
		},
		'rn1qk2r/ppp1bppp/3pp3/3nP3/3P2b1/5N2/PPP1BPPP/RNBQ1RK1 w kq' => {
			eco => 'B05l',
			# TRANSLATORS: B05l: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 Bg4 5. Be2 e6 6. O-O Be7
			variation => N__('Alekhine: Modern, 5. Be2 e6 6.O-O'),
			moves => {
				'c2c4' => 1,
			},
		},
		'rn1qk2r/ppp1bppp/3pp3/3nP3/2PP2b1/5N2/PP2BPPP/RNBQ1RK1 b kq' => {
			eco => 'B05m',
			# TRANSLATORS: B05m: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 Bg4 5. Be2 e6 6. O-O Be7 7. c4
			variation => N__('Alekhine: Modern, Main Line'),
			moves => {
				'd5b6' => 1,
			},
		},
		'rn1qk2r/ppp1bppp/1n1pp3/4P3/2PP2b1/5N2/PP2BPPP/RNBQ1RK1 w kq' => {
			eco => 'B05m',
			# TRANSLATORS: B05m: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 Bg4 5. Be2 e6 6. O-O Be7 7. c4 Nb6
			variation => N__('Alekhine: Modern, Main Line'),
			moves => {
				'b1c3' => 1,
				'e5d6' => 1,
				'h2h3' => 1,
			},
		},
		'rn1qk2r/ppp1bppp/1n1pp3/4P3/2PP2b1/5N1P/PP2BPP1/RNBQ1RK1 b kq' => {
			eco => 'B05n',
			# TRANSLATORS: B05n: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 Bg4 5. Be2 e6 6. O-O Be7 7. c4 Nb6 8. h3
			variation => N__('Alekhine: Modern, Main Line, 8. h3'),
			moves => {
				'g4h5' => 1,
			},
		},
		'rn1qk2r/ppp1bppp/1n1pp3/4P2b/2PP4/5N1P/PP2BPP1/RNBQ1RK1 w kq' => {
			eco => 'B05n',
			# TRANSLATORS: B05n: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 Bg4 5. Be2 e6 6. O-O Be7 7. c4 Nb6 8. h3 Bh5
			variation => N__('Alekhine: Modern, Main Line, 8. h3 Bh5'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rn1qk2r/ppp1bppp/1n1pp3/4P2b/2PP4/2N2N1P/PP2BPP1/R1BQ1RK1 b kq' => {
			eco => 'B05o',
			# TRANSLATORS: B05o: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 Bg4 5. Be2 e6 6. O-O Be7 7. c4 Nb6 8. h3 Bh5 9. Nc3
			variation => N__('Alekhine: Modern, Main Line, 8. h3 Bh5 9. Nc3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rn1q1rk1/ppp1bppp/1n1pp3/4P2b/2PP4/2N2N1P/PP2BPP1/R1BQ1RK1 w -' => {
			eco => 'B05o',
			# TRANSLATORS: B05o: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 Bg4 5. Be2 e6 6. O-O Be7 7. c4 Nb6 8. h3 Bh5 9. Nc3 O-O
			variation => N__('Alekhine: Modern, Main Line, 8. h3 Bh5 9. Nc3 O-O'),
			moves => {
				'c1e3' => 1,
			},
		},
		'rn1q1rk1/ppp1bppp/1n1pp3/4P2b/2PP4/2N1BN1P/PP2BPP1/R2Q1RK1 b -' => {
			eco => 'B05o',
			# TRANSLATORS: B05o: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 Bg4 5. Be2 e6 6. O-O Be7 7. c4 Nb6 8. h3 Bh5 9. Nc3 O-O 10. Be3
			variation => N__('Alekhine: Modern, Main Line, 8. h3 Bh5 9. Nc3 O-O 10. Be3'),
			moves => {
				'd6d5' => 1,
			},
		},
		'rn1q1rk1/ppp1bppp/1n2p3/3pP2b/2PP4/2N1BN1P/PP2BPP1/R2Q1RK1 w -' => {
			eco => 'B05p',
			# TRANSLATORS: B05p: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 Bg4 5. Be2 e6 6. O-O Be7 7. c4 Nb6 8. h3 Bh5 9. Nc3 O-O 10. Be3 d5
			variation => N__('Alekhine: Modern, Main Line, 8. h3 Bh5 9. Nc3 O-O 10. Be3 d5'),
			moves => {
			},
		},
		'rn1qk2r/ppp1bppp/1n1Pp3/8/2PP2b1/5N2/PP2BPPP/RNBQ1RK1 b kq' => {
			eco => 'B05q',
			# TRANSLATORS: B05q: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 Bg4 5. Be2 e6 6. O-O Be7 7. c4 Nb6 8. exd6
			variation => N__('Alekhine: Modern, Main Line, 8.exd6'),
			moves => {
			},
		},
		'rn1qk2r/ppp1bppp/1n1pp3/4P3/2PP2b1/2N2N2/PP2BPPP/R1BQ1RK1 b kq' => {
			eco => 'B05r',
			# TRANSLATORS: B05r: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 Bg4 5. Be2 e6 6. O-O Be7 7. c4 Nb6 8. Nc3
			variation => N__('Alekhine: Modern, Main Line, 8. Nc3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rn1q1rk1/ppp1bppp/1n1pp3/4P3/2PP2b1/2N2N2/PP2BPPP/R1BQ1RK1 w -' => {
			eco => 'B05r',
			# TRANSLATORS: B05r: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 Bg4 5. Be2 e6 6. O-O Be7 7. c4 Nb6 8. Nc3 O-O
			variation => N__('Alekhine: Modern, Main Line, 8. Nc3'),
			moves => {
				'c1e3' => 1,
			},
		},
		'rn1q1rk1/ppp1bppp/1n1pp3/4P3/2PP2b1/2N1BN2/PP2BPPP/R2Q1RK1 b -' => {
			eco => 'B05s',
			# TRANSLATORS: B05s: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 Bg4 5. Be2 e6 6. O-O Be7 7. c4 Nb6 8. Nc3 O-O 9. Be3
			variation => N__('Alekhine: Modern, Main Line, 8. Nc3 O-O 9. Be3'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r2q1rk1/ppp1bppp/1nnpp3/4P3/2PP2b1/2N1BN2/PP2BPPP/R2Q1RK1 w -' => {
			eco => 'B05t',
			# TRANSLATORS: B05t: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 Bg4 5. Be2 e6 6. O-O Be7 7. c4 Nb6 8. Nc3 O-O 9. Be3 Nc6
			variation => N__('Alekhine: Modern, Main Line, 8. Nc3 O-O 9. Be3 Nc6'),
			moves => {
				'e5d6' => 1,
			},
		},
		'r2q1rk1/ppp1bppp/1nnPp3/8/2PP2b1/2N1BN2/PP2BPPP/R2Q1RK1 b -' => {
			eco => 'B05t',
			# TRANSLATORS: B05t: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 Bg4 5. Be2 e6 6. O-O Be7 7. c4 Nb6 8. Nc3 O-O 9. Be3 Nc6 10. exd6
			variation => N__('Alekhine: Modern, Main Line, 8. Nc3 O-O 9. Be3 Nc6'),
			moves => {
				'c7d6' => 1,
			},
		},
		'r2q1rk1/pp2bppp/1nnpp3/8/2PP2b1/2N1BN2/PP2BPPP/R2Q1RK1 w -' => {
			eco => 'B05u',
			# TRANSLATORS: B05u: 1. e4 Nf6 2. e5 Nd5 3. d4 d6 4. Nf3 Bg4 5. Be2 e6 6. O-O Be7 7. c4 Nb6 8. Nc3 O-O 9. Be3 Nc6 10. exd6 cxd6
			variation => N__('Alekhine: Modern, Main Line, 8. Nc3 O-O 9. Be3 Nc6 10.exd6 cxd6'),
			moves => {
			},
		},
		'rnbqkbnr/pppppp1p/6p1/8/4P3/8/PPPP1PPP/RNBQKBNR w KQkq' => {
			eco => 'B06a',
			# TRANSLATORS: B06a: 1. e4 g6
			variation => N__('Modern'),
			moves => {
				'b1c3' => 1,
				'd2d4' => 1,
				'f2f4' => 1,
			},
		},
		'rnbqkbnr/pppppp1p/6p1/8/4P3/2N5/PPPP1PPP/R1BQKBNR b KQkq' => {
			eco => 'B06b',
			# TRANSLATORS: B06b: 1. e4 g6 2. Nc3
			variation => N__('Modern'),
			moves => {
				'd7d6' => 1,
				'f8g7' => 1,
			},
		},
		'rnbqkbnr/ppp1pp1p/3p2p1/8/4P3/2N5/PPPP1PPP/R1BQKBNR w KQkq' => {
			eco => 'B06b',
			# TRANSLATORS: B06b: 1. e4 g6 2. Nc3 d6
			variation => N__('Modern'),
			moves => {
			},
		},
		'rnbqk1nr/ppppppbp/6p1/8/4P3/2N5/PPPP1PPP/R1BQKBNR w KQkq' => {
			eco => 'B06b',
			# TRANSLATORS: B06b: 1. e4 g6 2. Nc3 Bg7
			variation => N__('Modern'),
			moves => {
				'f2f4' => 1,
			},
		},
		'rnbqk1nr/ppppppbp/6p1/8/4PP2/2N5/PPPP2PP/R1BQKBNR b KQkq' => {
			eco => 'B06b',
			# TRANSLATORS: B06b: 1. e4 g6 2. Nc3 Bg7 3. f4
			variation => N__('Modern'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rnbqk1nr/ppp1ppbp/3p2p1/8/4PP2/2N5/PPPP2PP/R1BQKBNR w KQkq' => {
			eco => 'B06c',
			# TRANSLATORS: B06c: 1. e4 g6 2. Nc3 Bg7 3. f4 d6
			variation => N__('Modern'),
			moves => {
			},
		},
		'rnbqkbnr/pppppp1p/6p1/8/4PP2/8/PPPP2PP/RNBQKBNR b KQkq' => {
			eco => 'B06c',
			# TRANSLATORS: B06c: 1. e4 g6 2. f4
			variation => N__('Modern'),
			moves => {
				'd7d6' => 1,
				'f8g7' => 1,
			},
		},
		'rnbqkbnr/ppp1pp1p/3p2p1/8/4PP2/8/PPPP2PP/RNBQKBNR w KQkq' => {
			eco => 'B06c',
			# TRANSLATORS: B06c: 1. e4 g6 2. f4 d6
			variation => N__('Modern'),
			moves => {
			},
		},
		'rnbqk1nr/ppppppbp/6p1/8/4PP2/8/PPPP2PP/RNBQKBNR w KQkq' => {
			eco => 'B06c',
			# TRANSLATORS: B06c: 1. e4 g6 2. f4 Bg7
			variation => N__('Modern'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqk1nr/ppppppbp/6p1/8/4PP2/5N2/PPPP2PP/RNBQKB1R b KQkq' => {
			eco => 'B06c',
			# TRANSLATORS: B06c: 1. e4 g6 2. f4 Bg7 3. Nf3
			variation => N__('Modern'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rnbqk1nr/ppp1ppbp/3p2p1/8/4PP2/5N2/PPPP2PP/RNBQKB1R w KQkq' => {
			eco => 'B06c',
			# TRANSLATORS: B06c: 1. e4 g6 2. f4 Bg7 3. Nf3 d6
			variation => N__('Modern'),
			moves => {
			},
		},
		'rnbqkbnr/pppppp1p/6p1/8/3PP3/8/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'B06d',
			# TRANSLATORS: B06d: 1. e4 g6 2. d4
			variation => N__('Modern'),
			moves => {
				'c7c6' => 1,
				'd7d6' => 1,
				'f8g7' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/pp1ppp1p/2p3p1/8/3PP3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B06d',
			# TRANSLATORS: B06d: 1. e4 g6 2. d4 c6
			variation => N__('Modern'),
			moves => {
			},
		},
		'rnbqkb1r/pppppp1p/5np1/8/3PP3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B06d',
			# TRANSLATORS: B06d: 1. e4 g6 2. d4 Nf6
			variation => N__('Modern: Norwegian Defence'),
			moves => {
				'e4e5' => 1,
			},
		},
		'rnbqkb1r/pppppp1p/5np1/4P3/3P4/8/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'B06d',
			# TRANSLATORS: B06d: 1. e4 g6 2. d4 Nf6 3. e5
			variation => N__('Modern: Norwegian Defence'),
			moves => {
				'f6h5' => 1,
			},
		},
		'rnbqkb1r/pppppp1p/6p1/4P2n/3P4/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B06d',
			# TRANSLATORS: B06d: 1. e4 g6 2. d4 Nf6 3. e5 Nh5
			variation => N__('Modern: Norwegian Defence'),
			moves => {
				'g2g4' => 1,
			},
		},
		'rnbqkb1r/pppppp1p/6p1/4P2n/3P2P1/8/PPP2P1P/RNBQKBNR b KQkq' => {
			eco => 'B06d',
			# TRANSLATORS: B06d: 1. e4 g6 2. d4 Nf6 3. e5 Nh5 4. g4
			variation => N__('Modern: Norwegian Defence'),
			moves => {
				'h5g7' => 1,
			},
		},
		'rnbqkb1r/ppppppnp/6p1/4P3/3P2P1/8/PPP2P1P/RNBQKBNR w KQkq' => {
			eco => 'B06d',
			# TRANSLATORS: B06d: 1. e4 g6 2. d4 Nf6 3. e5 Nh5 4. g4 Ng7
			variation => N__('Modern: Norwegian Defence'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pp1p/3p2p1/8/3PP3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B06e',
			# TRANSLATORS: B06e: 1. e4 g6 2. d4 d6
			variation => N__('Modern'),
			moves => {
			},
		},
		'rnbqk1nr/ppppppbp/6p1/8/3PP3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B06f',
			# TRANSLATORS: B06f: 1. e4 g6 2. d4 Bg7
			variation => N__('Modern'),
			moves => {
				'b1c3' => 1,
				'c2c3' => 1,
				'f1c4' => 1,
				'f2f4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqk1nr/ppppppbp/6p1/8/2BPP3/8/PPP2PPP/RNBQK1NR b KQkq' => {
			eco => 'B06f',
			# TRANSLATORS: B06f: 1. e4 g6 2. d4 Bg7 3. Bc4
			variation => N__('Modern: 3. Bc4'),
			moves => {
			},
		},
		'rnbqk1nr/ppppppbp/6p1/8/3PP3/2P5/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'B06g',
			# TRANSLATORS: B06g: 1. e4 g6 2. d4 Bg7 3. c3
			variation => N__('Modern: 3. c3'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rnbqk1nr/ppp1ppbp/3p2p1/8/3PP3/2P5/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'B06g',
			# TRANSLATORS: B06g: 1. e4 g6 2. d4 Bg7 3. c3 d6
			variation => N__('Modern: 3. c3'),
			moves => {
				'f2f4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqk1nr/ppp1ppbp/3p2p1/8/3PPP2/2P5/PP4PP/RNBQKBNR b KQkq' => {
			eco => 'B06g',
			# TRANSLATORS: B06g: 1. e4 g6 2. d4 Bg7 3. c3 d6 4. f4
			variation => N__('Modern: 3. c3'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqk1nr/pp2ppbp/3p2p1/2p5/3PPP2/2P5/PP4PP/RNBQKBNR w KQkq' => {
			eco => 'B06g',
			# TRANSLATORS: B06g: 1. e4 g6 2. d4 Bg7 3. c3 d6 4. f4 c5
			variation => N__('Modern: c3 Pterodactyl'),
			moves => {
			},
		},
		'rnbqk1nr/ppp1ppbp/3p2p1/8/3PP3/2P2N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'B06h',
			# TRANSLATORS: B06h: 1. e4 g6 2. d4 Bg7 3. c3 d6 4. Nf3
			variation => N__('Modern: Geller System'),
			moves => {
			},
		},
		'rnbqk1nr/ppppppbp/6p1/8/3PP3/5N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B06i',
			# TRANSLATORS: B06i: 1. e4 g6 2. d4 Bg7 3. Nf3
			variation => N__('Modern: 3. Nf3'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rnbqk1nr/ppp1ppbp/3p2p1/8/3PP3/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B06j',
			# TRANSLATORS: B06j: 1. e4 g6 2. d4 Bg7 3. Nf3 d6
			variation => N__('Modern: 3. Nf3 d6'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnbqk1nr/ppp1ppbp/3p2p1/8/2BPP3/5N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'B06k',
			# TRANSLATORS: B06k: 1. e4 g6 2. d4 Bg7 3. Nf3 d6 4. Bc4
			variation => N__('Modern: 3. Nf3 d6 4. Bc4'),
			moves => {
			},
		},
		'rnbqk1nr/ppppppbp/6p1/8/3PP3/2N5/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'B06l',
			# TRANSLATORS: B06l: 1. e4 g6 2. d4 Bg7 3. Nc3
			variation => N__('Modern: 3. Nc3'),
			moves => {
				'c7c5' => 1,
				'd7d5' => 1,
				'd7d6' => 1,
			},
		},
		'rnbqk1nr/pp1pppbp/6p1/2p5/3PP3/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'B06l',
			# TRANSLATORS: B06l: 1. e4 g6 2. d4 Bg7 3. Nc3 c5
			variation => N__('Modern: Nc3 Pterodactyl'),
			moves => {
			},
		},
		'rnbqk1nr/ppp1ppbp/6p1/3p4/3PP3/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'B06l',
			# TRANSLATORS: B06l: 1. e4 g6 2. d4 Bg7 3. Nc3 d5
			variation => N__('Modern: Mittenberger Gambit'),
			moves => {
			},
		},
		'rnbqk1nr/ppp1ppbp/3p2p1/8/3PP3/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'B06m',
			# TRANSLATORS: B06m: 1. e4 g6 2. d4 Bg7 3. Nc3 d6
			variation => N__('Modern: 3. Nc3'),
			moves => {
				'c1e3' => 1,
				'f1c4' => 1,
				'f2f4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqk1nr/ppp1ppbp/3p2p1/8/2BPP3/2N5/PPP2PPP/R1BQK1NR b KQkq' => {
			eco => 'B06n',
			# TRANSLATORS: B06n: 1. e4 g6 2. d4 Bg7 3. Nc3 d6 4. Bc4
			variation => N__('Modern: 3. Nc3 d6 4. Bc4'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rnbqk1nr/pp2ppbp/2pp2p1/8/2BPP3/2N5/PPP2PPP/R1BQK1NR w KQkq' => {
			eco => 'B06n',
			# TRANSLATORS: B06n: 1. e4 g6 2. d4 Bg7 3. Nc3 d6 4. Bc4 c6
			variation => N__('Modern: 3. Nc3 d6 4. Bc4'),
			moves => {
				'd1f3' => 1,
			},
		},
		'rnbqk1nr/pp2ppbp/2pp2p1/8/2BPP3/2N2Q2/PPP2PPP/R1B1K1NR b KQkq' => {
			eco => 'B06n',
			# TRANSLATORS: B06n: 1. e4 g6 2. d4 Bg7 3. Nc3 d6 4. Bc4 c6 5. Qf3
			variation => N__('Modern: 3. Nc3 d6 4. Bc4'),
			moves => {
				'e7e6' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqk1nr/pp3pbp/2ppp1p1/8/2BPP3/2N2Q2/PPP2PPP/R1B1K1NR w KQkq' => {
			eco => 'B06n',
			# TRANSLATORS: B06n: 1. e4 g6 2. d4 Bg7 3. Nc3 d6 4. Bc4 c6 5. Qf3 e6
			variation => N__('Modern: 3. Nc3 d6 4. Bc4'),
			moves => {
			},
		},
		'rnbqk2r/pp2ppbp/2pp1np1/8/2BPP3/2N2Q2/PPP2PPP/R1B1K1NR w KQkq' => {
			eco => 'B06n',
			# TRANSLATORS: B06n: 1. e4 g6 2. d4 Bg7 3. Nc3 d6 4. Bc4 c6 5. Qf3 Nf6
			variation => N__('Modern: 3. Nc3 d6 4. Bc4'),
			moves => {
			},
		},
		'rnbqk1nr/ppp1ppbp/3p2p1/8/3PP3/2N1B3/PPP2PPP/R2QKBNR b KQkq' => {
			eco => 'B06o',
			# TRANSLATORS: B06o: 1. e4 g6 2. d4 Bg7 3. Nc3 d6 4. Be3
			variation => N__('Modern: 3. Nc3 d6 4. Be3'),
			moves => {
				'a7a6' => 1,
				'c7c6' => 1,
			},
		},
		'rnbqk1nr/1pp1ppbp/p2p2p1/8/3PP3/2N1B3/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'B06p',
			# TRANSLATORS: B06p: 1. e4 g6 2. d4 Bg7 3. Nc3 d6 4. Be3 a6
			variation => N__('Modern: 3. Nc3 d6 4. Be3 a6'),
			moves => {
			},
		},
		'rnbqk1nr/pp2ppbp/2pp2p1/8/3PP3/2N1B3/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'B06q',
			# TRANSLATORS: B06q: 1. e4 g6 2. d4 Bg7 3. Nc3 d6 4. Be3 c6
			variation => N__('Modern: 3. Nc3 d6 4. Be3 c6'),
			moves => {
			},
		},
		'rnbqk1nr/ppp1ppbp/3p2p1/8/3PP3/2N2N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B06r',
			# TRANSLATORS: B06r: 1. e4 g6 2. d4 Bg7 3. Nc3 d6 4. Nf3
			variation => N__('Modern: Two Knights Variation'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rnbqk1nr/pp2ppbp/2pp2p1/8/3PP3/2N2N2/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B06r',
			# TRANSLATORS: B06r: 1. e4 g6 2. d4 Bg7 3. Nc3 d6 4. Nf3 c6
			variation => N__('Modern: Two Knights, Suttles Variation'),
			moves => {
				'c1g5' => 1,
			},
		},
		'rnbqk1nr/pp2ppbp/2pp2p1/6B1/3PP3/2N2N2/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'B06r',
			# TRANSLATORS: B06r: 1. e4 g6 2. d4 Bg7 3. Nc3 d6 4. Nf3 c6 5. Bg5
			variation => N__('Modern: Two Knights, Suttles Variation'),
			moves => {
				'd8b6' => 1,
			},
		},
		'rnb1k1nr/pp2ppbp/1qpp2p1/6B1/3PP3/2N2N2/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B06r',
			# TRANSLATORS: B06r: 1. e4 g6 2. d4 Bg7 3. Nc3 d6 4. Nf3 c6 5. Bg5 Qb6
			variation => N__('Modern: Two Knights, Suttles Variation'),
			moves => {
				'd1d2' => 1,
			},
		},
		'rnb1k1nr/pp2ppbp/1qpp2p1/6B1/3PP3/2N2N2/PPPQ1PPP/R3KB1R b KQkq' => {
			eco => 'B06r',
			# TRANSLATORS: B06r: 1. e4 g6 2. d4 Bg7 3. Nc3 d6 4. Nf3 c6 5. Bg5 Qb6 6. Qd2
			variation => N__('Modern: Two Knights, Suttles, Tal Gambit'),
			moves => {
			},
		},
		'rnbqk1nr/ppp1ppbp/3p2p1/8/3PPP2/2N5/PPP3PP/R1BQKBNR b KQkq' => {
			eco => 'B06s',
			# TRANSLATORS: B06s: 1. e4 g6 2. d4 Bg7 3. Nc3 d6 4. f4
			variation => N__('Modern: Pseudo-Austrian Attack'),
			moves => {
				'b8c6' => 1,
				'c7c6' => 1,
			},
		},
		'rnbqk1nr/pp2ppbp/2pp2p1/8/3PPP2/2N5/PPP3PP/R1BQKBNR w KQkq' => {
			eco => 'B06s',
			# TRANSLATORS: B06s: 1. e4 g6 2. d4 Bg7 3. Nc3 d6 4. f4 c6
			variation => N__('Modern: Pseudo-Austrian Attack'),
			moves => {
				'g1f3' => 1,
			},
		},
		'r1bqk1nr/ppp1ppbp/2np2p1/8/3PPP2/2N5/PPP3PP/R1BQKBNR w KQkq' => {
			eco => 'B06t',
			# TRANSLATORS: B06t: 1. e4 g6 2. d4 Bg7 3. Nc3 d6 4. f4 Nc6
			variation => N__('Modern: Pseudo-Austrian Attack'),
			moves => {
			},
		},
		'rnbqk1nr/pp2ppbp/2pp2p1/8/3PPP2/2N2N2/PPP3PP/R1BQKB1R b KQkq' => {
			eco => 'B06t',
			# TRANSLATORS: B06t: 1. e4 g6 2. d4 Bg7 3. Nc3 d6 4. f4 c6 5. Nf3
			variation => N__('Modern: Pseudo-Austrian Attack'),
			moves => {
			},
		},
		'rnbqk1nr/ppppppbp/6p1/8/3PPP2/8/PPP3PP/RNBQKBNR b KQkq' => {
			eco => 'B06u',
			# TRANSLATORS: B06u: 1. e4 g6 2. d4 Bg7 3. f4
			variation => N__('Modern: Three Pawns Attack'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/3p4/8/4P3/8/PPPP1PPP/RNBQKBNR w KQkq' => {
			eco => 'B07a',
			# TRANSLATORS: B07a: 1. e4 d6
			variation => N__('Pirc'),
			moves => {
				'b1c3' => 1,
				'c2c4' => 1,
				'd2d4' => 1,
				'f2f4' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/ppp1pppp/3p4/8/4P3/2N5/PPPP1PPP/R1BQKBNR b KQkq' => {
			eco => 'B07a',
			# TRANSLATORS: B07a: 1. e4 d6 2. Nc3
			variation => N__('Pirc: 2. Nc3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/3p1n2/8/4P3/2N5/PPPP1PPP/R1BQKBNR w KQkq' => {
			eco => 'B07a',
			# TRANSLATORS: B07a: 1. e4 d6 2. Nc3 Nf6
			variation => N__('Pirc: 2. Nc3'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/3p4/8/2P1P3/8/PP1P1PPP/RNBQKBNR b KQkq' => {
			eco => 'B07a',
			# TRANSLATORS: B07a: 1. e4 d6 2. c4
			variation => N__('Pirc'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/3p4/8/4P3/6P1/PPPP1P1P/RNBQKBNR b KQkq' => {
			eco => 'B07a',
			# TRANSLATORS: B07a: 1. e4 d6 2. g3
			variation => N__('Pirc'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/3p4/8/4P3/5N2/PPPP1PPP/RNBQKB1R b KQkq' => {
			eco => 'B07b',
			# TRANSLATORS: B07b: 1. e4 d6 2. Nf3
			variation => N__('Pirc: 2. Nf3'),
			moves => {
				'c8g4' => 1,
				'g8f6' => 1,
			},
		},
		'rn1qkbnr/ppp1pppp/3p4/8/4P1b1/5N2/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'B07b',
			# TRANSLATORS: B07b: 1. e4 d6 2. Nf3 Bg4
			variation => N__('Pirc/Reti: Wade Defence'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/3p1n2/8/4P3/5N2/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'B07b',
			# TRANSLATORS: B07b: 1. e4 d6 2. Nf3 Nf6
			variation => N__('Pirc: 2. Nf3 Nf6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/3p1n2/8/4P3/2N2N2/PPPP1PPP/R1BQKB1R b KQkq' => {
			eco => 'B07b',
			# TRANSLATORS: B07b: 1. e4 d6 2. Nf3 Nf6 3. Nc3
			variation => N__('Pirc: 2. Nf3 Nf6 3. Nc3'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/3p4/8/4PP2/8/PPPP2PP/RNBQKBNR b KQkq' => {
			eco => 'B07c',
			# TRANSLATORS: B07c: 1. e4 d6 2. f4
			variation => N__('Pirc: 2. f4'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/3p1n2/8/4PP2/8/PPPP2PP/RNBQKBNR w KQkq' => {
			eco => 'B07c',
			# TRANSLATORS: B07c: 1. e4 d6 2. f4 Nf6
			variation => N__('Pirc: 2. f4 Nf6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/3p1n2/8/4PP2/2N5/PPPP2PP/R1BQKBNR b KQkq' => {
			eco => 'B07c',
			# TRANSLATORS: B07c: 1. e4 d6 2. f4 Nf6 3. Nc3
			variation => N__('Pirc: 2. f4 Nf6 3. Nc3'),
			moves => {
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/3p1np1/8/4PP2/2N5/PPPP2PP/R1BQKBNR w KQkq' => {
			eco => 'B07c',
			# TRANSLATORS: B07c: 1. e4 d6 2. f4 Nf6 3. Nc3 g6
			variation => N__('Pirc: 2. f4 Nf6 3. Nc3'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/3p1np1/8/4PP2/2N2N2/PPPP2PP/R1BQKB1R b KQkq' => {
			eco => 'B07c',
			# TRANSLATORS: B07c: 1. e4 d6 2. f4 Nf6 3. Nc3 g6 4. Nf3
			variation => N__('Pirc: 2. f4 Nf6 3. Nc3'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/4PP2/2N2N2/PPPP2PP/R1BQKB1R w KQkq' => {
			eco => 'B07c',
			# TRANSLATORS: B07c: 1. e4 d6 2. f4 Nf6 3. Nc3 g6 4. Nf3 Bg7
			variation => N__('Pirc: 2. f4 Nf6 3. Nc3 g6 4. Nf3 Bg7'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/3p4/8/3PP3/8/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'B07d',
			# TRANSLATORS: B07d: 1. e4 d6 2. d4
			variation => N__('Pirc: 2. d4'),
			moves => {
				'b8d7' => 1,
				'c7c6' => 1,
				'e7e6' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkbnr/pppnpppp/3p4/8/3PP3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B07d',
			# TRANSLATORS: B07d: 1. e4 d6 2. d4 Nd7
			variation => N__('Pirc: 2. d4 Nd7'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/2pp4/8/3PP3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B07d',
			# TRANSLATORS: B07d: 1. e4 d6 2. d4 c6
			variation => N__('Pirc: 2. d4 c6'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/3pp3/8/3PP3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B07d',
			# TRANSLATORS: B07d: 1. e4 d6 2. d4 e6
			variation => N__('Pirc: Lengfellner System'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/3p1n2/8/3PP3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B07d',
			# TRANSLATORS: B07d: 1. e4 d6 2. d4 Nf6
			variation => N__('Pirc: 2. d4 Nf6'),
			moves => {
				'b1c3' => 1,
				'b1d2' => 1,
				'f1d3' => 1,
				'f2f3' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/3p1n2/8/3PP3/8/PPPN1PPP/R1BQKBNR b KQkq' => {
			eco => 'B07d',
			# TRANSLATORS: B07d: 1. e4 d6 2. d4 Nf6 3. Nd2
			variation => N__('Pirc: 3.Nbd2'),
			moves => {
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/3p1np1/8/3PP3/8/PPPN1PPP/R1BQKBNR w KQkq' => {
			eco => 'B07d',
			# TRANSLATORS: B07d: 1. e4 d6 2. d4 Nf6 3. Nd2 g6
			variation => N__('Pirc: 3.Nbd2 g6'),
			moves => {
				'c2c3' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/3p1np1/8/3PP3/2P5/PP1N1PPP/R1BQKBNR b KQkq' => {
			eco => 'B07d',
			# TRANSLATORS: B07d: 1. e4 d6 2. d4 Nf6 3. Nd2 g6 4. c3
			variation => N__('Pirc: 3.Nbd2 g6'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/3PP3/2P5/PP1N1PPP/R1BQKBNR w KQkq' => {
			eco => 'B07d',
			# TRANSLATORS: B07d: 1. e4 d6 2. d4 Nf6 3. Nd2 g6 4. c3 Bg7
			variation => N__('Pirc: 3.Nbd2 g6'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/3p1n2/8/3PP3/5N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B07d',
			# TRANSLATORS: B07d: 1. e4 d6 2. d4 Nf6 3. Nf3
			variation => N__('Pirc: Roscher Gambit'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/3p1n2/8/3PP3/5P2/PPP3PP/RNBQKBNR b KQkq' => {
			eco => 'B07e',
			# TRANSLATORS: B07e: 1. e4 d6 2. d4 Nf6 3. f3
			variation => N__('Pirc: 3. f3'),
			moves => {
				'e7e5' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/3p1n2/4p3/3PP3/5P2/PPP3PP/RNBQKBNR w KQkq' => {
			eco => 'B07f',
			# TRANSLATORS: B07f: 1. e4 d6 2. d4 Nf6 3. f3 e5
			variation => N__('Pirc: 3. f3 e5'),
			moves => {
				'd4d5' => 1,
				'd4e5' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/3p1n2/3Pp3/4P3/5P2/PPP3PP/RNBQKBNR b KQkq' => {
			eco => 'B07f',
			# TRANSLATORS: B07f: 1. e4 d6 2. d4 Nf6 3. f3 e5 4. d5
			variation => N__('Pirc: 3. f3 e5 4. d5'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/3p1n2/4P3/4P3/5P2/PPP3PP/RNBQKBNR b KQkq' => {
			eco => 'B07f',
			# TRANSLATORS: B07f: 1. e4 d6 2. d4 Nf6 3. f3 e5 4. dxe5
			variation => N__('Pirc: 3. f3 e5'),
			moves => {
				'd6e5' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/4p3/4P3/5P2/PPP3PP/RNBQKBNR w KQkq' => {
			eco => 'B07f',
			# TRANSLATORS: B07f: 1. e4 d6 2. d4 Nf6 3. f3 e5 4. dxe5 dxe5
			variation => N__('Pirc: 3. f3 e5'),
			moves => {
				'd1d8' => 1,
			},
		},
		'rnbQkb1r/ppp2ppp/5n2/4p3/4P3/5P2/PPP3PP/RNB1KBNR b KQkq' => {
			eco => 'B07f',
			# TRANSLATORS: B07f: 1. e4 d6 2. d4 Nf6 3. f3 e5 4. dxe5 dxe5 5. Qxd8+
			variation => N__('Pirc: 3. f3 e5 Queenswap'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/3p1np1/8/3PP3/5P2/PPP3PP/RNBQKBNR w KQkq' => {
			eco => 'B07g',
			# TRANSLATORS: B07g: 1. e4 d6 2. d4 Nf6 3. f3 g6
			variation => N__('Pirc: 3. f3 g6'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/3p1n2/8/3PP3/3B4/PPP2PPP/RNBQK1NR b KQkq' => {
			eco => 'B07h',
			# TRANSLATORS: B07h: 1. e4 d6 2. d4 Nf6 3. Bd3
			variation => N__('Pirc: 3. Bd3'),
			moves => {
				'e7e5' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/3p1n2/4p3/3PP3/3B4/PPP2PPP/RNBQK1NR w KQkq' => {
			eco => 'B07h',
			# TRANSLATORS: B07h: 1. e4 d6 2. d4 Nf6 3. Bd3 e5
			variation => N__('Pirc: 3. Bd3 e5'),
			moves => {
				'c2c3' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/3p1n2/4p3/3PP3/2PB4/PP3PPP/RNBQK1NR b KQkq' => {
			eco => 'B07h',
			# TRANSLATORS: B07h: 1. e4 d6 2. d4 Nf6 3. Bd3 e5 4. c3
			variation => N__('Pirc: 3. Bd3 e5'),
			moves => {
				'd6d5' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3pp3/3PP3/2PB4/PP3PPP/RNBQK1NR w KQkq' => {
			eco => 'B07h',
			# TRANSLATORS: B07h: 1. e4 d6 2. d4 Nf6 3. Bd3 e5 4. c3 d5
			variation => N__('Pirc: 3. Bd3 e5 4. c3 d5'),
			moves => {
				'd4e5' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3pP3/4P3/2PB4/PP3PPP/RNBQK1NR b KQkq' => {
			eco => 'B07h',
			# TRANSLATORS: B07h: 1. e4 d6 2. d4 Nf6 3. Bd3 e5 4. c3 d5 5. dxe5
			variation => N__('Pirc: 3. Bd3 e5 4. c3 d5'),
			moves => {
				'd5e4' => 1,
				'f6e4' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/4P3/4p3/2PB4/PP3PPP/RNBQK1NR w KQkq' => {
			eco => 'B07h',
			# TRANSLATORS: B07h: 1. e4 d6 2. d4 Nf6 3. Bd3 e5 4. c3 d5 5. dxe5 dxe4
			variation => N__('Pirc: 3. Bd3 e5 4. c3 d5'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/8/3pP3/4n3/2PB4/PP3PPP/RNBQK1NR w KQkq' => {
			eco => 'B07h',
			# TRANSLATORS: B07h: 1. e4 d6 2. d4 Nf6 3. Bd3 e5 4. c3 d5 5. dxe5 Nxe4
			variation => N__('Pirc: 3. Bd3 e5 4. c3 d5'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/3p1np1/8/3PP3/3B4/PPP2PPP/RNBQK1NR w KQkq' => {
			eco => 'B07i',
			# TRANSLATORS: B07i: 1. e4 d6 2. d4 Nf6 3. Bd3 g6
			variation => N__('Pirc: 3. Bd3 g6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/3p1np1/8/3PP3/3B1N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'B07i',
			# TRANSLATORS: B07i: 1. e4 d6 2. d4 Nf6 3. Bd3 g6 4. Nf3
			variation => N__('Pirc: 3. Bd3 g6'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/3PP3/3B1N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'B07i',
			# TRANSLATORS: B07i: 1. e4 d6 2. d4 Nf6 3. Bd3 g6 4. Nf3 Bg7
			variation => N__('Pirc: 3. Bd3 g6'),
			moves => {
				'c2c3' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/3PP3/2PB1N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'B07j',
			# TRANSLATORS: B07j: 1. e4 d6 2. d4 Nf6 3. Bd3 g6 4. Nf3 Bg7 5. c3
			variation => N__('Pirc: 3. Bd3 g6 4. Nf3 Bg7 5. c3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/3p1n2/8/3PP3/2N5/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'B07k',
			# TRANSLATORS: B07k: 1. e4 d6 2. d4 Nf6 3. Nc3
			variation => N__('Pirc: 3. Nc3'),
			moves => {
				'b8d7' => 1,
				'c7c6' => 1,
				'e7e5' => 1,
				'g7g6' => 1,
			},
		},
		'r1bqkb1r/pppnpppp/3p1n2/8/3PP3/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'B07l',
			# TRANSLATORS: B07l: 1. e4 d6 2. d4 Nf6 3. Nc3 Nbd7
			variation => N__('Pirc: 3. Nc3 Nbd7'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/3p1n2/4p3/3PP3/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'B07m',
			# TRANSLATORS: B07m: 1. e4 d6 2. d4 Nf6 3. Nc3 e5
			variation => N__('Pirc: 3. Nc3 e5'),
			moves => {
				'd4e5' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/3p1n2/4P3/4P3/2N5/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'B07m',
			# TRANSLATORS: B07m: 1. e4 d6 2. d4 Nf6 3. Nc3 e5 4. dxe5
			variation => N__('Pirc: 3. Nc3 e5'),
			moves => {
				'd6e5' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/4p3/4P3/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'B07m',
			# TRANSLATORS: B07m: 1. e4 d6 2. d4 Nf6 3. Nc3 e5 4. dxe5 dxe5
			variation => N__('Pirc: 3. Nc3 e5'),
			moves => {
				'd1d8' => 1,
			},
		},
		'rnbQkb1r/ppp2ppp/5n2/4p3/4P3/2N5/PPP2PPP/R1B1KBNR b KQkq' => {
			eco => 'B07m',
			# TRANSLATORS: B07m: 1. e4 d6 2. d4 Nf6 3. Nc3 e5 4. dxe5 dxe5 5. Qxd8+
			variation => N__('Pirc: 3. Nc3 e5 Queenswap'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/2pp1n2/8/3PP3/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'B07n',
			# TRANSLATORS: B07n: 1. e4 d6 2. d4 Nf6 3. Nc3 c6
			variation => N__('Pirc: Pytel/Czech'),
			moves => {
				'f2f4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/2pp1n2/8/3PP3/2N2N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B07o',
			# TRANSLATORS: B07o: 1. e4 d6 2. d4 Nf6 3. Nc3 c6 4. Nf3
			variation => N__('Pirc: Czech, 4. Nf3'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/2pp1n2/8/3PPP2/2N5/PPP3PP/R1BQKBNR b KQkq' => {
			eco => 'B07p',
			# TRANSLATORS: B07p: 1. e4 d6 2. d4 Nf6 3. Nc3 c6 4. f4
			variation => N__('Pirc: Czech, 4. f4'),
			moves => {
				'd8a5' => 1,
			},
		},
		'rnb1kb1r/pp2pppp/2pp1n2/q7/3PPP2/2N5/PPP3PP/R1BQKBNR w KQkq' => {
			eco => 'B07p',
			# TRANSLATORS: B07p: 1. e4 d6 2. d4 Nf6 3. Nc3 c6 4. f4 Qa5
			variation => N__('Pirc: Czech, 4. f4 Qa5'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/3p1np1/8/3PP3/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'B07q',
			# TRANSLATORS: B07q: 1. e4 d6 2. d4 Nf6 3. Nc3 g6
			variation => N__('Pirc: 3... g6'),
			moves => {
				'c1e3' => 1,
				'c1g5' => 1,
				'f1c4' => 1,
				'f1e2' => 1,
				'f2f4' => 1,
				'g1e2' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
				'h2h4' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/3p1np1/8/3PP3/2N5/PPP1NPPP/R1BQKB1R b KQkq' => {
			eco => 'B07q',
			# TRANSLATORS: B07q: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nge2
			variation => N__('Pirc: 4.Nge2'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/3PP3/2N5/PPP1NPPP/R1BQKB1R w KQkq' => {
			eco => 'B07q',
			# TRANSLATORS: B07q: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nge2 Bg7
			variation => N__('Pirc: 4.Nge2'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/3p1np1/8/3PP2P/2N5/PPP2PP1/R1BQKBNR b KQkq' => {
			eco => 'B07q',
			# TRANSLATORS: B07q: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. h4
			variation => N__('Pirc: 3... g6'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/3p1np1/8/3PP3/2N3P1/PPP2P1P/R1BQKBNR b KQkq' => {
			eco => 'B07r',
			# TRANSLATORS: B07r: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. g3
			variation => N__('Pirc: Sveshnikov (4. g3)'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/3PP3/2N3P1/PPP2P1P/R1BQKBNR w KQkq' => {
			eco => 'B07r',
			# TRANSLATORS: B07r: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. g3 Bg7
			variation => N__('Pirc: Sveshnikov (4. g3)'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/3PP3/2N3P1/PPP2PBP/R1BQK1NR b KQkq' => {
			eco => 'B07r',
			# TRANSLATORS: B07r: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. g3 Bg7 5. Bg2
			variation => N__('Pirc: Sveshnikov (4. g3)'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/2pp1np1/8/3PP3/2N3P1/PPP2PBP/R1BQK1NR w KQkq' => {
			eco => 'B07r',
			# TRANSLATORS: B07r: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. g3 Bg7 5. Bg2 c6
			variation => N__('Pirc: Sveshnikov (4. g3)'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/3p1np1/8/2BPP3/2N5/PPP2PPP/R1BQK1NR b KQkq' => {
			eco => 'B07s',
			# TRANSLATORS: B07s: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Bc4
			variation => N__('Pirc: Holmov (4. Bc4)'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/2BPP3/2N5/PPP2PPP/R1BQK1NR w KQkq' => {
			eco => 'B07s',
			# TRANSLATORS: B07s: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Bc4 Bg7
			variation => N__('Pirc: Holmov (4. Bc4)'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/3p1np1/8/3PP3/2N1B3/PPP2PPP/R2QKBNR b KQkq' => {
			eco => 'B07t',
			# TRANSLATORS: B07t: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Be3
			variation => N__('Pirc: 4. Be3'),
			moves => {
				'c7c6' => 1,
				'f8g7' => 1,
			},
		},
		'rnbqkb1r/pp2pp1p/2pp1np1/8/3PP3/2N1B3/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'B07t',
			# TRANSLATORS: B07t: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Be3 c6
			variation => N__('Pirc: 4. Be3 c6'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/3PP3/2N1B3/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'B07u',
			# TRANSLATORS: B07u: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Be3 Bg7
			variation => N__('Pirc: 4. Be3 Bg7'),
			moves => {
				'd1d2' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/3PP3/2N1B3/PPPQ1PPP/R3KBNR b KQkq' => {
			eco => 'B07u',
			# TRANSLATORS: B07u: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Be3 Bg7 5. Qd2
			variation => N__('Pirc: 4. Be3, 150 Attack'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/2pp1np1/8/3PP3/2N1B3/PPPQ1PPP/R3KBNR w KQkq' => {
			eco => 'B07v',
			# TRANSLATORS: B07v: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Be3 Bg7 5. Qd2 c6
			variation => N__('Pirc: 4. Be3, 150 Attack'),
			moves => {
				'f2f3' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/2pp1np1/8/3PP3/2N1BP2/PPPQ2PP/R3KBNR b KQkq' => {
			eco => 'B07v',
			# TRANSLATORS: B07v: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Be3 Bg7 5. Qd2 c6 6. f3
			variation => N__('Pirc: 4. Be3, 150 Attack'),
			moves => {
				'b7b5' => 1,
			},
		},
		'rnbqk2r/p3ppbp/2pp1np1/1p6/3PP3/2N1BP2/PPPQ2PP/R3KBNR w KQkq' => {
			eco => 'B07v',
			# TRANSLATORS: B07v: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Be3 Bg7 5. Qd2 c6 6. f3 b5
			variation => N__('Pirc: 4. Be3, 150 Attack'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/3p1np1/6B1/3PP3/2N5/PPP2PPP/R2QKBNR b KQkq' => {
			eco => 'B07w',
			# TRANSLATORS: B07w: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Bg5
			variation => N__('Pirc: Byrne 4. Bg5'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/6B1/3PP3/2N5/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'B07x',
			# TRANSLATORS: B07x: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Bg5 Bg7
			variation => N__('Pirc: 4. Bg5 Bg7'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/3p1np1/8/3PP3/2N5/PPP1BPPP/R1BQK1NR b KQkq' => {
			eco => 'B07y',
			# TRANSLATORS: B07y: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Be2
			variation => N__('Pirc: 4. Be2'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/3PP3/2N5/PPP1BPPP/R1BQK1NR w KQkq' => {
			eco => 'B07y',
			# TRANSLATORS: B07y: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Be2 Bg7
			variation => N__('Pirc: 4. Be2'),
			moves => {
				'g2g4' => 1,
				'h2h4' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/3PP1P1/2N5/PPP1BP1P/R1BQK1NR b KQkq' => {
			eco => 'B07y',
			# TRANSLATORS: B07y: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Be2 Bg7 5. g4
			variation => N__('Pirc: Chinese Variation'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/3PP2P/2N5/PPP1BPP1/R1BQK1NR b KQkq' => {
			eco => 'B07z',
			# TRANSLATORS: B07z: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Be2 Bg7 5. h4
			variation => N__('Pirc: Bayonet/Mariotti Attack'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/3p1np1/8/3PP3/2N2N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B08a',
			# TRANSLATORS: B08a: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nf3
			variation => N__('Pirc: Classical'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/3PP3/2N2N2/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B08a',
			# TRANSLATORS: B08a: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nf3 Bg7
			variation => N__('Pirc: Classical'),
			moves => {
				'a2a4' => 1,
				'c1e3' => 1,
				'f1c4' => 1,
				'f1e2' => 1,
				'h2h3' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/3PP3/2N2N1P/PPP2PP1/R1BQKB1R b KQkq' => {
			eco => 'B08b',
			# TRANSLATORS: B08b: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. h3
			variation => N__('Pirc: Classical, 5. h3'),
			moves => {
				'c7c6' => 1,
				'e8g8' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/2pp1np1/8/3PP3/2N2N1P/PPP2PP1/R1BQKB1R w KQkq' => {
			eco => 'B08b',
			# TRANSLATORS: B08b: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. h3 c6
			variation => N__('Pirc: Classical, 5. h3'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/3PP3/2N2N1P/PPP2PP1/R1BQKB1R w KQ' => {
			eco => 'B08b',
			# TRANSLATORS: B08b: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. h3 O-O
			variation => N__('Pirc: Classical, 5. h3'),
			moves => {
				'c1e3' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/3PP3/2N1BN1P/PPP2PP1/R2QKB1R b KQ' => {
			eco => 'B08c',
			# TRANSLATORS: B08c: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. h3 O-O 6. Be3
			variation => N__('Pirc: Classical, Spassky System'),
			moves => {
				'a7a6' => 1,
				'c7c6' => 1,
				'd6d5' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/3p4/3PP3/2N1BN1P/PPP2PP1/R2QKB1R w KQ' => {
			eco => 'B08c',
			# TRANSLATORS: B08c: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. h3 O-O 6. Be3 d5
			variation => N__('Pirc: Classical, Spassky System, 6... d5'),
			moves => {
			},
		},
		'rnbq1rk1/1pp1ppbp/p2p1np1/8/3PP3/2N1BN1P/PPP2PP1/R2QKB1R w KQ' => {
			eco => 'B08d',
			# TRANSLATORS: B08d: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. h3 O-O 6. Be3 a6
			variation => N__('Pirc: Classical, Spassky System, 6... a6'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/2pp1np1/8/3PP3/2N1BN1P/PPP2PP1/R2QKB1R w KQ' => {
			eco => 'B08e',
			# TRANSLATORS: B08e: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. h3 O-O 6. Be3 c6
			variation => N__('Pirc: Classical, Spassky System, 6... c6'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/P2PP3/2N2N2/1PP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B08f',
			# TRANSLATORS: B08f: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. a4
			variation => N__('Pirc: Classical, 5. a4'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/2pp1np1/8/P2PP3/2N2N2/1PP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B08f',
			# TRANSLATORS: B08f: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. a4 c6
			variation => N__('Pirc: Classical, 5. a4 c6'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/2BPP3/2N2N2/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'B08g',
			# TRANSLATORS: B08g: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. Bc4
			variation => N__('Pirc: Classical, 5. Bc4'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/2pp1np1/8/2BPP3/2N2N2/PPP2PPP/R1BQK2R w KQkq' => {
			eco => 'B08g',
			# TRANSLATORS: B08g: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. Bc4 c6
			variation => N__('Pirc: Classical, 5. Bc4 c6'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/3PP3/2N1BN2/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'B08h',
			# TRANSLATORS: B08h: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. Be3
			variation => N__('Pirc: Classical, 5. Be3'),
			moves => {
				'a7a6' => 1,
				'c7c6' => 1,
			},
		},
		'rnbqk2r/1pp1ppbp/p2p1np1/8/3PP3/2N1BN2/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B08h',
			# TRANSLATORS: B08h: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. Be3 a6
			variation => N__('Pirc: Classical, 5. Be3'),
			moves => {
				'a2a4' => 1,
			},
		},
		'rnbqk2r/1pp1ppbp/p2p1np1/8/P2PP3/2N1BN2/1PP2PPP/R2QKB1R b KQkq' => {
			eco => 'B08h',
			# TRANSLATORS: B08h: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. Be3 a6 6. a4
			variation => N__('Pirc: Classical, 5. Be3 a6 6. a4'),
			moves => {
			},
		},
		'rnbqk2r/pp2ppbp/2pp1np1/8/3PP3/2N1BN2/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B08i',
			# TRANSLATORS: B08i: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. Be3 c6
			variation => N__('Pirc: Classical, 5. Be3 c6'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/3PP3/2N2N2/PPP1BPPP/R1BQK2R b KQkq' => {
			eco => 'B08j',
			# TRANSLATORS: B08j: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. Be2
			variation => N__('Pirc: Classical, 5. Be2'),
			moves => {
				'a7a6' => 1,
				'c7c6' => 1,
				'e8g8' => 1,
			},
		},
		'rnbqk2r/1pp1ppbp/p2p1np1/8/3PP3/2N2N2/PPP1BPPP/R1BQK2R w KQkq' => {
			eco => 'B08j',
			# TRANSLATORS: B08j: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. Be2 a6
			variation => N__('Pirc: Classical, 5. Be2'),
			moves => {
				'a2a4' => 1,
			},
		},
		'rnbqk2r/1pp1ppbp/p2p1np1/8/P2PP3/2N2N2/1PP1BPPP/R1BQK2R b KQkq' => {
			eco => 'B08j',
			# TRANSLATORS: B08j: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. Be2 a6 6. a4
			variation => N__('Pirc: Classical, 5. Be2 a6 6. a4'),
			moves => {
			},
		},
		'rnbqk2r/pp2ppbp/2pp1np1/8/3PP3/2N2N2/PPP1BPPP/R1BQK2R w KQkq' => {
			eco => 'B08k',
			# TRANSLATORS: B08k: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. Be2 c6
			variation => N__('Pirc: Classical, 5. Be2 c6'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/3PP3/2N2N2/PPP1BPPP/R1BQK2R w KQ' => {
			eco => 'B08l',
			# TRANSLATORS: B08l: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. Be2 O-O
			variation => N__('Pirc: Classical, 5. Be2 O-O'),
			moves => {
				'c1e3' => 1,
				'e1g1' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/3PP3/2N1BN2/PPP1BPPP/R2QK2R b KQ' => {
			eco => 'B08m',
			# TRANSLATORS: B08m: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. Be2 O-O 6. Be3
			variation => N__('Pirc: Classical, 5. Be2 O-O 6. Be3'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/3PP3/2N2N2/PPP1BPPP/R1BQ1RK1 b -' => {
			eco => 'B08n',
			# TRANSLATORS: B08n: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. Be2 O-O 6. O-O
			variation => N__('Pirc: Classical, 5. Be2 O-O 6.O-O'),
			moves => {
				'b8c6' => 1,
				'c7c6' => 1,
				'c8g4' => 1,
			},
		},
		'r1bq1rk1/ppp1ppbp/2np1np1/8/3PP3/2N2N2/PPP1BPPP/R1BQ1RK1 w -' => {
			eco => 'B08o',
			# TRANSLATORS: B08o: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. Be2 O-O 6. O-O Nc6
			variation => N__('Pirc: Classical, 5. Be2 O-O 6.O-O Nc6'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/2pp1np1/8/3PP3/2N2N2/PPP1BPPP/R1BQ1RK1 w -' => {
			eco => 'B08p',
			# TRANSLATORS: B08p: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. Be2 O-O 6. O-O c6
			variation => N__('Pirc: Classical, 5. Be2 O-O 6.O-O c6'),
			moves => {
				'a2a4' => 1,
				'h2h3' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/2pp1np1/8/3PP3/2N2N1P/PPP1BPP1/R1BQ1RK1 b -' => {
			eco => 'B08q',
			# TRANSLATORS: B08q: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. Be2 O-O 6. O-O c6 7. h3
			variation => N__('Pirc: Classical, 5. Be2 O-O 6.O-O c6 7. h3'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/2pp1np1/8/P2PP3/2N2N2/1PP1BPPP/R1BQ1RK1 b -' => {
			eco => 'B08r',
			# TRANSLATORS: B08r: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. Be2 O-O 6. O-O c6 7. a4
			variation => N__('Pirc: Classical, 5. Be2 O-O 6.O-O c6 7. a4'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r1bq1rk1/pp1nppbp/2pp1np1/8/P2PP3/2N2N2/1PP1BPPP/R1BQ1RK1 w -' => {
			eco => 'B08s',
			# TRANSLATORS: B08s: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. Be2 O-O 6. O-O c6 7. a4 Nbd7
			variation => N__('Pirc: Classical, 5. Be2 O-O 6.O-O c6 7. a4 Nbd7'),
			moves => {
			},
		},
		'rn1q1rk1/ppp1ppbp/3p1np1/8/3PP1b1/2N2N2/PPP1BPPP/R1BQ1RK1 w -' => {
			eco => 'B08t',
			# TRANSLATORS: B08t: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. Be2 O-O 6. O-O Bg4
			variation => N__('Pirc: Classical, 5. Be2 O-O 6.O-O Bg4'),
			moves => {
				'c1e3' => 1,
			},
		},
		'rn1q1rk1/ppp1ppbp/3p1np1/8/3PP1b1/2N1BN2/PPP1BPPP/R2Q1RK1 b -' => {
			eco => 'B08t',
			# TRANSLATORS: B08t: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. Be2 O-O 6. O-O Bg4 7. Be3
			variation => N__('Pirc: Classical, 5. Be2 O-O 6.O-O Bg4'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r2q1rk1/ppp1ppbp/2np1np1/8/3PP1b1/2N1BN2/PPP1BPPP/R2Q1RK1 w -' => {
			eco => 'B08t',
			# TRANSLATORS: B08t: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. Be2 O-O 6. O-O Bg4 7. Be3 Nc6
			variation => N__('Pirc: Classical, 5. Be2 O-O 6.O-O Bg4'),
			moves => {
				'd1d2' => 1,
			},
		},
		'r2q1rk1/ppp1ppbp/2np1np1/8/3PP1b1/2N1BN2/PPPQBPPP/R4RK1 b -' => {
			eco => 'B08u',
			# TRANSLATORS: B08u: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. Be2 O-O 6. O-O Bg4 7. Be3 Nc6 8. Qd2
			variation => N__('Pirc: Classical, 5. Be2 O-O 6.O-O Bg4 7. Be3 Nc6 8. Qd2'),
			moves => {
				'e7e5' => 1,
			},
		},
		'r2q1rk1/ppp2pbp/2np1np1/4p3/3PP1b1/2N1BN2/PPPQBPPP/R4RK1 w -' => {
			eco => 'B08v',
			# TRANSLATORS: B08v: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. Nf3 Bg7 5. Be2 O-O 6. O-O Bg4 7. Be3 Nc6 8. Qd2 e5
			variation => N__('Pirc: Classical, 5. Be2 O-O 6.O-O Bg4 7. Be3 Nc6 8. Qd2 e5'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/3p1np1/8/3PPP2/2N5/PPP3PP/R1BQKBNR b KQkq' => {
			eco => 'B09a',
			# TRANSLATORS: B09a: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. f4
			variation => N__('Pirc: Austrian Attack'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/3PPP2/2N5/PPP3PP/R1BQKBNR w KQkq' => {
			eco => 'B09b',
			# TRANSLATORS: B09b: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. f4 Bg7
			variation => N__('Pirc: Austrian Attack'),
			moves => {
				'f1c4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/2BPPP2/2N5/PPP3PP/R1BQK1NR b KQkq' => {
			eco => 'B09c',
			# TRANSLATORS: B09c: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. f4 Bg7 5. Bc4
			variation => N__('Pirc: Austrian, Ljubojevic Variation'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/3PPP2/2N2N2/PPP3PP/R1BQKB1R b KQkq' => {
			eco => 'B09d',
			# TRANSLATORS: B09d: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. f4 Bg7 5. Nf3
			variation => N__('Pirc: Austrian, 5. Nf3'),
			moves => {
				'c7c5' => 1,
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/3PPP2/2N2N2/PPP3PP/R1BQKB1R w KQ' => {
			eco => 'B09e',
			# TRANSLATORS: B09e: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. f4 Bg7 5. Nf3 O-O
			variation => N__('Pirc: Austrian, 5...O-O'),
			moves => {
				'c1e3' => 1,
				'e4e5' => 1,
				'f1d3' => 1,
				'f1e2' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/4P3/3P1P2/2N2N2/PPP3PP/R1BQKB1R b KQ' => {
			eco => 'B09f',
			# TRANSLATORS: B09f: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. f4 Bg7 5. Nf3 O-O 6. e5
			variation => N__('Pirc: Austrian, 5...O-O 6. e5'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/3PPP2/2N1BN2/PPP3PP/R2QKB1R b KQ' => {
			eco => 'B09g',
			# TRANSLATORS: B09g: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. f4 Bg7 5. Nf3 O-O 6. Be3
			variation => N__('Pirc: Austrian, 5...O-O 6. Be3'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/3PPP2/2N2N2/PPP1B1PP/R1BQK2R b KQ' => {
			eco => 'B09h',
			# TRANSLATORS: B09h: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. f4 Bg7 5. Nf3 O-O 6. Be2
			variation => N__('Pirc: Austrian, 5...O-O 6. Be2'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/3PPP2/2NB1N2/PPP3PP/R1BQK2R b KQ' => {
			eco => 'B09i',
			# TRANSLATORS: B09i: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. f4 Bg7 5. Nf3 O-O 6. Bd3
			variation => N__('Pirc: Austrian, 5...O-O 6. Bd3'),
			moves => {
				'b8a6' => 1,
				'b8c6' => 1,
			},
		},
		'r1bq1rk1/ppp1ppbp/2np1np1/8/3PPP2/2NB1N2/PPP3PP/R1BQK2R w KQ' => {
			eco => 'B09j',
			# TRANSLATORS: B09j: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. f4 Bg7 5. Nf3 O-O 6. Bd3 Nc6
			variation => N__('Pirc: Austrian, 5...O-O 6. Bd3 Nc6'),
			moves => {
				'e4e5' => 1,
			},
		},
		'r1bq1rk1/ppp1ppbp/2np1np1/4P3/3P1P2/2NB1N2/PPP3PP/R1BQK2R b KQ' => {
			eco => 'B09k',
			# TRANSLATORS: B09k: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. f4 Bg7 5. Nf3 O-O 6. Bd3 Nc6 7. e5
			variation => N__('Pirc: Austrian, 5...O-O 6. Bd3 Nc6 7. e5'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1ppbp/n2p1np1/8/3PPP2/2NB1N2/PPP3PP/R1BQK2R w KQ' => {
			eco => 'B09l',
			# TRANSLATORS: B09l: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. f4 Bg7 5. Nf3 O-O 6. Bd3 Na6
			variation => N__('Pirc: Austrian, 5...O-O 6. Bd3 Na6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bq1rk1/ppp1ppbp/n2p1np1/8/3PPP2/2NB1N2/PPP3PP/R1BQ1RK1 b -' => {
			eco => 'B09l',
			# TRANSLATORS: B09l: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. f4 Bg7 5. Nf3 O-O 6. Bd3 Na6 7. O-O
			variation => N__('Pirc: Austrian, 5...O-O 6. Bd3 Na6'),
			moves => {
				'c7c5' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/n2p1np1/2p5/3PPP2/2NB1N2/PPP3PP/R1BQ1RK1 w -' => {
			eco => 'B09m',
			# TRANSLATORS: B09m: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. f4 Bg7 5. Nf3 O-O 6. Bd3 Na6 7. O-O c5
			variation => N__('Pirc: Austrian, 5...O-O 6. Bd3 Na6 7.O-O c5'),
			moves => {
				'd4d5' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/n2p1np1/2pP4/4PP2/2NB1N2/PPP3PP/R1BQ1RK1 b -' => {
			eco => 'B09m',
			# TRANSLATORS: B09m: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. f4 Bg7 5. Nf3 O-O 6. Bd3 Na6 7. O-O c5 8. d5
			variation => N__('Pirc: Austrian, 5...O-O 6. Bd3 Na6 7.O-O c5 8. d5'),
			moves => {
				'c8g4' => 1,
			},
		},
		'r2q1rk1/pp2ppbp/n2p1np1/2pP4/4PPb1/2NB1N2/PPP3PP/R1BQ1RK1 w -' => {
			eco => 'B09n',
			# TRANSLATORS: B09n: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. f4 Bg7 5. Nf3 O-O 6. Bd3 Na6 7. O-O c5 8. d5 Bg4
			variation => N__('Pirc: Austrian, 5...O-O 6. Bd3 Na6 7.O-O c5 8. d5 Bg4'),
			moves => {
			},
		},
		'rnbqk2r/pp2ppbp/3p1np1/2p5/3PPP2/2N2N2/PPP3PP/R1BQKB1R w KQkq' => {
			eco => 'B09o',
			# TRANSLATORS: B09o: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. f4 Bg7 5. Nf3 c5
			variation => N__('Pirc: Austrian, 5... c5'),
			moves => {
				'd4c5' => 1,
				'f1b5' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/3p1np1/2P5/4PP2/2N2N2/PPP3PP/R1BQKB1R b KQkq' => {
			eco => 'B09p',
			# TRANSLATORS: B09p: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. f4 Bg7 5. Nf3 c5 6. dxc5
			variation => N__('Pirc: Austrian, 5... c5 6.dxc5'),
			moves => {
				'd8a5' => 1,
			},
		},
		'rnb1k2r/pp2ppbp/3p1np1/q1P5/4PP2/2N2N2/PPP3PP/R1BQKB1R w KQkq' => {
			eco => 'B09p',
			# TRANSLATORS: B09p: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. f4 Bg7 5. Nf3 c5 6. dxc5 Qa5
			variation => N__('Pirc: Austrian, 5... c5 6.dxc5'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rnb1k2r/pp2ppbp/3p1np1/q1P5/4PP2/2NB1N2/PPP3PP/R1BQK2R b KQkq' => {
			eco => 'B09q',
			# TRANSLATORS: B09q: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. f4 Bg7 5. Nf3 c5 6. dxc5 Qa5 7. Bd3
			variation => N__('Pirc: Austrian, 5... c5 6.dxc5 Qa5 7. Bd3'),
			moves => {
			},
		},
		'rnbqk2r/pp2ppbp/3p1np1/1Bp5/3PPP2/2N2N2/PPP3PP/R1BQK2R b KQkq' => {
			eco => 'B09r',
			# TRANSLATORS: B09r: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. f4 Bg7 5. Nf3 c5 6. Bb5+
			variation => N__('Pirc: Austrian, 5... c5 6. Bb5+'),
			moves => {
				'c8d7' => 1,
			},
		},
		'rn1qk2r/pp1bppbp/3p1np1/1Bp5/3PPP2/2N2N2/PPP3PP/R1BQK2R w KQkq' => {
			eco => 'B09s',
			# TRANSLATORS: B09s: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. f4 Bg7 5. Nf3 c5 6. Bb5+ Bd7
			variation => N__('Pirc: Austrian, 5... c5 6. Bb5+'),
			moves => {
				'e4e5' => 1,
			},
		},
		'rn1qk2r/pp1bppbp/3p1np1/1Bp1P3/3P1P2/2N2N2/PPP3PP/R1BQK2R b KQkq' => {
			eco => 'B09t',
			# TRANSLATORS: B09t: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. f4 Bg7 5. Nf3 c5 6. Bb5+ Bd7 7. e5
			variation => N__('Pirc: Austrian, 5... c5 6. Bb5+ Bd7 7. e5'),
			moves => {
				'f6g4' => 1,
			},
		},
		'rn1qk2r/pp1bppbp/3p2p1/1Bp1P3/3P1Pn1/2N2N2/PPP3PP/R1BQK2R w KQkq' => {
			eco => 'B09u',
			# TRANSLATORS: B09u: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. f4 Bg7 5. Nf3 c5 6. Bb5+ Bd7 7. e5 Ng4
			variation => N__('Pirc: Austrian, 5... c5 6. Bb5+ Bd7 7. e5 Ng4'),
			moves => {
				'b5d7' => 1,
				'e5e6' => 1,
			},
		},
		'rn1qk2r/pp1Bppbp/3p2p1/2p1P3/3P1Pn1/2N2N2/PPP3PP/R1BQK2R b KQkq' => {
			eco => 'B09v',
			# TRANSLATORS: B09v: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. f4 Bg7 5. Nf3 c5 6. Bb5+ Bd7 7. e5 Ng4 8. Bxd7+
			variation => N__('Pirc: Austrian, 5... c5 6. Bb5+ Bd7 7. e5 Ng4 8.Bxd7+'),
			moves => {
			},
		},
		'rn1qk2r/pp1bppbp/3pP1p1/1Bp5/3P1Pn1/2N2N2/PPP3PP/R1BQK2R b KQkq' => {
			eco => 'B09w',
			# TRANSLATORS: B09w: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. f4 Bg7 5. Nf3 c5 6. Bb5+ Bd7 7. e5 Ng4 8. e6
			variation => N__('Pirc: Austrian, 5... c5 6. Bb5+ Bd7 7. e5 Ng4 8. e6'),
			moves => {
				'd7b5' => 1,
				'f7e6' => 1,
			},
		},
		'rn1qk2r/pp1bp1bp/3pp1p1/1Bp5/3P1Pn1/2N2N2/PPP3PP/R1BQK2R w KQkq' => {
			eco => 'B09w',
			# TRANSLATORS: B09w: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. f4 Bg7 5. Nf3 c5 6. Bb5+ Bd7 7. e5 Ng4 8. e6 fxe6
			variation => N__('Pirc: Austrian, 5... c5, Seirawan Variation'),
			moves => {
			},
		},
		'rn1qk2r/pp2ppbp/3pP1p1/1bp5/3P1Pn1/2N2N2/PPP3PP/R1BQK2R w KQkq' => {
			eco => 'B09x',
			# TRANSLATORS: B09x: 1. e4 d6 2. d4 Nf6 3. Nc3 g6 4. f4 Bg7 5. Nf3 c5 6. Bb5+ Bd7 7. e5 Ng4 8. e6 Bxb5
			variation => N__('Pirc: Austrian, 5... c5 6. Bb5+ Bd7 7. e5 Ng4 8. e6 Bxb5'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/2p5/8/4P3/8/PPPP1PPP/RNBQKBNR w KQkq' => {
			eco => 'B10a',
			# TRANSLATORS: B10a: 1. e4 c6
			variation => N__('Caro-Kann'),
			moves => {
				'b1c3' => 1,
				'c2c4' => 1,
				'd2d3' => 1,
				'd2d4' => 1,
				'f2f4' => 1,
				'g1e2' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pp1ppppp/2p5/8/4PP2/8/PPPP2PP/RNBQKBNR b KQkq' => {
			eco => 'B10a',
			# TRANSLATORS: B10a: 1. e4 c6 2. f4
			variation => N__('Caro-Kann: 2. f4'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/2p5/8/4P3/8/PPPPNPPP/RNBQKB1R b KQkq' => {
			eco => 'B10a',
			# TRANSLATORS: B10a: 1. e4 c6 2. Ne2
			variation => N__('Caro-Kann: 2. Ne2'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/2p5/8/4P3/3P4/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'B10b',
			# TRANSLATORS: B10b: 1. e4 c6 2. d3
			variation => N__('Caro-Kann: Breyer Variation'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3p4/4P3/3P4/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B10b',
			# TRANSLATORS: B10b: 1. e4 c6 2. d3 d5
			variation => N__('Caro-Kann: Breyer Variation'),
			moves => {
				'b1d2' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3p4/4P3/3P4/PPPN1PPP/R1BQKBNR b KQkq' => {
			eco => 'B10c',
			# TRANSLATORS: B10c: 1. e4 c6 2. d3 d5 3. Nd2
			variation => N__('Caro-Kann: Breyer, 3. Nd2'),
			moves => {
				'e7e5' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkbnr/pp2pp1p/2p3p1/3p4/4P3/3P4/PPPN1PPP/R1BQKBNR w KQkq' => {
			eco => 'B10d',
			# TRANSLATORS: B10d: 1. e4 c6 2. d3 d5 3. Nd2 g6
			variation => N__('Caro-Kann: Breyer, 3. Nd2 g6'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/2p5/3pp3/4P3/3P4/PPPN1PPP/R1BQKBNR w KQkq' => {
			eco => 'B10e',
			# TRANSLATORS: B10e: 1. e4 c6 2. d3 d5 3. Nd2 e5
			variation => N__('Caro-Kann: Breyer, 3. Nd2 e5'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/2p5/3pp3/4P3/3P1N2/PPPN1PPP/R1BQKB1R b KQkq' => {
			eco => 'B10e',
			# TRANSLATORS: B10e: 1. e4 c6 2. d3 d5 3. Nd2 e5 4. Ngf3
			variation => N__('Caro-Kann: Breyer, 3. Nd2 e5'),
			moves => {
				'f8d6' => 1,
			},
		},
		'rnbqk1nr/pp3ppp/2pb4/3pp3/4P3/3P1N2/PPPN1PPP/R1BQKB1R w KQkq' => {
			eco => 'B10e',
			# TRANSLATORS: B10e: 1. e4 c6 2. d3 d5 3. Nd2 e5 4. Ngf3 Bd6
			variation => N__('Caro-Kann: Breyer, 3. Nd2 e5'),
			moves => {
				'g2g3' => 1,
			},
		},
		'rnbqk1nr/pp3ppp/2pb4/3pp3/4P3/3P1NP1/PPPN1P1P/R1BQKB1R b KQkq' => {
			eco => 'B10f',
			# TRANSLATORS: B10f: 1. e4 c6 2. d3 d5 3. Nd2 e5 4. Ngf3 Bd6 5. g3
			variation => N__('Caro-Kann: Breyer, Main Line'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/2p5/8/2P1P3/8/PP1P1PPP/RNBQKBNR b KQkq' => {
			eco => 'B10g',
			# TRANSLATORS: B10g: 1. e4 c6 2. c4
			variation => N__('Caro-Kann: English Variation'),
			moves => {
				'd7d5' => 1,
				'e7e5' => 1,
			},
		},
		'rnbqkbnr/pp1p1ppp/2p5/4p3/2P1P3/8/PP1P1PPP/RNBQKBNR w KQkq' => {
			eco => 'B10h',
			# TRANSLATORS: B10h: 1. e4 c6 2. c4 e5
			variation => N__('Caro-Kann: English Variation'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3p4/2P1P3/8/PP1P1PPP/RNBQKBNR w KQkq' => {
			eco => 'B10i',
			# TRANSLATORS: B10i: 1. e4 c6 2. c4 d5
			variation => N__('Caro-Kann: English Variation'),
			moves => {
				'c4d5' => 1,
				'e4d5' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3P4/4P3/8/PP1P1PPP/RNBQKBNR b KQkq' => {
			eco => 'B10i',
			# TRANSLATORS: B10i: 1. e4 c6 2. c4 d5 3. cxd5
			variation => N__('Caro-Kann: English Variation'),
			moves => {
				'c6d5' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/8/3p4/4P3/8/PP1P1PPP/RNBQKBNR w KQkq' => {
			eco => 'B10i',
			# TRANSLATORS: B10i: 1. e4 c6 2. c4 d5 3. cxd5 cxd5
			variation => N__('Caro-Kann: English Variation'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3P4/2P5/8/PP1P1PPP/RNBQKBNR b KQkq' => {
			eco => 'B10i',
			# TRANSLATORS: B10i: 1. e4 c6 2. c4 d5 3. exd5
			variation => N__('Caro-Kann: English Variation'),
			moves => {
				'c6d5' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/8/3p4/2P5/8/PP1P1PPP/RNBQKBNR w KQkq' => {
			eco => 'B10i',
			# TRANSLATORS: B10i: 1. e4 c6 2. c4 d5 3. exd5 cxd5
			variation => N__('Caro-Kann: English Variation'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/8/3P4/8/8/PP1P1PPP/RNBQKBNR b KQkq' => {
			eco => 'B10j',
			# TRANSLATORS: B10j: 1. e4 c6 2. c4 d5 3. exd5 cxd5 4. cxd5
			variation => N__('Caro-Kann: English, Exchange'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/5n2/3P4/8/8/PP1P1PPP/RNBQKBNR w KQkq' => {
			eco => 'B10k',
			# TRANSLATORS: B10k: 1. e4 c6 2. c4 d5 3. exd5 cxd5 4. cxd5 Nf6
			variation => N__('Caro-Kann: English, Exchange, 4... Nf6'),
			moves => {
				'b1c3' => 1,
				'f1b5' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/5n2/1B1P4/8/8/PP1P1PPP/RNBQK1NR b KQkq' => {
			eco => 'B10l',
			# TRANSLATORS: B10l: 1. e4 c6 2. c4 d5 3. exd5 cxd5 4. cxd5 Nf6 5. Bb5+
			variation => N__('Caro-Kann: English, Exchange, 4... Nf6 5. Bb5+'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/5n2/3P4/8/2N5/PP1P1PPP/R1BQKBNR b KQkq' => {
			eco => 'B10m',
			# TRANSLATORS: B10m: 1. e4 c6 2. c4 d5 3. exd5 cxd5 4. cxd5 Nf6 5. Nc3
			variation => N__('Caro-Kann: English, Exchange, 4... Nf6 5. Nc3'),
			moves => {
				'f6d5' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/8/3n4/8/2N5/PP1P1PPP/R1BQKBNR w KQkq' => {
			eco => 'B10n',
			# TRANSLATORS: B10n: 1. e4 c6 2. c4 d5 3. exd5 cxd5 4. cxd5 Nf6 5. Nc3 Nxd5
			variation => N__('Caro-Kann: English, Exchange, 4... Nf6 5. Nc3 Nxd5'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/2p5/8/4P3/5N2/PPPP1PPP/RNBQKB1R b KQkq' => {
			eco => 'B10o',
			# TRANSLATORS: B10o: 1. e4 c6 2. Nf3
			variation => N__('Caro-Kann: 2. Nf3'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/2p5/8/4P3/2N5/PPPP1PPP/R1BQKBNR b KQkq' => {
			eco => 'B10p',
			# TRANSLATORS: B10p: 1. e4 c6 2. Nc3
			variation => N__('Caro-Kann: 2. Nc3'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3p4/4P3/2N5/PPPP1PPP/R1BQKBNR w KQkq' => {
			eco => 'B10q',
			# TRANSLATORS: B10q: 1. e4 c6 2. Nc3 d5
			variation => N__('Caro-Kann: 2. Nc3 d5'),
			moves => {
				'd1f3' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3p4/4P3/2N2Q2/PPPP1PPP/R1B1KBNR b KQkq' => {
			eco => 'B10r',
			# TRANSLATORS: B10r: 1. e4 c6 2. Nc3 d5 3. Qf3
			variation => N__('Caro-Kann: Goldman/Spielmann'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3p4/4P3/2N2N2/PPPP1PPP/R1BQKB1R b KQkq' => {
			eco => 'B10s',
			# TRANSLATORS: B10s: 1. e4 c6 2. Nc3 d5 3. Nf3
			variation => N__('Caro-Kann: Two Knights Variation'),
			moves => {
				'c8g4' => 1,
				'd5e4' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/2p5/8/4p3/2N2N2/PPPP1PPP/R1BQKB1R w KQkq' => {
			eco => 'B10t',
			# TRANSLATORS: B10t: 1. e4 c6 2. Nc3 d5 3. Nf3 dxe4
			variation => N__('Caro-Kann: Two Knights, 3...dxe4'),
			moves => {
				'c3e4' => 1,
				'f3g5' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/2p5/6N1/4p3/2N5/PPPP1PPP/R1BQKB1R b KQkq' => {
			eco => 'B10t',
			# TRANSLATORS: B10t: 1. e4 c6 2. Nc3 d5 3. Nf3 dxe4 4. Ng5
			variation => N__('Caro-Kann: Hector Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/2p5/8/4N3/5N2/PPPP1PPP/R1BQKB1R b KQkq' => {
			eco => 'B10u',
			# TRANSLATORS: B10u: 1. e4 c6 2. Nc3 d5 3. Nf3 dxe4 4. Nxe4
			variation => N__('Caro-Kann: Two Knights, 3...dxe4 4.Nxe4'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/8/4N3/5N2/PPPP1PPP/R1BQKB1R w KQkq' => {
			eco => 'B10v',
			# TRANSLATORS: B10v: 1. e4 c6 2. Nc3 d5 3. Nf3 dxe4 4. Nxe4 Nf6
			variation => N__('Caro-Kann: Two Knights, 3...dxe4 4.Nxe4 Nf6'),
			moves => {
			},
		},
		'rn1qkbnr/pp2pppp/2p5/3p4/4P1b1/2N2N2/PPPP1PPP/R1BQKB1R w KQkq' => {
			eco => 'B11a',
			# TRANSLATORS: B11a: 1. e4 c6 2. Nc3 d5 3. Nf3 Bg4
			variation => N__('Caro-Kann: Two Knights, 3... Bg4'),
			moves => {
				'h2h3' => 1,
			},
		},
		'rn1qkbnr/pp2pppp/2p5/3p4/4P1b1/2N2N1P/PPPP1PP1/R1BQKB1R b KQkq' => {
			eco => 'B11b',
			# TRANSLATORS: B11b: 1. e4 c6 2. Nc3 d5 3. Nf3 Bg4 4. h3
			variation => N__('Caro-Kann: Two Knights, 3... Bg4 4. h3'),
			moves => {
				'g4f3' => 1,
				'g4h5' => 1,
			},
		},
		'rn1qkbnr/pp2pppp/2p5/3p3b/4P3/2N2N1P/PPPP1PP1/R1BQKB1R w KQkq' => {
			eco => 'B11b',
			# TRANSLATORS: B11b: 1. e4 c6 2. Nc3 d5 3. Nf3 Bg4 4. h3 Bh5
			variation => N__('Caro-Kann: Two Knights, 3... Bg4 4. h3 Bh5'),
			moves => {
				'e4d5' => 1,
			},
		},
		'rn1qkbnr/pp2pppp/2p5/3P3b/8/2N2N1P/PPPP1PP1/R1BQKB1R b KQkq' => {
			eco => 'B11b',
			# TRANSLATORS: B11b: 1. e4 c6 2. Nc3 d5 3. Nf3 Bg4 4. h3 Bh5 5. exd5
			variation => N__('Caro-Kann: Two Knights, 3... Bg4 4. h3 Bh5'),
			moves => {
				'c6d5' => 1,
			},
		},
		'rn1qkbnr/pp2pppp/8/3p3b/8/2N2N1P/PPPP1PP1/R1BQKB1R w KQkq' => {
			eco => 'B11b',
			# TRANSLATORS: B11b: 1. e4 c6 2. Nc3 d5 3. Nf3 Bg4 4. h3 Bh5 5. exd5 cxd5
			variation => N__('Caro-Kann: Two Knights, 3... Bg4 4. h3 Bh5'),
			moves => {
				'f1b5' => 1,
			},
		},
		'rn1qkbnr/pp2pppp/8/1B1p3b/8/2N2N1P/PPPP1PP1/R1BQK2R b KQkq' => {
			eco => 'B11b',
			# TRANSLATORS: B11b: 1. e4 c6 2. Nc3 d5 3. Nf3 Bg4 4. h3 Bh5 5. exd5 cxd5 6. Bb5+
			variation => N__('Caro-Kann: Two Knights, 3... Bg4 4. h3 Bh5'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r2qkbnr/pp2pppp/2n5/1B1p3b/8/2N2N1P/PPPP1PP1/R1BQK2R w KQkq' => {
			eco => 'B11b',
			# TRANSLATORS: B11b: 1. e4 c6 2. Nc3 d5 3. Nf3 Bg4 4. h3 Bh5 5. exd5 cxd5 6. Bb5+ Nc6
			variation => N__('Caro-Kann: Two Knights, 3... Bg4 4. h3 Bh5'),
			moves => {
				'g2g4' => 1,
			},
		},
		'r2qkbnr/pp2pppp/2n5/1B1p3b/6P1/2N2N1P/PPPP1P2/R1BQK2R b KQkq' => {
			eco => 'B11b',
			# TRANSLATORS: B11b: 1. e4 c6 2. Nc3 d5 3. Nf3 Bg4 4. h3 Bh5 5. exd5 cxd5 6. Bb5+ Nc6 7. g4
			variation => N__('Caro-Kann: Two Knights, 3... Bg4 4. h3 Bh5'),
			moves => {
				'h5g6' => 1,
			},
		},
		'r2qkbnr/pp2pppp/2n3b1/1B1p4/6P1/2N2N1P/PPPP1P2/R1BQK2R w KQkq' => {
			eco => 'B11c',
			# TRANSLATORS: B11c: 1. e4 c6 2. Nc3 d5 3. Nf3 Bg4 4. h3 Bh5 5. exd5 cxd5 6. Bb5+ Nc6 7. g4 Bg6
			variation => N__('Caro-Kann: Two Knights, 3... Bg4 4. h3 Bh5, 7. g4 Bg6'),
			moves => {
			},
		},
		'rn1qkbnr/pp2pppp/2p5/3p4/4P3/2N2b1P/PPPP1PP1/R1BQKB1R w KQkq' => {
			eco => 'B11d',
			# TRANSLATORS: B11d: 1. e4 c6 2. Nc3 d5 3. Nf3 Bg4 4. h3 Bxf3
			variation => N__('Caro-Kann: Two Knights, 3... Bg4 4. h3 Bxf3'),
			moves => {
				'd1f3' => 1,
			},
		},
		'rn1qkbnr/pp2pppp/2p5/3p4/4P3/2N2Q1P/PPPP1PP1/R1B1KB1R b KQkq' => {
			eco => 'B11d',
			# TRANSLATORS: B11d: 1. e4 c6 2. Nc3 d5 3. Nf3 Bg4 4. h3 Bxf3 5. Qxf3
			variation => N__('Caro-Kann: Two Knights, 3... Bg4 4. h3 Bxf3 5.Qxf3'),
			moves => {
				'd5e4' => 1,
				'e7e6' => 1,
				'g8f6' => 1,
			},
		},
		'rn1qkbnr/pp2pppp/2p5/8/4p3/2N2Q1P/PPPP1PP1/R1B1KB1R w KQkq' => {
			eco => 'B11e',
			# TRANSLATORS: B11e: 1. e4 c6 2. Nc3 d5 3. Nf3 Bg4 4. h3 Bxf3 5. Qxf3 dxe4
			variation => N__('Caro-Kann: Two Knights, 3... Bg4 4. h3 Bxf3 5.Qxf3 dxe4'),
			moves => {
				'c3e4' => 1,
			},
		},
		'rn1qkbnr/pp2pppp/2p5/8/4N3/5Q1P/PPPP1PP1/R1B1KB1R b KQkq' => {
			eco => 'B11e',
			# TRANSLATORS: B11e: 1. e4 c6 2. Nc3 d5 3. Nf3 Bg4 4. h3 Bxf3 5. Qxf3 dxe4 6. Nxe4
			variation => N__('Caro-Kann: Two Knights, 3... Bg4 4. h3 Bxf3 5.Qxf3 dxe4'),
			moves => {
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/3p4/4P3/2N2Q1P/PPPP1PP1/R1B1KB1R w KQkq' => {
			eco => 'B11f',
			# TRANSLATORS: B11f: 1. e4 c6 2. Nc3 d5 3. Nf3 Bg4 4. h3 Bxf3 5. Qxf3 Nf6
			variation => N__('Caro-Kann: Two Knights, 3... Bg4 4. h3 Bxf3 5.Qxf3 Nf6'),
			moves => {
			},
		},
		'rn1qkbnr/pp3ppp/2p1p3/3p4/4P3/2N2Q1P/PPPP1PP1/R1B1KB1R w KQkq' => {
			eco => 'B11g',
			# TRANSLATORS: B11g: 1. e4 c6 2. Nc3 d5 3. Nf3 Bg4 4. h3 Bxf3 5. Qxf3 e6
			variation => N__('Caro-Kann: Two Knights, 3... Bg4 4. h3 Bxf3 5.Qxf3 e6'),
			moves => {
				'd2d3' => 1,
				'd2d4' => 1,
				'g2g3' => 1,
			},
		},
		'rn1qkbnr/pp3ppp/2p1p3/3p4/3PP3/2N2Q1P/PPP2PP1/R1B1KB1R b KQkq' => {
			eco => 'B11h',
			# TRANSLATORS: B11h: 1. e4 c6 2. Nc3 d5 3. Nf3 Bg4 4. h3 Bxf3 5. Qxf3 e6 6. d4
			variation => N__('Caro-Kann: Two Knights, 3... Bg4 4. h3 Bxf3 5.Qxf3 e6 6. d4'),
			moves => {
			},
		},
		'rn1qkbnr/pp3ppp/2p1p3/3p4/4P3/2N2QPP/PPPP1P2/R1B1KB1R b KQkq' => {
			eco => 'B11i',
			# TRANSLATORS: B11i: 1. e4 c6 2. Nc3 d5 3. Nf3 Bg4 4. h3 Bxf3 5. Qxf3 e6 6. g3
			variation => N__('Caro-Kann: Two Knights, 3... Bg4 4. h3 Bxf3 5.Qxf3 e6 6. g3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rn1qkb1r/pp3ppp/2p1pn2/3p4/4P3/2N2QPP/PPPP1P2/R1B1KB1R w KQkq' => {
			eco => 'B11i',
			# TRANSLATORS: B11i: 1. e4 c6 2. Nc3 d5 3. Nf3 Bg4 4. h3 Bxf3 5. Qxf3 e6 6. g3 Nf6
			variation => N__('Caro-Kann: Two Knights, 3... Bg4 4. h3 Bxf3 5.Qxf3 e6 6. g3 Nf6'),
			moves => {
			},
		},
		'rn1qkbnr/pp3ppp/2p1p3/3p4/4P3/2NP1Q1P/PPP2PP1/R1B1KB1R b KQkq' => {
			eco => 'B11j',
			# TRANSLATORS: B11j: 1. e4 c6 2. Nc3 d5 3. Nf3 Bg4 4. h3 Bxf3 5. Qxf3 e6 6. d3
			variation => N__('Caro-Kann: Two Knights, 3... Bg4 4. h3 Bxf3 5.Qxf3 e6 6. d3'),
			moves => {
				'b8d7' => 1,
				'g8f6' => 1,
			},
		},
		'r2qkbnr/pp1n1ppp/2p1p3/3p4/4P3/2NP1Q1P/PPP2PP1/R1B1KB1R w KQkq' => {
			eco => 'B11k',
			# TRANSLATORS: B11k: 1. e4 c6 2. Nc3 d5 3. Nf3 Bg4 4. h3 Bxf3 5. Qxf3 e6 6. d3 Nd7
			variation => N__('Caro-Kann: Two Knights, 3... Bg4 4. h3 Bxf3 5.Qxf3 e6 6. d3 Nd7'),
			moves => {
			},
		},
		'rn1qkb1r/pp3ppp/2p1pn2/3p4/4P3/2NP1Q1P/PPP2PP1/R1B1KB1R w KQkq' => {
			eco => 'B11l',
			# TRANSLATORS: B11l: 1. e4 c6 2. Nc3 d5 3. Nf3 Bg4 4. h3 Bxf3 5. Qxf3 e6 6. d3 Nf6
			variation => N__('Caro-Kann: Two Knights, 3... Bg4 4. h3 Bxf3 5.Qxf3 e6 6. d3 Nf6'),
			moves => {
				'a2a3' => 1,
				'c1d2' => 1,
			},
		},
		'rn1qkb1r/pp3ppp/2p1pn2/3p4/4P3/P1NP1Q1P/1PP2PP1/R1B1KB1R b KQkq' => {
			eco => 'B11m',
			# TRANSLATORS: B11m: 1. e4 c6 2. Nc3 d5 3. Nf3 Bg4 4. h3 Bxf3 5. Qxf3 e6 6. d3 Nf6 7. a3
			variation => N__('Caro-Kann: Two Knights, 3... Bg4 4. h3 Bxf3 5.Qxf3 e6 6. d3 Nf6 7. a3'),
			moves => {
			},
		},
		'rn1qkb1r/pp3ppp/2p1pn2/3p4/4P3/2NP1Q1P/PPPB1PP1/R3KB1R b KQkq' => {
			eco => 'B11n',
			# TRANSLATORS: B11n: 1. e4 c6 2. Nc3 d5 3. Nf3 Bg4 4. h3 Bxf3 5. Qxf3 e6 6. d3 Nf6 7. Bd2
			variation => N__('Caro-Kann: Two Knights, 3... Bg4 4. h3 Bxf3 5.Qxf3 e6 6. d3 Nf6 7. Bd2'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/2p5/8/3PP3/8/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'B12a',
			# TRANSLATORS: B12a: 1. e4 c6 2. d4
			variation => N__('Caro-Kann: 2. d4'),
			moves => {
				'b8a6' => 1,
				'd7d5' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkbnr/pp1ppppp/n1p5/8/3PP3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B12a',
			# TRANSLATORS: B12a: 1. e4 c6 2. d4 Na6
			variation => N__('Caro-Kann: de Bruycker Defence'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/2p2n2/8/3PP3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B12a',
			# TRANSLATORS: B12a: 1. e4 c6 2. d4 Nf6
			variation => N__('Caro-Kann: Masi Defence'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3p4/3PP3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B12b',
			# TRANSLATORS: B12b: 1. e4 c6 2. d4 d5
			variation => N__('Caro-Kann: 2. d4 d5'),
			moves => {
				'b1c3' => 1,
				'b1d2' => 1,
				'c1e3' => 1,
				'e4d5' => 1,
				'e4e5' => 1,
				'f2f3' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3p4/3PP3/5N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B12b',
			# TRANSLATORS: B12b: 1. e4 c6 2. d4 d5 3. Nf3
			variation => N__('Caro-Kann: Ulysses Gambit'),
			moves => {
				'd5e4' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/2p5/8/3Pp3/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B12b',
			# TRANSLATORS: B12b: 1. e4 c6 2. d4 d5 3. Nf3 dxe4
			variation => N__('Caro-Kann: Ulysses Gambit'),
			moves => {
				'f3g5' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/2p5/6N1/3Pp3/8/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B12b',
			# TRANSLATORS: B12b: 1. e4 c6 2. d4 d5 3. Nf3 dxe4 4. Ng5
			variation => N__('Caro-Kann: Ulysses Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3p4/3PP3/4B3/PPP2PPP/RN1QKBNR b KQkq' => {
			eco => 'B12c',
			# TRANSLATORS: B12c: 1. e4 c6 2. d4 d5 3. Be3
			variation => N__('Caro-Kann: Mieses Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3p4/3PP3/5P2/PPP3PP/RNBQKBNR b KQkq' => {
			eco => 'B12d',
			# TRANSLATORS: B12d: 1. e4 c6 2. d4 d5 3. f3
			variation => N__('Caro-Kann: Maroczy (Fantasy) Variation'),
			moves => {
				'd5e4' => 1,
				'e7e6' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/2p1p3/3p4/3PP3/5P2/PPP3PP/RNBQKBNR w KQkq' => {
			eco => 'B12e',
			# TRANSLATORS: B12e: 1. e4 c6 2. d4 d5 3. f3 e6
			variation => N__('Caro-Kann: Maroczy (Fantasy), 3... e6'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/2p5/8/3Pp3/5P2/PPP3PP/RNBQKBNR w KQkq' => {
			eco => 'B12f',
			# TRANSLATORS: B12f: 1. e4 c6 2. d4 d5 3. f3 dxe4
			variation => N__('Caro-Kann: Maroczy (Fantasy), 3...dxe4'),
			moves => {
				'f3e4' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/2p5/8/3PP3/8/PPP3PP/RNBQKBNR b KQkq' => {
			eco => 'B12f',
			# TRANSLATORS: B12f: 1. e4 c6 2. d4 d5 3. f3 dxe4 4. fxe4
			variation => N__('Caro-Kann: Maroczy (Fantasy), 3...dxe4'),
			moves => {
				'e7e5' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/2p5/4p3/3PP3/8/PPP3PP/RNBQKBNR w KQkq' => {
			eco => 'B12f',
			# TRANSLATORS: B12f: 1. e4 c6 2. d4 d5 3. f3 dxe4 4. fxe4 e5
			variation => N__('Caro-Kann: Maroczy (Fantasy), 3...dxe4'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/2p5/4p3/3PP3/5N2/PPP3PP/RNBQKB1R b KQkq' => {
			eco => 'B12f',
			# TRANSLATORS: B12f: 1. e4 c6 2. d4 d5 3. f3 dxe4 4. fxe4 e5 5. Nf3
			variation => N__('Caro-Kann: Maroczy (Fantasy), 3...dxe4'),
			moves => {
				'e5d4' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/2p5/8/3pP3/5N2/PPP3PP/RNBQKB1R w KQkq' => {
			eco => 'B12f',
			# TRANSLATORS: B12f: 1. e4 c6 2. d4 d5 3. f3 dxe4 4. fxe4 e5 5. Nf3 exd4
			variation => N__('Caro-Kann: Maroczy (Fantasy), 3...dxe4'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/2p5/8/2BpP3/5N2/PPP3PP/RNBQK2R b KQkq' => {
			eco => 'B12f',
			# TRANSLATORS: B12f: 1. e4 c6 2. d4 d5 3. f3 dxe4 4. fxe4 e5 5. Nf3 exd4 6. Bc4
			variation => N__('Caro-Kann: Maroczy (Fantasy), Gambit line'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3p4/3PP3/8/PPPN1PPP/R1BQKBNR b KQkq' => {
			eco => 'B12g',
			# TRANSLATORS: B12g: 1. e4 c6 2. d4 d5 3. Nd2
			variation => N__('Caro-Kann: 3. Nd2'),
			moves => {
				'd5e4' => 1,
				'd8b6' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/2p5/8/3Pp3/8/PPPN1PPP/R1BQKBNR w KQkq' => {
			eco => 'B12g',
			# TRANSLATORS: B12g: 1. e4 c6 2. d4 d5 3. Nd2 dxe4
			variation => N__('Caro-Kann: 3. Nd2 dxe4'),
			moves => {
			},
		},
		'rnb1kbnr/pp2pppp/1qp5/3p4/3PP3/8/PPPN1PPP/R1BQKBNR w KQkq' => {
			eco => 'B12g',
			# TRANSLATORS: B12g: 1. e4 c6 2. d4 d5 3. Nd2 Qb6
			variation => N__('Caro-Kann: Edinburgh Variation'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pp1p/2p3p1/3p4/3PP3/8/PPPN1PPP/R1BQKBNR w KQkq' => {
			eco => 'B12h',
			# TRANSLATORS: B12h: 1. e4 c6 2. d4 d5 3. Nd2 g6
			variation => N__('Caro-Kann: Gurgenidze/Modern: 3. Nd2 g6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pp2pp1p/2p3p1/3p4/3PP3/5N2/PPPN1PPP/R1BQKB1R b KQkq' => {
			eco => 'B12h',
			# TRANSLATORS: B12h: 1. e4 c6 2. d4 d5 3. Nd2 g6 4. Ngf3
			variation => N__('Caro-Kann: Gurgenidze/Modern: 3. Nd2 g6 4.Ngf3'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk1nr/pp2ppbp/2p3p1/3p4/3PP3/5N2/PPPN1PPP/R1BQKB1R w KQkq' => {
			eco => 'B12h',
			# TRANSLATORS: B12h: 1. e4 c6 2. d4 d5 3. Nd2 g6 4. Ngf3 Bg7
			variation => N__('Caro-Kann: Gurgenidze/Modern: 3. Nd2 g6 4.Ngf3 Bg7'),
			moves => {
				'c2c3' => 1,
				'h2h3' => 1,
			},
		},
		'rnbqk1nr/pp2ppbp/2p3p1/3p4/3PP3/2P2N2/PP1N1PPP/R1BQKB1R b KQkq' => {
			eco => 'B12h',
			# TRANSLATORS: B12h: 1. e4 c6 2. d4 d5 3. Nd2 g6 4. Ngf3 Bg7 5. c3
			variation => N__('Caro-Kann: Gurgenidze/Modern: 3. Nd2 g6 4.Ngf3 Bg7 5. c3'),
			moves => {
			},
		},
		'rnbqk1nr/pp2ppbp/2p3p1/3p4/3PP3/5N1P/PPPN1PP1/R1BQKB1R b KQkq' => {
			eco => 'B12h',
			# TRANSLATORS: B12h: 1. e4 c6 2. d4 d5 3. Nd2 g6 4. Ngf3 Bg7 5. h3
			variation => N__('Caro-Kann: Gurgenidze/Modern: 3. Nd2 g6 4.Ngf3 Bg7 5. h3'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3pP3/3P4/8/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'B12i',
			# TRANSLATORS: B12i: 1. e4 c6 2. d4 d5 3. e5
			variation => N__('Caro-Kann: Advance Variation'),
			moves => {
				'c6c5' => 1,
				'c8f5' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/8/2ppP3/3P4/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B12j',
			# TRANSLATORS: B12j: 1. e4 c6 2. d4 d5 3. e5 c5
			variation => N__('Caro-Kann: Advance, 3... c5'),
			moves => {
				'd4c5' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/8/2PpP3/8/8/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'B12j',
			# TRANSLATORS: B12j: 1. e4 c6 2. d4 d5 3. e5 c5 4. dxc5
			variation => N__('Caro-Kann: Advance, 3... c5 4.dxc5'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkbnr/pp2pppp/2n5/2PpP3/8/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B12k',
			# TRANSLATORS: B12k: 1. e4 c6 2. d4 d5 3. e5 c5 4. dxc5 Nc6
			variation => N__('Caro-Kann: Advance, 3... c5 4.dxc5 Nc6'),
			moves => {
			},
		},
		'rn1qkbnr/pp2pppp/2p5/3pPb2/3P4/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B12l',
			# TRANSLATORS: B12l: 1. e4 c6 2. d4 d5 3. e5 Bf5
			variation => N__('Caro-Kann: Advance, 3... Bf5'),
			moves => {
				'b1c3' => 1,
				'c2c3' => 1,
				'f1d3' => 1,
				'g1f3' => 1,
				'g2g4' => 1,
				'h2h4' => 1,
			},
		},
		'rn1qkbnr/pp2pppp/2p5/3pPb2/3P2P1/8/PPP2P1P/RNBQKBNR b KQkq' => {
			eco => 'B12l',
			# TRANSLATORS: B12l: 1. e4 c6 2. d4 d5 3. e5 Bf5 4. g4
			variation => N__('Caro-Kann: Advance, Bayonet Variation'),
			moves => {
			},
		},
		'rn1qkbnr/pp2pppp/2p5/3pPb2/3P3P/8/PPP2PP1/RNBQKBNR b KQkq' => {
			eco => 'B12m',
			# TRANSLATORS: B12m: 1. e4 c6 2. d4 d5 3. e5 Bf5 4. h4
			variation => N__('Caro-Kann: Advance, 4. h4'),
			moves => {
			},
		},
		'rn1qkbnr/pp2pppp/2p5/3pPb2/3P4/2P5/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'B12n',
			# TRANSLATORS: B12n: 1. e4 c6 2. d4 d5 3. e5 Bf5 4. c3
			variation => N__('Caro-Kann: Advance, 4. c3'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rn1qkbnr/pp3ppp/2p1p3/3pPb2/3P4/2P5/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'B12n',
			# TRANSLATORS: B12n: 1. e4 c6 2. d4 d5 3. e5 Bf5 4. c3 e6
			variation => N__('Caro-Kann: Advance, 4. c3'),
			moves => {
				'f1e2' => 1,
			},
		},
		'rn1qkbnr/pp3ppp/2p1p3/3pPb2/3P4/2P5/PP2BPPP/RNBQK1NR b KQkq' => {
			eco => 'B12n',
			# TRANSLATORS: B12n: 1. e4 c6 2. d4 d5 3. e5 Bf5 4. c3 e6 5. Be2
			variation => N__('Caro-Kann: Advance, Short Variation'),
			moves => {
			},
		},
		'rn1qkbnr/pp2pppp/2p5/3pPb2/3P4/3B4/PPP2PPP/RNBQK1NR b KQkq' => {
			eco => 'B12o',
			# TRANSLATORS: B12o: 1. e4 c6 2. d4 d5 3. e5 Bf5 4. Bd3
			variation => N__('Caro-Kann: Advance, 4. Bd3'),
			moves => {
			},
		},
		'rn1qkbnr/pp2pppp/2p5/3pPb2/3P4/5N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B12p',
			# TRANSLATORS: B12p: 1. e4 c6 2. d4 d5 3. e5 Bf5 4. Nf3
			variation => N__('Caro-Kann: Advance, 4. Nf3'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rn1qkbnr/pp3ppp/2p1p3/3pPb2/3P4/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B12p',
			# TRANSLATORS: B12p: 1. e4 c6 2. d4 d5 3. e5 Bf5 4. Nf3 e6
			variation => N__('Caro-Kann: Advance, 4. Nf3 e6'),
			moves => {
				'f1e2' => 1,
			},
		},
		'rn1qkbnr/pp3ppp/2p1p3/3pPb2/3P4/5N2/PPP1BPPP/RNBQK2R b KQkq' => {
			eco => 'B12q',
			# TRANSLATORS: B12q: 1. e4 c6 2. d4 d5 3. e5 Bf5 4. Nf3 e6 5. Be2
			variation => N__('Caro-Kann: Advance, 4. Nf3 e6 5. Be2'),
			moves => {
				'b8d7' => 1,
				'c6c5' => 1,
			},
		},
		'r2qkbnr/pp1n1ppp/2p1p3/3pPb2/3P4/5N2/PPP1BPPP/RNBQK2R w KQkq' => {
			eco => 'B12r',
			# TRANSLATORS: B12r: 1. e4 c6 2. d4 d5 3. e5 Bf5 4. Nf3 e6 5. Be2 Nd7
			variation => N__('Caro-Kann: Advance, 4. Nf3 e6 5. Be2 Nd7'),
			moves => {
			},
		},
		'rn1qkbnr/pp3ppp/4p3/2ppPb2/3P4/5N2/PPP1BPPP/RNBQK2R w KQkq' => {
			eco => 'B12s',
			# TRANSLATORS: B12s: 1. e4 c6 2. d4 d5 3. e5 Bf5 4. Nf3 e6 5. Be2 c5
			variation => N__('Caro-Kann: Advance, 4. Nf3 e6 5. Be2 c5'),
			moves => {
				'c1e3' => 1,
				'e1g1' => 1,
			},
		},
		'rn1qkbnr/pp3ppp/4p3/2ppPb2/3P4/5N2/PPP1BPPP/RNBQ1RK1 b kq' => {
			eco => 'B12t',
			# TRANSLATORS: B12t: 1. e4 c6 2. d4 d5 3. e5 Bf5 4. Nf3 e6 5. Be2 c5 6. O-O
			variation => N__('Caro-Kann: Advance, 4. Nf3 e6 5. Be2 c5 6.O-O'),
			moves => {
				'b8d7' => 1,
				'g8e7' => 1,
			},
		},
		'r2qkbnr/pp1n1ppp/4p3/2ppPb2/3P4/5N2/PPP1BPPP/RNBQ1RK1 w kq' => {
			eco => 'B12t',
			# TRANSLATORS: B12t: 1. e4 c6 2. d4 d5 3. e5 Bf5 4. Nf3 e6 5. Be2 c5 6. O-O Nd7
			variation => N__('Caro-Kann: Advance, 4. Nf3 e6 5. Be2 c5 6.O-O'),
			moves => {
			},
		},
		'rn1qkb1r/pp2nppp/4p3/2ppPb2/3P4/5N2/PPP1BPPP/RNBQ1RK1 w kq' => {
			eco => 'B12t',
			# TRANSLATORS: B12t: 1. e4 c6 2. d4 d5 3. e5 Bf5 4. Nf3 e6 5. Be2 c5 6. O-O Ne7
			variation => N__('Caro-Kann: Advance, 4. Nf3 e6 5. Be2 c5 6.O-O'),
			moves => {
			},
		},
		'rn1qkbnr/pp3ppp/4p3/2ppPb2/3P4/4BN2/PPP1BPPP/RN1QK2R b KQkq' => {
			eco => 'B12u',
			# TRANSLATORS: B12u: 1. e4 c6 2. d4 d5 3. e5 Bf5 4. Nf3 e6 5. Be2 c5 6. Be3
			variation => N__('Caro-Kann: Advance, 4. Nf3 e6 5. Be2 c5 6. Be3'),
			moves => {
				'b8d7' => 1,
				'g8e7' => 1,
			},
		},
		'r2qkbnr/pp1n1ppp/4p3/2ppPb2/3P4/4BN2/PPP1BPPP/RN1QK2R w KQkq' => {
			eco => 'B12u',
			# TRANSLATORS: B12u: 1. e4 c6 2. d4 d5 3. e5 Bf5 4. Nf3 e6 5. Be2 c5 6. Be3 Nd7
			variation => N__('Caro-Kann: Advance, 4. Nf3 e6 5. Be2 c5 6. Be3'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r2qkbnr/pp1n1ppp/4p3/2ppPb2/3P4/4BN2/PPP1BPPP/RN1Q1RK1 b kq' => {
			eco => 'B12u',
			# TRANSLATORS: B12u: 1. e4 c6 2. d4 d5 3. e5 Bf5 4. Nf3 e6 5. Be2 c5 6. Be3 Nd7 7. O-O
			variation => N__('Caro-Kann: Advance, 4. Nf3 e6 5. Be2 c5 6. Be3'),
			moves => {
			},
		},
		'rn1qkb1r/pp2nppp/4p3/2ppPb2/3P4/4BN2/PPP1BPPP/RN1QK2R w KQkq' => {
			eco => 'B12u',
			# TRANSLATORS: B12u: 1. e4 c6 2. d4 d5 3. e5 Bf5 4. Nf3 e6 5. Be2 c5 6. Be3 Ne7
			variation => N__('Caro-Kann: Advance, 4. Nf3 e6 5. Be2 c5 6. Be3'),
			moves => {
			},
		},
		'rn1qkbnr/pp2pppp/2p5/3pPb2/3P4/2N5/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'B12v',
			# TRANSLATORS: B12v: 1. e4 c6 2. d4 d5 3. e5 Bf5 4. Nc3
			variation => N__('Caro-Kann: Advance, 4. Nc3'),
			moves => {
				'd8b6' => 1,
				'e7e6' => 1,
				'h7h5' => 1,
			},
		},
		'rn2kbnr/pp2pppp/1qp5/3pPb2/3P4/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'B12v',
			# TRANSLATORS: B12v: 1. e4 c6 2. d4 d5 3. e5 Bf5 4. Nc3 Qb6
			variation => N__('Caro-Kann: Advance, 4. Nc3 Qb6'),
			moves => {
			},
		},
		'rn1qkbnr/pp3ppp/2p1p3/3pPb2/3P4/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'B12v',
			# TRANSLATORS: B12v: 1. e4 c6 2. d4 d5 3. e5 Bf5 4. Nc3 e6
			variation => N__('Caro-Kann: Advance, 4. Nc3 e6'),
			moves => {
				'g2g4' => 1,
			},
		},
		'rn1qkbnr/pp2ppp1/2p5/3pPb1p/3P4/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'B12v',
			# TRANSLATORS: B12v: 1. e4 c6 2. d4 d5 3. e5 Bf5 4. Nc3 h5
			variation => N__('Caro-Kann: Advance, 4. Nc3 h5'),
			moves => {
			},
		},
		'rn1qkbnr/pp3ppp/2p1p3/3pPb2/3P2P1/2N5/PPP2P1P/R1BQKBNR b KQkq' => {
			eco => 'B12w',
			# TRANSLATORS: B12w: 1. e4 c6 2. d4 d5 3. e5 Bf5 4. Nc3 e6 5. g4
			variation => N__('Caro-Kann: Advance, Main Line'),
			moves => {
				'f5g6' => 1,
			},
		},
		'rn1qkbnr/pp3ppp/2p1p1b1/3pP3/3P2P1/2N5/PPP2P1P/R1BQKBNR w KQkq' => {
			eco => 'B12w',
			# TRANSLATORS: B12w: 1. e4 c6 2. d4 d5 3. e5 Bf5 4. Nc3 e6 5. g4 Bg6
			variation => N__('Caro-Kann: Advance, Main Line'),
			moves => {
				'g1e2' => 1,
			},
		},
		'rn1qkbnr/pp3ppp/2p1p1b1/3pP3/3P2P1/2N5/PPP1NP1P/R1BQKB1R b KQkq' => {
			eco => 'B12w',
			# TRANSLATORS: B12w: 1. e4 c6 2. d4 d5 3. e5 Bf5 4. Nc3 e6 5. g4 Bg6 6. Nge2
			variation => N__('Caro-Kann: Advance, Main Line, 6.Nge2'),
			moves => {
				'c6c5' => 1,
			},
		},
		'rn1qkbnr/pp3ppp/4p1b1/2ppP3/3P2P1/2N5/PPP1NP1P/R1BQKB1R w KQkq' => {
			eco => 'B12x',
			# TRANSLATORS: B12x: 1. e4 c6 2. d4 d5 3. e5 Bf5 4. Nc3 e6 5. g4 Bg6 6. Nge2 c5
			variation => N__('Caro-Kann: Advance, Main Line, 6.Nge2 c5'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3P4/3P4/8/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'B13a',
			# TRANSLATORS: B13a: 1. e4 c6 2. d4 d5 3. exd5
			variation => N__('Caro-Kann: Exchange Variation'),
			moves => {
				'c6d5' => 1,
				'd8d5' => 1,
			},
		},
		'rnb1kbnr/pp2pppp/2p5/3q4/3P4/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B13a',
			# TRANSLATORS: B13a: 1. e4 c6 2. d4 d5 3. exd5 Qxd5
			variation => N__('Caro-Kann: Exchange, 3...Qxd5'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/8/3p4/3P4/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B13b',
			# TRANSLATORS: B13b: 1. e4 c6 2. d4 d5 3. exd5 cxd5
			variation => N__('Caro-Kann: Exchange, 3...cxd5'),
			moves => {
				'c2c4' => 1,
				'f1d3' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/8/3p4/3P4/5N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B13c',
			# TRANSLATORS: B13c: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. Nf3
			variation => N__('Caro-Kann: Exchange, 4. Nf3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/5n2/3p4/3P4/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B13d',
			# TRANSLATORS: B13d: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. Nf3 Nf6
			variation => N__('Caro-Kann: Exchange, 4. Nf3 Nf6'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/8/3p4/3P4/3B4/PPP2PPP/RNBQK1NR b KQkq' => {
			eco => 'B13e',
			# TRANSLATORS: B13e: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. Bd3
			variation => N__('Caro-Kann: Exchange, 4. Bd3'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkbnr/pp2pppp/2n5/3p4/3P4/3B4/PPP2PPP/RNBQK1NR w KQkq' => {
			eco => 'B13f',
			# TRANSLATORS: B13f: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. Bd3 Nc6
			variation => N__('Caro-Kann: Exchange, 4. Bd3 Nc6'),
			moves => {
				'c2c3' => 1,
			},
		},
		'r1bqkbnr/pp2pppp/2n5/3p4/3P4/2PB4/PP3PPP/RNBQK1NR b KQkq' => {
			eco => 'B13f',
			# TRANSLATORS: B13f: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. Bd3 Nc6 5. c3
			variation => N__('Caro-Kann: Exchange, 4. Bd3 Nc6 5. c3'),
			moves => {
				'g7g6' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkbnr/pp2pp1p/2n3p1/3p4/3P4/2PB4/PP3PPP/RNBQK1NR w KQkq' => {
			eco => 'B13g',
			# TRANSLATORS: B13g: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. Bd3 Nc6 5. c3 g6
			variation => N__('Caro-Kann: Exchange, 4. Bd3 Nc6 5. c3 g6'),
			moves => {
			},
		},
		'r1bqkb1r/pp2pppp/2n2n2/3p4/3P4/2PB4/PP3PPP/RNBQK1NR w KQkq' => {
			eco => 'B13h',
			# TRANSLATORS: B13h: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. Bd3 Nc6 5. c3 Nf6
			variation => N__('Caro-Kann: Exchange, 4. Bd3 Nc6 5. c3 Nf6'),
			moves => {
				'c1f4' => 1,
				'g1f3' => 1,
			},
		},
		'r1bqkb1r/pp2pppp/2n2n2/3p4/3P4/2PB1N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'B13i',
			# TRANSLATORS: B13i: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. Bd3 Nc6 5. c3 Nf6 6. Nf3
			variation => N__('Caro-Kann: Exchange, 4. Bd3 Nc6 5. c3 Nf6 6. Nf3'),
			moves => {
			},
		},
		'r1bqkb1r/pp2pppp/2n2n2/3p4/3P1B2/2PB4/PP3PPP/RN1QK1NR b KQkq' => {
			eco => 'B13j',
			# TRANSLATORS: B13j: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. Bd3 Nc6 5. c3 Nf6 6. Bf4
			variation => N__('Caro-Kann: Exchange, Rubinstein Variation'),
			moves => {
				'c8g4' => 1,
			},
		},
		'r2qkb1r/pp2pppp/2n2n2/3p4/3P1Bb1/2PB4/PP3PPP/RN1QK1NR w KQkq' => {
			eco => 'B13k',
			# TRANSLATORS: B13k: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. Bd3 Nc6 5. c3 Nf6 6. Bf4 Bg4
			variation => N__('Caro-Kann: Exchange, Rubinstein, 6... Bg4'),
			moves => {
				'd1b3' => 1,
			},
		},
		'r2qkb1r/pp2pppp/2n2n2/3p4/3P1Bb1/1QPB4/PP3PPP/RN2K1NR b KQkq' => {
			eco => 'B13k',
			# TRANSLATORS: B13k: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. Bd3 Nc6 5. c3 Nf6 6. Bf4 Bg4 7. Qb3
			variation => N__('Caro-Kann: Exchange, Rubinstein, 6... Bg4'),
			moves => {
				'd8c8' => 1,
				'd8d7' => 1,
			},
		},
		'r1q1kb1r/pp2pppp/2n2n2/3p4/3P1Bb1/1QPB4/PP3PPP/RN2K1NR w KQkq' => {
			eco => 'B13l',
			# TRANSLATORS: B13l: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. Bd3 Nc6 5. c3 Nf6 6. Bf4 Bg4 7. Qb3 Qc8
			variation => N__('Caro-Kann: Exchange, Rubinstein, 7. Qb3 Qc8'),
			moves => {
			},
		},
		'r3kb1r/pp1qpppp/2n2n2/3p4/3P1Bb1/1QPB4/PP3PPP/RN2K1NR w KQkq' => {
			eco => 'B13m',
			# TRANSLATORS: B13m: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. Bd3 Nc6 5. c3 Nf6 6. Bf4 Bg4 7. Qb3 Qd7
			variation => N__('Caro-Kann: Exchange, Rubinstein, 7. Qb3 Qd7'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/8/3p4/2PP4/8/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'B13n',
			# TRANSLATORS: B13n: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4
			variation => N__('Caro-Kann: Panov-Botvinnik Attack'),
			moves => {
				'e7e6' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/4p3/3p4/2PP4/8/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'B13n',
			# TRANSLATORS: B13n: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 e6
			variation => N__('Caro-Kann: Panov-Botvinnik, 4... e6'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/5n2/3p4/2PP4/8/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'B13o',
			# TRANSLATORS: B13o: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6
			variation => N__('Caro-Kann: Panov-Botvinnik, 4... Nf6'),
			moves => {
				'b1c3' => 1,
				'c4c5' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/5n2/2Pp4/3P4/8/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'B13o',
			# TRANSLATORS: B13o: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. c5
			variation => N__('Caro-Kann: Panov-Botvinnik, Gunderam Variation'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/5n2/3p4/2PP4/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'B13p',
			# TRANSLATORS: B13p: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3
			variation => N__('Caro-Kann: Panov-Botvinnik, 5. Nc3'),
			moves => {
				'b8c6' => 1,
				'd5c4' => 1,
				'e7e6' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/5n2/8/2pP4/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'B13p',
			# TRANSLATORS: B13p: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 dxc4
			variation => N__('Caro-Kann: Panov-Botvinnik, 5...dxc4'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/5n2/8/2BP4/2N5/PP3PPP/R1BQK1NR b KQkq' => {
			eco => 'B13p',
			# TRANSLATORS: B13p: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 dxc4 6. Bxc4
			variation => N__('Caro-Kann: Panov-Botvinnik, 5...dxc4'),
			moves => {
			},
		},
		'r1bqkb1r/pp2pppp/2n2n2/3p4/2PP4/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'B13q',
			# TRANSLATORS: B13q: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 Nc6
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... Nc6'),
			moves => {
				'c1g5' => 1,
				'c4d5' => 1,
				'g1f3' => 1,
			},
		},
		'r1bqkb1r/pp2pppp/2n2n2/3P4/3P4/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'B13q',
			# TRANSLATORS: B13q: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 Nc6 6. cxd5
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... Nc6 6.cxd5'),
			moves => {
				'f6d5' => 1,
			},
		},
		'r1bqkb1r/pp2pppp/2n5/3n4/3P4/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'B13q',
			# TRANSLATORS: B13q: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 Nc6 6. cxd5 Nxd5
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... Nc6 6.cxd5 Nxd5'),
			moves => {
			},
		},
		'r1bqkb1r/pp2pppp/2n2n2/3p4/2PP4/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'B13r',
			# TRANSLATORS: B13r: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 Nc6 6. Nf3
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... Nc6 6. Nf3'),
			moves => {
				'c8g4' => 1,
			},
		},
		'r2qkb1r/pp2pppp/2n2n2/3p4/2PP2b1/2N2N2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'B13s',
			# TRANSLATORS: B13s: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 Nc6 6. Nf3 Bg4
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... Nc6 6. Nf3 Bg4'),
			moves => {
				'c4d5' => 1,
			},
		},
		'r2qkb1r/pp2pppp/2n2n2/3P4/3P2b1/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'B13s',
			# TRANSLATORS: B13s: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 Nc6 6. Nf3 Bg4 7. cxd5
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... Nc6 6. Nf3 Bg4'),
			moves => {
				'f6d5' => 1,
			},
		},
		'r2qkb1r/pp2pppp/2n5/3n4/3P2b1/2N2N2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'B13s',
			# TRANSLATORS: B13s: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 Nc6 6. Nf3 Bg4 7. cxd5 Nxd5
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... Nc6 6. Nf3 Bg4'),
			moves => {
				'd1b3' => 1,
			},
		},
		'r2qkb1r/pp2pppp/2n5/3n4/3P2b1/1QN2N2/PP3PPP/R1B1KB1R b KQkq' => {
			eco => 'B13t',
			# TRANSLATORS: B13t: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 Nc6 6. Nf3 Bg4 7. cxd5 Nxd5 8. Qb3
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... Nc6 6. Nf3 Bg4: 8. Qb3'),
			moves => {
				'g4f3' => 1,
			},
		},
		'r2qkb1r/pp2pppp/2n5/3n4/3P4/1QN2b2/PP3PPP/R1B1KB1R w KQkq' => {
			eco => 'B13t',
			# TRANSLATORS: B13t: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 Nc6 6. Nf3 Bg4 7. cxd5 Nxd5 8. Qb3 Bxf3
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... Nc6 6. Nf3 Bg4: 8. Qb3'),
			moves => {
				'g2f3' => 1,
			},
		},
		'r2qkb1r/pp2pppp/2n5/3n4/3P4/1QN2P2/PP3P1P/R1B1KB1R b KQkq' => {
			eco => 'B13t',
			# TRANSLATORS: B13t: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 Nc6 6. Nf3 Bg4 7. cxd5 Nxd5 8. Qb3 Bxf3 9. gxf3
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... Nc6 6. Nf3 Bg4: 8. Qb3'),
			moves => {
				'd5b6' => 1,
				'e7e6' => 1,
			},
		},
		'r2qkb1r/pp2pppp/1nn5/8/3P4/1QN2P2/PP3P1P/R1B1KB1R w KQkq' => {
			eco => 'B13t',
			# TRANSLATORS: B13t: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 Nc6 6. Nf3 Bg4 7. cxd5 Nxd5 8. Qb3 Bxf3 9. gxf3 Nb6
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... Nc6 6. Nf3 Bg4: 9.gxf3 Nb6'),
			moves => {
			},
		},
		'r2qkb1r/pp3ppp/2n1p3/3n4/3P4/1QN2P2/PP3P1P/R1B1KB1R w KQkq' => {
			eco => 'B13u',
			# TRANSLATORS: B13u: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 Nc6 6. Nf3 Bg4 7. cxd5 Nxd5 8. Qb3 Bxf3 9. gxf3 e6
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... Nc6 6. Nf3 Bg4: Main Line'),
			moves => {
			},
		},
		'r1bqkb1r/pp2pppp/2n2n2/3p2B1/2PP4/2N5/PP3PPP/R2QKBNR b KQkq' => {
			eco => 'B13v',
			# TRANSLATORS: B13v: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 Nc6 6. Bg5
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... Nc6 6. Bg5'),
			moves => {
				'c8e6' => 1,
				'd5c4' => 1,
				'd8a5' => 1,
				'd8b6' => 1,
				'e7e6' => 1,
			},
		},
		'r1bqkb1r/pp2pppp/2n2n2/6B1/2pP4/2N5/PP3PPP/R2QKBNR w KQkq' => {
			eco => 'B13v',
			# TRANSLATORS: B13v: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 Nc6 6. Bg5 dxc4
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... Nc6 6. Bg5 dxc4'),
			moves => {
				'd4d5' => 1,
			},
		},
		'r1bqkb1r/pp2pppp/2n2n2/3P2B1/2p5/2N5/PP3PPP/R2QKBNR b KQkq' => {
			eco => 'B13v',
			# TRANSLATORS: B13v: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 Nc6 6. Bg5 dxc4 7. d5
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... Nc6 6. Bg5 dxc4'),
			moves => {
				'c6a5' => 1,
			},
		},
		'r1bqkb1r/pp2pppp/5n2/n2P2B1/2p5/2N5/PP3PPP/R2QKBNR w KQkq' => {
			eco => 'B13v',
			# TRANSLATORS: B13v: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 Nc6 6. Bg5 dxc4 7. d5 Na5
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... Nc6, Herzog Defence'),
			moves => {
			},
		},
		'r1b1kb1r/pp2pppp/1qn2n2/3p2B1/2PP4/2N5/PP3PPP/R2QKBNR w KQkq' => {
			eco => 'B13v',
			# TRANSLATORS: B13v: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 Nc6 6. Bg5 Qb6
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... Nc6, Spielmann Variation'),
			moves => {
			},
		},
		'r1b1kb1r/pp2pppp/2n2n2/q2p2B1/2PP4/2N5/PP3PPP/R2QKBNR w KQkq' => {
			eco => 'B13w',
			# TRANSLATORS: B13w: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 Nc6 6. Bg5 Qa5
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... Nc6, Czerniak Variation'),
			moves => {
			},
		},
		'r2qkb1r/pp2pppp/2n1bn2/3p2B1/2PP4/2N5/PP3PPP/R2QKBNR w KQkq' => {
			eco => 'B13x',
			# TRANSLATORS: B13x: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 Nc6 6. Bg5 Be6
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... Nc6 6. Bg5 Be6'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2n1pn2/3p2B1/2PP4/2N5/PP3PPP/R2QKBNR w KQkq' => {
			eco => 'B13y',
			# TRANSLATORS: B13y: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 Nc6 6. Bg5 e6
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... Nc6, Normal Variation'),
			moves => {
				'g1f3' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2n1pn2/3p2B1/2PP4/2N2N2/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'B13y',
			# TRANSLATORS: B13y: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Nf3
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... Nc6, Normal Variation'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2n1pn2/3p2B1/2PP4/2N2N2/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'B13y',
			# TRANSLATORS: B13y: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Nf3 Be7
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... Nc6, Normal Variation'),
			moves => {
				'c4c5' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2n1pn2/2Pp2B1/3P4/2N2N2/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'B13z',
			# TRANSLATORS: B13z: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Nf3 Be7 8. c5
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... Nc6, Normal Variaiton, 8. c5'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2n1pn2/2Pp2B1/3P4/2N2N2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'B13z',
			# TRANSLATORS: B13z: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Nf3 Be7 8. c5 O-O
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... Nc6, Normal Variation, 8. c5 O-O'),
			moves => {
				'f1b5' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2n1pn2/1BPp2B1/3P4/2N2N2/PP3PPP/R2QK2R b KQ' => {
			eco => 'B13z',
			# TRANSLATORS: B13z: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Nf3 Be7 8. c5 O-O 9. Bb5
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... Nc6, Normal Variation, 8. c5 O-O 9. Bb5'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pp1p/5np1/3p4/2PP4/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'B14a',
			# TRANSLATORS: B14a: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 g6
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... g6'),
			moves => {
				'c4d5' => 1,
				'd1b3' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/pp2pp1p/5np1/3p4/2PP4/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'B14a',
			# TRANSLATORS: B14a: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 g6 6. Nf3
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... g6 6. Nf3'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pp1p/5np1/3P4/3P4/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'B14b',
			# TRANSLATORS: B14b: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 g6 6. cxd5
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... g6 6.cxd5'),
			moves => {
				'f6d5' => 1,
				'f8g7' => 1,
			},
		},
		'rnbqkb1r/pp2pp1p/6p1/3n4/3P4/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'B14c',
			# TRANSLATORS: B14c: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 g6 6. cxd5 Nxd5
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... g6 6.cxd5 Nxd5'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnbqkb1r/pp2pp1p/6p1/3n4/2BP4/2N5/PP3PPP/R1BQK1NR b KQkq' => {
			eco => 'B14d',
			# TRANSLATORS: B14d: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 g6 6. cxd5 Nxd5 7. Bc4
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... g6 6.cxd5 Nxd5 7. Bc4'),
			moves => {
			},
		},
		'rnbqk2r/pp2ppbp/5np1/3P4/3P4/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'B14e',
			# TRANSLATORS: B14e: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 g6 6. cxd5 Bg7
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... g6 6.cxd5 Bg7'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pp1p/5np1/3p4/2PP4/1QN5/PP3PPP/R1B1KBNR b KQkq' => {
			eco => 'B14f',
			# TRANSLATORS: B14f: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 g6 6. Qb3
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... g6 6. Qb3'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/5np1/3p4/2PP4/1QN5/PP3PPP/R1B1KBNR w KQkq' => {
			eco => 'B14f',
			# TRANSLATORS: B14f: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 g6 6. Qb3 Bg7
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... g6 6. Qb3'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/5np1/3P4/3P4/1QN5/PP3PPP/R1B1KBNR b KQkq' => {
			eco => 'B14f',
			# TRANSLATORS: B14f: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 g6 6. Qb3 Bg7 7. cxd5
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... g6 6. Qb3 Bg7 7.cxd5'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/5np1/3P4/3P4/1QN5/PP3PPP/R1B1KBNR w KQ' => {
			eco => 'B14f',
			# TRANSLATORS: B14f: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 g6 6. Qb3 Bg7 7. cxd5 O-O
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... g6, Main Line'),
			moves => {
				'f1e2' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/5np1/3P4/3P4/1QN5/PP2BPPP/R1B1K1NR b KQ' => {
			eco => 'B14g',
			# TRANSLATORS: B14g: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 g6 6. Qb3 Bg7 7. cxd5 O-O 8. Be2
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... g6, Main Line, 8. Be2'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r1bq1rk1/pp1nppbp/5np1/3P4/3P4/1QN5/PP2BPPP/R1B1K1NR w KQ' => {
			eco => 'B14h',
			# TRANSLATORS: B14h: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 g6 6. Qb3 Bg7 7. cxd5 O-O 8. Be2 Nbd7
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... g6, Main Line, 8. Be2 Nbd7'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/3p4/2PP4/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'B14i',
			# TRANSLATORS: B14i: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 e6
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... e6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/3p4/2PP4/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'B14j',
			# TRANSLATORS: B14j: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 e6 6. Nf3
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... e6 6. Nf3'),
			moves => {
				'b8c6' => 1,
				'f8b4' => 1,
				'f8e7' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2n1pn2/3p4/2PP4/2N2N2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'B14j',
			# TRANSLATORS: B14j: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 e6 6. Nf3 Nc6
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... e6 6. Nf3 Nc6'),
			moves => {
			},
		},
		'rnbqk2r/pp2bppp/4pn2/3p4/2PP4/2N2N2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'B14k',
			# TRANSLATORS: B14k: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 e6 6. Nf3 Be7
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... e6 6. Nf3 Be7'),
			moves => {
				'c4d5' => 1,
				'f1d3' => 1,
			},
		},
		'rnbqk2r/pp2bppp/4pn2/3p4/2PP4/2NB1N2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'B14l',
			# TRANSLATORS: B14l: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 e6 6. Nf3 Be7 7. Bd3
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... e6 6. Nf3 Be7 7. Bd3'),
			moves => {
			},
		},
		'rnbqk2r/pp2bppp/4pn2/3P4/3P4/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'B14m',
			# TRANSLATORS: B14m: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 e6 6. Nf3 Be7 7. cxd5
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... e6 6. Nf3 Be7 7.cxd5'),
			moves => {
				'f6d5' => 1,
			},
		},
		'rnbqk2r/pp2bppp/4p3/3n4/3P4/2N2N2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'B14n',
			# TRANSLATORS: B14n: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 e6 6. Nf3 Be7 7. cxd5 Nxd5
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... e6 6. Nf3 Be7 7.cxd5 Nxd5'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rnbqk2r/pp2bppp/4p3/3n4/3P4/2NB1N2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'B14o',
			# TRANSLATORS: B14o: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 e6 6. Nf3 Be7 7. cxd5 Nxd5 8. Bd3
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... e6 6. Nf3 Be7 7.cxd5 Nxd5 8. Bd3'),
			moves => {
			},
		},
		'rnbqk2r/pp3ppp/4pn2/3p4/1bPP4/2N2N2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'B14p',
			# TRANSLATORS: B14p: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 e6 6. Nf3 Bb4
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... e6 6. Nf3 Bb4'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rnbqk2r/pp3ppp/4pn2/3P4/1b1P4/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'B14p',
			# TRANSLATORS: B14p: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 e6 6. Nf3 Bb4 7. cxd5
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... e6 6. Nf3 Bb4'),
			moves => {
				'e6d5' => 1,
				'f6d5' => 1,
			},
		},
		'rnbqk2r/pp3ppp/5n2/3p4/1b1P4/2N2N2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'B14q',
			# TRANSLATORS: B14q: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 e6 6. Nf3 Bb4 7. cxd5 exd5
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... e6 6. Nf3 Bb4 7.cxd5 exd5'),
			moves => {
			},
		},
		'rnbqk2r/pp3ppp/4p3/3n4/1b1P4/2N2N2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'B14r',
			# TRANSLATORS: B14r: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 e6 6. Nf3 Bb4 7. cxd5 Nxd5
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... e6 6. Nf3 Bb4 7.cxd5 Nxd5'),
			moves => {
				'c1d2' => 1,
				'd1c2' => 1,
			},
		},
		'rnbqk2r/pp3ppp/4p3/3n4/1b1P4/2N2N2/PPQ2PPP/R1B1KB1R b KQkq' => {
			eco => 'B14s',
			# TRANSLATORS: B14s: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 e6 6. Nf3 Bb4 7. cxd5 Nxd5 8. Qc2
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... e6 6. Nf3 Bb4 7.cxd5 Nxd5 8. Qc2'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqk2r/pp3ppp/2n1p3/3n4/1b1P4/2N2N2/PPQ2PPP/R1B1KB1R w KQkq' => {
			eco => 'B14t',
			# TRANSLATORS: B14t: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 e6 6. Nf3 Bb4 7. cxd5 Nxd5 8. Qc2 Nc6
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... e6 6. Nf3 Bb4 7.cxd5 Nxd5 8. Qc2 Nc6'),
			moves => {
				'f1d3' => 1,
			},
		},
		'r1bqk2r/pp3ppp/2n1p3/3n4/1b1P4/2NB1N2/PPQ2PPP/R1B1K2R b KQkq' => {
			eco => 'B14u',
			# TRANSLATORS: B14u: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 e6 6. Nf3 Bb4 7. cxd5 Nxd5 8. Qc2 Nc6 9. Bd3
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... e6 6. Nf3 Bb4 7.cxd5 Nxd5 8. Qc2 Nc6 9. Bd3'),
			moves => {
			},
		},
		'rnbqk2r/pp3ppp/4p3/3n4/1b1P4/2N2N2/PP1B1PPP/R2QKB1R b KQkq' => {
			eco => 'B14v',
			# TRANSLATORS: B14v: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 e6 6. Nf3 Bb4 7. cxd5 Nxd5 8. Bd2
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... e6 6. Nf3 Bb4 7.cxd5 Nxd5 8. Bd2'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqk2r/pp3ppp/2n1p3/3n4/1b1P4/2N2N2/PP1B1PPP/R2QKB1R w KQkq' => {
			eco => 'B14w',
			# TRANSLATORS: B14w: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 e6 6. Nf3 Bb4 7. cxd5 Nxd5 8. Bd2 Nc6
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... e6 6. Nf3 Bb4 7.cxd5 Nxd5 8. Bd2 Nc6'),
			moves => {
				'f1d3' => 1,
			},
		},
		'r1bqk2r/pp3ppp/2n1p3/3n4/1b1P4/2NB1N2/PP1B1PPP/R2QK2R b KQkq' => {
			eco => 'B14w',
			# TRANSLATORS: B14w: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 e6 6. Nf3 Bb4 7. cxd5 Nxd5 8. Bd2 Nc6 9. Bd3
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... e6 6. Nf3 Bb4 7.cxd5 Nxd5 8. Bd2 Nc6'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp3ppp/2n1p3/3n4/1b1P4/2NB1N2/PP1B1PPP/R2QK2R w KQ' => {
			eco => 'B14x',
			# TRANSLATORS: B14x: 1. e4 c6 2. d4 d5 3. exd5 cxd5 4. c4 Nf6 5. Nc3 e6 6. Nf3 Bb4 7. cxd5 Nxd5 8. Bd2 Nc6 9. Bd3 O-O
			variation => N__('Caro-Kann: Panov-Botvinnik, 5... e6 6. Nf3 Bb4 7.cxd5 Nxd5 8. Bd2 Nc6'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3p4/3PP3/2N5/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'B15a',
			# TRANSLATORS: B15a: 1. e4 c6 2. d4 d5 3. Nc3
			variation => N__('Caro-Kann: 3. Nc3'),
			moves => {
				'b7b5' => 1,
				'd5e4' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkbnr/p3pppp/2p5/1p1p4/3PP3/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'B15b',
			# TRANSLATORS: B15b: 1. e4 c6 2. d4 d5 3. Nc3 b5
			variation => N__('Caro-Kann: Gurgenidze Counterattack'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pp1p/2p3p1/3p4/3PP3/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'B15c',
			# TRANSLATORS: B15c: 1. e4 c6 2. d4 d5 3. Nc3 g6
			variation => N__('Caro-Kann: Gurgenidze/Modern'),
			moves => {
				'c1e3' => 1,
				'e4e5' => 1,
				'g1f3' => 1,
				'h2h3' => 1,
			},
		},
		'rnbqkbnr/pp2pp1p/2p3p1/3p4/3PP3/2N1B3/PPP2PPP/R2QKBNR b KQkq' => {
			eco => 'B15d',
			# TRANSLATORS: B15d: 1. e4 c6 2. d4 d5 3. Nc3 g6 4. Be3
			variation => N__('Caro-Kann: Gurgenidze: 4. Be3'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk1nr/pp2ppbp/2p3p1/3p4/3PP3/2N1B3/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'B15d',
			# TRANSLATORS: B15d: 1. e4 c6 2. d4 d5 3. Nc3 g6 4. Be3 Bg7
			variation => N__('Caro-Kann: Gurgenidze: 4. Be3'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pp1p/2p3p1/3p4/3PP3/2N4P/PPP2PP1/R1BQKBNR b KQkq' => {
			eco => 'B15e',
			# TRANSLATORS: B15e: 1. e4 c6 2. d4 d5 3. Nc3 g6 4. h3
			variation => N__('Caro-Kann: Gurgenidze: 4. h3'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk1nr/pp2ppbp/2p3p1/3p4/3PP3/2N4P/PPP2PP1/R1BQKBNR w KQkq' => {
			eco => 'B15e',
			# TRANSLATORS: B15e: 1. e4 c6 2. d4 d5 3. Nc3 g6 4. h3 Bg7
			variation => N__('Caro-Kann: Gurgenidze: 4. h3'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pp1p/2p3p1/3pP3/3P4/2N5/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'B15f',
			# TRANSLATORS: B15f: 1. e4 c6 2. d4 d5 3. Nc3 g6 4. e5
			variation => N__('Caro-Kann: Gurgenidze: 4. e5'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk1nr/pp2ppbp/2p3p1/3pP3/3P4/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'B15f',
			# TRANSLATORS: B15f: 1. e4 c6 2. d4 d5 3. Nc3 g6 4. e5 Bg7
			variation => N__('Caro-Kann: Gurgenidze: 4. e5'),
			moves => {
				'f2f4' => 1,
			},
		},
		'rnbqk1nr/pp2ppbp/2p3p1/3pP3/3P1P2/2N5/PPP3PP/R1BQKBNR b KQkq' => {
			eco => 'B15g',
			# TRANSLATORS: B15g: 1. e4 c6 2. d4 d5 3. Nc3 g6 4. e5 Bg7 5. f4
			variation => N__('Caro-Kann: Gurgenidze: 4. e5 Bg7 5. f4'),
			moves => {
				'g8h6' => 1,
				'h7h5' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/2p3pn/3pP3/3P1P2/2N5/PPP3PP/R1BQKBNR w KQkq' => {
			eco => 'B15g',
			# TRANSLATORS: B15g: 1. e4 c6 2. d4 d5 3. Nc3 g6 4. e5 Bg7 5. f4 Nh6
			variation => N__('Caro-Kann: Gurgenidze: 4. e5 Bg7 5. f4 Nh6'),
			moves => {
			},
		},
		'rnbqk1nr/pp2ppb1/2p3p1/3pP2p/3P1P2/2N5/PPP3PP/R1BQKBNR w KQkq' => {
			eco => 'B15h',
			# TRANSLATORS: B15h: 1. e4 c6 2. d4 d5 3. Nc3 g6 4. e5 Bg7 5. f4 h5
			variation => N__('Caro-Kann: Gurgenidze: 4. e5 Bg7 5. f4 h5'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqk1nr/pp2ppb1/2p3p1/3pP2p/3P1P2/2N2N2/PPP3PP/R1BQKB1R b KQkq' => {
			eco => 'B15i',
			# TRANSLATORS: B15i: 1. e4 c6 2. d4 d5 3. Nc3 g6 4. e5 Bg7 5. f4 h5 6. Nf3
			variation => N__('Caro-Kann: Gurgenidze: 4. e5 Bg7 5. f4 h5 6. Nf3'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pp1p/2p3p1/3p4/3PP3/2N2N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B15j',
			# TRANSLATORS: B15j: 1. e4 c6 2. d4 d5 3. Nc3 g6 4. Nf3
			variation => N__('Caro-Kann: Gurgenidze: 4. Nf3'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk1nr/pp2ppbp/2p3p1/3p4/3PP3/2N2N2/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B15k',
			# TRANSLATORS: B15k: 1. e4 c6 2. d4 d5 3. Nc3 g6 4. Nf3 Bg7
			variation => N__('Caro-Kann: Gurgenidze: 4. Nf3 Bg7'),
			moves => {
				'e4d5' => 1,
				'e4e5' => 1,
				'h2h3' => 1,
			},
		},
		'rnbqk1nr/pp2ppbp/2p3p1/3P4/3P4/2N2N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B15k',
			# TRANSLATORS: B15k: 1. e4 c6 2. d4 d5 3. Nc3 g6 4. Nf3 Bg7 5. exd5
			variation => N__('Caro-Kann: Gurgenidze: 4. Nf3 Bg7 5.exd5'),
			moves => {
			},
		},
		'rnbqk1nr/pp2ppbp/2p3p1/3pP3/3P4/2N2N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B15k',
			# TRANSLATORS: B15k: 1. e4 c6 2. d4 d5 3. Nc3 g6 4. Nf3 Bg7 5. e5
			variation => N__('Caro-Kann: Gurgenidze: 4. Nf3 Bg7 5. e5'),
			moves => {
			},
		},
		'rnbqk1nr/pp2ppbp/2p3p1/3p4/3PP3/2N2N1P/PPP2PP1/R1BQKB1R b KQkq' => {
			eco => 'B15l',
			# TRANSLATORS: B15l: 1. e4 c6 2. d4 d5 3. Nc3 g6 4. Nf3 Bg7 5. h3
			variation => N__('Caro-Kann: Gurgenidze: 4. Nf3 Bg7 5. h3'),
			moves => {
				'd5e4' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqk1nr/pp2ppbp/2p3p1/8/3Pp3/2N2N1P/PPP2PP1/R1BQKB1R w KQkq' => {
			eco => 'B15m',
			# TRANSLATORS: B15m: 1. e4 c6 2. d4 d5 3. Nc3 g6 4. Nf3 Bg7 5. h3 dxe4
			variation => N__('Caro-Kann: Gurgenidze: 4. Nf3 Bg7 5. h3 dxe4'),
			moves => {
				'c3e4' => 1,
			},
		},
		'rnbqk1nr/pp2ppbp/2p3p1/8/3PN3/5N1P/PPP2PP1/R1BQKB1R b KQkq' => {
			eco => 'B15m',
			# TRANSLATORS: B15m: 1. e4 c6 2. d4 d5 3. Nc3 g6 4. Nf3 Bg7 5. h3 dxe4 6. Nxe4
			variation => N__('Caro-Kann: Gurgenidze: 4. Nf3 Bg7 5. h3 dxe4'),
			moves => {
			},
		},
		'rnbqk2r/pp2ppbp/2p2np1/3p4/3PP3/2N2N1P/PPP2PP1/R1BQKB1R w KQkq' => {
			eco => 'B15n',
			# TRANSLATORS: B15n: 1. e4 c6 2. d4 d5 3. Nc3 g6 4. Nf3 Bg7 5. h3 Nf6
			variation => N__('Caro-Kann: Gurgenidze: 4. Nf3 Bg7 5. h3 Nf6'),
			moves => {
				'e4e5' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/2p2np1/3pP3/3P4/2N2N1P/PPP2PP1/R1BQKB1R b KQkq' => {
			eco => 'B15o',
			# TRANSLATORS: B15o: 1. e4 c6 2. d4 d5 3. Nc3 g6 4. Nf3 Bg7 5. h3 Nf6 6. e5
			variation => N__('Caro-Kann: Gurgenidze: 4. Nf3 Bg7 5. h3 Nf6 6. e5'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/2p5/8/3Pp3/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'B15p',
			# TRANSLATORS: B15p: 1. e4 c6 2. d4 d5 3. Nc3 dxe4
			variation => N__('Caro-Kann: 3. Nc3 dxe4'),
			moves => {
				'c3e4' => 1,
				'f1c4' => 1,
				'f2f3' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/2p5/8/2BPp3/2N5/PPP2PPP/R1BQK1NR b KQkq' => {
			eco => 'B15p',
			# TRANSLATORS: B15p: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Bc4
			variation => N__('Caro-Kann: von Hennig Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/2p5/8/3Pp3/2N2P2/PPP3PP/R1BQKBNR b KQkq' => {
			eco => 'B15p',
			# TRANSLATORS: B15p: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. f3
			variation => N__('Caro-Kann: Rasa-Studier Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/2p5/8/3PN3/8/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'B15q',
			# TRANSLATORS: B15q: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4
			variation => N__('Caro-Kann: 4.Nxe4'),
			moves => {
				'b8d7' => 1,
				'c8f5' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/8/3PN3/8/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'B15r',
			# TRANSLATORS: B15r: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nf6
			variation => N__('Caro-Kann: 4.Nxe4 Nf6'),
			moves => {
				'e4f6' => 1,
				'e4g3' => 1,
				'f1d3' => 1,
				'f2f3' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/8/3PN3/3B4/PPP2PPP/R1BQK1NR b KQkq' => {
			eco => 'B15r',
			# TRANSLATORS: B15r: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nf6 5. Bd3
			variation => N__('Caro-Kann: Alekhine Gambit'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/8/3PN3/5P2/PPP3PP/R1BQKBNR b KQkq' => {
			eco => 'B15r',
			# TRANSLATORS: B15r: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nf6 5. f3
			variation => N__('Caro-Kann: 4.Nxe4 Nf6 5. f3 Gambit'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/8/3P4/6N1/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'B15s',
			# TRANSLATORS: B15s: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nf6 5. Ng3
			variation => N__('Caro-Kann: 4.Nxe4 Nf6 5. Ng3'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/2p2N2/8/3P4/8/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'B15t',
			# TRANSLATORS: B15t: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nf6 5. Nxf6+
			variation => N__('Caro-Kann: 4.Nxe4 Nf6 5.Nxf6+'),
			moves => {
				'e7f6' => 1,
				'g7f6' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/2p2p2/8/3P4/8/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'B15t',
			# TRANSLATORS: B15t: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nf6 5. Nxf6+ exf6
			variation => N__('Caro-Kann: Tartakower (Nimzowitsch) Variation'),
			moves => {
				'c2c3' => 1,
				'f1c4' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/2p2p2/8/2BP4/8/PPP2PPP/R1BQK1NR b KQkq' => {
			eco => 'B15u',
			# TRANSLATORS: B15u: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nf6 5. Nxf6+ exf6 6. Bc4
			variation => N__('Caro-Kann: Tartakower, Forgacs Variation'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/2p2p2/8/3P4/2P5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'B15v',
			# TRANSLATORS: B15v: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nf6 5. Nxf6+ exf6 6. c3
			variation => N__('Caro-Kann: Tartakower, 6. c3'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pp1p/2p2p2/8/3P4/8/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'B16a',
			# TRANSLATORS: B16a: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nf6 5. Nxf6+ gxf6
			variation => N__('Caro-Kann: Bronstein-Larsen'),
			moves => {
				'c2c3' => 1,
				'd1d3' => 1,
				'f1c4' => 1,
				'g1e2' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/pp2pp1p/2p2p2/8/3P4/3Q4/PPP2PPP/R1B1KBNR b KQkq' => {
			eco => 'B16b',
			# TRANSLATORS: B16b: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nf6 5. Nxf6+ gxf6 6. Qd3
			variation => N__('Caro-Kann: Bronstein-Larsen, 6. Qd3'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pp1p/2p2p2/8/3P4/8/PPP1NPPP/R1BQKB1R b KQkq' => {
			eco => 'B16c',
			# TRANSLATORS: B16c: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nf6 5. Nxf6+ gxf6 6. Ne2
			variation => N__('Caro-Kann: Bronstein-Larsen, 6. Ne2'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pp1p/2p2p2/8/2BP4/8/PPP2PPP/R1BQK1NR b KQkq' => {
			eco => 'B16d',
			# TRANSLATORS: B16d: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nf6 5. Nxf6+ gxf6 6. Bc4
			variation => N__('Caro-Kann: Bronstein-Larsen, 6. Bc4'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pp1p/2p2p2/8/3P4/5N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B16e',
			# TRANSLATORS: B16e: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nf6 5. Nxf6+ gxf6 6. Nf3
			variation => N__('Caro-Kann: Bronstein-Larsen, 6. Nf3'),
			moves => {
				'c8f5' => 1,
				'c8g4' => 1,
			},
		},
		'rn1qkb1r/pp2pp1p/2p2p2/5b2/3P4/5N2/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B16f',
			# TRANSLATORS: B16f: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nf6 5. Nxf6+ gxf6 6. Nf3 Bf5
			variation => N__('Caro-Kann: Bronstein-Larsen, 6. Nf3 Bf5'),
			moves => {
			},
		},
		'rn1qkb1r/pp2pp1p/2p2p2/8/3P2b1/5N2/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B16g',
			# TRANSLATORS: B16g: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nf6 5. Nxf6+ gxf6 6. Nf3 Bg4
			variation => N__('Caro-Kann: Bronstein-Larsen, 6. Nf3 Bg4'),
			moves => {
				'f1e2' => 1,
			},
		},
		'rn1qkb1r/pp2pp1p/2p2p2/8/3P2b1/5N2/PPP1BPPP/R1BQK2R b KQkq' => {
			eco => 'B16g',
			# TRANSLATORS: B16g: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nf6 5. Nxf6+ gxf6 6. Nf3 Bg4 7. Be2
			variation => N__('Caro-Kann: Bronstein-Larsen, 6. Nf3 Bg4'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rn1qkb1r/pp3p1p/2p1pp2/8/3P2b1/5N2/PPP1BPPP/R1BQK2R w KQkq' => {
			eco => 'B16h',
			# TRANSLATORS: B16h: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nf6 5. Nxf6+ gxf6 6. Nf3 Bg4 7. Be2 e6
			variation => N__('Caro-Kann: Bronstein-Larsen, 6. Nf3 Bg4 7. Be2 e6'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pp1p/2p2p2/8/3P4/2P5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'B16i',
			# TRANSLATORS: B16i: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nf6 5. Nxf6+ gxf6 6. c3
			variation => N__('Caro-Kann: Bronstein-Larsen, 6. c3'),
			moves => {
				'c8f5' => 1,
			},
		},
		'rn1qkb1r/pp2pp1p/2p2p2/5b2/3P4/2P5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'B16j',
			# TRANSLATORS: B16j: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nf6 5. Nxf6+ gxf6 6. c3 Bf5
			variation => N__('Caro-Kann: Bronstein-Larsen, 6. c3 Bf5'),
			moves => {
				'g1e2' => 1,
				'g1f3' => 1,
			},
		},
		'rn1qkb1r/pp2pp1p/2p2p2/5b2/3P4/2P5/PP2NPPP/R1BQKB1R b KQkq' => {
			eco => 'B16k',
			# TRANSLATORS: B16k: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nf6 5. Nxf6+ gxf6 6. c3 Bf5 7. Ne2
			variation => N__('Caro-Kann: Bronstein-Larsen, 6. c3 Bf5 7. Ne2'),
			moves => {
			},
		},
		'rn1qkb1r/pp2pp1p/2p2p2/5b2/3P4/2P2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'B16l',
			# TRANSLATORS: B16l: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nf6 5. Nxf6+ gxf6 6. c3 Bf5 7. Nf3
			variation => N__('Caro-Kann: Bronstein-Larsen, 6. c3 Bf5 7. Nf3'),
			moves => {
				'd8c7' => 1,
				'e7e6' => 1,
			},
		},
		'rn2kb1r/ppq1pp1p/2p2p2/5b2/3P4/2P2N2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'B16m',
			# TRANSLATORS: B16m: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nf6 5. Nxf6+ gxf6 6. c3 Bf5 7. Nf3 Qc7
			variation => N__('Caro-Kann: Bronstein-Larsen, 6. c3 Bf5 7. Nf3 Qc7'),
			moves => {
			},
		},
		'rn1qkb1r/pp3p1p/2p1pp2/5b2/3P4/2P2N2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'B16n',
			# TRANSLATORS: B16n: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nf6 5. Nxf6+ gxf6 6. c3 Bf5 7. Nf3 e6
			variation => N__('Caro-Kann: Bronstein-Larsen, 6. c3 Bf5 7. Nf3 e6'),
			moves => {
			},
		},
		'r1bqkbnr/pp1npppp/2p5/8/3PN3/8/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'B17a',
			# TRANSLATORS: B17a: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7
			variation => N__('Caro-Kann: Steinitz Variation'),
			moves => {
				'e4g5' => 1,
				'f1c4' => 1,
				'g1f3' => 1,
			},
		},
		'r1bqkbnr/pp1npppp/2p5/8/3PN3/5N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B17b',
			# TRANSLATORS: B17b: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Nf3
			variation => N__('Caro-Kann: Steinitz, 5. Nf3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r1bqkb1r/pp1npppp/2p2n2/8/3PN3/5N2/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B17c',
			# TRANSLATORS: B17c: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Nf3 Ngf6
			variation => N__('Caro-Kann: Steinitz, 5. Nf3 Ngf6'),
			moves => {
				'e4f6' => 1,
				'e4g3' => 1,
			},
		},
		'r1bqkb1r/pp1npppp/2p2N2/8/3P4/5N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B17d',
			# TRANSLATORS: B17d: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Nf3 Ngf6 6. Nxf6+
			variation => N__('Caro-Kann: Steinitz, 5. Nf3 Ngf6 6.Nxf6+'),
			moves => {
				'd7f6' => 1,
			},
		},
		'r1bqkb1r/pp2pppp/2p2n2/8/3P4/5N2/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B17d',
			# TRANSLATORS: B17d: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Nf3 Ngf6 6. Nxf6+ Nxf6
			variation => N__('Caro-Kann: Steinitz, 5. Nf3 Ngf6 6.Nxf6+'),
			moves => {
				'f1c4' => 1,
			},
		},
		'r1bqkb1r/pp2pppp/2p2n2/8/2BP4/5N2/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'B17e',
			# TRANSLATORS: B17e: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Nf3 Ngf6 6. Nxf6+ Nxf6 7. Bc4
			variation => N__('Caro-Kann: Steinitz, 5. Nf3 Ngf6 6.Nxf6+ Nxf6 7. Bc4'),
			moves => {
			},
		},
		'r1bqkb1r/pp1npppp/2p2n2/8/3P4/5NN1/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B17f',
			# TRANSLATORS: B17f: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Nf3 Ngf6 6. Ng3
			variation => N__('Caro-Kann: Steinitz, 5. Nf3 Ngf6 6. Ng3'),
			moves => {
				'e7e6' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/2p1pn2/8/3P4/5NN1/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B17g',
			# TRANSLATORS: B17g: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Nf3 Ngf6 6. Ng3 e6
			variation => N__('Caro-Kann: Steinitz, 5. Nf3 Ngf6 6. Ng3 e6'),
			moves => {
			},
		},
		'r1bqkbnr/pp1npppp/2p5/6N1/3P4/8/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'B17h',
			# TRANSLATORS: B17h: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Ng5
			variation => N__('Caro-Kann: Steinitz, 5. Ng5'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r1bqkb1r/pp1npppp/2p2n2/6N1/3P4/8/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'B17i',
			# TRANSLATORS: B17i: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Ng5 Ngf6
			variation => N__('Caro-Kann: Steinitz, 5. Ng5 Ngf6'),
			moves => {
				'f1d3' => 1,
			},
		},
		'r1bqkb1r/pp1npppp/2p2n2/6N1/3P4/3B4/PPP2PPP/R1BQK1NR b KQkq' => {
			eco => 'B17j',
			# TRANSLATORS: B17j: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Ng5 Ngf6 6. Bd3
			variation => N__('Caro-Kann: Steinitz, 5. Ng5 Ngf6 6. Bd3'),
			moves => {
				'e7e6' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/2p1pn2/6N1/3P4/3B4/PPP2PPP/R1BQK1NR w KQkq' => {
			eco => 'B17k',
			# TRANSLATORS: B17k: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Ng5 Ngf6 6. Bd3 e6
			variation => N__('Caro-Kann: Steinitz, 5. Ng5 Ngf6 6. Bd3 e6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/2p1pn2/6N1/3P4/3B1N2/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'B17k',
			# TRANSLATORS: B17k: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Ng5 Ngf6 6. Bd3 e6 7. N1f3
			variation => N__('Caro-Kann: Steinitz, 5. Ng5 Ngf6 6. Bd3 e6'),
			moves => {
				'f8d6' => 1,
			},
		},
		'r1bqk2r/pp1n1ppp/2pbpn2/6N1/3P4/3B1N2/PPP2PPP/R1BQK2R w KQkq' => {
			eco => 'B17k',
			# TRANSLATORS: B17k: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Ng5 Ngf6 6. Bd3 e6 7. N1f3 Bd6
			variation => N__('Caro-Kann: Steinitz, 5. Ng5 Ngf6 6. Bd3 e6'),
			moves => {
				'd1e2' => 1,
			},
		},
		'r1bqk2r/pp1n1ppp/2pbpn2/6N1/3P4/3B1N2/PPP1QPPP/R1B1K2R b KQkq' => {
			eco => 'B17l',
			# TRANSLATORS: B17l: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Ng5 Ngf6 6. Bd3 e6 7. N1f3 Bd6 8. Qe2
			variation => N__('Caro-Kann: Steinitz, 5. Ng5 Ngf6 6. Bd3 e6 7.N1f3 Bd6 8. Qe2'),
			moves => {
				'h7h6' => 1,
			},
		},
		'r1bqk2r/pp1n1pp1/2pbpn1p/6N1/3P4/3B1N2/PPP1QPPP/R1B1K2R w KQkq' => {
			eco => 'B17l',
			# TRANSLATORS: B17l: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Ng5 Ngf6 6. Bd3 e6 7. N1f3 Bd6 8. Qe2 h6
			variation => N__('Caro-Kann: Steinitz, 5. Ng5 Ngf6 6. Bd3 e6 7.N1f3 Bd6 8. Qe2'),
			moves => {
				'g5e4' => 1,
			},
		},
		'r1bqk2r/pp1n1pp1/2pbpn1p/8/3PN3/3B1N2/PPP1QPPP/R1B1K2R b KQkq' => {
			eco => 'B17l',
			# TRANSLATORS: B17l: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Ng5 Ngf6 6. Bd3 e6 7. N1f3 Bd6 8. Qe2 h6 9. Ne4
			variation => N__('Caro-Kann: Steinitz, 5. Ng5 Ngf6 6. Bd3 e6 7.N1f3 Bd6 8. Qe2'),
			moves => {
				'f6e4' => 1,
			},
		},
		'r1bqk2r/pp1n1pp1/2pbp2p/8/3Pn3/3B1N2/PPP1QPPP/R1B1K2R w KQkq' => {
			eco => 'B17l',
			# TRANSLATORS: B17l: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Ng5 Ngf6 6. Bd3 e6 7. N1f3 Bd6 8. Qe2 h6 9. Ne4 Nxe4
			variation => N__('Caro-Kann: Steinitz, 5. Ng5 Ngf6 6. Bd3 e6 7.N1f3 Bd6 8. Qe2'),
			moves => {
				'e2e4' => 1,
			},
		},
		'r1bqk2r/pp1n1pp1/2pbp2p/8/3PQ3/3B1N2/PPP2PPP/R1B1K2R b KQkq' => {
			eco => 'B17m',
			# TRANSLATORS: B17m: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Ng5 Ngf6 6. Bd3 e6 7. N1f3 Bd6 8. Qe2 h6 9. Ne4 Nxe4 10. Qxe4
			variation => N__('Caro-Kann: Steinitz, 5. Ng5 Ngf6 6. Bd3, Main Line 10.Qxe4'),
			moves => {
				'd7f6' => 1,
				'd8c7' => 1,
			},
		},
		'r1b1k2r/ppqn1pp1/2pbp2p/8/3PQ3/3B1N2/PPP2PPP/R1B1K2R w KQkq' => {
			eco => 'B17n',
			# TRANSLATORS: B17n: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Ng5 Ngf6 6. Bd3 e6 7. N1f3 Bd6 8. Qe2 h6 9. Ne4 Nxe4 10. Qxe4 Qc7
			variation => N__('Caro-Kann: Steinitz, 5. Ng5 Ngf6 6. Bd3, Main Line 10.Qxe4 Qc7'),
			moves => {
			},
		},
		'r1bqk2r/pp3pp1/2pbpn1p/8/3PQ3/3B1N2/PPP2PPP/R1B1K2R w KQkq' => {
			eco => 'B17o',
			# TRANSLATORS: B17o: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Ng5 Ngf6 6. Bd3 e6 7. N1f3 Bd6 8. Qe2 h6 9. Ne4 Nxe4 10. Qxe4 Nf6
			variation => N__('Caro-Kann: Steinitz, 5. Ng5 Ngf6 6. Bd3, Main Line 10.Qxe4 Nf6'),
			moves => {
			},
		},
		'r1bqkbnr/pp1npppp/2p5/8/2BPN3/8/PPP2PPP/R1BQK1NR b KQkq' => {
			eco => 'B17p',
			# TRANSLATORS: B17p: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Bc4
			variation => N__('Caro-Kann: Steinitz, 5. Bc4'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r1bqkb1r/pp1npppp/2p2n2/8/2BPN3/8/PPP2PPP/R1BQK1NR w KQkq' => {
			eco => 'B17q',
			# TRANSLATORS: B17q: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Bc4 Ngf6
			variation => N__('Caro-Kann: Steinitz, 5. Bc4 Ngf6'),
			moves => {
				'e4g5' => 1,
			},
		},
		'r1bqkb1r/pp1npppp/2p2n2/6N1/2BP4/8/PPP2PPP/R1BQK1NR b KQkq' => {
			eco => 'B17r',
			# TRANSLATORS: B17r: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Bc4 Ngf6 6. Ng5
			variation => N__('Caro-Kann: Steinitz, 5. Bc4 Ngf6 6. Ng5'),
			moves => {
				'e7e6' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/2p1pn2/6N1/2BP4/8/PPP2PPP/R1BQK1NR w KQkq' => {
			eco => 'B17r',
			# TRANSLATORS: B17r: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Bc4 Ngf6 6. Ng5 e6
			variation => N__('Caro-Kann: Steinitz, 5. Bc4 Ngf6 6. Ng5'),
			moves => {
				'd1e2' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/2p1pn2/6N1/2BP4/8/PPP1QPPP/R1B1K1NR b KQkq' => {
			eco => 'B17r',
			# TRANSLATORS: B17r: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Bc4 Ngf6 6. Ng5 e6 7. Qe2
			variation => N__('Caro-Kann: Steinitz, 5. Bc4 Ngf6 6. Ng5'),
			moves => {
				'd7b6' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/1np1pn2/6N1/2BP4/8/PPP1QPPP/R1B1K1NR w KQkq' => {
			eco => 'B17r',
			# TRANSLATORS: B17r: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Bc4 Ngf6 6. Ng5 e6 7. Qe2 Nb6
			variation => N__('Caro-Kann: Steinitz, 5. Bc4 Ngf6 6. Ng5'),
			moves => {
				'c4b3' => 1,
				'c4d3' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/1np1pn2/6N1/3P4/1B6/PPP1QPPP/R1B1K1NR b KQkq' => {
			eco => 'B17s',
			# TRANSLATORS: B17s: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Bc4 Ngf6 6. Ng5 e6 7. Qe2 Nb6 8. Bb3
			variation => N__('Caro-Kann: Steinitz, 5. Bc4 Ngf6 6. Ng5, 8. Bb3'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/1np1pn2/6N1/3P4/3B4/PPP1QPPP/R1B1K1NR b KQkq' => {
			eco => 'B17t',
			# TRANSLATORS: B17t: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Bc4 Ngf6 6. Ng5 e6 7. Qe2 Nb6 8. Bd3
			variation => N__('Caro-Kann: Steinitz, 5. Bc4 Ngf6 6. Ng5, 8. Bd3'),
			moves => {
				'h7h6' => 1,
			},
		},
		'r1bqkb1r/pp3pp1/1np1pn1p/6N1/3P4/3B4/PPP1QPPP/R1B1K1NR w KQkq' => {
			eco => 'B17u',
			# TRANSLATORS: B17u: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Bc4 Ngf6 6. Ng5 e6 7. Qe2 Nb6 8. Bd3 h6
			variation => N__('Caro-Kann: Steinitz, 5. Bc4 Ngf6 6. Ng5, 8. Bd3 h6'),
			moves => {
			},
		},
		'rn1qkbnr/pp2pppp/2p5/5b2/3PN3/8/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'B18a',
			# TRANSLATORS: B18a: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5
			variation => N__('Caro-Kann: Classical'),
			moves => {
				'e4c5' => 1,
				'e4g3' => 1,
			},
		},
		'rn1qkbnr/pp2pppp/2p5/2N2b2/3P4/8/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'B18b',
			# TRANSLATORS: B18b: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Nc5
			variation => N__('Caro-Kann: Classical, 5. Nc5'),
			moves => {
				'b7b6' => 1,
			},
		},
		'rn1qkbnr/p3pppp/1pp5/2N2b2/3P4/8/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'B18c',
			# TRANSLATORS: B18c: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Nc5 b6
			variation => N__('Caro-Kann: Classical, 5. Nc5 b6'),
			moves => {
			},
		},
		'rn1qkbnr/pp2pppp/2p5/5b2/3P4/6N1/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'B18d',
			# TRANSLATORS: B18d: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3
			variation => N__('Caro-Kann: Classical, 5. Ng3'),
			moves => {
				'f5g6' => 1,
			},
		},
		'rn1qkbnr/pp2pppp/2p3b1/8/3P4/6N1/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'B18e',
			# TRANSLATORS: B18e: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6
			variation => N__('Caro-Kann: Classical, 5. Ng3 Bg6'),
			moves => {
				'f1c4' => 1,
				'f2f4' => 1,
				'g1e2' => 1,
				'g1f3' => 1,
				'g1h3' => 1,
				'h2h4' => 1,
			},
		},
		'rn1qkbnr/pp2pppp/2p3b1/8/3P1P2/6N1/PPP3PP/R1BQKBNR b KQkq' => {
			eco => 'B18f',
			# TRANSLATORS: B18f: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. f4
			variation => N__('Caro-Kann: Classical, Maroczy Attack'),
			moves => {
			},
		},
		'rn1qkbnr/pp2pppp/2p3b1/8/3P4/6NN/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B18g',
			# TRANSLATORS: B18g: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. Nh3
			variation => N__('Caro-Kann: Classical, Flohr Variation'),
			moves => {
			},
		},
		'rn1qkbnr/pp2pppp/2p3b1/8/3P4/6N1/PPP1NPPP/R1BQKB1R b KQkq' => {
			eco => 'B18h',
			# TRANSLATORS: B18h: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. N1e2
			variation => N__('Caro-Kann: Classical, 6.N1e2'),
			moves => {
			},
		},
		'rn1qkbnr/pp2pppp/2p3b1/8/2BP4/6N1/PPP2PPP/R1BQK1NR b KQkq' => {
			eco => 'B18i',
			# TRANSLATORS: B18i: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. Bc4
			variation => N__('Caro-Kann: Classical, 6. Bc4'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rn1qkbnr/pp3ppp/2p1p1b1/8/2BP4/6N1/PPP2PPP/R1BQK1NR w KQkq' => {
			eco => 'B18i',
			# TRANSLATORS: B18i: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. Bc4 e6
			variation => N__('Caro-Kann: Classical, 6. Bc4'),
			moves => {
				'g1e2' => 1,
			},
		},
		'rn1qkbnr/pp3ppp/2p1p1b1/8/2BP4/6N1/PPP1NPPP/R1BQK2R b KQkq' => {
			eco => 'B18j',
			# TRANSLATORS: B18j: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. Bc4 e6 7. N1e2
			variation => N__('Caro-Kann: Classical, 6. Bc4 e6 7.N1e2'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rn1qkb1r/pp3ppp/2p1pnb1/8/2BP4/6N1/PPP1NPPP/R1BQK2R w KQkq' => {
			eco => 'B18k',
			# TRANSLATORS: B18k: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. Bc4 e6 7. N1e2 Nf6
			variation => N__('Caro-Kann: Classical, 6. Bc4 e6 7.N1e2 Nf6'),
			moves => {
			},
		},
		'rn1qkbnr/pp2pppp/2p3b1/8/3P4/5NN1/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B18l',
			# TRANSLATORS: B18l: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. Nf3
			variation => N__('Caro-Kann: Classical, 6. Nf3'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r2qkbnr/pp1npppp/2p3b1/8/3P4/5NN1/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B18m',
			# TRANSLATORS: B18m: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. Nf3 Nd7
			variation => N__('Caro-Kann: Classical, 6. Nf3 Nd7'),
			moves => {
				'f1d3' => 1,
			},
		},
		'r2qkbnr/pp1npppp/2p3b1/8/3P4/3B1NN1/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'B18n',
			# TRANSLATORS: B18n: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. Nf3 Nd7 7. Bd3
			variation => N__('Caro-Kann: Classical, 6. Nf3 Nd7 7. Bd3'),
			moves => {
				'e7e6' => 1,
			},
		},
		'r2qkbnr/pp1n1ppp/2p1p1b1/8/3P4/3B1NN1/PPP2PPP/R1BQK2R w KQkq' => {
			eco => 'B18o',
			# TRANSLATORS: B18o: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. Nf3 Nd7 7. Bd3 e6
			variation => N__('Caro-Kann: Classical, 6. Nf3 Nd7 7. Bd3 e6'),
			moves => {
			},
		},
		'rn1qkbnr/pp2pppp/2p3b1/8/3P3P/6N1/PPP2PP1/R1BQKBNR b KQkq' => {
			eco => 'B18p',
			# TRANSLATORS: B18p: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. h4
			variation => N__('Caro-Kann: Classical, 6. h4'),
			moves => {
				'h7h6' => 1,
			},
		},
		'rn1qkbnr/pp2ppp1/2p3bp/8/3P3P/6N1/PPP2PP1/R1BQKBNR w KQkq' => {
			eco => 'B18p',
			# TRANSLATORS: B18p: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. h4 h6
			variation => N__('Caro-Kann: Classical, 6. h4 h6'),
			moves => {
				'f2f4' => 1,
				'g1f3' => 1,
				'g1h3' => 1,
				'h4h5' => 1,
			},
		},
		'rn1qkbnr/pp2ppp1/2p3bp/8/3P3P/6NN/PPP2PP1/R1BQKB1R b KQkq' => {
			eco => 'B18q',
			# TRANSLATORS: B18q: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. h4 h6 7. Nh3
			variation => N__('Caro-Kann: Classical, 6. h4 h6 7. Nh3'),
			moves => {
			},
		},
		'rn1qkbnr/pp2ppp1/2p3bp/8/3P1P1P/6N1/PPP3P1/R1BQKBNR b KQkq' => {
			eco => 'B18r',
			# TRANSLATORS: B18r: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. h4 h6 7. f4
			variation => N__('Caro-Kann: Classical, 6. h4 h6 7. f4'),
			moves => {
			},
		},
		'rn1qkbnr/pp2ppp1/2p3bp/7P/3P4/6N1/PPP2PP1/R1BQKBNR b KQkq' => {
			eco => 'B18s',
			# TRANSLATORS: B18s: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. h4 h6 7. h5
			variation => N__('Caro-Kann: Classical, 6. h4 h6 7. h5'),
			moves => {
			},
		},
		'rn1qkbnr/pp2ppp1/2p3bp/8/3P3P/5NN1/PPP2PP1/R1BQKB1R b KQkq' => {
			eco => 'B19a',
			# TRANSLATORS: B19a: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. h4 h6 7. Nf3
			variation => N__('Caro-Kann: Classical, 7. Nf3'),
			moves => {
				'b8d7' => 1,
				'e7e6' => 1,
				'g8f6' => 1,
			},
		},
		'rn1qkbnr/pp3pp1/2p1p1bp/8/3P3P/5NN1/PPP2PP1/R1BQKB1R w KQkq' => {
			eco => 'B19b',
			# TRANSLATORS: B19b: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. h4 h6 7. Nf3 e6
			variation => N__('Caro-Kann: Classical, 7. Nf3 e6'),
			moves => {
			},
		},
		'rn1qkb1r/pp2ppp1/2p2nbp/8/3P3P/5NN1/PPP2PP1/R1BQKB1R w KQkq' => {
			eco => 'B19c',
			# TRANSLATORS: B19c: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. h4 h6 7. Nf3 Nf6
			variation => N__('Caro-Kann: Classical, 7. Nf3 Nf6'),
			moves => {
				'f3e5' => 1,
				'h4h5' => 1,
			},
		},
		'rn1qkb1r/pp2ppp1/2p2nbp/7P/3P4/5NN1/PPP2PP1/R1BQKB1R b KQkq' => {
			eco => 'B19d',
			# TRANSLATORS: B19d: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. h4 h6 7. Nf3 Nf6 8. h5
			variation => N__('Caro-Kann: Classical, 7. Nf3 Nf6 8. h5'),
			moves => {
				'g6h7' => 1,
			},
		},
		'rn1qkb1r/pp2pppb/2p2n1p/7P/3P4/5NN1/PPP2PP1/R1BQKB1R w KQkq' => {
			eco => 'B19d',
			# TRANSLATORS: B19d: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. h4 h6 7. Nf3 Nf6 8. h5 Bh7
			variation => N__('Caro-Kann: Classical, 7. Nf3 Nf6 8. h5'),
			moves => {
			},
		},
		'rn1qkb1r/pp2ppp1/2p2nbp/4N3/3P3P/6N1/PPP2PP1/R1BQKB1R b KQkq' => {
			eco => 'B19e',
			# TRANSLATORS: B19e: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. h4 h6 7. Nf3 Nf6 8. Ne5
			variation => N__('Caro-Kann: Classical, 7. Nf3 Nf6 8. Ne5'),
			moves => {
				'g6h7' => 1,
			},
		},
		'rn1qkb1r/pp2pppb/2p2n1p/4N3/3P3P/6N1/PPP2PP1/R1BQKB1R w KQkq' => {
			eco => 'B19e',
			# TRANSLATORS: B19e: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. h4 h6 7. Nf3 Nf6 8. Ne5 Bh7
			variation => N__('Caro-Kann: Classical, 7. Nf3 Nf6 8. Ne5'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rn1qkb1r/pp2pppb/2p2n1p/4N3/3P3P/3B2N1/PPP2PP1/R1BQK2R b KQkq' => {
			eco => 'B19f',
			# TRANSLATORS: B19f: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. h4 h6 7. Nf3 Nf6 8. Ne5 Bh7 9. Bd3
			variation => N__('Caro-Kann: Classical, 7. Nf3 Nf6 8. Ne5 Bh7 9. Bd3'),
			moves => {
			},
		},
		'r2qkbnr/pp1nppp1/2p3bp/8/3P3P/5NN1/PPP2PP1/R1BQKB1R w KQkq' => {
			eco => 'B19g',
			# TRANSLATORS: B19g: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. h4 h6 7. Nf3 Nd7
			variation => N__('Caro-Kann: Classical, 7. Nf3 Nd7'),
			moves => {
				'h4h5' => 1,
			},
		},
		'r2qkbnr/pp1nppp1/2p3bp/7P/3P4/5NN1/PPP2PP1/R1BQKB1R b KQkq' => {
			eco => 'B19h',
			# TRANSLATORS: B19h: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. h4 h6 7. Nf3 Nd7 8. h5
			variation => N__('Caro-Kann: Classical, Spassky Variation'),
			moves => {
				'g6h7' => 1,
			},
		},
		'r2qkbnr/pp1npppb/2p4p/7P/3P4/5NN1/PPP2PP1/R1BQKB1R w KQkq' => {
			eco => 'B19h',
			# TRANSLATORS: B19h: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. h4 h6 7. Nf3 Nd7 8. h5 Bh7
			variation => N__('Caro-Kann: Classical, Spassky Variation'),
			moves => {
				'f1d3' => 1,
			},
		},
		'r2qkbnr/pp1npppb/2p4p/7P/3P4/3B1NN1/PPP2PP1/R1BQK2R b KQkq' => {
			eco => 'B19h',
			# TRANSLATORS: B19h: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. h4 h6 7. Nf3 Nd7 8. h5 Bh7 9. Bd3
			variation => N__('Caro-Kann: Classical, Spassky Variation'),
			moves => {
				'h7d3' => 1,
			},
		},
		'r2qkbnr/pp1nppp1/2p4p/7P/3P4/3b1NN1/PPP2PP1/R1BQK2R w KQkq' => {
			eco => 'B19h',
			# TRANSLATORS: B19h: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. h4 h6 7. Nf3 Nd7 8. h5 Bh7 9. Bd3 Bxd3
			variation => N__('Caro-Kann: Classical, Spassky Variation'),
			moves => {
				'd1d3' => 1,
			},
		},
		'r2qkbnr/pp1nppp1/2p4p/7P/3P4/3Q1NN1/PPP2PP1/R1B1K2R b KQkq' => {
			eco => 'B19i',
			# TRANSLATORS: B19i: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. h4 h6 7. Nf3 Nd7 8. h5 Bh7 9. Bd3 Bxd3 10. Qxd3
			variation => N__('Caro-Kann: Classical, Spassky, 10.Qxd3'),
			moves => {
				'd8c7' => 1,
				'e7e6' => 1,
				'g8f6' => 1,
			},
		},
		'r2qkb1r/pp1nppp1/2p2n1p/7P/3P4/3Q1NN1/PPP2PP1/R1B1K2R w KQkq' => {
			eco => 'B19j',
			# TRANSLATORS: B19j: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. h4 h6 7. Nf3 Nd7 8. h5 Bh7 9. Bd3 Bxd3 10. Qxd3 Ngf6
			variation => N__('Caro-Kann: Classical, Spassky, 10.Qxd3 Ngf6'),
			moves => {
			},
		},
		'r2qkbnr/pp1n1pp1/2p1p2p/7P/3P4/3Q1NN1/PPP2PP1/R1B1K2R w KQkq' => {
			eco => 'B19k',
			# TRANSLATORS: B19k: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. h4 h6 7. Nf3 Nd7 8. h5 Bh7 9. Bd3 Bxd3 10. Qxd3 e6
			variation => N__('Caro-Kann: Classical, Spassky, 10.Qxd3 e6'),
			moves => {
				'c1f4' => 1,
			},
		},
		'r2qkbnr/pp1n1pp1/2p1p2p/7P/3P1B2/3Q1NN1/PPP2PP1/R3K2R b KQkq' => {
			eco => 'B19l',
			# TRANSLATORS: B19l: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. h4 h6 7. Nf3 Nd7 8. h5 Bh7 9. Bd3 Bxd3 10. Qxd3 e6 11. Bf4
			variation => N__('Caro-Kann: Classical, Spassky, 10.Qxd3 e6 11. Bf4'),
			moves => {
			},
		},
		'r3kbnr/ppqnppp1/2p4p/7P/3P4/3Q1NN1/PPP2PP1/R1B1K2R w KQkq' => {
			eco => 'B19m',
			# TRANSLATORS: B19m: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. h4 h6 7. Nf3 Nd7 8. h5 Bh7 9. Bd3 Bxd3 10. Qxd3 Qc7
			variation => N__('Caro-Kann: Classical, Spassky, 10.Qxd3 Qc7'),
			moves => {
				'c1d2' => 1,
			},
		},
		'r3kbnr/ppqnppp1/2p4p/7P/3P4/3Q1NN1/PPPB1PP1/R3K2R b KQkq' => {
			eco => 'B19n',
			# TRANSLATORS: B19n: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. h4 h6 7. Nf3 Nd7 8. h5 Bh7 9. Bd3 Bxd3 10. Qxd3 Qc7 11. Bd2
			variation => N__('Caro-Kann: Classical, Spassky, 10.Qxd3 Qc7 11. Bd2'),
			moves => {
				'e7e6' => 1,
			},
		},
		'r3kbnr/ppqn1pp1/2p1p2p/7P/3P4/3Q1NN1/PPPB1PP1/R3K2R w KQkq' => {
			eco => 'B19o',
			# TRANSLATORS: B19o: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. h4 h6 7. Nf3 Nd7 8. h5 Bh7 9. Bd3 Bxd3 10. Qxd3 Qc7 11. Bd2 e6
			variation => N__('Caro-Kann: Classical, Spassky, 10.Qxd3 Qc7 11. Bd2 e6'),
			moves => {
				'e1c1' => 1,
			},
		},
		'r3kbnr/ppqn1pp1/2p1p2p/7P/3P4/3Q1NN1/PPPB1PP1/2KR3R b kq' => {
			eco => 'B19p',
			# TRANSLATORS: B19p: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. h4 h6 7. Nf3 Nd7 8. h5 Bh7 9. Bd3 Bxd3 10. Qxd3 Qc7 11. Bd2 e6 12. O-O-O
			variation => N__('Caro-Kann: Classical, Spassky, 10.Qxd3 Qc7 11. Bd2 e6 12.O-O-O'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r3kb1r/ppqn1pp1/2p1pn1p/7P/3P4/3Q1NN1/PPPB1PP1/2KR3R w kq' => {
			eco => 'B19q',
			# TRANSLATORS: B19q: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. h4 h6 7. Nf3 Nd7 8. h5 Bh7 9. Bd3 Bxd3 10. Qxd3 Qc7 11. Bd2 e6 12. O-O-O Ngf6
			variation => N__('Caro-Kann: Classical, Spassky, Main Line'),
			moves => {
				'g3e4' => 1,
			},
		},
		'r3kb1r/ppqn1pp1/2p1pn1p/7P/3PN3/3Q1N2/PPPB1PP1/2KR3R b kq' => {
			eco => 'B19r',
			# TRANSLATORS: B19r: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. h4 h6 7. Nf3 Nd7 8. h5 Bh7 9. Bd3 Bxd3 10. Qxd3 Qc7 11. Bd2 e6 12. O-O-O Ngf6 13. Ne4
			variation => N__('Caro-Kann: Classical, Spassky, Main Line, 13. Ne4'),
			moves => {
				'e8c8' => 1,
			},
		},
		'2kr1b1r/ppqn1pp1/2p1pn1p/7P/3PN3/3Q1N2/PPPB1PP1/2KR3R w -' => {
			eco => 'B19s',
			# TRANSLATORS: B19s: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. h4 h6 7. Nf3 Nd7 8. h5 Bh7 9. Bd3 Bxd3 10. Qxd3 Qc7 11. Bd2 e6 12. O-O-O Ngf6 13. Ne4 O-O-O
			variation => N__('Caro-Kann: Classical, Spassky, Main Line, 13. Ne4 O-O-O'),
			moves => {
				'g2g3' => 1,
			},
		},
		'2kr1b1r/ppqn1pp1/2p1pn1p/7P/3PN3/3Q1NP1/PPPB1P2/2KR3R b -' => {
			eco => 'B19s',
			# TRANSLATORS: B19s: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. h4 h6 7. Nf3 Nd7 8. h5 Bh7 9. Bd3 Bxd3 10. Qxd3 Qc7 11. Bd2 e6 12. O-O-O Ngf6 13. Ne4 O-O-O 14. g3
			variation => N__('Caro-Kann: Classical, Spassky, Main Line, 13. Ne4 O-O-O'),
			moves => {
				'f6e4' => 1,
			},
		},
		'2kr1b1r/ppqn1pp1/2p1p2p/7P/3Pn3/3Q1NP1/PPPB1P2/2KR3R w -' => {
			eco => 'B19t',
			# TRANSLATORS: B19t: 1. e4 c6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bf5 5. Ng3 Bg6 6. h4 h6 7. Nf3 Nd7 8. h5 Bh7 9. Bd3 Bxd3 10. Qxd3 Qc7 11. Bd2 e6 12. O-O-O Ngf6 13. Ne4 O-O-O 14. g3 Nxe4
			variation => N__('Caro-Kann: Classical, Spassky, Main Line, 14. g3 Nxe4'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/8/2p5/4P3/8/PPPP1PPP/RNBQKBNR w KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5
			variation => N__('Sicilian Defence'),
			moves => {
				'a2a3' => 1,
				'b1c3' => 1,
				'b2b3' => 1,
				'b2b4' => 1,
				'c2c3' => 1,
				'c2c4' => 1,
				'd2d3' => 1,
				'd2d4' => 1,
				'f1c4' => 1,
				'f2f4' => 1,
				'g1e2' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/pp1ppppp/8/2p5/4P3/P7/1PPP1PPP/RNBQKBNR b KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5 2. a3
			variation => N__('Sicilian: Mengarini'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/8/2p5/4P3/1P6/P1PP1PPP/RNBQKBNR b KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5 2. b3
			variation => N__('Sicilian: Snyder'),
			moves => {
				'b8c6' => 1,
				'd7d6' => 1,
				'e7e6' => 1,
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/2p5/4P3/1P6/P1PP1PPP/RNBQKBNR w KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5 2. b3 Nc6
			variation => N__('Sicilian: Snyder, 2... Nc6'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/3p4/2p5/4P3/1P6/P1PP1PPP/RNBQKBNR w KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5 2. b3 d6
			variation => N__('Sicilian: Snyder, 2... d6'),
			moves => {
			},
		},
		'rnbqkbnr/pp1p1ppp/4p3/2p5/4P3/1P6/P1PP1PPP/RNBQKBNR w KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5 2. b3 e6
			variation => N__('Sicilian: Snyder, 2... e6'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/8/2p5/1P2P3/8/P1PP1PPP/RNBQKBNR b KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5 2. b4
			variation => N__('Sicilian: Wing Gambit'),
			moves => {
				'c5b4' => 1,
			},
		},
		'rnbqkbnr/pp1ppppp/8/8/1p2P3/8/P1PP1PPP/RNBQKBNR w KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5 2. b4 cxb4
			variation => N__('Sicilian: Wing Gambit'),
			moves => {
				'a2a3' => 1,
				'c2c4' => 1,
			},
		},
		'rnbqkbnr/pp1ppppp/8/8/1p2P3/P7/2PP1PPP/RNBQKBNR b KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5 2. b4 cxb4 3. a3
			variation => N__('Sicilian: Wing Gambit, Marshall Variation'),
			moves => {
				'b4a3' => 1,
				'd7d5' => 1,
			},
		},
		'rnbqkbnr/pp1ppppp/8/8/4P3/p7/2PP1PPP/RNBQKBNR w KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5 2. b4 cxb4 3. a3 bxa3
			variation => N__('Sicilian: Wing Gambit, Carlsbad Variation'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/8/3p4/1p2P3/P7/2PP1PPP/RNBQKBNR w KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5 2. b4 cxb4 3. a3 d5
			variation => N__('Sicilian: Wing Gambit, Marshall Variation'),
			moves => {
				'e4d5' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/8/3P4/1p6/P7/2PP1PPP/RNBQKBNR b KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5 2. b4 cxb4 3. a3 d5 4. exd5
			variation => N__('Sicilian: Wing Gambit, Marshall Variation'),
			moves => {
				'd8d5' => 1,
			},
		},
		'rnb1kbnr/pp2pppp/8/3q4/1p6/P7/2PP1PPP/RNBQKBNR w KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5 2. b4 cxb4 3. a3 d5 4. exd5 Qxd5
			variation => N__('Sicilian: Wing Gambit, Marshall Variation'),
			moves => {
				'c1b2' => 1,
			},
		},
		'rnb1kbnr/pp2pppp/8/3q4/1p6/P7/1BPP1PPP/RN1QKBNR b KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5 2. b4 cxb4 3. a3 d5 4. exd5 Qxd5 5. Bb2
			variation => N__('Sicilian: Wing Gambit, Marienbad Variation'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/8/8/1pP1P3/8/P2P1PPP/RNBQKBNR b KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5 2. b4 cxb4 3. c4
			variation => N__('Sicilian: Wing Gambit, Santasiere Variation'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/8/2p5/2P1P3/8/PP1P1PPP/RNBQKBNR b KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5 2. c4
			variation => N__('Sicilian: English (2. c4)'),
			moves => {
				'b8c6' => 1,
				'd7d6' => 1,
				'e7e6' => 1,
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/2p5/2P1P3/8/PP1P1PPP/RNBQKBNR w KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5 2. c4 Nc6
			variation => N__('Sicilian: English, 2... Nc6'),
			moves => {
				'b1c3' => 1,
				'g1e2' => 1,
				'g1f3' => 1,
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/2p5/2P1P3/2N5/PP1P1PPP/R1BQKBNR b KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5 2. c4 Nc6 3. Nc3
			variation => N__('Sicilian: English, 2... Nc6 3. Nc3'),
			moves => {
				'g7g6' => 1,
			},
		},
		'r1bqkbnr/pp1ppp1p/2n3p1/2p5/2P1P3/2N5/PP1P1PPP/R1BQKBNR w KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5 2. c4 Nc6 3. Nc3 g6
			variation => N__('Sicilian: English, 2... Nc6 3. Nc3 g6'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/2p5/2P1P3/8/PP1PNPPP/RNBQKB1R b KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5 2. c4 Nc6 3. Ne2
			variation => N__('Sicilian: English, 2... Nc6 3. Ne2'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/2p5/2P1P3/5N2/PP1P1PPP/RNBQKB1R b KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5 2. c4 Nc6 3. Nf3
			variation => N__('Sicilian: English, 2... Nc6 3. Nf3'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/3p4/2p5/2P1P3/8/PP1P1PPP/RNBQKBNR w KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5 2. c4 d6
			variation => N__('Sicilian: English, 2... d6'),
			moves => {
			},
		},
		'rnbqkbnr/pp1p1ppp/4p3/2p5/2P1P3/8/PP1P1PPP/RNBQKBNR w KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5 2. c4 e6
			variation => N__('Sicilian: English, 2... e6'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/8/2p5/4P3/3P4/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5 2. d3
			variation => N__('Sicilian: 2. d3'),
			moves => {
				'b8c6' => 1,
				'e7e6' => 1,
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/2p5/4P3/3P4/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5 2. d3 Nc6
			variation => N__('Sicilian: 2. d3 Nc6'),
			moves => {
				'g2g3' => 1,
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/2p5/4P3/3P2P1/PPP2P1P/RNBQKBNR b KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5 2. d3 Nc6 3. g3
			variation => N__('Sicilian: 2. d3 Nc6 3. g3'),
			moves => {
			},
		},
		'rnbqkbnr/pp1p1ppp/4p3/2p5/4P3/3P4/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5 2. d3 e6
			variation => N__('Sicilian: 2. d3 e6'),
			moves => {
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/pp1p1ppp/4p3/2p5/4P3/3P2P1/PPP2P1P/RNBQKBNR b KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5 2. d3 e6 3. g3
			variation => N__('Sicilian: 2. d3 e6 3. g3'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/8/2p5/2B1P3/8/PPPP1PPP/RNBQK1NR b KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5 2. Bc4
			variation => N__('Sicilian: 2. Bc4'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/8/2p5/4P3/8/PPPPNPPP/RNBQKB1R b KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5 2. Ne2
			variation => N__('Sicilian: Keres Variation (2. Ne2)'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/8/2p5/4P3/6P1/PPPP1P1P/RNBQKBNR b KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5 2. g3
			variation => N__('Sicilian: 2. g3'),
			moves => {
				'g7g6' => 1,
			},
		},
		'rnbqkbnr/pp1ppp1p/6p1/2p5/4P3/6P1/PPPP1P1P/RNBQKBNR w KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5 2. g3 g6
			variation => N__('Sicilian: 2. g3'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkbnr/pp1ppp1p/6p1/2p5/4P3/6P1/PPPP1PBP/RNBQK1NR b KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5 2. g3 g6 3. Bg2
			variation => N__('Sicilian: 2. g3'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk1nr/pp1pppbp/6p1/2p5/4P3/6P1/PPPP1PBP/RNBQK1NR w KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5 2. g3 g6 3. Bg2 Bg7
			variation => N__('Sicilian: 2. g3'),
			moves => {
				'f2f4' => 1,
			},
		},
		'rnbqk1nr/pp1pppbp/6p1/2p5/4PP2/6P1/PPPP2BP/RNBQK1NR b KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5 2. g3 g6 3. Bg2 Bg7 4. f4
			variation => N__('Sicilian: 2. g3'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rnbqk1nr/pp2ppbp/3p2p1/2p5/4PP2/6P1/PPPP2BP/RNBQK1NR w KQkq' => {
			eco => 'B20',
			# TRANSLATORS: B20: 1. e4 c5 2. g3 g6 3. Bg2 Bg7 4. f4 d6
			variation => N__('Sicilian: 2. g3'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/8/2p5/4PP2/8/PPPP2PP/RNBQKBNR b KQkq' => {
			eco => 'B21a',
			# TRANSLATORS: B21a: 1. e4 c5 2. f4
			variation => N__('Sicilian: Grand Prix Attack'),
			moves => {
				'b8c6' => 1,
				'd7d5' => 1,
				'd7d6' => 1,
				'e7e6' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkbnr/pp1ppp1p/6p1/2p5/4PP2/8/PPPP2PP/RNBQKBNR w KQkq' => {
			eco => 'B21b',
			# TRANSLATORS: B21b: 1. e4 c5 2. f4 g6
			variation => N__('Sicilian: Grand Prix, 2... g6'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/3p4/2p5/4PP2/8/PPPP2PP/RNBQKBNR w KQkq' => {
			eco => 'B21c',
			# TRANSLATORS: B21c: 1. e4 c5 2. f4 d6
			variation => N__('Sicilian: Grand Prix, 2... d6'),
			moves => {
			},
		},
		'rnbqkbnr/pp1p1ppp/4p3/2p5/4PP2/8/PPPP2PP/RNBQKBNR w KQkq' => {
			eco => 'B21d',
			# TRANSLATORS: B21d: 1. e4 c5 2. f4 e6
			variation => N__('Sicilian: Grand Prix, 2... e6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pp1p1ppp/4p3/2p5/4PP2/5N2/PPPP2PP/RNBQKB1R b KQkq' => {
			eco => 'B21d',
			# TRANSLATORS: B21d: 1. e4 c5 2. f4 e6 3. Nf3
			variation => N__('Sicilian: Grand Prix, 2... e6 3. Nf3'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/2p5/4PP2/8/PPPP2PP/RNBQKBNR w KQkq' => {
			eco => 'B21e',
			# TRANSLATORS: B21e: 1. e4 c5 2. f4 Nc6
			variation => N__('Sicilian: Grand Prix, 2... Nc6'),
			moves => {
				'd2d3' => 1,
				'g1f3' => 1,
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/2p5/4PP2/3P4/PPP3PP/RNBQKBNR b KQkq' => {
			eco => 'B21e',
			# TRANSLATORS: B21e: 1. e4 c5 2. f4 Nc6 3. d3
			variation => N__('Sicilian: Grand Prix, 2... Nc6 3. d3'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/2p5/4PP2/5N2/PPPP2PP/RNBQKB1R b KQkq' => {
			eco => 'B21f',
			# TRANSLATORS: B21f: 1. e4 c5 2. f4 Nc6 3. Nf3
			variation => N__('Sicilian: Grand Prix, 2... Nc6 3. Nf3'),
			moves => {
				'e7e6' => 1,
				'g7g6' => 1,
			},
		},
		'r1bqkbnr/pp1p1ppp/2n1p3/2p5/4PP2/5N2/PPPP2PP/RNBQKB1R w KQkq' => {
			eco => 'B21g',
			# TRANSLATORS: B21g: 1. e4 c5 2. f4 Nc6 3. Nf3 e6
			variation => N__('Sicilian: Grand Prix, 2... Nc6 3. Nf3 e6'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppp1p/2n3p1/2p5/4PP2/5N2/PPPP2PP/RNBQKB1R w KQkq' => {
			eco => 'B21h',
			# TRANSLATORS: B21h: 1. e4 c5 2. f4 Nc6 3. Nf3 g6
			variation => N__('Sicilian: Grand Prix, 2... Nc6 3. Nf3 g6'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/8/2pp4/4PP2/8/PPPP2PP/RNBQKBNR w KQkq' => {
			eco => 'B21i',
			# TRANSLATORS: B21i: 1. e4 c5 2. f4 d5
			variation => N__('Sicilian: Grand Prix, Tal Defence'),
			moves => {
				'b1c3' => 1,
				'e4d5' => 1,
				'e4e5' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/8/2pp4/4PP2/2N5/PPPP2PP/R1BQKBNR b KQkq' => {
			eco => 'B21i',
			# TRANSLATORS: B21i: 1. e4 c5 2. f4 d5 3. Nc3
			variation => N__('Sicilian: Grand Prix, Toilet Variation'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/8/2ppP3/5P2/8/PPPP2PP/RNBQKBNR b KQkq' => {
			eco => 'B21i',
			# TRANSLATORS: B21i: 1. e4 c5 2. f4 d5 3. e5
			variation => N__('Sicilian: Grand Prix, Tal Defence, 3. e5'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/8/2pP4/5P2/8/PPPP2PP/RNBQKBNR b KQkq' => {
			eco => 'B21j',
			# TRANSLATORS: B21j: 1. e4 c5 2. f4 d5 3. exd5
			variation => N__('Sicilian: Grand Prix, Tal Defence, 3.exd5'),
			moves => {
				'd8d5' => 1,
				'g8f6' => 1,
			},
		},
		'rnb1kbnr/pp2pppp/8/2pq4/5P2/8/PPPP2PP/RNBQKBNR w KQkq' => {
			eco => 'B21j',
			# TRANSLATORS: B21j: 1. e4 c5 2. f4 d5 3. exd5 Qxd5
			variation => N__('Sicilian: Grand Prix, Tal Defence, 3.exd5 Qxd5'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/5n2/2pP4/5P2/8/PPPP2PP/RNBQKBNR w KQkq' => {
			eco => 'B21k',
			# TRANSLATORS: B21k: 1. e4 c5 2. f4 d5 3. exd5 Nf6
			variation => N__('Sicilian: Grand Prix, Tal Gambit'),
			moves => {
				'f1b5' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/5n2/1BpP4/5P2/8/PPPP2PP/RNBQK1NR b KQkq' => {
			eco => 'B21l',
			# TRANSLATORS: B21l: 1. e4 c5 2. f4 d5 3. exd5 Nf6 4. Bb5+
			variation => N__('Sicilian: Grand Prix, Tal Gambit, 4. Bb5+'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/8/2p5/3PP3/8/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'B21m',
			# TRANSLATORS: B21m: 1. e4 c5 2. d4
			variation => N__('Sicilian: Smith-Morra Gambit'),
			moves => {
				'c5d4' => 1,
				'd7d5' => 1,
			},
		},
		'rnbqkbnr/pp1ppppp/8/8/3pP3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B21m',
			# TRANSLATORS: B21m: 1. e4 c5 2. d4 cxd4
			variation => N__('Sicilian: Smith-Morra, 2...cxd4'),
			moves => {
				'c2c3' => 1,
				'f2f4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pp1ppppp/8/8/3pPP2/8/PPP3PP/RNBQKBNR b KQkq' => {
			eco => 'B21m',
			# TRANSLATORS: B21m: 1. e4 c5 2. d4 cxd4 3. f4
			variation => N__('Sicilian: Halasz Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/8/2pp4/3PP3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'B21m',
			# TRANSLATORS: B21m: 1. e4 c5 2. d4 d5
			variation => N__('Sicilian: Smith-Morra, 2... d5'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/8/8/3pP3/5N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B21n',
			# TRANSLATORS: B21n: 1. e4 c5 2. d4 cxd4 3. Nf3
			variation => N__('Sicilian: Smith-Morra, Morphy Gambit'),
			moves => {
				'e7e5' => 1,
			},
		},
		'rnbqkbnr/pp1p1ppp/8/4p3/3pP3/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B21n',
			# TRANSLATORS: B21n: 1. e4 c5 2. d4 cxd4 3. Nf3 e5
			variation => N__('Sicilian: Smith-Morra, Morphy Gambit'),
			moves => {
				'c2c3' => 1,
			},
		},
		'rnbqkbnr/pp1p1ppp/8/4p3/3pP3/2P2N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'B21n',
			# TRANSLATORS: B21n: 1. e4 c5 2. d4 cxd4 3. Nf3 e5 4. c3
			variation => N__('Sicilian: Smith-Morra, Andreaschek Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/8/8/3pP3/2P5/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'B21o',
			# TRANSLATORS: B21o: 1. e4 c5 2. d4 cxd4 3. c3
			variation => N__('Sicilian: Smith-Morra, 3. c3'),
			moves => {
				'd4c3' => 1,
				'd4d3' => 1,
				'd7d5' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/8/3pP3/2P5/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'B21p',
			# TRANSLATORS: B21p: 1. e4 c5 2. d4 cxd4 3. c3 Nf6
			variation => N__('Sicilian: Smith-Morra, 3. c3 Nf6'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/8/3p4/3pP3/2P5/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'B21q',
			# TRANSLATORS: B21q: 1. e4 c5 2. d4 cxd4 3. c3 d5
			variation => N__('Sicilian: Smith-Morra, 3. c3 d5'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/8/8/4P3/2Pp4/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'B21r',
			# TRANSLATORS: B21r: 1. e4 c5 2. d4 cxd4 3. c3 d3
			variation => N__('Sicilian: Smith-Morra, 3. c3 d3'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/8/8/4P3/2p5/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'B21s',
			# TRANSLATORS: B21s: 1. e4 c5 2. d4 cxd4 3. c3 dxc3
			variation => N__('Sicilian: Smith-Morra Accepted'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkbnr/pp1ppppp/8/8/4P3/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'B21s',
			# TRANSLATORS: B21s: 1. e4 c5 2. d4 cxd4 3. c3 dxc3 4. Nxc3
			variation => N__('Sicilian: Smith-Morra Accepted'),
			moves => {
				'b8c6' => 1,
				'd7d6' => 1,
				'e7e6' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/3p4/8/4P3/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'B21t',
			# TRANSLATORS: B21t: 1. e4 c5 2. d4 cxd4 3. c3 dxc3 4. Nxc3 d6
			variation => N__('Sicilian: Smith-Morra, 4.Nxc3 d6'),
			moves => {
			},
		},
		'rnbqkbnr/pp1p1ppp/4p3/8/4P3/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'B21u',
			# TRANSLATORS: B21u: 1. e4 c5 2. d4 cxd4 3. c3 dxc3 4. Nxc3 e6
			variation => N__('Sicilian: Smith-Morra, 4.Nxc3 e6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pp1p1ppp/4p3/8/4P3/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'B21v',
			# TRANSLATORS: B21v: 1. e4 c5 2. d4 cxd4 3. c3 dxc3 4. Nxc3 e6 5. Nf3
			variation => N__('Sicilian: Smith-Morra, 4.Nxc3 e6 5. Nf3'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/8/4P3/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'B21w',
			# TRANSLATORS: B21w: 1. e4 c5 2. d4 cxd4 3. c3 dxc3 4. Nxc3 Nc6
			variation => N__('Sicilian: Smith-Morra, 4.Nxc3 Nc6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/8/4P3/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'B21w',
			# TRANSLATORS: B21w: 1. e4 c5 2. d4 cxd4 3. c3 dxc3 4. Nxc3 Nc6 5. Nf3
			variation => N__('Sicilian: Smith-Morra, 4.Nxc3 Nc6 5. Nf3'),
			moves => {
				'd7d6' => 1,
				'e7e6' => 1,
			},
		},
		'r1bqkbnr/pp1p1ppp/2n1p3/8/4P3/2N2N2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'B21x',
			# TRANSLATORS: B21x: 1. e4 c5 2. d4 cxd4 3. c3 dxc3 4. Nxc3 Nc6 5. Nf3 e6
			variation => N__('Sicilian: Smith-Morra, 4.Nxc3 Nc6 5. Nf3 e6'),
			moves => {
				'f1c4' => 1,
			},
		},
		'r1bqkbnr/pp1p1ppp/2n1p3/8/2B1P3/2N2N2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'B21x',
			# TRANSLATORS: B21x: 1. e4 c5 2. d4 cxd4 3. c3 dxc3 4. Nxc3 Nc6 5. Nf3 e6 6. Bc4
			variation => N__('Sicilian: Smith-Morra, 4.Nxc3 Nc6 5. Nf3 e6 6. Bc4'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r1bqkbnr/1p1p1ppp/p1n1p3/8/2B1P3/2N2N2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'B21x',
			# TRANSLATORS: B21x: 1. e4 c5 2. d4 cxd4 3. c3 dxc3 4. Nxc3 Nc6 5. Nf3 e6 6. Bc4 a6
			variation => N__('Sicilian: Smith-Morra, 4.Nxc3 Nc6 5. Nf3 e6 6. Bc4 a6'),
			moves => {
			},
		},
		'r1bqkbnr/pp2pppp/2np4/8/4P3/2N2N2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'B21y',
			# TRANSLATORS: B21y: 1. e4 c5 2. d4 cxd4 3. c3 dxc3 4. Nxc3 Nc6 5. Nf3 d6
			variation => N__('Sicilian: Smith-Morra, 4.Nxc3 Nc6 5. Nf3 d6'),
			moves => {
				'f1c4' => 1,
			},
		},
		'r1bqkbnr/pp2pppp/2np4/8/2B1P3/2N2N2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'B21y',
			# TRANSLATORS: B21y: 1. e4 c5 2. d4 cxd4 3. c3 dxc3 4. Nxc3 Nc6 5. Nf3 d6 6. Bc4
			variation => N__('Sicilian: Smith-Morra, 5. Nf3 d6 6. Bc4'),
			moves => {
				'a7a6' => 1,
				'e7e6' => 1,
			},
		},
		'r1bqkbnr/1p2pppp/p1np4/8/2B1P3/2N2N2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'B21y',
			# TRANSLATORS: B21y: 1. e4 c5 2. d4 cxd4 3. c3 dxc3 4. Nxc3 Nc6 5. Nf3 d6 6. Bc4 a6
			variation => N__('Sicilian: Smith-Morra, 5. Nf3 d6 6. Bc4 a6'),
			moves => {
			},
		},
		'r1bqkbnr/pp3ppp/2npp3/8/2B1P3/2N2N2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'B21y',
			# TRANSLATORS: B21y: 1. e4 c5 2. d4 cxd4 3. c3 dxc3 4. Nxc3 Nc6 5. Nf3 d6 6. Bc4 e6
			variation => N__('Sicilian: Smith-Morra, 5. Nf3 d6 6. Bc4 e6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqkbnr/pp3ppp/2npp3/8/2B1P3/2N2N2/PP3PPP/R1BQ1RK1 b kq' => {
			eco => 'B21y',
			# TRANSLATORS: B21y: 1. e4 c5 2. d4 cxd4 3. c3 dxc3 4. Nxc3 Nc6 5. Nf3 d6 6. Bc4 e6 7. O-O
			variation => N__('Sicilian: Smith-Morra, 5. Nf3 d6 6. Bc4 e6 7.O-O'),
			moves => {
				'a7a6' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkbnr/1p3ppp/p1npp3/8/2B1P3/2N2N2/PP3PPP/R1BQ1RK1 w kq' => {
			eco => 'B21y',
			# TRANSLATORS: B21y: 1. e4 c5 2. d4 cxd4 3. c3 dxc3 4. Nxc3 Nc6 5. Nf3 d6 6. Bc4 e6 7. O-O a6
			variation => N__('Sicilian: Smith-Morra, 5. Nf3 d6 6. Bc4 e6 7.O-O'),
			moves => {
				'd1e2' => 1,
			},
		},
		'r1bqkbnr/1p3ppp/p1npp3/8/2B1P3/2N2N2/PP2QPPP/R1B2RK1 b kq' => {
			eco => 'B21y',
			# TRANSLATORS: B21y: 1. e4 c5 2. d4 cxd4 3. c3 dxc3 4. Nxc3 Nc6 5. Nf3 d6 6. Bc4 e6 7. O-O a6 8. Qe2
			variation => N__('Sicilian: Smith-Morra, 5. Nf3 d6 6. Bc4 e6 7.O-O'),
			moves => {
				'b7b5' => 1,
			},
		},
		'r1bqkbnr/5ppp/p1npp3/1p6/2B1P3/2N2N2/PP2QPPP/R1B2RK1 w kq' => {
			eco => 'B21y',
			# TRANSLATORS: B21y: 1. e4 c5 2. d4 cxd4 3. c3 dxc3 4. Nxc3 Nc6 5. Nf3 d6 6. Bc4 e6 7. O-O a6 8. Qe2 b5
			variation => N__('Sicilian: Smith-Morra, 5. Nf3 d6 6. Bc4 e6 7.O-O'),
			moves => {
				'c4b3' => 1,
			},
		},
		'r1bqkbnr/5ppp/p1npp3/1p6/4P3/1BN2N2/PP2QPPP/R1B2RK1 b kq' => {
			eco => 'B21y',
			# TRANSLATORS: B21y: 1. e4 c5 2. d4 cxd4 3. c3 dxc3 4. Nxc3 Nc6 5. Nf3 d6 6. Bc4 e6 7. O-O a6 8. Qe2 b5 9. Bb3
			variation => N__('Sicilian: Smith-Morra, 5. Nf3 d6 6. Bc4 e6 7.O-O'),
			moves => {
				'a8a7' => 1,
			},
		},
		'2bqkbnr/r4ppp/p1npp3/1p6/4P3/1BN2N2/PP2QPPP/R1B2RK1 w k' => {
			eco => 'B21y',
			# TRANSLATORS: B21y: 1. e4 c5 2. d4 cxd4 3. c3 dxc3 4. Nxc3 Nc6 5. Nf3 d6 6. Bc4 e6 7. O-O a6 8. Qe2 b5 9. Bb3 Ra7
			variation => N__('Sicilian: Smith-Morra Gambit, Chicago Defence'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2nppn2/8/2B1P3/2N2N2/PP3PPP/R1BQ1RK1 w kq' => {
			eco => 'B21z',
			# TRANSLATORS: B21z: 1. e4 c5 2. d4 cxd4 3. c3 dxc3 4. Nxc3 Nc6 5. Nf3 d6 6. Bc4 e6 7. O-O Nf6
			variation => N__('Sicilian: Smith-Morra, 5. Nf3 d6 6. Bc4 e6 7.O-O Nf6'),
			moves => {
				'd1e2' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2nppn2/8/2B1P3/2N2N2/PP2QPPP/R1B2RK1 b kq' => {
			eco => 'B21z',
			# TRANSLATORS: B21z: 1. e4 c5 2. d4 cxd4 3. c3 dxc3 4. Nxc3 Nc6 5. Nf3 d6 6. Bc4 e6 7. O-O Nf6 8. Qe2
			variation => N__('Sicilian: Smith-Morra, 5. Nf3 d6 6. Bc4 e6 7.O-O Nf6'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2nppn2/8/2B1P3/2N2N2/PP2QPPP/R1B2RK1 w kq' => {
			eco => 'B21z',
			# TRANSLATORS: B21z: 1. e4 c5 2. d4 cxd4 3. c3 dxc3 4. Nxc3 Nc6 5. Nf3 d6 6. Bc4 e6 7. O-O Nf6 8. Qe2 Be7
			variation => N__('Sicilian: Smith-Morra, 5. Nf3 d6 6. Bc4 e6 7.O-O Nf6 8. Qe2 Be7'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/8/2p5/4P3/2P5/PP1P1PPP/RNBQKBNR b KQkq' => {
			eco => 'B22a',
			# TRANSLATORS: B22a: 1. e4 c5 2. c3
			variation => N__('Sicilian: Alapin'),
			moves => {
				'b8c6' => 1,
				'd7d5' => 1,
				'd7d6' => 1,
				'e7e5' => 1,
				'e7e6' => 1,
				'g7g6' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/pp1p1ppp/8/2p1p3/4P3/2P5/PP1P1PPP/RNBQKBNR w KQkq' => {
			eco => 'B22a',
			# TRANSLATORS: B22a: 1. e4 c5 2. c3 e5
			variation => N__('Sicilian: Alapin, 2... e5'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppp1p/6p1/2p5/4P3/2P5/PP1P1PPP/RNBQKBNR w KQkq' => {
			eco => 'B22a',
			# TRANSLATORS: B22a: 1. e4 c5 2. c3 g6
			variation => N__('Sicilian: Alapin, 2... g6'),
			moves => {
				'd2d4' => 1,
			},
		},
		'rnbqkbnr/pp1ppp1p/6p1/2p5/3PP3/2P5/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'B22a',
			# TRANSLATORS: B22a: 1. e4 c5 2. c3 g6 3. d4
			variation => N__('Sicilian: Alapin, 2... g6 3. d4'),
			moves => {
				'c5d4' => 1,
			},
		},
		'rnbqkbnr/pp1ppp1p/6p1/8/3pP3/2P5/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'B22a',
			# TRANSLATORS: B22a: 1. e4 c5 2. c3 g6 3. d4 cxd4
			variation => N__('Sicilian: Alapin, 2... g6 3. d4 cxd4'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/2p5/4P3/2P5/PP1P1PPP/RNBQKBNR w KQkq' => {
			eco => 'B22b',
			# TRANSLATORS: B22b: 1. e4 c5 2. c3 Nc6
			variation => N__('Sicilian: Alapin, 2... Nc6'),
			moves => {
				'd2d4' => 1,
				'g1f3' => 1,
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/2p5/3PP3/2P5/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'B22b',
			# TRANSLATORS: B22b: 1. e4 c5 2. c3 Nc6 3. d4
			variation => N__('Sicilian: Alapin, 2... Nc6 3. d4'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/2p5/4P3/2P2N2/PP1P1PPP/RNBQKB1R b KQkq' => {
			eco => 'B22b',
			# TRANSLATORS: B22b: 1. e4 c5 2. c3 Nc6 3. Nf3
			variation => N__('Sicilian: Alapin, 2... Nc6 3. Nf3'),
			moves => {
			},
		},
		'rnbqkbnr/pp1p1ppp/4p3/2p5/4P3/2P5/PP1P1PPP/RNBQKBNR w KQkq' => {
			eco => 'B22c',
			# TRANSLATORS: B22c: 1. e4 c5 2. c3 e6
			variation => N__('Sicilian: Alapin, 2... e6'),
			moves => {
				'd2d4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pp1p1ppp/4p3/2p5/4P3/2P2N2/PP1P1PPP/RNBQKB1R b KQkq' => {
			eco => 'B22c',
			# TRANSLATORS: B22c: 1. e4 c5 2. c3 e6 3. Nf3
			variation => N__('Sicilian: Alapin, 2... e6 3. Nf3'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/4p3/2pp4/4P3/2P2N2/PP1P1PPP/RNBQKB1R w KQkq' => {
			eco => 'B22c',
			# TRANSLATORS: B22c: 1. e4 c5 2. c3 e6 3. Nf3 d5
			variation => N__('Sicilian: Alapin, 2... e6 3. Nf3 d5'),
			moves => {
			},
		},
		'rnbqkbnr/pp1p1ppp/4p3/2p5/3PP3/2P5/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'B22d',
			# TRANSLATORS: B22d: 1. e4 c5 2. c3 e6 3. d4
			variation => N__('Sicilian: Alapin, 2... e6 3. d4'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/4p3/2pp4/3PP3/2P5/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'B22d',
			# TRANSLATORS: B22d: 1. e4 c5 2. c3 e6 3. d4 d5
			variation => N__('Sicilian: Alapin, 2... e6 3. d4 d5'),
			moves => {
				'e4d5' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/4p3/2pP4/3P4/2P5/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'B22d',
			# TRANSLATORS: B22d: 1. e4 c5 2. c3 e6 3. d4 d5 4. exd5
			variation => N__('Sicilian: Alapin, 2... e6 3. d4 d5 4.exd5'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/8/2pp4/3P4/2P5/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'B22d',
			# TRANSLATORS: B22d: 1. e4 c5 2. c3 e6 3. d4 d5 4. exd5 exd5
			variation => N__('Sicilian: Alapin, 2... e6 3. d4 d5 4.exd5 exd5'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/8/2pp4/3P4/2P2N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'B22d',
			# TRANSLATORS: B22d: 1. e4 c5 2. c3 e6 3. d4 d5 4. exd5 exd5 5. Nf3
			variation => N__('Sicilian: Alapin, 2... e6 3. d4 d5 4.exd5 exd5 5. Nf3'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkbnr/pp3ppp/2n5/2pp4/3P4/2P2N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'B22d',
			# TRANSLATORS: B22d: 1. e4 c5 2. c3 e6 3. d4 d5 4. exd5 exd5 5. Nf3 Nc6
			variation => N__('Sicilian: Alapin, 2... e6 3. d4 d5 4.exd5 exd5 5. Nf3 Nc6'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/3p4/2p5/4P3/2P5/PP1P1PPP/RNBQKBNR w KQkq' => {
			eco => 'B22e',
			# TRANSLATORS: B22e: 1. e4 c5 2. c3 d6
			variation => N__('Sicilian: Alapin, 2... d6'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/8/2pp4/4P3/2P5/PP1P1PPP/RNBQKBNR w KQkq' => {
			eco => 'B22f',
			# TRANSLATORS: B22f: 1. e4 c5 2. c3 d5
			variation => N__('Sicilian: Alapin, 2... d5'),
			moves => {
				'e4d5' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/8/2pP4/8/2P5/PP1P1PPP/RNBQKBNR b KQkq' => {
			eco => 'B22f',
			# TRANSLATORS: B22f: 1. e4 c5 2. c3 d5 3. exd5
			variation => N__('Sicilian: Alapin, 2... d5 3.exd5'),
			moves => {
				'd8d5' => 1,
			},
		},
		'rnb1kbnr/pp2pppp/8/2pq4/8/2P5/PP1P1PPP/RNBQKBNR w KQkq' => {
			eco => 'B22f',
			# TRANSLATORS: B22f: 1. e4 c5 2. c3 d5 3. exd5 Qxd5
			variation => N__('Sicilian: Alapin, 2... d5 3.exd5 Qxd5'),
			moves => {
				'd2d4' => 1,
			},
		},
		'rnb1kbnr/pp2pppp/8/2pq4/3P4/2P5/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'B22f',
			# TRANSLATORS: B22f: 1. e4 c5 2. c3 d5 3. exd5 Qxd5 4. d4
			variation => N__('Sicilian: Alapin, 2... d5 3.exd5 Qxd5 4. d4'),
			moves => {
				'b8c6' => 1,
				'c5d4' => 1,
				'e7e6' => 1,
				'g8f6' => 1,
			},
		},
		'rnb1kbnr/pp2pppp/8/3q4/3p4/2P5/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'B22f',
			# TRANSLATORS: B22f: 1. e4 c5 2. c3 d5 3. exd5 Qxd5 4. d4 cxd4
			variation => N__('Sicilian: Alapin, 2... d5 3.exd5 Qxd5 4. d4 cxd4'),
			moves => {
				'c3d4' => 1,
			},
		},
		'rnb1kbnr/pp2pppp/8/3q4/3P4/8/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'B22f',
			# TRANSLATORS: B22f: 1. e4 c5 2. c3 d5 3. exd5 Qxd5 4. d4 cxd4 5. cxd4
			variation => N__('Sicilian: Alapin, 2... d5 3.exd5 Qxd5 4. d4 cxd4 5.cxd4'),
			moves => {
			},
		},
		'rnb1kbnr/pp3ppp/4p3/2pq4/3P4/2P5/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'B22g',
			# TRANSLATORS: B22g: 1. e4 c5 2. c3 d5 3. exd5 Qxd5 4. d4 e6
			variation => N__('Sicilian: Alapin, 2... d5 3.exd5 Qxd5 4. d4 e6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnb1kbnr/pp3ppp/4p3/2pq4/3P4/2P2N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'B22g',
			# TRANSLATORS: B22g: 1. e4 c5 2. c3 d5 3. exd5 Qxd5 4. d4 e6 5. Nf3
			variation => N__('Sicilian: Alapin, 2... d5 3.exd5 Qxd5 4. d4 e6 5. Nf3'),
			moves => {
			},
		},
		'r1b1kbnr/pp2pppp/2n5/2pq4/3P4/2P5/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'B22h',
			# TRANSLATORS: B22h: 1. e4 c5 2. c3 d5 3. exd5 Qxd5 4. d4 Nc6
			variation => N__('Sicilian: Alapin, 2... d5 3.exd5 Qxd5 4. d4 Nc6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'r1b1kbnr/pp2pppp/2n5/2pq4/3P4/2P2N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'B22h',
			# TRANSLATORS: B22h: 1. e4 c5 2. c3 d5 3. exd5 Qxd5 4. d4 Nc6 5. Nf3
			variation => N__('Sicilian: Alapin, 2... d5 3.exd5 Qxd5 4. d4 Nc6 5. Nf3'),
			moves => {
				'c5d4' => 1,
				'c8g4' => 1,
			},
		},
		'r1b1kbnr/pp2pppp/2n5/3q4/3p4/2P2N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'B22h',
			# TRANSLATORS: B22h: 1. e4 c5 2. c3 d5 3. exd5 Qxd5 4. d4 Nc6 5. Nf3 cxd4
			variation => N__('Sicilian: Alapin, 2... d5 3.exd5 Qxd5 4. d4 Nc6 5. Nf3 cxd4'),
			moves => {
				'c3d4' => 1,
			},
		},
		'r1b1kbnr/pp2pppp/2n5/3q4/3P4/5N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'B22h',
			# TRANSLATORS: B22h: 1. e4 c5 2. c3 d5 3. exd5 Qxd5 4. d4 Nc6 5. Nf3 cxd4 6. cxd4
			variation => N__('Sicilian: Alapin, 2... d5 3.exd5 Qxd5 4. d4 Nc6 5. Nf3 cxd4 6.cxd4'),
			moves => {
			},
		},
		'r3kbnr/pp2pppp/2n5/2pq4/3P2b1/2P2N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'B22i',
			# TRANSLATORS: B22i: 1. e4 c5 2. c3 d5 3. exd5 Qxd5 4. d4 Nc6 5. Nf3 Bg4
			variation => N__('Sicilian: Alapin, 2... d5 3.exd5 Qxd5 4. d4 Nc6 5. Nf3 Bg4'),
			moves => {
			},
		},
		'rnb1kb1r/pp2pppp/5n2/2pq4/3P4/2P5/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'B22j',
			# TRANSLATORS: B22j: 1. e4 c5 2. c3 d5 3. exd5 Qxd5 4. d4 Nf6
			variation => N__('Sicilian: Alapin, 2... d5 3.exd5 Qxd5 4. d4 Nf6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnb1kb1r/pp2pppp/5n2/2pq4/3P4/2P2N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'B22j',
			# TRANSLATORS: B22j: 1. e4 c5 2. c3 d5 3. exd5 Qxd5 4. d4 Nf6 5. Nf3
			variation => N__('Sicilian: Alapin, 2... d5 3.exd5 Qxd5 4. d4 Nf6 5. Nf3'),
			moves => {
				'c8g4' => 1,
				'e7e6' => 1,
			},
		},
		'rnb1kb1r/pp3ppp/4pn2/2pq4/3P4/2P2N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'B22j',
			# TRANSLATORS: B22j: 1. e4 c5 2. c3 d5 3. exd5 Qxd5 4. d4 Nf6 5. Nf3 e6
			variation => N__('Sicilian: Alapin, 2... d5 3.exd5 Qxd5 4. d4 Nf6 5. Nf3'),
			moves => {
				'c1e3' => 1,
				'f1e2' => 1,
			},
		},
		'rn2kb1r/pp2pppp/5n2/2pq4/3P2b1/2P2N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'B22k',
			# TRANSLATORS: B22k: 1. e4 c5 2. c3 d5 3. exd5 Qxd5 4. d4 Nf6 5. Nf3 Bg4
			variation => N__('Sicilian: Alapin, 2... d5 3.exd5 Qxd5 4. d4 Nf6 5. Nf3 Bg4'),
			moves => {
				'f1e2' => 1,
			},
		},
		'rn2kb1r/pp2pppp/5n2/2pq4/3P2b1/2P2N2/PP2BPPP/RNBQK2R b KQkq' => {
			eco => 'B22k',
			# TRANSLATORS: B22k: 1. e4 c5 2. c3 d5 3. exd5 Qxd5 4. d4 Nf6 5. Nf3 Bg4 6. Be2
			variation => N__('Sicilian: Alapin, 2... d5 3.exd5 Qxd5 4. d4 Nf6 5. Nf3 Bg4'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rn2kb1r/pp3ppp/4pn2/2pq4/3P2b1/2P2N2/PP2BPPP/RNBQK2R w KQkq' => {
			eco => 'B22l',
			# TRANSLATORS: B22l: 1. e4 c5 2. c3 d5 3. exd5 Qxd5 4. d4 Nf6 5. Nf3 Bg4 6. Be2 e6
			variation => N__('Sicilian: Alapin, 2... d5 3.exd5 Qxd5 4. d4 Nf6 5. Nf3 Bg4 6. Be2 e6'),
			moves => {
			},
		},
		'rnb1kb1r/pp3ppp/4pn2/2pq4/3P4/2P1BN2/PP3PPP/RN1QKB1R b KQkq' => {
			eco => 'B22m',
			# TRANSLATORS: B22m: 1. e4 c5 2. c3 d5 3. exd5 Qxd5 4. d4 Nf6 5. Nf3 e6 6. Be3
			variation => N__('Sicilian: Alapin, 2... d5 3.exd5 Qxd5 4. d4 Nf6 5. Nf3 e6 6. Be3'),
			moves => {
			},
		},
		'rnb1kb1r/pp3ppp/4pn2/2pq4/3P4/2P2N2/PP2BPPP/RNBQK2R b KQkq' => {
			eco => 'B22n',
			# TRANSLATORS: B22n: 1. e4 c5 2. c3 d5 3. exd5 Qxd5 4. d4 Nf6 5. Nf3 e6 6. Be2
			variation => N__('Sicilian: Alapin, 2... d5 3.exd5 Qxd5 4. d4 Nf6 5. Nf3 e6 6. Be2'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/2p5/4P3/2P5/PP1P1PPP/RNBQKBNR w KQkq' => {
			eco => 'B22o',
			# TRANSLATORS: B22o: 1. e4 c5 2. c3 Nf6
			variation => N__('Sicilian: Alapin, 2... Nf6'),
			moves => {
				'e4e5' => 1,
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/2p1P3/8/2P5/PP1P1PPP/RNBQKBNR b KQkq' => {
			eco => 'B22o',
			# TRANSLATORS: B22o: 1. e4 c5 2. c3 Nf6 3. e5
			variation => N__('Sicilian: Alapin, 2... Nf6 3. e5'),
			moves => {
				'f6d5' => 1,
			},
		},
		'rnbqkb1r/pp1ppppp/8/2pnP3/8/2P5/PP1P1PPP/RNBQKBNR w KQkq' => {
			eco => 'B22o',
			# TRANSLATORS: B22o: 1. e4 c5 2. c3 Nf6 3. e5 Nd5
			variation => N__('Sicilian: Alapin, 2... Nf6 3. e5 Nd5'),
			moves => {
				'd2d4' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/pp1ppppp/8/2pnP3/8/2P3P1/PP1P1P1P/RNBQKBNR b KQkq' => {
			eco => 'B22o',
			# TRANSLATORS: B22o: 1. e4 c5 2. c3 Nf6 3. e5 Nd5 4. g3
			variation => N__('Sicilian: Alapin, 2... Nf6 3. e5 Nd5 4. g3'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/8/2pnP3/3P4/2P5/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'B22p',
			# TRANSLATORS: B22p: 1. e4 c5 2. c3 Nf6 3. e5 Nd5 4. d4
			variation => N__('Sicilian: Alapin, 2... Nf6 3. e5 Nd5 4. d4'),
			moves => {
				'c5d4' => 1,
			},
		},
		'rnbqkb1r/pp1ppppp/8/2pnP3/8/2P2N2/PP1P1PPP/RNBQKB1R b KQkq' => {
			eco => 'B22p',
			# TRANSLATORS: B22p: 1. e4 c5 2. c3 Nf6 3. e5 Nd5 4. Nf3
			variation => N__('Sicilian: Alapin, 2... Nf6 3. e5 Nd5 4. Nf3'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkb1r/pp1ppppp/2n5/2pnP3/8/2P2N2/PP1P1PPP/RNBQKB1R w KQkq' => {
			eco => 'B22p',
			# TRANSLATORS: B22p: 1. e4 c5 2. c3 Nf6 3. e5 Nd5 4. Nf3 Nc6
			variation => N__('Sicilian: Alapin, 2... Nf6 3. e5 Nd5 4. Nf3 Nc6'),
			moves => {
				'b1a3' => 1,
			},
		},
		'r1bqkb1r/pp1ppppp/2n5/2pnP3/8/N1P2N2/PP1P1PPP/R1BQKB1R b KQkq' => {
			eco => 'B22p',
			# TRANSLATORS: B22p: 1. e4 c5 2. c3 Nf6 3. e5 Nd5 4. Nf3 Nc6 5. Na3
			variation => N__('Sicilian: Alapin, Heidenfeld Variation'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/8/3nP3/3p4/2P5/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'B22q',
			# TRANSLATORS: B22q: 1. e4 c5 2. c3 Nf6 3. e5 Nd5 4. d4 cxd4
			variation => N__('Sicilian: Alapin, 2... Nf6 3. e5 Nd5 4. d4 cxd4'),
			moves => {
				'c3d4' => 1,
				'd1d4' => 1,
				'f1c4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/pp1ppppp/8/3nP3/3Q4/2P5/PP3PPP/RNB1KBNR b KQkq' => {
			eco => 'B22q',
			# TRANSLATORS: B22q: 1. e4 c5 2. c3 Nf6 3. e5 Nd5 4. d4 cxd4 5. Qxd4
			variation => N__('Sicilian: Alapin, 2... Nf6, 5.Qxd4'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/8/3nP3/2Bp4/2P5/PP3PPP/RNBQK1NR b KQkq' => {
			eco => 'B22q',
			# TRANSLATORS: B22q: 1. e4 c5 2. c3 Nf6 3. e5 Nd5 4. d4 cxd4 5. Bc4
			variation => N__('Sicilian: Alapin, 2... Nf6, 5. Bc4'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/8/3nP3/3p4/2P2N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'B22r',
			# TRANSLATORS: B22r: 1. e4 c5 2. c3 Nf6 3. e5 Nd5 4. d4 cxd4 5. Nf3
			variation => N__('Sicilian: Alapin, 2... Nf6 3. e5 Nd5 4. d4 cxd4 5. Nf3'),
			moves => {
				'b8c6' => 1,
				'e7e6' => 1,
			},
		},
		'r1bqkb1r/pp1ppppp/2n5/3nP3/3p4/2P2N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'B22r',
			# TRANSLATORS: B22r: 1. e4 c5 2. c3 Nf6 3. e5 Nd5 4. d4 cxd4 5. Nf3 Nc6
			variation => N__('Sicilian: Alapin, 2... Nf6 3. e5 Nd5 4. d4 cxd4 5. Nf3 Nc6'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnbqkb1r/pp1p1ppp/4p3/3nP3/3p4/2P2N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'B22r',
			# TRANSLATORS: B22r: 1. e4 c5 2. c3 Nf6 3. e5 Nd5 4. d4 cxd4 5. Nf3 e6
			variation => N__('Sicilian: Alapin, 2... Nf6 3. e5 Nd5 4. d4 cxd4 5. Nf3 e6'),
			moves => {
			},
		},
		'r1bqkb1r/pp1ppppp/2n5/3nP3/2Bp4/2P2N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'B22s',
			# TRANSLATORS: B22s: 1. e4 c5 2. c3 Nf6 3. e5 Nd5 4. d4 cxd4 5. Nf3 Nc6 6. Bc4
			variation => N__('Sicilian: Alapin, 2... Nf6 3. e5 Nd5 4. d4 cxd4 5. Nf3 Nc6 6. Bc4'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/8/3nP3/3P4/8/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'B22t',
			# TRANSLATORS: B22t: 1. e4 c5 2. c3 Nf6 3. e5 Nd5 4. d4 cxd4 5. cxd4
			variation => N__('Sicilian: Alapin, 2... Nf6, 5.cxd4'),
			moves => {
				'b8c6' => 1,
				'd7d6' => 1,
				'e7e6' => 1,
			},
		},
		'r1bqkb1r/pp1ppppp/2n5/3nP3/3P4/8/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'B22t',
			# TRANSLATORS: B22t: 1. e4 c5 2. c3 Nf6 3. e5 Nd5 4. d4 cxd4 5. cxd4 Nc6
			variation => N__('Sicilian: Alapin, 2... Nf6, 5.cxd4 Nc6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'r1bqkb1r/pp1ppppp/2n5/3nP3/3P4/5N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'B22t',
			# TRANSLATORS: B22t: 1. e4 c5 2. c3 Nf6 3. e5 Nd5 4. d4 cxd4 5. cxd4 Nc6 6. Nf3
			variation => N__('Sicilian: Alapin, 2... Nf6, 5.cxd4 Nc6 6. Nf3'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/3p4/3nP3/3P4/8/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'B22t',
			# TRANSLATORS: B22t: 1. e4 c5 2. c3 Nf6 3. e5 Nd5 4. d4 cxd4 5. cxd4 d6
			variation => N__('Sicilian: Alapin, 2... Nf6, 5.cxd4 d6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/3p4/3nP3/3P4/5N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'B22t',
			# TRANSLATORS: B22t: 1. e4 c5 2. c3 Nf6 3. e5 Nd5 4. d4 cxd4 5. cxd4 d6 6. Nf3
			variation => N__('Sicilian: Alapin, 2... Nf6, 5.cxd4 d6'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkb1r/pp2pppp/2np4/3nP3/3P4/5N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'B22t',
			# TRANSLATORS: B22t: 1. e4 c5 2. c3 Nf6 3. e5 Nd5 4. d4 cxd4 5. cxd4 d6 6. Nf3 Nc6
			variation => N__('Sicilian: Alapin, 2... Nf6, 5.cxd4 d6 6. Nf3 Nc6'),
			moves => {
				'f1c4' => 1,
			},
		},
		'r1bqkb1r/pp2pppp/2np4/3nP3/2BP4/5N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'B22u',
			# TRANSLATORS: B22u: 1. e4 c5 2. c3 Nf6 3. e5 Nd5 4. d4 cxd4 5. cxd4 d6 6. Nf3 Nc6 7. Bc4
			variation => N__('Sicilian: Alapin, 2... Nf6, 5.cxd4 d6 6. Nf3 Nc6 7. Bc4'),
			moves => {
				'd5b6' => 1,
			},
		},
		'r1bqkb1r/pp2pppp/1nnp4/4P3/2BP4/5N2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'B22u',
			# TRANSLATORS: B22u: 1. e4 c5 2. c3 Nf6 3. e5 Nd5 4. d4 cxd4 5. cxd4 d6 6. Nf3 Nc6 7. Bc4 Nb6
			variation => N__('Sicilian: Alapin, 2... Nf6, 5.cxd4 d6 6. Nf3 Nc6 7. Bc4 Nb6'),
			moves => {
				'c4b5' => 1,
			},
		},
		'r1bqkb1r/pp2pppp/1nnp4/1B2P3/3P4/5N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'B22u',
			# TRANSLATORS: B22u: 1. e4 c5 2. c3 Nf6 3. e5 Nd5 4. d4 cxd4 5. cxd4 d6 6. Nf3 Nc6 7. Bc4 Nb6 8. Bb5
			variation => N__('Sicilian: Alapin, 2... Nf6, 5.cxd4 d6 6. Nf3 Nc6 7. Bc4 Nb6 8. Bb5'),
			moves => {
			},
		},
		'rnbqkb1r/pp1p1ppp/4p3/3nP3/3P4/8/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'B22v',
			# TRANSLATORS: B22v: 1. e4 c5 2. c3 Nf6 3. e5 Nd5 4. d4 cxd4 5. cxd4 e6
			variation => N__('Sicilian: Alapin, 2... Nf6, 5.cxd4 e6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/pp1p1ppp/4p3/3nP3/3P4/5N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'B22v',
			# TRANSLATORS: B22v: 1. e4 c5 2. c3 Nf6 3. e5 Nd5 4. d4 cxd4 5. cxd4 e6 6. Nf3
			variation => N__('Sicilian: Alapin, 2... Nf6, 5.cxd4 e6 6. Nf3'),
			moves => {
				'b7b6' => 1,
				'b8c6' => 1,
				'd7d6' => 1,
			},
		},
		'r1bqkb1r/pp1p1ppp/2n1p3/3nP3/3P4/5N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'B22v',
			# TRANSLATORS: B22v: 1. e4 c5 2. c3 Nf6 3. e5 Nd5 4. d4 cxd4 5. cxd4 e6 6. Nf3 Nc6
			variation => N__('Sicilian: Alapin, 2... Nf6, 5.cxd4 e6 6. Nf3 Nc6'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/3pp3/3nP3/3P4/5N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'B22w',
			# TRANSLATORS: B22w: 1. e4 c5 2. c3 Nf6 3. e5 Nd5 4. d4 cxd4 5. cxd4 e6 6. Nf3 d6
			variation => N__('Sicilian: Alapin, 2... Nf6, 5.cxd4 e6 6. Nf3 d6'),
			moves => {
			},
		},
		'rnbqkb1r/p2p1ppp/1p2p3/3nP3/3P4/5N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'B22x',
			# TRANSLATORS: B22x: 1. e4 c5 2. c3 Nf6 3. e5 Nd5 4. d4 cxd4 5. cxd4 e6 6. Nf3 b6
			variation => N__('Sicilian: Alapin, 2... Nf6, 5.cxd4 e6 6. Nf3 b6'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/8/2p5/4P3/2N5/PPPP1PPP/R1BQKBNR b KQkq' => {
			eco => 'B23a',
			# TRANSLATORS: B23a: 1. e4 c5 2. Nc3
			variation => N__('Sicilian: Closed'),
			moves => {
				'b8c6' => 1,
				'd7d6' => 1,
				'e7e6' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkbnr/pp1ppp1p/6p1/2p5/4P3/2N5/PPPP1PPP/R1BQKBNR w KQkq' => {
			eco => 'B23b',
			# TRANSLATORS: B23b: 1. e4 c5 2. Nc3 g6
			variation => N__('Sicilian: Closed'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/3p4/2p5/4P3/2N5/PPPP1PPP/R1BQKBNR w KQkq' => {
			eco => 'B23c',
			# TRANSLATORS: B23c: 1. e4 c5 2. Nc3 d6
			variation => N__('Sicilian: Closed'),
			moves => {
				'f2f4' => 1,
				'g1e2' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/3p4/2p5/4P3/2N5/PPPPNPPP/R1BQKB1R b KQkq' => {
			eco => 'B23c',
			# TRANSLATORS: B23c: 1. e4 c5 2. Nc3 d6 3. Nge2
			variation => N__('Sicilian: Closed'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/3p4/2p5/4P3/2N3P1/PPPP1P1P/R1BQKBNR b KQkq' => {
			eco => 'B23d',
			# TRANSLATORS: B23d: 1. e4 c5 2. Nc3 d6 3. g3
			variation => N__('Sicilian: Closed'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/3p4/2p5/4PP2/2N5/PPPP2PP/R1BQKBNR b KQkq' => {
			eco => 'B23e',
			# TRANSLATORS: B23e: 1. e4 c5 2. Nc3 d6 3. f4
			variation => N__('Sicilian: Closed'),
			moves => {
			},
		},
		'rnbqkbnr/pp1p1ppp/4p3/2p5/4P3/2N5/PPPP1PPP/R1BQKBNR w KQkq' => {
			eco => 'B23f',
			# TRANSLATORS: B23f: 1. e4 c5 2. Nc3 e6
			variation => N__('Sicilian: Closed'),
			moves => {
				'f2f4' => 1,
				'g1e2' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/pp1p1ppp/4p3/2p5/4PP2/2N5/PPPP2PP/R1BQKBNR b KQkq' => {
			eco => 'B23g',
			# TRANSLATORS: B23g: 1. e4 c5 2. Nc3 e6 3. f4
			variation => N__('Sicilian: Closed'),
			moves => {
			},
		},
		'rnbqkbnr/pp1p1ppp/4p3/2p5/4P3/2N5/PPPPNPPP/R1BQKB1R b KQkq' => {
			eco => 'B23h',
			# TRANSLATORS: B23h: 1. e4 c5 2. Nc3 e6 3. Nge2
			variation => N__('Sicilian: Closed'),
			moves => {
			},
		},
		'rnbqkbnr/pp1p1ppp/4p3/2p5/4P3/2N3P1/PPPP1P1P/R1BQKBNR b KQkq' => {
			eco => 'B23i',
			# TRANSLATORS: B23i: 1. e4 c5 2. Nc3 e6 3. g3
			variation => N__('Sicilian: Closed'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/4p3/2pp4/4P3/2N3P1/PPPP1P1P/R1BQKBNR w KQkq' => {
			eco => 'B23j',
			# TRANSLATORS: B23j: 1. e4 c5 2. Nc3 e6 3. g3 d5
			variation => N__('Sicilian: Closed, Korchnoi Variation'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/2p5/4P3/2N5/PPPP1PPP/R1BQKBNR w KQkq' => {
			eco => 'B23k',
			# TRANSLATORS: B23k: 1. e4 c5 2. Nc3 Nc6
			variation => N__('Sicilian: Closed, 2... Nc6'),
			moves => {
				'f1b5' => 1,
				'f2f4' => 1,
				'g1e2' => 1,
				'g2g3' => 1,
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/1Bp5/4P3/2N5/PPPP1PPP/R1BQK1NR b KQkq' => {
			eco => 'B23l',
			# TRANSLATORS: B23l: 1. e4 c5 2. Nc3 Nc6 3. Bb5
			variation => N__('Sicilian: Closed, 2... Nc6 3. Bb5'),
			moves => {
				'c6d4' => 1,
			},
		},
		'r1bqkbnr/pp1ppppp/8/1Bp5/3nP3/2N5/PPPP1PPP/R1BQK1NR w KQkq' => {
			eco => 'B23m',
			# TRANSLATORS: B23m: 1. e4 c5 2. Nc3 Nc6 3. Bb5 Nd4
			variation => N__('Sicilian: Closed, 2... Nc6 3. Bb5 Nd4'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/2p5/4P3/2N5/PPPPNPPP/R1BQKB1R b KQkq' => {
			eco => 'B23n',
			# TRANSLATORS: B23n: 1. e4 c5 2. Nc3 Nc6 3. Nge2
			variation => N__('Sicilian: Chameleon Variation'),
			moves => {
				'e7e5' => 1,
				'g7g6' => 1,
			},
		},
		'r1bqkbnr/pp1p1ppp/2n5/2p1p3/4P3/2N5/PPPPNPPP/R1BQKB1R w KQkq' => {
			eco => 'B23n',
			# TRANSLATORS: B23n: 1. e4 c5 2. Nc3 Nc6 3. Nge2 e5
			variation => N__('Sicilian: Chameleon, 3... e5'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppp1p/2n3p1/2p5/4P3/2N5/PPPPNPPP/R1BQKB1R w KQkq' => {
			eco => 'B23n',
			# TRANSLATORS: B23n: 1. e4 c5 2. Nc3 Nc6 3. Nge2 g6
			variation => N__('Sicilian: Chameleon, 3... g6'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/2p5/4PP2/2N5/PPPP2PP/R1BQKBNR b KQkq' => {
			eco => 'B23o',
			# TRANSLATORS: B23o: 1. e4 c5 2. Nc3 Nc6 3. f4
			variation => N__('Sicilian: Closed, Grand Prix'),
			moves => {
				'd7d6' => 1,
				'e7e6' => 1,
				'g7g6' => 1,
			},
		},
		'r1bqkbnr/pp2pppp/2np4/2p5/4PP2/2N5/PPPP2PP/R1BQKBNR w KQkq' => {
			eco => 'B23o',
			# TRANSLATORS: B23o: 1. e4 c5 2. Nc3 Nc6 3. f4 d6
			variation => N__('Sicilian: Closed, Grand Prix, 3... d6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'r1bqkbnr/pp2pppp/2np4/2p5/4PP2/2N2N2/PPPP2PP/R1BQKB1R b KQkq' => {
			eco => 'B23o',
			# TRANSLATORS: B23o: 1. e4 c5 2. Nc3 Nc6 3. f4 d6 4. Nf3
			variation => N__('Sicilian: Closed, Grand Prix, 3... d6'),
			moves => {
				'g7g6' => 1,
			},
		},
		'r1bqkbnr/pp2pp1p/2np2p1/2p5/4PP2/2N2N2/PPPP2PP/R1BQKB1R w KQkq' => {
			eco => 'B23p',
			# TRANSLATORS: B23p: 1. e4 c5 2. Nc3 Nc6 3. f4 d6 4. Nf3 g6
			variation => N__('Sicilian: Closed, Grand Prix, 3... d6 4. Nf3 g6'),
			moves => {
			},
		},
		'r1bqkbnr/pp1p1ppp/2n1p3/2p5/4PP2/2N5/PPPP2PP/R1BQKBNR w KQkq' => {
			eco => 'B23q',
			# TRANSLATORS: B23q: 1. e4 c5 2. Nc3 Nc6 3. f4 e6
			variation => N__('Sicilian: Closed, Grand Prix, 3... e6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'r1bqkbnr/pp1p1ppp/2n1p3/2p5/4PP2/2N2N2/PPPP2PP/R1BQKB1R b KQkq' => {
			eco => 'B23q',
			# TRANSLATORS: B23q: 1. e4 c5 2. Nc3 Nc6 3. f4 e6 4. Nf3
			variation => N__('Sicilian: Closed, Grand Prix, 3... e6 4. Nf3'),
			moves => {
				'd7d5' => 1,
			},
		},
		'r1bqkbnr/pp3ppp/2n1p3/2pp4/4PP2/2N2N2/PPPP2PP/R1BQKB1R w KQkq' => {
			eco => 'B23r',
			# TRANSLATORS: B23r: 1. e4 c5 2. Nc3 Nc6 3. f4 e6 4. Nf3 d5
			variation => N__('Sicilian: Closed, Grand Prix, 3... e6 4. Nf3 d5'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppp1p/2n3p1/2p5/4PP2/2N5/PPPP2PP/R1BQKBNR w KQkq' => {
			eco => 'B23s',
			# TRANSLATORS: B23s: 1. e4 c5 2. Nc3 Nc6 3. f4 g6
			variation => N__('Sicilian: Closed, Grand Prix, 3... g6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'r1bqkbnr/pp1ppp1p/2n3p1/2p5/4PP2/2N2N2/PPPP2PP/R1BQKB1R b KQkq' => {
			eco => 'B23s',
			# TRANSLATORS: B23s: 1. e4 c5 2. Nc3 Nc6 3. f4 g6 4. Nf3
			variation => N__('Sicilian: Closed, Grand Prix, 3... g6'),
			moves => {
				'f8g7' => 1,
			},
		},
		'r1bqk1nr/pp1pppbp/2n3p1/2p5/4PP2/2N2N2/PPPP2PP/R1BQKB1R w KQkq' => {
			eco => 'B23s',
			# TRANSLATORS: B23s: 1. e4 c5 2. Nc3 Nc6 3. f4 g6 4. Nf3 Bg7
			variation => N__('Sicilian: Closed, Grand Prix, 3... g6'),
			moves => {
				'f1b5' => 1,
				'f1c4' => 1,
			},
		},
		'r1bqk1nr/pp1pppbp/2n3p1/2p5/2B1PP2/2N2N2/PPPP2PP/R1BQK2R b KQkq' => {
			eco => 'B23t',
			# TRANSLATORS: B23t: 1. e4 c5 2. Nc3 Nc6 3. f4 g6 4. Nf3 Bg7 5. Bc4
			variation => N__('Sicilian: Closed, Grand Prix, 3... g6 4. Nf3 Bg7 5. Bc4'),
			moves => {
				'e7e6' => 1,
			},
		},
		'r1bqk1nr/pp1p1pbp/2n1p1p1/2p5/2B1PP2/2N2N2/PPPP2PP/R1BQK2R w KQkq' => {
			eco => 'B23u',
			# TRANSLATORS: B23u: 1. e4 c5 2. Nc3 Nc6 3. f4 g6 4. Nf3 Bg7 5. Bc4 e6
			variation => N__('Sicilian: Closed, Grand Prix, 3... g6 4. Nf3 Bg7 5. Bc4 e6'),
			moves => {
				'f4f5' => 1,
			},
		},
		'r1bqk1nr/pp1p1pbp/2n1p1p1/2p2P2/2B1P3/2N2N2/PPPP2PP/R1BQK2R b KQkq' => {
			eco => 'B23v',
			# TRANSLATORS: B23v: 1. e4 c5 2. Nc3 Nc6 3. f4 g6 4. Nf3 Bg7 5. Bc4 e6 6. f5
			variation => N__('Sicilian: Closed, Grand Prix, Schofman Variation'),
			moves => {
			},
		},
		'r1bqk1nr/pp1pppbp/2n3p1/1Bp5/4PP2/2N2N2/PPPP2PP/R1BQK2R b KQkq' => {
			eco => 'B23w',
			# TRANSLATORS: B23w: 1. e4 c5 2. Nc3 Nc6 3. f4 g6 4. Nf3 Bg7 5. Bb5
			variation => N__('Sicilian: Closed, Grand Prix, 3... g6 4. Nf3 Bg7 5. Bb5'),
			moves => {
				'c6d4' => 1,
			},
		},
		'r1bqk1nr/pp1pppbp/6p1/1Bp5/3nPP2/2N2N2/PPPP2PP/R1BQK2R w KQkq' => {
			eco => 'B23w',
			# TRANSLATORS: B23w: 1. e4 c5 2. Nc3 Nc6 3. f4 g6 4. Nf3 Bg7 5. Bb5 Nd4
			variation => N__('Sicilian: Closed, Grand Prix, 3... g6 4. Nf3 Bg7 5. Bb5 Nd4'),
			moves => {
				'b5d3' => 1,
				'e1g1' => 1,
			},
		},
		'r1bqk1nr/pp1pppbp/6p1/2p5/3nPP2/2NB1N2/PPPP2PP/R1BQK2R b KQkq' => {
			eco => 'B23x',
			# TRANSLATORS: B23x: 1. e4 c5 2. Nc3 Nc6 3. f4 g6 4. Nf3 Bg7 5. Bb5 Nd4 6. Bd3
			variation => N__('Sicilian: Closed, Grand Prix, 3... g6 4. Nf3 Bg7 5. Bb5 Nd4 6. Bd3'),
			moves => {
			},
		},
		'r1bqk1nr/pp1pppbp/6p1/1Bp5/3nPP2/2N2N2/PPPP2PP/R1BQ1RK1 b kq' => {
			eco => 'B23y',
			# TRANSLATORS: B23y: 1. e4 c5 2. Nc3 Nc6 3. f4 g6 4. Nf3 Bg7 5. Bb5 Nd4 6. O-O
			variation => N__('Sicilian: Closed, Grand Prix, 3... g6 4. Nf3 Bg7 5. Bb5 Nd4 6.O-O'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/2p5/4P3/2N3P1/PPPP1P1P/R1BQKBNR b KQkq' => {
			eco => 'B24',
			# TRANSLATORS: B24: 1. e4 c5 2. Nc3 Nc6 3. g3
			variation => N__('Sicilian: Closed, 3. g3'),
			moves => {
				'e7e6' => 1,
				'g7g6' => 1,
			},
		},
		'r1bqkbnr/pp1p1ppp/2n1p3/2p5/4P3/2N3P1/PPPP1P1P/R1BQKBNR w KQkq' => {
			eco => 'B24',
			# TRANSLATORS: B24: 1. e4 c5 2. Nc3 Nc6 3. g3 e6
			variation => N__('Sicilian: Closed, 3. g3 e6'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppp1p/2n3p1/2p5/4P3/2N3P1/PPPP1P1P/R1BQKBNR w KQkq' => {
			eco => 'B24',
			# TRANSLATORS: B24: 1. e4 c5 2. Nc3 Nc6 3. g3 g6
			variation => N__('Sicilian: Closed, 3. g3 g6'),
			moves => {
				'd2d3' => 1,
				'f1g2' => 1,
			},
		},
		'r1bqkbnr/pp1ppp1p/2n3p1/2p5/4P3/2NP2P1/PPP2P1P/R1BQKBNR b KQkq' => {
			eco => 'B24',
			# TRANSLATORS: B24: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. d3
			variation => N__('Sicilian: Closed, 3. g3 g6'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppp1p/2n3p1/2p5/4P3/2N3P1/PPPP1PBP/R1BQK1NR b KQkq' => {
			eco => 'B24',
			# TRANSLATORS: B24: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2
			variation => N__('Sicilian: Closed, 3. g3 g6'),
			moves => {
				'f8g7' => 1,
			},
		},
		'r1bqk1nr/pp1pppbp/2n3p1/2p5/4P3/2N3P1/PPPP1PBP/R1BQK1NR w KQkq' => {
			eco => 'B24',
			# TRANSLATORS: B24: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7
			variation => N__('Sicilian: Closed, 3. g3 g6'),
			moves => {
				'd2d3' => 1,
				'f2f4' => 1,
				'g1e2' => 1,
			},
		},
		'r1bqk1nr/pp1pppbp/2n3p1/2p5/4P3/2NP2P1/PPP2PBP/R1BQK1NR b KQkq' => {
			eco => 'B24',
			# TRANSLATORS: B24: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3
			variation => N__('Sicilian: Closed, 3. g3 g6, 5. d3'),
			moves => {
				'd7d6' => 1,
				'e7e6' => 1,
			},
		},
		'r1bqk1nr/pp1p1pbp/2n1p1p1/2p5/4P3/2NP2P1/PPP2PBP/R1BQK1NR w KQkq' => {
			eco => 'B24',
			# TRANSLATORS: B24: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 e6
			variation => N__('Sicilian: Closed, 3. g3 g6, 5. d3 e6'),
			moves => {
				'c1e3' => 1,
				'f2f4' => 1,
			},
		},
		'r1bqk1nr/pp1p1pbp/2n1p1p1/2p5/4P3/2NPB1P1/PPP2PBP/R2QK1NR b KQkq' => {
			eco => 'B24',
			# TRANSLATORS: B24: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 e6 6. Be3
			variation => N__('Sicilian: Closed, 3. g3 g6, 5. d3 e6'),
			moves => {
				'c6d4' => 1,
			},
		},
		'r1bqk1nr/pp1p1pbp/4p1p1/2p5/3nP3/2NPB1P1/PPP2PBP/R2QK1NR w KQkq' => {
			eco => 'B24',
			# TRANSLATORS: B24: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 e6 6. Be3 Nd4
			variation => N__('Sicilian: Closed, 3. g3 g6, 5. d3 e6'),
			moves => {
				'c3e2' => 1,
			},
		},
		'r1bqk1nr/pp1p1pbp/4p1p1/2p5/3nP3/3PB1P1/PPP1NPBP/R2QK1NR b KQkq' => {
			eco => 'B24',
			# TRANSLATORS: B24: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 e6 6. Be3 Nd4 7. Nce2
			variation => N__('Sicilian: Closed, Smyslov Variation'),
			moves => {
			},
		},
		'r1bqk1nr/pp1p1pbp/2n1p1p1/2p5/4PP2/2NP2P1/PPP3BP/R1BQK1NR b KQkq' => {
			eco => 'B24',
			# TRANSLATORS: B24: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 e6 6. f4
			variation => N__('Sicilian: Closed, 3. g3 g6, 5. d3 e6 6. f4'),
			moves => {
			},
		},
		'r1bqk1nr/pp1pppbp/2n3p1/2p5/4PP2/2N3P1/PPPP2BP/R1BQK1NR b KQkq' => {
			eco => 'B24',
			# TRANSLATORS: B24: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. f4
			variation => N__('Sicilian: Closed, 3. g3 g6, 5. f4'),
			moves => {
			},
		},
		'r1bqk1nr/pp1pppbp/2n3p1/2p5/4P3/2N3P1/PPPPNPBP/R1BQK2R b KQkq' => {
			eco => 'B24',
			# TRANSLATORS: B24: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. Nge2
			variation => N__('Sicilian: Closed, 3. g3 g6, 5.Nge2'),
			moves => {
			},
		},
		'r1bqk1nr/pp2ppbp/2np2p1/2p5/4P3/2NP2P1/PPP2PBP/R1BQK1NR w KQkq' => {
			eco => 'B25a',
			# TRANSLATORS: B25a: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6
			variation => N__('Sicilian: Closed, 3. g3, 5. d3 d6'),
			moves => {
				'c1e3' => 1,
				'f2f4' => 1,
				'g1e2' => 1,
			},
		},
		'r1bqk1nr/pp2ppbp/2np2p1/2p5/4P3/2NP2P1/PPP1NPBP/R1BQK2R b KQkq' => {
			eco => 'B25b',
			# TRANSLATORS: B25b: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. Nge2
			variation => N__('Sicilian: Closed, 3. g3, 5. d3 d6 6.Nge2'),
			moves => {
				'e7e5' => 1,
				'e7e6' => 1,
			},
		},
		'r1bqk1nr/pp3pbp/2np2p1/2p1p3/4P3/2NP2P1/PPP1NPBP/R1BQK2R w KQkq' => {
			eco => 'B25c',
			# TRANSLATORS: B25c: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. Nge2 e5
			variation => N__('Sicilian: Closed, Botvinnik'),
			moves => {
			},
		},
		'r1bqk1nr/pp3pbp/2npp1p1/2p5/4P3/2NP2P1/PPP1NPBP/R1BQK2R w KQkq' => {
			eco => 'B25d',
			# TRANSLATORS: B25d: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. Nge2 e6
			variation => N__('Sicilian: Closed, 3. g3, 5. d3 d6 6.Nge2 e6'),
			moves => {
			},
		},
		'r1bqk1nr/pp2ppbp/2np2p1/2p5/4PP2/2NP2P1/PPP3BP/R1BQK1NR b KQkq' => {
			eco => 'B25e',
			# TRANSLATORS: B25e: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. f4
			variation => N__('Sicilian: Closed, 6. f4'),
			moves => {
				'a8b8' => 1,
				'e7e5' => 1,
				'e7e6' => 1,
				'g8f6' => 1,
			},
		},
		'1rbqk1nr/pp2ppbp/2np2p1/2p5/4PP2/2NP2P1/PPP3BP/R1BQK1NR w KQk' => {
			eco => 'B25f',
			# TRANSLATORS: B25f: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. f4 Rb8
			variation => N__('Sicilian: Closed, 6. f4 Rb8'),
			moves => {
			},
		},
		'r1bqk2r/pp2ppbp/2np1np1/2p5/4PP2/2NP2P1/PPP3BP/R1BQK1NR w KQkq' => {
			eco => 'B25g',
			# TRANSLATORS: B25g: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. f4 Nf6
			variation => N__('Sicilian: Closed, 6. f4 Nf6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'r1bqk2r/pp2ppbp/2np1np1/2p5/4PP2/2NP1NP1/PPP3BP/R1BQK2R b KQkq' => {
			eco => 'B25h',
			# TRANSLATORS: B25h: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. f4 Nf6 7. Nf3
			variation => N__('Sicilian: Closed, 6. f4 Nf6 7. Nf3'),
			moves => {
			},
		},
		'r1bqk1nr/pp3pbp/2np2p1/2p1p3/4PP2/2NP2P1/PPP3BP/R1BQK1NR w KQkq' => {
			eco => 'B25i',
			# TRANSLATORS: B25i: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. f4 e5
			variation => N__('Sicilian: Closed, 6. f4 e5'),
			moves => {
				'g1f3' => 1,
			},
		},
		'r1bqk1nr/pp3pbp/2np2p1/2p1p3/4PP2/2NP1NP1/PPP3BP/R1BQK2R b KQkq' => {
			eco => 'B25j',
			# TRANSLATORS: B25j: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. f4 e5 7. Nf3
			variation => N__('Sicilian: Closed, 6. f4 e5 7. Nf3'),
			moves => {
				'g8e7' => 1,
			},
		},
		'r1bqk2r/pp2npbp/2np2p1/2p1p3/4PP2/2NP1NP1/PPP3BP/R1BQK2R w KQkq' => {
			eco => 'B25j',
			# TRANSLATORS: B25j: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. f4 e5 7. Nf3 Nge7
			variation => N__('Sicilian: Closed, 6. f4 e5 7. Nf3 Nge7'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqk2r/pp2npbp/2np2p1/2p1p3/4PP2/2NP1NP1/PPP3BP/R1BQ1RK1 b kq' => {
			eco => 'B25k',
			# TRANSLATORS: B25k: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. f4 e5 7. Nf3 Nge7 8. O-O
			variation => N__('Sicilian: Closed, 6. f4 e5 7. Nf3 Nge7 8.O-O'),
			moves => {
			},
		},
		'r1bqk1nr/pp3pbp/2npp1p1/2p5/4PP2/2NP2P1/PPP3BP/R1BQK1NR w KQkq' => {
			eco => 'B25l',
			# TRANSLATORS: B25l: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. f4 e6
			variation => N__('Sicilian: Closed, 6. f4 e6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'r1bqk1nr/pp3pbp/2npp1p1/2p5/4PP2/2NP1NP1/PPP3BP/R1BQK2R b KQkq' => {
			eco => 'B25m',
			# TRANSLATORS: B25m: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. f4 e6 7. Nf3
			variation => N__('Sicilian: Closed, 6. f4 e6'),
			moves => {
				'g8e7' => 1,
			},
		},
		'r1bqk2r/pp2npbp/2npp1p1/2p5/4PP2/2NP1NP1/PPP3BP/R1BQK2R w KQkq' => {
			eco => 'B25n',
			# TRANSLATORS: B25n: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. f4 e6 7. Nf3 Nge7
			variation => N__('Sicilian: Closed, 6. f4 e6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqk2r/pp2npbp/2npp1p1/2p5/4PP2/2NP1NP1/PPP3BP/R1BQ1RK1 b kq' => {
			eco => 'B25o',
			# TRANSLATORS: B25o: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. f4 e6 7. Nf3 Nge7 8. O-O
			variation => N__('Sicilian: Closed, 6. f4 e6'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp2npbp/2npp1p1/2p5/4PP2/2NP1NP1/PPP3BP/R1BQ1RK1 w -' => {
			eco => 'B25p',
			# TRANSLATORS: B25p: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. f4 e6 7. Nf3 Nge7 8. O-O O-O
			variation => N__('Sicilian: Closed, 6. f4 e6'),
			moves => {
				'c1e3' => 1,
			},
		},
		'r1bq1rk1/pp2npbp/2npp1p1/2p5/4PP2/2NPBNP1/PPP3BP/R2Q1RK1 b -' => {
			eco => 'B25q',
			# TRANSLATORS: B25q: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. f4 e6 7. Nf3 Nge7 8. O-O O-O 9. Be3
			variation => N__('Sicilian: Closed, 6. f4 e6: 9. Be3'),
			moves => {
				'a8b8' => 1,
				'b7b6' => 1,
				'c6d4' => 1,
			},
		},
		'1rbq1rk1/pp2npbp/2npp1p1/2p5/4PP2/2NPBNP1/PPP3BP/R2Q1RK1 w -' => {
			eco => 'B25r',
			# TRANSLATORS: B25r: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. f4 e6 7. Nf3 Nge7 8. O-O O-O 9. Be3 Rb8
			variation => N__('Sicilian: Closed, 6. f4 e6: 9. Be3 Rb8'),
			moves => {
			},
		},
		'r1bq1rk1/p3npbp/1pnpp1p1/2p5/4PP2/2NPBNP1/PPP3BP/R2Q1RK1 w -' => {
			eco => 'B25s',
			# TRANSLATORS: B25s: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. f4 e6 7. Nf3 Nge7 8. O-O O-O 9. Be3 b6
			variation => N__('Sicilian: Closed, 6. f4 e6: 9. Be3 b6'),
			moves => {
			},
		},
		'r1bq1rk1/pp2npbp/3pp1p1/2p5/3nPP2/2NPBNP1/PPP3BP/R2Q1RK1 w -' => {
			eco => 'B25t',
			# TRANSLATORS: B25t: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. f4 e6 7. Nf3 Nge7 8. O-O O-O 9. Be3 Nd4
			variation => N__('Sicilian: Closed, 6. f4 e6: 9. Be3 Nd4'),
			moves => {
				'a1b1' => 1,
				'd1d2' => 1,
				'e4e5' => 1,
			},
		},
		'r1bq1rk1/pp2npbp/3pp1p1/2p5/3nPP2/2NPBNP1/PPP3BP/1R1Q1RK1 b -' => {
			eco => 'B25u',
			# TRANSLATORS: B25u: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. f4 e6 7. Nf3 Nge7 8. O-O O-O 9. Be3 Nd4 10. Rb1
			variation => N__('Sicilian: Closed, 6. f4 e6: 9. Be3 Nd4 10. Rb1'),
			moves => {
			},
		},
		'r1bq1rk1/pp2npbp/3pp1p1/2p5/3nPP2/2NPBNP1/PPPQ2BP/R4RK1 b -' => {
			eco => 'B25v',
			# TRANSLATORS: B25v: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. f4 e6 7. Nf3 Nge7 8. O-O O-O 9. Be3 Nd4 10. Qd2
			variation => N__('Sicilian: Closed, 6. f4 e6: 9. Be3 Nd4 10. Qd2'),
			moves => {
			},
		},
		'r1bq1rk1/pp2npbp/3pp1p1/2p1P3/3n1P2/2NPBNP1/PPP3BP/R2Q1RK1 b -' => {
			eco => 'B25w',
			# TRANSLATORS: B25w: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. f4 e6 7. Nf3 Nge7 8. O-O O-O 9. Be3 Nd4 10. e5
			variation => N__('Sicilian: Closed, 6. f4 e6: 9. Be3 Nd4 10. e5'),
			moves => {
				'e7f5' => 1,
			},
		},
		'r1bq1rk1/pp3pbp/3pp1p1/2p1Pn2/3n1P2/2NPBNP1/PPP3BP/R2Q1RK1 w -' => {
			eco => 'B25x',
			# TRANSLATORS: B25x: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. f4 e6 7. Nf3 Nge7 8. O-O O-O 9. Be3 Nd4 10. e5 Nef5
			variation => N__('Sicilian: Closed, 6. f4 e6: 9. Be3 Nd4 10. e5 Nef5'),
			moves => {
			},
		},
		'r1bqk1nr/pp2ppbp/2np2p1/2p5/4P3/2NPB1P1/PPP2PBP/R2QK1NR b KQkq' => {
			eco => 'B26a',
			# TRANSLATORS: B26a: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. Be3
			variation => N__('Sicilian: Closed, 6. Be3'),
			moves => {
				'a8b8' => 1,
				'e7e5' => 1,
				'e7e6' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqk2r/pp2ppbp/2np1np1/2p5/4P3/2NPB1P1/PPP2PBP/R2QK1NR w KQkq' => {
			eco => 'B26b',
			# TRANSLATORS: B26b: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. Be3 Nf6
			variation => N__('Sicilian: Closed, 6. Be3 Nf6'),
			moves => {
				'h2h3' => 1,
			},
		},
		'r1bqk2r/pp2ppbp/2np1np1/2p5/4P3/2NPB1PP/PPP2PB1/R2QK1NR b KQkq' => {
			eco => 'B26c',
			# TRANSLATORS: B26c: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. Be3 Nf6 7. h3
			variation => N__('Sicilian: Closed, 6. Be3 Nf6 7. h3'),
			moves => {
			},
		},
		'r1bqk1nr/pp3pbp/2np2p1/2p1p3/4P3/2NPB1P1/PPP2PBP/R2QK1NR w KQkq' => {
			eco => 'B26d',
			# TRANSLATORS: B26d: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. Be3 e5
			variation => N__('Sicilian: Closed, 6. Be3 e5'),
			moves => {
				'd1d2' => 1,
			},
		},
		'r1bqk1nr/pp3pbp/2np2p1/2p1p3/4P3/2NPB1P1/PPPQ1PBP/R3K1NR b KQkq' => {
			eco => 'B26e',
			# TRANSLATORS: B26e: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. Be3 e5 7. Qd2
			variation => N__('Sicilian: Closed, 6. Be3 e5 7. Qd2'),
			moves => {
				'g8e7' => 1,
			},
		},
		'r1bqk2r/pp2npbp/2np2p1/2p1p3/4P3/2NPB1P1/PPPQ1PBP/R3K1NR w KQkq' => {
			eco => 'B26f',
			# TRANSLATORS: B26f: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. Be3 e5 7. Qd2 Nge7
			variation => N__('Sicilian: Closed, 6. Be3 e5 7. Qd2 Nge7'),
			moves => {
			},
		},
		'1rbqk1nr/pp2ppbp/2np2p1/2p5/4P3/2NPB1P1/PPP2PBP/R2QK1NR w KQk' => {
			eco => 'B26g',
			# TRANSLATORS: B26g: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. Be3 Rb8
			variation => N__('Sicilian: Closed, 6. Be3 Rb8'),
			moves => {
				'd1d2' => 1,
			},
		},
		'1rbqk1nr/pp2ppbp/2np2p1/2p5/4P3/2NPB1P1/PPPQ1PBP/R3K1NR b KQk' => {
			eco => 'B26h',
			# TRANSLATORS: B26h: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. Be3 Rb8 7. Qd2
			variation => N__('Sicilian: Closed, 6. Be3 Rb8 7. Qd2'),
			moves => {
				'b7b5' => 1,
			},
		},
		'1rbqk1nr/p3ppbp/2np2p1/1pp5/4P3/2NPB1P1/PPPQ1PBP/R3K1NR w KQk' => {
			eco => 'B26i',
			# TRANSLATORS: B26i: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. Be3 Rb8 7. Qd2 b5
			variation => N__('Sicilian: Closed, 6. Be3 Rb8 7. Qd2 b5'),
			moves => {
				'g1e2' => 1,
			},
		},
		'1rbqk1nr/p3ppbp/2np2p1/1pp5/4P3/2NPB1P1/PPPQNPBP/R3K2R b KQk' => {
			eco => 'B26j',
			# TRANSLATORS: B26j: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. Be3 Rb8 7. Qd2 b5 8. Nge2
			variation => N__('Sicilian: Closed, 6. Be3 Rb8 7. Qd2 b5 8.Nge2'),
			moves => {
			},
		},
		'r1bqk1nr/pp3pbp/2npp1p1/2p5/4P3/2NPB1P1/PPP2PBP/R2QK1NR w KQkq' => {
			eco => 'B26k',
			# TRANSLATORS: B26k: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. Be3 e6
			variation => N__('Sicilian: Closed, 6. Be3 e6'),
			moves => {
				'd1d2' => 1,
			},
		},
		'r1bqk1nr/pp3pbp/2npp1p1/2p5/4P3/2NPB1P1/PPPQ1PBP/R3K1NR b KQkq' => {
			eco => 'B26l',
			# TRANSLATORS: B26l: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. Be3 e6 7. Qd2
			variation => N__('Sicilian: Closed, 6. Be3 e6 7. Qd2'),
			moves => {
				'a8b8' => 1,
				'c6d4' => 1,
				'd8a5' => 1,
				'g8e7' => 1,
			},
		},
		'r1b1k1nr/pp3pbp/2npp1p1/q1p5/4P3/2NPB1P1/PPPQ1PBP/R3K1NR w KQkq' => {
			eco => 'B26m',
			# TRANSLATORS: B26m: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. Be3 e6 7. Qd2 Qa5
			variation => N__('Sicilian: Closed, 6. Be3 e6 7. Qd2 Qa5'),
			moves => {
			},
		},
		'r1bqk1nr/pp3pbp/3pp1p1/2p5/3nP3/2NPB1P1/PPPQ1PBP/R3K1NR w KQkq' => {
			eco => 'B26n',
			# TRANSLATORS: B26n: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. Be3 e6 7. Qd2 Nd4
			variation => N__('Sicilian: Closed, 6. Be3 e6 7. Qd2 Nd4'),
			moves => {
			},
		},
		'r1bqk2r/pp2npbp/2npp1p1/2p5/4P3/2NPB1P1/PPPQ1PBP/R3K1NR w KQkq' => {
			eco => 'B26o',
			# TRANSLATORS: B26o: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. Be3 e6 7. Qd2 Nge7
			variation => N__('Sicilian: Closed, 6. Be3 e6 7. Qd2 Nge7'),
			moves => {
			},
		},
		'1rbqk1nr/pp3pbp/2npp1p1/2p5/4P3/2NPB1P1/PPPQ1PBP/R3K1NR w KQk' => {
			eco => 'B26p',
			# TRANSLATORS: B26p: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. Be3 e6 7. Qd2 Rb8
			variation => N__('Sicilian: Closed, 6. Be3 e6 7. Qd2 Rb8'),
			moves => {
				'g1e2' => 1,
			},
		},
		'1rbqk1nr/pp3pbp/2npp1p1/2p5/4P3/2NPB1P1/PPPQNPBP/R3K2R b KQk' => {
			eco => 'B26q',
			# TRANSLATORS: B26q: 1. e4 c5 2. Nc3 Nc6 3. g3 g6 4. Bg2 Bg7 5. d3 d6 6. Be3 e6 7. Qd2 Rb8 8. Nge2
			variation => N__('Sicilian: Closed, 6. Be3 e6 7. Qd2 Rb8 8.Nge2'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppppp/8/2p5/4P3/5N2/PPPP1PPP/RNBQKB1R b KQkq' => {
			eco => 'B27a',
			# TRANSLATORS: B27a: 1. e4 c5 2. Nf3
			variation => N__('Sicilian: 2. Nf3'),
			moves => {
				'a7a6' => 1,
				'b7b6' => 1,
				'b8c6' => 1,
				'd7d6' => 1,
				'd8a5' => 1,
				'd8c7' => 1,
				'e7e6' => 1,
				'g7g6' => 1,
				'g8f6' => 1,
			},
		},
		'rnb1kbnr/pp1ppppp/8/q1p5/4P3/5N2/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'B27b',
			# TRANSLATORS: B27b: 1. e4 c5 2. Nf3 Qa5
			variation => N__('Sicilian: Mongoose Variation'),
			moves => {
			},
		},
		'rnb1kbnr/ppqppppp/8/2p5/4P3/5N2/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'B27c',
			# TRANSLATORS: B27c: 1. e4 c5 2. Nf3 Qc7
			variation => N__('Sicilian: Quinteros Variation'),
			moves => {
			},
		},
		'rnbqkbnr/p2ppppp/1p6/2p5/4P3/5N2/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'B27d',
			# TRANSLATORS: B27d: 1. e4 c5 2. Nf3 b6
			variation => N__('Sicilian: Katalimov Variation'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppp1p/6p1/2p5/4P3/5N2/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'B27e',
			# TRANSLATORS: B27e: 1. e4 c5 2. Nf3 g6
			variation => N__('Sicilian: Hungarian Variation'),
			moves => {
				'c2c3' => 1,
				'c2c4' => 1,
				'd2d4' => 1,
			},
		},
		'rnbqkbnr/pp1ppp1p/6p1/2p5/2P1P3/5N2/PP1P1PPP/RNBQKB1R b KQkq' => {
			eco => 'B27f',
			# TRANSLATORS: B27f: 1. e4 c5 2. Nf3 g6 3. c4
			variation => N__('Sicilian: Hungarian, 3. c4'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppp1p/6p1/2p5/4P3/2P2N2/PP1P1PPP/RNBQKB1R b KQkq' => {
			eco => 'B27g',
			# TRANSLATORS: B27g: 1. e4 c5 2. Nf3 g6 3. c3
			variation => N__('Sicilian: Hungarian, 3. c3'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk1nr/pp1pppbp/6p1/2p5/4P3/2P2N2/PP1P1PPP/RNBQKB1R w KQkq' => {
			eco => 'B27g',
			# TRANSLATORS: B27g: 1. e4 c5 2. Nf3 g6 3. c3 Bg7
			variation => N__('Sicilian: Hungarian, 3. c3'),
			moves => {
				'd2d4' => 1,
			},
		},
		'rnbqk1nr/pp1pppbp/6p1/2p5/3PP3/2P2N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'B27g',
			# TRANSLATORS: B27g: 1. e4 c5 2. Nf3 g6 3. c3 Bg7 4. d4
			variation => N__('Sicilian: Hungarian, 3. c3'),
			moves => {
				'c5d4' => 1,
			},
		},
		'rnbqk1nr/pp1pppbp/6p1/8/3pP3/2P2N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'B27g',
			# TRANSLATORS: B27g: 1. e4 c5 2. Nf3 g6 3. c3 Bg7 4. d4 cxd4
			variation => N__('Sicilian: Hungarian, 3. c3'),
			moves => {
				'c3d4' => 1,
			},
		},
		'rnbqk1nr/pp1pppbp/6p1/8/3PP3/5N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'B27h',
			# TRANSLATORS: B27h: 1. e4 c5 2. Nf3 g6 3. c3 Bg7 4. d4 cxd4 5. cxd4
			variation => N__('Sicilian: Hungarian, 3. c3 Bg7 4. d4 cxd4 5.cxd4'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqk1nr/pp2ppbp/6p1/3p4/3PP3/5N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'B27i',
			# TRANSLATORS: B27i: 1. e4 c5 2. Nf3 g6 3. c3 Bg7 4. d4 cxd4 5. cxd4 d5
			variation => N__('Sicilian: Hungarian, 3. c3 Bg7 4. d4 cxd4 5.cxd4 d5'),
			moves => {
			},
		},
		'rnbqkbnr/pp1ppp1p/6p1/2p5/3PP3/5N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B27j',
			# TRANSLATORS: B27j: 1. e4 c5 2. Nf3 g6 3. d4
			variation => N__('Sicilian: Hungarian, 3. d4'),
			moves => {
				'c5d4' => 1,
				'f8g7' => 1,
			},
		},
		'rnbqkbnr/pp1ppp1p/6p1/8/3pP3/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B27k',
			# TRANSLATORS: B27k: 1. e4 c5 2. Nf3 g6 3. d4 cxd4
			variation => N__('Sicilian: Hungarian, 3. d4 cxd4'),
			moves => {
				'f3d4' => 1,
			},
		},
		'rnbqkbnr/pp1ppp1p/6p1/8/3NP3/8/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B27l',
			# TRANSLATORS: B27l: 1. e4 c5 2. Nf3 g6 3. d4 cxd4 4. Nxd4
			variation => N__('Sicilian: Hungarian, 3. d4 cxd4 4.Nxd4'),
			moves => {
			},
		},
		'rnbqk1nr/pp1pppbp/6p1/2p5/3PP3/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B27m',
			# TRANSLATORS: B27m: 1. e4 c5 2. Nf3 g6 3. d4 Bg7
			variation => N__('Sicilian: Accelerated Pterodactyl'),
			moves => {
				'b1c3' => 1,
				'c2c4' => 1,
				'd4c5' => 1,
			},
		},
		'rnbqk1nr/pp1pppbp/6p1/2P5/4P3/5N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B27n',
			# TRANSLATORS: B27n: 1. e4 c5 2. Nf3 g6 3. d4 Bg7 4. dxc5
			variation => N__('Sicilian: Accelerated Pterodactyl, 4.dxc5'),
			moves => {
				'd8a5' => 1,
			},
		},
		'rnb1k1nr/pp1pppbp/6p1/q1P5/4P3/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B27o',
			# TRANSLATORS: B27o: 1. e4 c5 2. Nf3 g6 3. d4 Bg7 4. dxc5 Qa5+
			variation => N__('Sicilian: Accelerated Pterodactyl, 4.dxc5 Qa5+'),
			moves => {
				'b1c3' => 1,
				'c2c3' => 1,
			},
		},
		'rnb1k1nr/pp1pppbp/6p1/q1P5/4P3/2N2N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B27p',
			# TRANSLATORS: B27p: 1. e4 c5 2. Nf3 g6 3. d4 Bg7 4. dxc5 Qa5+ 5. Nc3
			variation => N__('Sicilian: Accelerated Pterodactyl, 4.dxc5 Qa5+ 5. Nc3'),
			moves => {
			},
		},
		'rnb1k1nr/pp1pppbp/6p1/q1P5/4P3/2P2N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'B27q',
			# TRANSLATORS: B27q: 1. e4 c5 2. Nf3 g6 3. d4 Bg7 4. dxc5 Qa5+ 5. c3
			variation => N__('Sicilian: Accelerated Pterodactyl, 4.dxc5 Qa5+ 5. c3'),
			moves => {
				'a5c5' => 1,
			},
		},
		'rnb1k1nr/pp1pppbp/6p1/2q5/4P3/2P2N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'B27r',
			# TRANSLATORS: B27r: 1. e4 c5 2. Nf3 g6 3. d4 Bg7 4. dxc5 Qa5+ 5. c3 Qxc5
			variation => N__('Sicilian: Accelerated Pterodactyl, 4.dxc5 Qa5+ 5. c3'),
			moves => {
			},
		},
		'rnbqk1nr/pp1pppbp/6p1/2p5/2PPP3/5N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'B27s',
			# TRANSLATORS: B27s: 1. e4 c5 2. Nf3 g6 3. d4 Bg7 4. c4
			variation => N__('Sicilian: Accelerated Pterodactyl, 4. c4'),
			moves => {
				'd8a5' => 1,
			},
		},
		'rnbqk1nr/pp1pppbp/6p1/2p5/3PP3/2N2N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B27t',
			# TRANSLATORS: B27t: 1. e4 c5 2. Nf3 g6 3. d4 Bg7 4. Nc3
			variation => N__('Sicilian: Accelerated Pterodactyl, 4. Nc3'),
			moves => {
			},
		},
		'rnb1k1nr/pp1pppbp/6p1/q1p5/2PPP3/5N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'B27t',
			# TRANSLATORS: B27t: 1. e4 c5 2. Nf3 g6 3. d4 Bg7 4. c4 Qa5+
			variation => N__('Sicilian: Accelerated Pterodactyl, 4. c4 Qa5+'),
			moves => {
			},
		},
		'rnbqkbnr/1p1ppppp/p7/2p5/4P3/5N2/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'B28a',
			# TRANSLATORS: B28a: 1. e4 c5 2. Nf3 a6
			variation => N__('Sicilian: O\'Kelly Variation'),
			moves => {
				'b1c3' => 1,
				'c2c3' => 1,
				'c2c4' => 1,
				'd2d4' => 1,
			},
		},
		'rnbqkbnr/1p1ppppp/p7/2p5/4P3/2N2N2/PPPP1PPP/R1BQKB1R b KQkq' => {
			eco => 'B28b',
			# TRANSLATORS: B28b: 1. e4 c5 2. Nf3 a6 3. Nc3
			variation => N__('Sicilian: O\'Kelly, 3. Nc3'),
			moves => {
			},
		},
		'rnbqkbnr/1p1ppppp/p7/2p5/3PP3/5N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B28c',
			# TRANSLATORS: B28c: 1. e4 c5 2. Nf3 a6 3. d4
			variation => N__('Sicilian: O\'Kelly, 3. d4'),
			moves => {
				'c5d4' => 1,
			},
		},
		'rnbqkbnr/1p1ppppp/p7/8/3pP3/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B28c',
			# TRANSLATORS: B28c: 1. e4 c5 2. Nf3 a6 3. d4 cxd4
			variation => N__('Sicilian: O\'Kelly, 3. d4'),
			moves => {
				'f3d4' => 1,
			},
		},
		'rnbqkbnr/1p1ppppp/p7/8/3NP3/8/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B28d',
			# TRANSLATORS: B28d: 1. e4 c5 2. Nf3 a6 3. d4 cxd4 4. Nxd4
			variation => N__('Sicilian: O\'Kelly, 3. d4 cxd4 4.Nxd4'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/1p1ppppp/p4n2/8/3NP3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B28e',
			# TRANSLATORS: B28e: 1. e4 c5 2. Nf3 a6 3. d4 cxd4 4. Nxd4 Nf6
			variation => N__('Sicilian: O\'Kelly, 3. d4 cxd4 4.Nxd4 Nf6'),
			moves => {
			},
		},
		'rnbqkbnr/1p1ppppp/p7/2p5/2P1P3/5N2/PP1P1PPP/RNBQKB1R b KQkq' => {
			eco => 'B28f',
			# TRANSLATORS: B28f: 1. e4 c5 2. Nf3 a6 3. c4
			variation => N__('Sicilian: O\'Kelly, 3. c4'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rnbqkbnr/1p1p1ppp/p3p3/2p5/2P1P3/5N2/PP1P1PPP/RNBQKB1R w KQkq' => {
			eco => 'B28g',
			# TRANSLATORS: B28g: 1. e4 c5 2. Nf3 a6 3. c4 e6
			variation => N__('Sicilian: O\'Kelly, 3. c4 e6'),
			moves => {
			},
		},
		'rnbqkbnr/1p1ppppp/p7/2p5/4P3/2P2N2/PP1P1PPP/RNBQKB1R b KQkq' => {
			eco => 'B28h',
			# TRANSLATORS: B28h: 1. e4 c5 2. Nf3 a6 3. c3
			variation => N__('Sicilian: O\'Kelly, 3. c3'),
			moves => {
				'd7d5' => 1,
				'e7e6' => 1,
			},
		},
		'rnbqkbnr/1p1p1ppp/p3p3/2p5/4P3/2P2N2/PP1P1PPP/RNBQKB1R w KQkq' => {
			eco => 'B28i',
			# TRANSLATORS: B28i: 1. e4 c5 2. Nf3 a6 3. c3 e6
			variation => N__('Sicilian: O\'Kelly, 3. c3 e6'),
			moves => {
			},
		},
		'rnbqkbnr/1p2pppp/p7/2pp4/4P3/2P2N2/PP1P1PPP/RNBQKB1R w KQkq' => {
			eco => 'B28j',
			# TRANSLATORS: B28j: 1. e4 c5 2. Nf3 a6 3. c3 d5
			variation => N__('Sicilian: O\'Kelly, 3. c3 d5'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/2p5/4P3/5N2/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'B29a',
			# TRANSLATORS: B29a: 1. e4 c5 2. Nf3 Nf6
			variation => N__('Sicilian: Nimzowitsch'),
			moves => {
				'b1c3' => 1,
				'd2d3' => 1,
				'e4e5' => 1,
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/2p5/4P3/3P1N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B29b',
			# TRANSLATORS: B29b: 1. e4 c5 2. Nf3 Nf6 3. d3
			variation => N__('Sicilian: Nimzowitsch, 3. d3'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/2p5/4P3/2N2N2/PPPP1PPP/R1BQKB1R b KQkq' => {
			eco => 'B29c',
			# TRANSLATORS: B29c: 1. e4 c5 2. Nf3 Nf6 3. Nc3
			variation => N__('Sicilian: Nimzowitsch, 3. Nc3'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/5n2/2pp4/4P3/2N2N2/PPPP1PPP/R1BQKB1R w KQkq' => {
			eco => 'B29d',
			# TRANSLATORS: B29d: 1. e4 c5 2. Nf3 Nf6 3. Nc3 d5
			variation => N__('Sicilian: Nimzowitsch, 3. Nc3 d5'),
			moves => {
				'e4d5' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/5n2/2pP4/8/2N2N2/PPPP1PPP/R1BQKB1R b KQkq' => {
			eco => 'B29e',
			# TRANSLATORS: B29e: 1. e4 c5 2. Nf3 Nf6 3. Nc3 d5 4. exd5
			variation => N__('Sicilian: Nimzowitsch, 3. Nc3 d5 4.exd5'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/5n2/2p1P3/8/5N2/PPPP1PPP/RNBQKB1R b KQkq' => {
			eco => 'B29f',
			# TRANSLATORS: B29f: 1. e4 c5 2. Nf3 Nf6 3. e5
			variation => N__('Sicilian: Nimzowitsch, 3. e5'),
			moves => {
				'f6d5' => 1,
			},
		},
		'rnbqkb1r/pp1ppppp/8/2pnP3/8/5N2/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'B29f',
			# TRANSLATORS: B29f: 1. e4 c5 2. Nf3 Nf6 3. e5 Nd5
			variation => N__('Sicilian: Nimzowitsch, 3. e5 Nd5'),
			moves => {
				'b1c3' => 1,
				'c2c4' => 1,
				'd2d4' => 1,
			},
		},
		'rnbqkb1r/pp1ppppp/8/2pnP3/2P5/5N2/PP1P1PPP/RNBQKB1R b KQkq' => {
			eco => 'B29g',
			# TRANSLATORS: B29g: 1. e4 c5 2. Nf3 Nf6 3. e5 Nd5 4. c4
			variation => N__('Sicilian: Nimzowitsch, 4. c4'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/8/2pnP3/3P4/5N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B29h',
			# TRANSLATORS: B29h: 1. e4 c5 2. Nf3 Nf6 3. e5 Nd5 4. d4
			variation => N__('Sicilian: Nimzowitsch, 4. d4'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppppp/8/2pnP3/8/2N2N2/PPPP1PPP/R1BQKB1R b KQkq' => {
			eco => 'B29i',
			# TRANSLATORS: B29i: 1. e4 c5 2. Nf3 Nf6 3. e5 Nd5 4. Nc3
			variation => N__('Sicilian: Nimzowitsch, 4. Nc3'),
			moves => {
				'd5c3' => 1,
				'e7e6' => 1,
			},
		},
		'rnbqkb1r/pp1ppppp/8/2p1P3/8/2n2N2/PPPP1PPP/R1BQKB1R w KQkq' => {
			eco => 'B29j',
			# TRANSLATORS: B29j: 1. e4 c5 2. Nf3 Nf6 3. e5 Nd5 4. Nc3 Nxc3
			variation => N__('Sicilian: Nimzowitsch, 4. Nc3 Nxc3'),
			moves => {
			},
		},
		'rnbqkb1r/pp1p1ppp/4p3/2pnP3/8/2N2N2/PPPP1PPP/R1BQKB1R w KQkq' => {
			eco => 'B29k',
			# TRANSLATORS: B29k: 1. e4 c5 2. Nf3 Nf6 3. e5 Nd5 4. Nc3 e6
			variation => N__('Sicilian: Nimzowitsch, 4. Nc3 e6'),
			moves => {
				'c3d5' => 1,
			},
		},
		'rnbqkb1r/pp1p1ppp/4p3/2pNP3/8/5N2/PPPP1PPP/R1BQKB1R b KQkq' => {
			eco => 'B29l',
			# TRANSLATORS: B29l: 1. e4 c5 2. Nf3 Nf6 3. e5 Nd5 4. Nc3 e6 5. Nxd5
			variation => N__('Sicilian: Nimzowitsch, 4. Nc3 e6 5.Nxd5'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rnbqkb1r/pp1p1ppp/8/2ppP3/8/5N2/PPPP1PPP/R1BQKB1R w KQkq' => {
			eco => 'B29l',
			# TRANSLATORS: B29l: 1. e4 c5 2. Nf3 Nf6 3. e5 Nd5 4. Nc3 e6 5. Nxd5 exd5
			variation => N__('Sicilian: Nimzowitsch, 4. Nc3 e6 5.Nxd5'),
			moves => {
				'd2d4' => 1,
			},
		},
		'rnbqkb1r/pp1p1ppp/8/2ppP3/3P4/5N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B29l',
			# TRANSLATORS: B29l: 1. e4 c5 2. Nf3 Nf6 3. e5 Nd5 4. Nc3 e6 5. Nxd5 exd5 6. d4
			variation => N__('Sicilian: Nimzowitsch, 4. Nc3 e6 5.Nxd5'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkb1r/pp1p1ppp/2n5/2ppP3/3P4/5N2/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B29m',
			# TRANSLATORS: B29m: 1. e4 c5 2. Nf3 Nf6 3. e5 Nd5 4. Nc3 e6 5. Nxd5 exd5 6. d4 Nc6
			variation => N__('Sicilian: Nimzowitsch, Rubinstein Countergambit'),
			moves => {
				'd4c5' => 1,
			},
		},
		'r1bqkb1r/pp1p1ppp/2n5/2PpP3/8/5N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B29n',
			# TRANSLATORS: B29n: 1. e4 c5 2. Nf3 Nf6 3. e5 Nd5 4. Nc3 e6 5. Nxd5 exd5 6. d4 Nc6 7. dxc5
			variation => N__('Sicilian: Nimzowitsch, Rubinstein Countergambit, 7.dxc5'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/2p5/4P3/5N2/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'B30a',
			# TRANSLATORS: B30a: 1. e4 c5 2. Nf3 Nc6
			variation => N__('Sicilian: 2... Nc6'),
			moves => {
				'b1c3' => 1,
				'b2b3' => 1,
				'd2d3' => 1,
				'd2d4' => 1,
				'f1b5' => 1,
				'f1c4' => 1,
				'g2g3' => 1,
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/2p5/4P3/1P3N2/P1PP1PPP/RNBQKB1R b KQkq' => {
			eco => 'B30b',
			# TRANSLATORS: B30b: 1. e4 c5 2. Nf3 Nc6 3. b3
			variation => N__('Sicilian: 2... Nc6 3. b3'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/2p5/4P3/3P1N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B30c',
			# TRANSLATORS: B30c: 1. e4 c5 2. Nf3 Nc6 3. d3
			variation => N__('Sicilian: 2... Nc6 3. d3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r1bqkb1r/pp1ppppp/2n2n2/2p5/4P3/3P1N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B30c',
			# TRANSLATORS: B30c: 1. e4 c5 2. Nf3 Nc6 3. d3 Nf6
			variation => N__('Sicilian: 2... Nc6 3. d3 Nf6'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/2p5/4P3/5NP1/PPPP1P1P/RNBQKB1R b KQkq' => {
			eco => 'B30d',
			# TRANSLATORS: B30d: 1. e4 c5 2. Nf3 Nc6 3. g3
			variation => N__('Sicilian: 2... Nc6 3. g3'),
			moves => {
				'e7e6' => 1,
			},
		},
		'r1bqkbnr/pp1p1ppp/2n1p3/2p5/4P3/5NP1/PPPP1P1P/RNBQKB1R w KQkq' => {
			eco => 'B30d',
			# TRANSLATORS: B30d: 1. e4 c5 2. Nf3 Nc6 3. g3 e6
			variation => N__('Sicilian: 2... Nc6 3. g3'),
			moves => {
				'd2d3' => 1,
			},
		},
		'r1bqkbnr/pp1p1ppp/2n1p3/2p5/4P3/3P1NP1/PPP2P1P/RNBQKB1R b KQkq' => {
			eco => 'B30e',
			# TRANSLATORS: B30e: 1. e4 c5 2. Nf3 Nc6 3. g3 e6 4. d3
			variation => N__('Sicilian: 2... Nc6 3. g3 e6 4. d3'),
			moves => {
				'd7d5' => 1,
			},
		},
		'r1bqkbnr/pp3ppp/2n1p3/2pp4/4P3/3P1NP1/PPP2P1P/RNBQKB1R w KQkq' => {
			eco => 'B30f',
			# TRANSLATORS: B30f: 1. e4 c5 2. Nf3 Nc6 3. g3 e6 4. d3 d5
			variation => N__('Sicilian: 2... Nc6 3. g3 e6 4. d3 d5'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/2p5/2B1P3/5N2/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'B30g',
			# TRANSLATORS: B30g: 1. e4 c5 2. Nf3 Nc6 3. Bc4
			variation => N__('Sicilian: 2... Nc6 3. Bc4'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/2p5/4P3/2N2N2/PPPP1PPP/R1BQKB1R b KQkq' => {
			eco => 'B30h',
			# TRANSLATORS: B30h: 1. e4 c5 2. Nf3 Nc6 3. Nc3
			variation => N__('Sicilian: 2... Nc6 3. Nc3'),
			moves => {
				'e7e5' => 1,
				'g7g6' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkb1r/pp1ppppp/2n2n2/2p5/4P3/2N2N2/PPPP1PPP/R1BQKB1R w KQkq' => {
			eco => 'B30h',
			# TRANSLATORS: B30h: 1. e4 c5 2. Nf3 Nc6 3. Nc3 Nf6
			variation => N__('Sicilian: 2... Nc6 3. Nc3 Nf6'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppp1p/2n3p1/2p5/4P3/2N2N2/PPPP1PPP/R1BQKB1R w KQkq' => {
			eco => 'B30i',
			# TRANSLATORS: B30i: 1. e4 c5 2. Nf3 Nc6 3. Nc3 g6
			variation => N__('Sicilian: 2... Nc6 3. Nc3 g6'),
			moves => {
			},
		},
		'r1bqkbnr/pp1p1ppp/2n5/2p1p3/4P3/2N2N2/PPPP1PPP/R1BQKB1R w KQkq' => {
			eco => 'B30j',
			# TRANSLATORS: B30j: 1. e4 c5 2. Nf3 Nc6 3. Nc3 e5
			variation => N__('Sicilian: 2... Nc6 3. Nc3 e5'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/1Bp5/4P3/5N2/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'B30k',
			# TRANSLATORS: B30k: 1. e4 c5 2. Nf3 Nc6 3. Bb5
			variation => N__('Sicilian: Rossolimo'),
			moves => {
				'd8b6' => 1,
				'e7e6' => 1,
				'g7g6' => 1,
				'g8f6' => 1,
			},
		},
		'r1b1kbnr/pp1ppppp/1qn5/1Bp5/4P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'B30l',
			# TRANSLATORS: B30l: 1. e4 c5 2. Nf3 Nc6 3. Bb5 Qb6
			variation => N__('Sicilian: Rossolimo, 3... Qb6'),
			moves => {
			},
		},
		'r1bqkb1r/pp1ppppp/2n2n2/1Bp5/4P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'B30m',
			# TRANSLATORS: B30m: 1. e4 c5 2. Nf3 Nc6 3. Bb5 Nf6
			variation => N__('Sicilian: Rossolimo, 3... Nf6'),
			moves => {
			},
		},
		'r1bqkbnr/pp1p1ppp/2n1p3/1Bp5/4P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'B30n',
			# TRANSLATORS: B30n: 1. e4 c5 2. Nf3 Nc6 3. Bb5 e6
			variation => N__('Sicilian: Rossolimo, 3... e6'),
			moves => {
				'b1c3' => 1,
				'b2b3' => 1,
				'b5c6' => 1,
				'e1g1' => 1,
			},
		},
		'r1bqkbnr/pp1p1ppp/2n1p3/1Bp5/4P3/1P3N2/P1PP1PPP/RNBQK2R b KQkq' => {
			eco => 'B30o',
			# TRANSLATORS: B30o: 1. e4 c5 2. Nf3 Nc6 3. Bb5 e6 4. b3
			variation => N__('Sicilian: Rossolimo, 3... e6 4. b3'),
			moves => {
			},
		},
		'r1bqkbnr/pp1p1ppp/2n1p3/1Bp5/4P3/2N2N2/PPPP1PPP/R1BQK2R b KQkq' => {
			eco => 'B30p',
			# TRANSLATORS: B30p: 1. e4 c5 2. Nf3 Nc6 3. Bb5 e6 4. Nc3
			variation => N__('Sicilian: Rossolimo, 3... e6 4. Nc3'),
			moves => {
			},
		},
		'r1bqkbnr/pp1p1ppp/2B1p3/2p5/4P3/5N2/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'B30q',
			# TRANSLATORS: B30q: 1. e4 c5 2. Nf3 Nc6 3. Bb5 e6 4. Bxc6
			variation => N__('Sicilian: Rossolimo, 3... e6 4.Bxc6'),
			moves => {
			},
		},
		'r1bqkbnr/pp1p1ppp/2n1p3/1Bp5/4P3/5N2/PPPP1PPP/RNBQ1RK1 b kq' => {
			eco => 'B30r',
			# TRANSLATORS: B30r: 1. e4 c5 2. Nf3 Nc6 3. Bb5 e6 4. O-O
			variation => N__('Sicilian: Rossolimo, 3... e6 4.O-O'),
			moves => {
				'g8e7' => 1,
			},
		},
		'r1bqkb1r/pp1pnppp/2n1p3/1Bp5/4P3/5N2/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'B30s',
			# TRANSLATORS: B30s: 1. e4 c5 2. Nf3 Nc6 3. Bb5 e6 4. O-O Nge7
			variation => N__('Sicilian: Rossolimo, 3... e6 4.O-O Nge7'),
			moves => {
				'b1c3' => 1,
				'b2b3' => 1,
				'c2c3' => 1,
				'f1e1' => 1,
			},
		},
		'r1bqkb1r/pp1pnppp/2n1p3/1Bp5/4P3/1P3N2/P1PP1PPP/RNBQ1RK1 b kq' => {
			eco => 'B30s',
			# TRANSLATORS: B30s: 1. e4 c5 2. Nf3 Nc6 3. Bb5 e6 4. O-O Nge7 5. b3
			variation => N__('Sicilian: Rossolimo, 3... e6 4.O-O Nge7 5. b3'),
			moves => {
			},
		},
		'r1bqkb1r/pp1pnppp/2n1p3/1Bp5/4P3/5N2/PPPP1PPP/RNBQR1K1 b kq' => {
			eco => 'B30t',
			# TRANSLATORS: B30t: 1. e4 c5 2. Nf3 Nc6 3. Bb5 e6 4. O-O Nge7 5. Re1
			variation => N__('Sicilian: Rossolimo, 3... e6 4.O-O Nge7 5. Re1'),
			moves => {
			},
		},
		'r1bqkb1r/pp1pnppp/2n1p3/1Bp5/4P3/2N2N2/PPPP1PPP/R1BQ1RK1 b kq' => {
			eco => 'B30u',
			# TRANSLATORS: B30u: 1. e4 c5 2. Nf3 Nc6 3. Bb5 e6 4. O-O Nge7 5. Nc3
			variation => N__('Sicilian: Rossolimo, 3... e6 4.O-O Nge7 5. Nc3'),
			moves => {
			},
		},
		'r1bqkb1r/pp1pnppp/2n1p3/1Bp5/4P3/2P2N2/PP1P1PPP/RNBQ1RK1 b kq' => {
			eco => 'B30v',
			# TRANSLATORS: B30v: 1. e4 c5 2. Nf3 Nc6 3. Bb5 e6 4. O-O Nge7 5. c3
			variation => N__('Sicilian: Rossolimo, 3... e6 4.O-O Nge7 5. c3'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r1bqkb1r/1p1pnppp/p1n1p3/1Bp5/4P3/2P2N2/PP1P1PPP/RNBQ1RK1 w kq' => {
			eco => 'B30w',
			# TRANSLATORS: B30w: 1. e4 c5 2. Nf3 Nc6 3. Bb5 e6 4. O-O Nge7 5. c3 a6
			variation => N__('Sicilian: Rossolimo, 3... e6 4.O-O Nge7 5. c3 a6'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppp1p/2n3p1/1Bp5/4P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'B31a',
			# TRANSLATORS: B31a: 1. e4 c5 2. Nf3 Nc6 3. Bb5 g6
			variation => N__('Sicilian: Rossolimo, 3... g6'),
			moves => {
				'b1c3' => 1,
				'b5c6' => 1,
				'e1g1' => 1,
			},
		},
		'r1bqkbnr/pp1ppp1p/2n3p1/1Bp5/4P3/2N2N2/PPPP1PPP/R1BQK2R b KQkq' => {
			eco => 'B31b',
			# TRANSLATORS: B31b: 1. e4 c5 2. Nf3 Nc6 3. Bb5 g6 4. Nc3
			variation => N__('Sicilian: Rossolimo, 3... g6 4. Nc3'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppp1p/2B3p1/2p5/4P3/5N2/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'B31c',
			# TRANSLATORS: B31c: 1. e4 c5 2. Nf3 Nc6 3. Bb5 g6 4. Bxc6
			variation => N__('Sicilian: Rossolimo, 3... g6 4.Bxc6'),
			moves => {
				'd7c6' => 1,
			},
		},
		'r1bqkbnr/pp2pp1p/2p3p1/2p5/4P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'B31d',
			# TRANSLATORS: B31d: 1. e4 c5 2. Nf3 Nc6 3. Bb5 g6 4. Bxc6 dxc6
			variation => N__('Sicilian: Rossolimo, 3... g6 4.Bxc6 dxc6'),
			moves => {
				'd2d3' => 1,
			},
		},
		'r1bqkbnr/pp2pp1p/2p3p1/2p5/4P3/3P1N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'B31e',
			# TRANSLATORS: B31e: 1. e4 c5 2. Nf3 Nc6 3. Bb5 g6 4. Bxc6 dxc6 5. d3
			variation => N__('Sicilian: Rossolimo, 3... g6 4.Bxc6 dxc6 5. d3'),
			moves => {
				'f8g7' => 1,
			},
		},
		'r1bqk1nr/pp2ppbp/2p3p1/2p5/4P3/3P1N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'B31e',
			# TRANSLATORS: B31e: 1. e4 c5 2. Nf3 Nc6 3. Bb5 g6 4. Bxc6 dxc6 5. d3 Bg7
			variation => N__('Sicilian: Rossolimo, 3... g6 4.Bxc6 dxc6 5. d3'),
			moves => {
				'h2h3' => 1,
			},
		},
		'r1bqk1nr/pp2ppbp/2p3p1/2p5/4P3/3P1N1P/PPP2PP1/RNBQK2R b KQkq' => {
			eco => 'B31f',
			# TRANSLATORS: B31f: 1. e4 c5 2. Nf3 Nc6 3. Bb5 g6 4. Bxc6 dxc6 5. d3 Bg7 6. h3
			variation => N__('Sicilian: Rossolimo, 3... g6 4.Bxc6 dxc6 5. d3 Bg7 6. h3'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppp1p/2n3p1/1Bp5/4P3/5N2/PPPP1PPP/RNBQ1RK1 b kq' => {
			eco => 'B31g',
			# TRANSLATORS: B31g: 1. e4 c5 2. Nf3 Nc6 3. Bb5 g6 4. O-O
			variation => N__('Sicilian: Rossolimo, 3... g6 4.O-O'),
			moves => {
				'f8g7' => 1,
			},
		},
		'r1bqk1nr/pp1pppbp/2n3p1/1Bp5/4P3/5N2/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'B31g',
			# TRANSLATORS: B31g: 1. e4 c5 2. Nf3 Nc6 3. Bb5 g6 4. O-O Bg7
			variation => N__('Sicilian: Rossolimo, 3... g6 4.O-O'),
			moves => {
				'c2c3' => 1,
				'f1e1' => 1,
			},
		},
		'r1bqk1nr/pp1pppbp/2n3p1/1Bp5/4P3/2P2N2/PP1P1PPP/RNBQ1RK1 b kq' => {
			eco => 'B31h',
			# TRANSLATORS: B31h: 1. e4 c5 2. Nf3 Nc6 3. Bb5 g6 4. O-O Bg7 5. c3
			variation => N__('Sicilian: Rossolimo, 3... g6 4.O-O Bg7 5. c3'),
			moves => {
				'e7e5' => 1,
			},
		},
		'r1bqk1nr/pp1p1pbp/2n3p1/1Bp1p3/4P3/2P2N2/PP1P1PPP/RNBQ1RK1 w kq' => {
			eco => 'B31i',
			# TRANSLATORS: B31i: 1. e4 c5 2. Nf3 Nc6 3. Bb5 g6 4. O-O Bg7 5. c3 e5
			variation => N__('Sicilian: Rossolimo, 3... g6 4.O-O Bg7 5. c3 e5'),
			moves => {
			},
		},
		'r1bqk1nr/pp1pppbp/2n3p1/1Bp5/4P3/5N2/PPPP1PPP/RNBQR1K1 b kq' => {
			eco => 'B31j',
			# TRANSLATORS: B31j: 1. e4 c5 2. Nf3 Nc6 3. Bb5 g6 4. O-O Bg7 5. Re1
			variation => N__('Sicilian: Rossolimo, 3... g6 4.O-O Bg7 5. Re1'),
			moves => {
				'e7e5' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqk2r/pp1pppbp/2n2np1/1Bp5/4P3/5N2/PPPP1PPP/RNBQR1K1 w kq' => {
			eco => 'B31k',
			# TRANSLATORS: B31k: 1. e4 c5 2. Nf3 Nc6 3. Bb5 g6 4. O-O Bg7 5. Re1 Nf6
			variation => N__('Sicilian: Rossolimo, 3... g6 4.O-O Bg7 5. Re1 Nf6'),
			moves => {
				'c2c3' => 1,
			},
		},
		'r1bqk2r/pp1pppbp/2n2np1/1Bp5/4P3/2P2N2/PP1P1PPP/RNBQR1K1 b kq' => {
			eco => 'B31l',
			# TRANSLATORS: B31l: 1. e4 c5 2. Nf3 Nc6 3. Bb5 g6 4. O-O Bg7 5. Re1 Nf6 6. c3
			variation => N__('Sicilian: Rossolimo, 3... g6 4.O-O Bg7 5. Re1 Nf6 6. c3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp1pppbp/2n2np1/1Bp5/4P3/2P2N2/PP1P1PPP/RNBQR1K1 w -' => {
			eco => 'B31l',
			# TRANSLATORS: B31l: 1. e4 c5 2. Nf3 Nc6 3. Bb5 g6 4. O-O Bg7 5. Re1 Nf6 6. c3 O-O
			variation => N__('Sicilian: Rossolimo, 3... g6 4.O-O Bg7 5. Re1 Nf6 6. c3'),
			moves => {
				'd2d4' => 1,
				'h2h3' => 1,
			},
		},
		'r1bq1rk1/pp1pppbp/2n2np1/1Bp5/4P3/2P2N1P/PP1P1PP1/RNBQR1K1 b -' => {
			eco => 'B31m',
			# TRANSLATORS: B31m: 1. e4 c5 2. Nf3 Nc6 3. Bb5 g6 4. O-O Bg7 5. Re1 Nf6 6. c3 O-O 7. h3
			variation => N__('Sicilian: Rossolimo, 3... g6 4.O-O Bg7 5. Re1 Nf6 6. c3 O-O 7. h3'),
			moves => {
			},
		},
		'r1bq1rk1/pp1pppbp/2n2np1/1Bp5/3PP3/2P2N2/PP3PPP/RNBQR1K1 b -' => {
			eco => 'B31n',
			# TRANSLATORS: B31n: 1. e4 c5 2. Nf3 Nc6 3. Bb5 g6 4. O-O Bg7 5. Re1 Nf6 6. c3 O-O 7. d4
			variation => N__('Sicilian: Rossolimo, 3... g6 4.O-O Bg7 5. Re1 Nf6 6. c3 O-O 7. d4'),
			moves => {
			},
		},
		'r1bqk1nr/pp1p1pbp/2n3p1/1Bp1p3/4P3/5N2/PPPP1PPP/RNBQR1K1 w kq' => {
			eco => 'B31o',
			# TRANSLATORS: B31o: 1. e4 c5 2. Nf3 Nc6 3. Bb5 g6 4. O-O Bg7 5. Re1 e5
			variation => N__('Sicilian: Rossolimo, 3... g6 4.O-O Bg7 5. Re1 e5'),
			moves => {
				'b2b4' => 1,
				'c2c3' => 1,
			},
		},
		'r1bqk1nr/pp1p1pbp/2n3p1/1Bp1p3/1P2P3/5N2/P1PP1PPP/RNBQR1K1 b kq' => {
			eco => 'B31p',
			# TRANSLATORS: B31p: 1. e4 c5 2. Nf3 Nc6 3. Bb5 g6 4. O-O Bg7 5. Re1 e5 6. b4
			variation => N__('Sicilian: Rossolimo, Gurgenidze Variation'),
			moves => {
			},
		},
		'r1bqk1nr/pp1p1pbp/2n3p1/1Bp1p3/4P3/2P2N2/PP1P1PPP/RNBQR1K1 b kq' => {
			eco => 'B31q',
			# TRANSLATORS: B31q: 1. e4 c5 2. Nf3 Nc6 3. Bb5 g6 4. O-O Bg7 5. Re1 e5 6. c3
			variation => N__('Sicilian: Rossolimo, 3... g6 4.O-O Bg7 5. Re1 e5'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/2p5/3PP3/5N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B32a',
			# TRANSLATORS: B32a: 1. e4 c5 2. Nf3 Nc6 3. d4
			variation => N__('Sicilian: 2... Nc6 3. d4'),
			moves => {
				'c5d4' => 1,
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/8/3pP3/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B32b',
			# TRANSLATORS: B32b: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4
			variation => N__('Sicilian: 2... Nc6 3. d4 cxd4'),
			moves => {
				'f3d4' => 1,
			},
		},
		'r1bqkbnr/pp1ppppp/2n5/8/3NP3/8/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B32c',
			# TRANSLATORS: B32c: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4
			variation => N__('Sicilian: Open, 2... Nc6'),
			moves => {
				'd7d5' => 1,
				'd7d6' => 1,
				'd8b6' => 1,
				'd8c7' => 1,
				'e7e5' => 1,
				'g7g6' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkbnr/pp2pppp/2np4/8/3NP3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B32d',
			# TRANSLATORS: B32d: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 d6
			variation => N__('Sicilian: Open, 2... Nc6, 4... d6'),
			moves => {
			},
		},
		'r1b1kbnr/pp1ppppp/1qn5/8/3NP3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B32e',
			# TRANSLATORS: B32e: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Qb6
			variation => N__('Sicilian: Open, 2... Nc6, 4... Qb6'),
			moves => {
			},
		},
		'r1b1kbnr/ppqppppp/2n5/8/3NP3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B32f',
			# TRANSLATORS: B32f: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Qc7
			variation => N__('Sicilian: Flohr Variation'),
			moves => {
				'd4b5' => 1,
			},
		},
		'r1b1kbnr/ppqppppp/2n5/1N6/4P3/8/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B32g',
			# TRANSLATORS: B32g: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Qc7 5. Nb5
			variation => N__('Sicilian: Flohr, 5. Nb5'),
			moves => {
			},
		},
		'r1bqkbnr/pp2pppp/2n5/3p4/3NP3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B32h',
			# TRANSLATORS: B32h: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 d5
			variation => N__('Sicilian: 2..Nc6, Nimzowitsch Variation'),
			moves => {
			},
		},
		'r1bqkbnr/pp1p1ppp/2n5/4p3/3NP3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B32i',
			# TRANSLATORS: B32i: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 e5
			variation => N__('Sicilian: Lowenthal'),
			moves => {
				'd4b5' => 1,
			},
		},
		'r1bqkbnr/pp1p1ppp/2n5/1N2p3/4P3/8/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B32j',
			# TRANSLATORS: B32j: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 e5 5. Nb5
			variation => N__('Sicilian: Lowenthal, 5. Nb5'),
			moves => {
				'a7a6' => 1,
				'd7d6' => 1,
			},
		},
		'r1bqkbnr/1p1p1ppp/p1n5/1N2p3/4P3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B32k',
			# TRANSLATORS: B32k: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 e5 5. Nb5 a6
			variation => N__('Sicilian: Lowenthal, 5... a6'),
			moves => {
				'b5d6' => 1,
			},
		},
		'r1bqkbnr/1p1p1ppp/p1nN4/4p3/4P3/8/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B32k',
			# TRANSLATORS: B32k: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 e5 5. Nb5 a6 6. Nd6+
			variation => N__('Sicilian: Lowenthal, 5... a6'),
			moves => {
				'f8d6' => 1,
			},
		},
		'r1bqk1nr/1p1p1ppp/p1nb4/4p3/4P3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B32k',
			# TRANSLATORS: B32k: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 e5 5. Nb5 a6 6. Nd6+ Bxd6
			variation => N__('Sicilian: Lowenthal, 5... a6'),
			moves => {
				'd1d6' => 1,
			},
		},
		'r1bqk1nr/1p1p1ppp/p1nQ4/4p3/4P3/8/PPP2PPP/RNB1KB1R b KQkq' => {
			eco => 'B32k',
			# TRANSLATORS: B32k: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 e5 5. Nb5 a6 6. Nd6+ Bxd6 7. Qxd6
			variation => N__('Sicilian: Lowenthal, 5... a6'),
			moves => {
				'd8f6' => 1,
			},
		},
		'r1b1k1nr/1p1p1ppp/p1nQ1q2/4p3/4P3/8/PPP2PPP/RNB1KB1R w KQkq' => {
			eco => 'B32k',
			# TRANSLATORS: B32k: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 e5 5. Nb5 a6 6. Nd6+ Bxd6 7. Qxd6 Qf6
			variation => N__('Sicilian: Lowenthal, 5... a6'),
			moves => {
				'd6d1' => 1,
				'd6f6' => 1,
			},
		},
		'r1b1k1nr/1p1p1ppp/p1n2Q2/4p3/4P3/8/PPP2PPP/RNB1KB1R b KQkq' => {
			eco => 'B32l',
			# TRANSLATORS: B32l: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 e5 5. Nb5 a6 6. Nd6+ Bxd6 7. Qxd6 Qf6 8. Qxf6
			variation => N__('Sicilian: Lowenthal, 5... a6, Queenswap'),
			moves => {
			},
		},
		'r1b1k1nr/1p1p1ppp/p1n2q2/4p3/4P3/8/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B32m',
			# TRANSLATORS: B32m: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 e5 5. Nb5 a6 6. Nd6+ Bxd6 7. Qxd6 Qf6 8. Qd1
			variation => N__('Sicilian: Lowenthal, 5... a6, 8. Qd1'),
			moves => {
			},
		},
		'r1bqkbnr/pp3ppp/2np4/1N2p3/4P3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B32n',
			# TRANSLATORS: B32n: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 e5 5. Nb5 d6
			variation => N__('Sicilian: Lowenthal, Kalashnikov'),
			moves => {
				'a2a4' => 1,
				'b1c3' => 1,
				'c2c4' => 1,
			},
		},
		'r1bqkbnr/pp3ppp/2np4/1N2p3/P3P3/8/1PP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B32o',
			# TRANSLATORS: B32o: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 e5 5. Nb5 d6 6. a4
			variation => N__('Sicilian: Lowenthal, Kalashnikov, 6. a4'),
			moves => {
			},
		},
		'r1bqkbnr/pp3ppp/2np4/1N2p3/4P3/2N5/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B32p',
			# TRANSLATORS: B32p: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 e5 5. Nb5 d6 6. N1c3
			variation => N__('Sicilian: Lowenthal, Kalashnikov, 6.N1c3'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r1bqkbnr/1p3ppp/p1np4/1N2p3/4P3/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B32p',
			# TRANSLATORS: B32p: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 e5 5. Nb5 d6 6. N1c3 a6
			variation => N__('Sicilian: Lowenthal, Kalashnikov, 6.N1c3'),
			moves => {
				'b5a3' => 1,
			},
		},
		'r1bqkbnr/1p3ppp/p1np4/4p3/4P3/N1N5/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B32p',
			# TRANSLATORS: B32p: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 e5 5. Nb5 d6 6. N1c3 a6 7. Na3
			variation => N__('Sicilian: Lowenthal, Kalashnikov, 6.N1c3'),
			moves => {
				'b7b5' => 1,
			},
		},
		'r1bqkbnr/5ppp/p1np4/1p2p3/4P3/N1N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B32q',
			# TRANSLATORS: B32q: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 e5 5. Nb5 d6 6. N1c3 a6 7. Na3 b5
			variation => N__('Sicilian: Lowenthal, Kalashnikov, 6.N1c3 a6 7. Na3 b5'),
			moves => {
				'c3d5' => 1,
			},
		},
		'r1bqkbnr/5ppp/p1np4/1p1Np3/4P3/N7/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B32q',
			# TRANSLATORS: B32q: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 e5 5. Nb5 d6 6. N1c3 a6 7. Na3 b5 8. Nd5
			variation => N__('Sicilian: Lowenthal, Kalashnikov, 6.N1c3 a6 7. Na3 b5'),
			moves => {
				'g8e7' => 1,
			},
		},
		'r1bqkb1r/4nppp/p1np4/1p1Np3/4P3/N7/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B32r',
			# TRANSLATORS: B32r: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 e5 5. Nb5 d6 6. N1c3 a6 7. Na3 b5 8. Nd5 Nge7
			variation => N__('Sicilian: Lowenthal, Kalashnikov, 6.N1c3 a6 7. Na3 b5 8. Nd5 Nge7'),
			moves => {
			},
		},
		'r1bqkbnr/pp3ppp/2np4/1N2p3/2P1P3/8/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'B32s',
			# TRANSLATORS: B32s: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 e5 5. Nb5 d6 6. c4
			variation => N__('Sicilian: Lowenthal, Kalashnikov, 6. c4'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r1bqk1nr/pp2bppp/2np4/1N2p3/2P1P3/8/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'B32t',
			# TRANSLATORS: B32t: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 e5 5. Nb5 d6 6. c4 Be7
			variation => N__('Sicilian: Lowenthal, Kalashnikov, 6. c4 Be7'),
			moves => {
				'b1c3' => 1,
				'f1e2' => 1,
			},
		},
		'r1bqk1nr/pp2bppp/2np4/1N2p3/2P1P3/8/PP2BPPP/RNBQK2R b KQkq' => {
			eco => 'B32u',
			# TRANSLATORS: B32u: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 e5 5. Nb5 d6 6. c4 Be7 7. Be2
			variation => N__('Sicilian: Lowenthal, Kalashnikov, 6. c4 Be7 7. Be2'),
			moves => {
			},
		},
		'r1bqk1nr/pp2bppp/2np4/1N2p3/2P1P3/2N5/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'B32v',
			# TRANSLATORS: B32v: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 e5 5. Nb5 d6 6. c4 Be7 7. N1c3
			variation => N__('Sicilian: Lowenthal, Kalashnikov, 6. c4 Be7 7.N1c3'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r1bqk1nr/1p2bppp/p1np4/1N2p3/2P1P3/2N5/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'B32v',
			# TRANSLATORS: B32v: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 e5 5. Nb5 d6 6. c4 Be7 7. N1c3 a6
			variation => N__('Sicilian: Lowenthal, Kalashnikov, 6. c4 Be7 7.N1c3'),
			moves => {
				'b5a3' => 1,
			},
		},
		'r1bqk1nr/1p2bppp/p1np4/4p3/2P1P3/N1N5/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'B32v',
			# TRANSLATORS: B32v: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 e5 5. Nb5 d6 6. c4 Be7 7. N1c3 a6 8. Na3
			variation => N__('Sicilian: Lowenthal, Kalashnikov, 6. c4 Be7 7.N1c3'),
			moves => {
				'c8e6' => 1,
			},
		},
		'r2qk1nr/1p2bppp/p1npb3/4p3/2P1P3/N1N5/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'B32w',
			# TRANSLATORS: B32w: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 e5 5. Nb5 d6 6. c4 Be7 7. N1c3 a6 8. Na3 Be6
			variation => N__('Sicilian: Lowenthal, Kalashnikov, Main Line'),
			moves => {
				'a3c2' => 1,
				'f1e2' => 1,
			},
		},
		'r2qk1nr/1p2bppp/p1npb3/4p3/2P1P3/2N5/PPN2PPP/R1BQKB1R b KQkq' => {
			eco => 'B32x',
			# TRANSLATORS: B32x: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 e5 5. Nb5 d6 6. c4 Be7 7. N1c3 a6 8. Na3 Be6 9. Nc2
			variation => N__('Sicilian: Lowenthal, Kalashnikov, Main Line, 9. Nc2'),
			moves => {
			},
		},
		'r2qk1nr/1p2bppp/p1npb3/4p3/2P1P3/N1N5/PP2BPPP/R1BQK2R b KQkq' => {
			eco => 'B32y',
			# TRANSLATORS: B32y: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 e5 5. Nb5 d6 6. c4 Be7 7. N1c3 a6 8. Na3 Be6 9. Be2
			variation => N__('Sicilian: Lowenthal, Kalashnikov, Main Line, 9. Be2'),
			moves => {
			},
		},
		'r1bqkb1r/pp1ppppp/2n2n2/8/3NP3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B33a',
			# TRANSLATORS: B33a: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6
			variation => N__('Sicilian: Open, 2... Nc6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r1bqkb1r/pp1ppppp/2n2n2/8/3NP3/2N5/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B33a',
			# TRANSLATORS: B33a: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3
			variation => N__('Sicilian: Open, 2... Nc6'),
			moves => {
				'd8b6' => 1,
				'e7e5' => 1,
			},
		},
		'r1b1kb1r/pp1ppppp/1qn2n2/8/3NP3/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B33b',
			# TRANSLATORS: B33b: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Qb6
			variation => N__('Sicilian: Open, 2... Nc6, 5... Qb6'),
			moves => {
				'd4b3' => 1,
			},
		},
		'r1b1kb1r/pp1ppppp/1qn2n2/8/4P3/1NN5/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B33b',
			# TRANSLATORS: B33b: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Qb6 6. Nb3
			variation => N__('Sicilian: Open, 2... Nc6, 5... Qb6 6. Nb3'),
			moves => {
				'e7e6' => 1,
			},
		},
		'r1b1kb1r/pp1p1ppp/1qn1pn2/8/4P3/1NN5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B33b',
			# TRANSLATORS: B33b: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Qb6 6. Nb3 e6
			variation => N__('Sicilian: Open, 2... Nc6, 5... Qb6 6. Nb3 e6'),
			moves => {
				'f1d3' => 1,
			},
		},
		'r1b1kb1r/pp1p1ppp/1qn1pn2/8/4P3/1NNB4/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'B33c',
			# TRANSLATORS: B33c: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Qb6 6. Nb3 e6 7. Bd3
			variation => N__('Sicilian: Open, 2... Nc6, 5... Qb6 6. Nb3 e6 7. Bd3'),
			moves => {
			},
		},
		'r1bqkb1r/pp1p1ppp/2n2n2/4p3/3NP3/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B33d',
			# TRANSLATORS: B33d: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5
			variation => N__('Sicilian: Pelikan/Sveshnikov'),
			moves => {
				'd4b3' => 1,
				'd4b5' => 1,
				'd4c6' => 1,
				'd4f3' => 1,
				'd4f5' => 1,
			},
		},
		'r1bqkb1r/pp1p1ppp/2n2n2/4p3/4P3/1NN5/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B33d',
			# TRANSLATORS: B33d: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Nb3
			variation => N__('Sicilian: Pelikan/Sveshnikov, 6. Nb3'),
			moves => {
			},
		},
		'r1bqkb1r/pp1p1ppp/2N2n2/4p3/4P3/2N5/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B33d',
			# TRANSLATORS: B33d: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Nxc6
			variation => N__('Sicilian: Pelikan/Sveshnikov, 6.Nxc6'),
			moves => {
			},
		},
		'r1bqkb1r/pp1p1ppp/2n2n2/4p3/4P3/2N2N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B33d',
			# TRANSLATORS: B33d: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Nf3
			variation => N__('Sicilian: Pelikan/Sveshnikov, 6. Nf3'),
			moves => {
			},
		},
		'r1bqkb1r/pp1p1ppp/2n2n2/4pN2/4P3/2N5/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B33d',
			# TRANSLATORS: B33d: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Nf5
			variation => N__('Sicilian: Pelikan/Sveshnikov, 6. Nf5'),
			moves => {
			},
		},
		'r1bqkb1r/pp1p1ppp/2n2n2/1N2p3/4P3/2N5/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B33e',
			# TRANSLATORS: B33e: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5
			variation => N__('Sicilian: Pelikan/Sveshnikov, 6.Nbd5'),
			moves => {
				'd7d6' => 1,
				'h7h6' => 1,
			},
		},
		'r1bqkb1r/pp1p1pp1/2n2n1p/1N2p3/4P3/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B33e',
			# TRANSLATORS: B33e: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 h6
			variation => N__('Sicilian: Pelikan, Haberditz Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2np1n2/1N2p3/4P3/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B33f',
			# TRANSLATORS: B33f: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6
			variation => N__('Sicilian: Pelikan/Sveshnikov, Pelikan Variation'),
			moves => {
				'a2a4' => 1,
				'b5a3' => 1,
				'c1g5' => 1,
				'c3d5' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2np1n2/4p3/4P3/N1N5/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B33f',
			# TRANSLATORS: B33f: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. Na3
			variation => N__('Sicilian: Pelikan, 7. Na3'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2np1n2/1N2p3/P3P3/2N5/1PP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B33g',
			# TRANSLATORS: B33g: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. a4
			variation => N__('Sicilian: Pelikan, 7. a4'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r1bqkb1r/1p3ppp/p1np1n2/1N2p3/P3P3/2N5/1PP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B33g',
			# TRANSLATORS: B33g: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. a4 a6
			variation => N__('Sicilian: Pelikan, 7. a4'),
			moves => {
				'b5a3' => 1,
			},
		},
		'r1bqkb1r/1p3ppp/p1np1n2/4p3/P3P3/N1N5/1PP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B33g',
			# TRANSLATORS: B33g: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. a4 a6 8. Na3
			variation => N__('Sicilian: Pelikan, 7. a4'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2np1n2/1N1Np3/4P3/8/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B33h',
			# TRANSLATORS: B33h: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. Nd5
			variation => N__('Sicilian: Pelikan, 7. Nd5'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2np1n2/1N2p1B1/4P3/2N5/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'B33i',
			# TRANSLATORS: B33i: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. Bg5
			variation => N__('Sicilian: Pelikan, 7. Bg5'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r1bqkb1r/1p3ppp/p1np1n2/1N2p1B1/4P3/2N5/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B33i',
			# TRANSLATORS: B33i: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. Bg5 a6
			variation => N__('Sicilian: Pelikan, 7. Bg5 a6'),
			moves => {
				'b5a3' => 1,
				'g5f6' => 1,
			},
		},
		'r1bqkb1r/1p3ppp/p1np1B2/1N2p3/4P3/2N5/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'B33j',
			# TRANSLATORS: B33j: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. Bg5 a6 8. Bxf6
			variation => N__('Sicilian: Pelikan, 7. Bg5 a6 8.Bxf6'),
			moves => {
			},
		},
		'r1bqkb1r/1p3ppp/p1np1n2/4p1B1/4P3/N1N5/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'B33k',
			# TRANSLATORS: B33k: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. Bg5 a6 8. Na3
			variation => N__('Sicilian: Pelikan, 7. Bg5 a6 8. Na3'),
			moves => {
				'b7b5' => 1,
				'c8e6' => 1,
			},
		},
		'r2qkb1r/1p3ppp/p1npbn2/4p1B1/4P3/N1N5/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B33k',
			# TRANSLATORS: B33k: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. Bg5 a6 8. Na3 Be6
			variation => N__('Sicilian: Pelikan, Bird Variation'),
			moves => {
			},
		},
		'r1bqkb1r/5ppp/p1np1n2/1p2p1B1/4P3/N1N5/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B33l',
			# TRANSLATORS: B33l: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. Bg5 a6 8. Na3 b5
			variation => N__('Sicilian: Pelikan, Chelyabinsk Variation'),
			moves => {
				'c3d5' => 1,
				'g5f6' => 1,
			},
		},
		'r1bqkb1r/5ppp/p1np1n2/1p1Np1B1/4P3/N7/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'B33l',
			# TRANSLATORS: B33l: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. Bg5 a6 8. Na3 b5 9. Nd5
			variation => N__('Sicilian: Pelikan, Chelyabinsk, 9. Nd5'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r1bqk2r/4bppp/p1np1n2/1p1Np1B1/4P3/N7/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B33m',
			# TRANSLATORS: B33m: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. Bg5 a6 8. Na3 b5 9. Nd5 Be7
			variation => N__('Sicilian: Pelikan, Chelyabinsk, 9. Nd5 Be7'),
			moves => {
				'g5f6' => 1,
			},
		},
		'r1bqk2r/4bppp/p1np1B2/1p1Np3/4P3/N7/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'B33m',
			# TRANSLATORS: B33m: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. Bg5 a6 8. Na3 b5 9. Nd5 Be7 10. Bxf6
			variation => N__('Sicilian: Pelikan, Chelyabinsk, 9. Nd5 Be7'),
			moves => {
				'e7f6' => 1,
			},
		},
		'r1bqk2r/5ppp/p1np1b2/1p1Np3/4P3/N7/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B33m',
			# TRANSLATORS: B33m: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. Bg5 a6 8. Na3 b5 9. Nd5 Be7 10. Bxf6 Bxf6
			variation => N__('Sicilian: Pelikan, Chelyabinsk, 9. Nd5 Be7'),
			moves => {
				'c2c3' => 1,
			},
		},
		'r1bqk2r/5ppp/p1np1b2/1p1Np3/4P3/N1P5/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'B33n',
			# TRANSLATORS: B33n: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. Bg5 a6 8. Na3 b5 9. Nd5 Be7 10. Bxf6 Bxf6 11. c3
			variation => N__('Sicilian: Pelikan, Chelyabinsk, 9. Nd5 Be7, 11. c3'),
			moves => {
				'e8g8' => 1,
				'f6g5' => 1,
			},
		},
		'r1bq1rk1/5ppp/p1np1b2/1p1Np3/4P3/N1P5/PP3PPP/R2QKB1R w KQ' => {
			eco => 'B33o',
			# TRANSLATORS: B33o: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. Bg5 a6 8. Na3 b5 9. Nd5 Be7 10. Bxf6 Bxf6 11. c3 O-O
			variation => N__('Sicilian: Pelikan, Chelyabinsk, 9. Nd5 Be7, 11. c3 O-O'),
			moves => {
				'a3c2' => 1,
			},
		},
		'r1bq1rk1/5ppp/p1np1b2/1p1Np3/4P3/2P5/PPN2PPP/R2QKB1R b KQ' => {
			eco => 'B33o',
			# TRANSLATORS: B33o: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. Bg5 a6 8. Na3 b5 9. Nd5 Be7 10. Bxf6 Bxf6 11. c3 O-O 12. Nc2
			variation => N__('Sicilian: Pelikan, Chelyabinsk, 9. Nd5 Be7, 11. c3 O-O'),
			moves => {
				'f6g5' => 1,
			},
		},
		'r1bqk2r/5ppp/p1np4/1p1Np1b1/4P3/N1P5/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'B33p',
			# TRANSLATORS: B33p: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. Bg5 a6 8. Na3 b5 9. Nd5 Be7 10. Bxf6 Bxf6 11. c3 Bg5
			variation => N__('Sicilian: Pelikan, Chelyabinsk, 9. Nd5 Be7, 11. c3 Bg5'),
			moves => {
			},
		},
		'r1bq1rk1/5ppp/p1np4/1p1Np1b1/4P3/2P5/PPN2PPP/R2QKB1R w KQ' => {
			eco => 'B33q',
			# TRANSLATORS: B33q: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. Bg5 a6 8. Na3 b5 9. Nd5 Be7 10. Bxf6 Bxf6 11. c3 O-O 12. Nc2 Bg5
			variation => N__('Sicilian: Pelikan, Chelyabinsk, 9. Nd5 Be7, 11. c3 O-O 12. Nc2 Bg5'),
			moves => {
				'a2a4' => 1,
			},
		},
		'r1bq1rk1/5ppp/p1np4/1p1Np1b1/P3P3/2P5/1PN2PPP/R2QKB1R b KQ' => {
			eco => 'B33r',
			# TRANSLATORS: B33r: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. Bg5 a6 8. Na3 b5 9. Nd5 Be7 10. Bxf6 Bxf6 11. c3 O-O 12. Nc2 Bg5 13. a4
			variation => N__('Sicilian: Pelikan, Chelyabinsk, 9. Nd5 Be7, 11. c3 O-O 12. Nc2 Bg5 13. a4'),
			moves => {
			},
		},
		'r1bqkb1r/5ppp/p1np1B2/1p2p3/4P3/N1N5/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'B33s',
			# TRANSLATORS: B33s: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. Bg5 a6 8. Na3 b5 9. Bxf6
			variation => N__('Sicilian: Pelikan, Chelyabinsk, 9.Bxf6'),
			moves => {
				'g7f6' => 1,
			},
		},
		'r1bqkb1r/5p1p/p1np1p2/1p2p3/4P3/N1N5/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B33s',
			# TRANSLATORS: B33s: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. Bg5 a6 8. Na3 b5 9. Bxf6 gxf6
			variation => N__('Sicilian: Pelikan, Chelyabinsk, 9.Bxf6 gxf6'),
			moves => {
				'c3d5' => 1,
			},
		},
		'r1bqkb1r/5p1p/p1np1p2/1p1Np3/4P3/N7/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'B33s',
			# TRANSLATORS: B33s: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. Bg5 a6 8. Na3 b5 9. Bxf6 gxf6 10. Nd5
			variation => N__('Sicilian: Pelikan, Chelyabinsk, 9.Bxf6 gxf6 10. Nd5'),
			moves => {
				'f6f5' => 1,
				'f8g7' => 1,
			},
		},
		'r1bqk2r/5pbp/p1np1p2/1p1Np3/4P3/N7/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B33s',
			# TRANSLATORS: B33s: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. Bg5 a6 8. Na3 b5 9. Bxf6 gxf6 10. Nd5 Bg7
			variation => N__('Sicilian: Pelikan, Chelyabinsk, 9.Bxf6 gxf6 10. Nd5 Bg7'),
			moves => {
				'f1d3' => 1,
			},
		},
		'r1bqk2r/5pbp/p1np1p2/1p1Np3/4P3/N2B4/PPP2PPP/R2QK2R b KQkq' => {
			eco => 'B33t',
			# TRANSLATORS: B33t: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. Bg5 a6 8. Na3 b5 9. Bxf6 gxf6 10. Nd5 Bg7 11. Bd3
			variation => N__('Sicilian: Pelikan, Chelyabinsk, 9.Bxf6 gxf6 10. Nd5 Bg7 11. Bd3'),
			moves => {
			},
		},
		'r1bqkb1r/5p1p/p1np4/1p1Npp2/4P3/N7/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B33u',
			# TRANSLATORS: B33u: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. Bg5 a6 8. Na3 b5 9. Bxf6 gxf6 10. Nd5 f5
			variation => N__('Sicilian: Pelikan, Sveshnikov Variation'),
			moves => {
				'c2c3' => 1,
				'f1d3' => 1,
			},
		},
		'r1bqkb1r/5p1p/p1np4/1p1Npp2/4P3/N1P5/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'B33v',
			# TRANSLATORS: B33v: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. Bg5 a6 8. Na3 b5 9. Bxf6 gxf6 10. Nd5 f5 11. c3
			variation => N__('Sicilian: Pelikan, Sveshnikov, 11. c3'),
			moves => {
				'f8g7' => 1,
			},
		},
		'r1bqk2r/5pbp/p1np4/1p1Npp2/4P3/N1P5/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'B33v',
			# TRANSLATORS: B33v: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. Bg5 a6 8. Na3 b5 9. Bxf6 gxf6 10. Nd5 f5 11. c3 Bg7
			variation => N__('Sicilian: Pelikan, Sveshnikov, 11. c3 Bg7'),
			moves => {
				'e4f5' => 1,
			},
		},
		'r1bqk2r/5pbp/p1np4/1p1NpP2/8/N1P5/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'B33v',
			# TRANSLATORS: B33v: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. Bg5 a6 8. Na3 b5 9. Bxf6 gxf6 10. Nd5 f5 11. c3 Bg7 12. exf5
			variation => N__('Sicilian: Pelikan, Sveshnikov, 11. c3 Bg7'),
			moves => {
				'c8f5' => 1,
			},
		},
		'r2qk2r/5pbp/p1np4/1p1Npb2/8/N1P5/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'B33v',
			# TRANSLATORS: B33v: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. Bg5 a6 8. Na3 b5 9. Bxf6 gxf6 10. Nd5 f5 11. c3 Bg7 12. exf5 Bxf5
			variation => N__('Sicilian: Pelikan, Sveshnikov, 11. c3 Bg7 12.exf5 Bxf5'),
			moves => {
				'a3c2' => 1,
			},
		},
		'r2qk2r/5pbp/p1np4/1p1Npb2/8/2P5/PPN2PPP/R2QKB1R b KQkq' => {
			eco => 'B33v',
			# TRANSLATORS: B33v: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. Bg5 a6 8. Na3 b5 9. Bxf6 gxf6 10. Nd5 f5 11. c3 Bg7 12. exf5 Bxf5 13. Nc2
			variation => N__('Sicilian: Pelikan, Sveshnikov, 11. c3 Bg7 12.exf5 Bxf5'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r2q1rk1/5pbp/p1np4/1p1Npb2/8/2P5/PPN2PPP/R2QKB1R w KQ' => {
			eco => 'B33w',
			# TRANSLATORS: B33w: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. Bg5 a6 8. Na3 b5 9. Bxf6 gxf6 10. Nd5 f5 11. c3 Bg7 12. exf5 Bxf5 13. Nc2 O-O
			variation => N__('Sicilian: Pelikan, Sveshnikov, 11. c3 Bg7 12.exf5 Bxf5 13. Nc2 O-O'),
			moves => {
			},
		},
		'r1bqkb1r/5p1p/p1np4/1p1Npp2/4P3/N2B4/PPP2PPP/R2QK2R b KQkq' => {
			eco => 'B33x',
			# TRANSLATORS: B33x: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. Bg5 a6 8. Na3 b5 9. Bxf6 gxf6 10. Nd5 f5 11. Bd3
			variation => N__('Sicilian: Pelikan, Sveshnikov, 11. Bd3'),
			moves => {
				'c8e6' => 1,
			},
		},
		'r2qkb1r/5p1p/p1npb3/1p1Npp2/4P3/N2B4/PPP2PPP/R2QK2R w KQkq' => {
			eco => 'B33x',
			# TRANSLATORS: B33x: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. Bg5 a6 8. Na3 b5 9. Bxf6 gxf6 10. Nd5 f5 11. Bd3 Be6
			variation => N__('Sicilian: Pelikan, Sveshnikov, 11. Bd3 Be6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r2qkb1r/5p1p/p1npb3/1p1Npp2/4P3/N2B4/PPP2PPP/R2Q1RK1 b kq' => {
			eco => 'B33y',
			# TRANSLATORS: B33y: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Ndb5 d6 7. Bg5 a6 8. Na3 b5 9. Bxf6 gxf6 10. Nd5 f5 11. Bd3 Be6 12. O-O
			variation => N__('Sicilian: Pelikan, Sveshnikov, 11. Bd3 Be6 12.O-O'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppp1p/2n3p1/8/3NP3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B34a',
			# TRANSLATORS: B34a: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6
			variation => N__('Sicilian: Accelerated Fianchetto'),
			moves => {
				'b1c3' => 1,
				'c1e3' => 1,
				'c2c4' => 1,
				'd4c6' => 1,
				'f1c4' => 1,
				'f1e2' => 1,
			},
		},
		'r1bqkbnr/pp1ppp1p/2n3p1/8/2BNP3/8/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'B34b',
			# TRANSLATORS: B34b: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Bc4
			variation => N__('Sicilian: Accelerated Fianchetto, 5. Bc4'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppp1p/2N3p1/8/4P3/8/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B34c',
			# TRANSLATORS: B34c: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nxc6
			variation => N__('Sicilian: Accelerated Fianchetto, Exchange Variation'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppp1p/2n3p1/8/3NP3/8/PPP1BPPP/RNBQK2R b KQkq' => {
			eco => 'B34d',
			# TRANSLATORS: B34d: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Be2
			variation => N__('Sicilian: Accelerated Fianchetto, 5. Be2'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppp1p/2n3p1/8/3NP3/4B3/PPP2PPP/RN1QKB1R b KQkq' => {
			eco => 'B34e',
			# TRANSLATORS: B34e: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Be3
			variation => N__('Sicilian: Accelerated Fianchetto, 5. Be3'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppp1p/2n3p1/8/3NP3/2N5/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B34f',
			# TRANSLATORS: B34f: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3
			variation => N__('Sicilian: Accelerated Fianchetto, Modern Variation'),
			moves => {
				'f8g7' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkb1r/pp1ppp1p/2n2np1/8/3NP3/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B34g',
			# TRANSLATORS: B34g: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Nf6
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 5... Nf6'),
			moves => {
				'd4c6' => 1,
			},
		},
		'r1bqkb1r/pp1ppp1p/2N2np1/8/4P3/2N5/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B34h',
			# TRANSLATORS: B34h: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Nf6 6. Nxc6
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 5... Nf6 6.Nxc6'),
			moves => {
				'b7c6' => 1,
			},
		},
		'r1bqkb1r/p2ppp1p/2p2np1/8/4P3/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B34i',
			# TRANSLATORS: B34i: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Nf6 6. Nxc6 bxc6
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 5... Nf6 6.Nxc6 bxc6'),
			moves => {
			},
		},
		'r1bqk1nr/pp1pppbp/2n3p1/8/3NP3/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B34j',
			# TRANSLATORS: B34j: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 5... Bg7'),
			moves => {
				'c1e3' => 1,
				'd4b3' => 1,
				'd4e2' => 1,
			},
		},
		'r1bqk1nr/pp1pppbp/2n3p1/8/4P3/2N5/PPP1NPPP/R1BQKB1R b KQkq' => {
			eco => 'B34k',
			# TRANSLATORS: B34k: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Nde2
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 6.Nde2'),
			moves => {
			},
		},
		'r1bqk1nr/pp1pppbp/2n3p1/8/4P3/1NN5/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B34l',
			# TRANSLATORS: B34l: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Nb3
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 6. Nb3'),
			moves => {
			},
		},
		'r1bqk1nr/pp1pppbp/2n3p1/8/3NP3/2N1B3/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'B34m',
			# TRANSLATORS: B34m: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 6. Be3'),
			moves => {
				'd7d6' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqk1nr/pp2ppbp/2np2p1/8/3NP3/2N1B3/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B34n',
			# TRANSLATORS: B34n: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 d6
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 6. Be3 d6'),
			moves => {
				'd1d2' => 1,
			},
		},
		'r1bqk1nr/pp2ppbp/2np2p1/8/3NP3/2N1B3/PPPQ1PPP/R3KB1R b KQkq' => {
			eco => 'B34o',
			# TRANSLATORS: B34o: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 d6 7. Qd2
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 6. Be3 d6 7. Qd2'),
			moves => {
			},
		},
		'r1bqk2r/pp1pppbp/2n2np1/8/3NP3/2N1B3/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B34p',
			# TRANSLATORS: B34p: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 Nf6
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 6. Be3 Nf6'),
			moves => {
				'd4c6' => 1,
				'f1c4' => 1,
				'f1e2' => 1,
				'f2f3' => 1,
			},
		},
		'r1bqk2r/pp1pppbp/2n2np1/8/3NP3/2N1BP2/PPP3PP/R2QKB1R b KQkq' => {
			eco => 'B34q',
			# TRANSLATORS: B34q: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 Nf6 7. f3
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 6. Be3 Nf6 7. f3'),
			moves => {
			},
		},
		'r1bqk2r/pp1pppbp/2N2np1/8/4P3/2N1B3/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'B34r',
			# TRANSLATORS: B34r: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 Nf6 7. Nxc6
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 6. Be3 Nf6 7.Nxc6'),
			moves => {
				'b7c6' => 1,
			},
		},
		'r1bqk2r/p2pppbp/2p2np1/8/4P3/2N1B3/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B34r',
			# TRANSLATORS: B34r: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 Nf6 7. Nxc6 bxc6
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 6. Be3 Nf6 7.Nxc6 bxc6'),
			moves => {
				'e4e5' => 1,
			},
		},
		'r1bqk2r/p2pppbp/2p2np1/4P3/8/2N1B3/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'B34r',
			# TRANSLATORS: B34r: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 Nf6 7. Nxc6 bxc6 8. e5
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 6. Be3 Nf6 7.Nxc6 bxc6 8. e5'),
			moves => {
				'f6g8' => 1,
			},
		},
		'r1bqk1nr/p2pppbp/2p3p1/4P3/8/2N1B3/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B34s',
			# TRANSLATORS: B34s: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 Nf6 7. Nxc6 bxc6 8. e5 Ng8
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 6. Be3 Nf6 7.Nxc6 bxc6 8. e5 Ng8'),
			moves => {
			},
		},
		'r1bqk2r/pp1pppbp/2n2np1/8/3NP3/2N1B3/PPP1BPPP/R2QK2R b KQkq' => {
			eco => 'B34t',
			# TRANSLATORS: B34t: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 Nf6 7. Be2
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 6. Be3 Nf6 7. Be2'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp1pppbp/2n2np1/8/3NP3/2N1B3/PPP1BPPP/R2QK2R w KQ' => {
			eco => 'B34u',
			# TRANSLATORS: B34u: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 Nf6 7. Be2 O-O
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 6. Be3 Nf6 7. Be2 O-O'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bq1rk1/pp1pppbp/2n2np1/8/3NP3/2N1B3/PPP1BPPP/R2Q1RK1 b -' => {
			eco => 'B34v',
			# TRANSLATORS: B34v: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 Nf6 7. Be2 O-O 8. O-O
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 6. Be3 Nf6 7. Be2 O-O 8.O-O'),
			moves => {
				'd7d5' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2n2np1/3p4/3NP3/2N1B3/PPP1BPPP/R2Q1RK1 w -' => {
			eco => 'B34v',
			# TRANSLATORS: B34v: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 Nf6 7. Be2 O-O 8. O-O d5
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 6. Be3 Nf6 7. Be2 O-O 8.O-O d5'),
			moves => {
				'e4d5' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2n2np1/3P4/3N4/2N1B3/PPP1BPPP/R2Q1RK1 b -' => {
			eco => 'B34w',
			# TRANSLATORS: B34w: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 Nf6 7. Be2 O-O 8. O-O d5 9. exd5
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 6. Be3 Nf6 7. Be2 O-O 8.O-O d5 9.exd5'),
			moves => {
			},
		},
		'r1bqk2r/pp1pppbp/2n2np1/8/2BNP3/2N1B3/PPP2PPP/R2QK2R b KQkq' => {
			eco => 'B35a',
			# TRANSLATORS: B35a: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 Nf6 7. Bc4
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 7. Bc4'),
			moves => {
				'd8a5' => 1,
				'e8g8' => 1,
			},
		},
		'r1b1k2r/pp1pppbp/2n2np1/q7/2BNP3/2N1B3/PPP2PPP/R2QK2R w KQkq' => {
			eco => 'B35b',
			# TRANSLATORS: B35b: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 Nf6 7. Bc4 Qa5
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 7. Bc4 Qa5'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1b1k2r/pp1pppbp/2n2np1/q7/2BNP3/2N1B3/PPP2PPP/R2Q1RK1 b kq' => {
			eco => 'B35b',
			# TRANSLATORS: B35b: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 Nf6 7. Bc4 Qa5 8. O-O
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 7. Bc4 Qa5'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1b2rk1/pp1pppbp/2n2np1/q7/2BNP3/2N1B3/PPP2PPP/R2Q1RK1 w -' => {
			eco => 'B35c',
			# TRANSLATORS: B35c: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 Nf6 7. Bc4 Qa5 8. O-O O-O
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 7. Bc4 Qa5 8.O-O O-O'),
			moves => {
				'c4b3' => 1,
			},
		},
		'r1b2rk1/pp1pppbp/2n2np1/q7/3NP3/1BN1B3/PPP2PPP/R2Q1RK1 b -' => {
			eco => 'B35d',
			# TRANSLATORS: B35d: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 Nf6 7. Bc4 Qa5 8. O-O O-O 9. Bb3
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 7. Bc4 Qa5 8.O-O O-O 9. Bb3'),
			moves => {
				'd7d6' => 1,
			},
		},
		'r1b2rk1/pp2ppbp/2np1np1/q7/3NP3/1BN1B3/PPP2PPP/R2Q1RK1 w -' => {
			eco => 'B35d',
			# TRANSLATORS: B35d: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 Nf6 7. Bc4 Qa5 8. O-O O-O 9. Bb3 d6
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 7. Bc4 Qa5 8.O-O O-O 9. Bb3'),
			moves => {
				'h2h3' => 1,
			},
		},
		'r1b2rk1/pp2ppbp/2np1np1/q7/3NP3/1BN1B2P/PPP2PP1/R2Q1RK1 b -' => {
			eco => 'B35d',
			# TRANSLATORS: B35d: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 Nf6 7. Bc4 Qa5 8. O-O O-O 9. Bb3 d6 10. h3
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 7. Bc4 Qa5 8.O-O O-O 9. Bb3'),
			moves => {
				'c8d7' => 1,
			},
		},
		'r4rk1/pp1bppbp/2np1np1/q7/3NP3/1BN1B2P/PPP2PP1/R2Q1RK1 w -' => {
			eco => 'B35d',
			# TRANSLATORS: B35d: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 Nf6 7. Bc4 Qa5 8. O-O O-O 9. Bb3 d6 10. h3 Bd7
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 7. Bc4 Qa5 8.O-O O-O 9. Bb3'),
			moves => {
				'f2f4' => 1,
			},
		},
		'r4rk1/pp1bppbp/2np1np1/q7/3NPP2/1BN1B2P/PPP3P1/R2Q1RK1 b -' => {
			eco => 'B35e',
			# TRANSLATORS: B35e: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 Nf6 7. Bc4 Qa5 8. O-O O-O 9. Bb3 d6 10. h3 Bd7 11. f4
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 7. Bc4 Qa5 8.O-O O-O 9. Bb3 d6 10. h3 Bd7 11. f4'),
			moves => {
			},
		},
		'r1bq1rk1/pp1pppbp/2n2np1/8/2BNP3/2N1B3/PPP2PPP/R2QK2R w KQ' => {
			eco => 'B35f',
			# TRANSLATORS: B35f: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 Nf6 7. Bc4 O-O
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 7. Bc4 O-O'),
			moves => {
				'c4b3' => 1,
				'e1g1' => 1,
				'f2f3' => 1,
			},
		},
		'r1bq1rk1/pp1pppbp/2n2np1/8/2BNP3/2N1BP2/PPP3PP/R2QK2R b KQ' => {
			eco => 'B35g',
			# TRANSLATORS: B35g: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 Nf6 7. Bc4 O-O 8. f3
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 7. Bc4 O-O 8. f3'),
			moves => {
			},
		},
		'r1bq1rk1/pp1pppbp/2n2np1/8/2BNP3/2N1B3/PPP2PPP/R2Q1RK1 b -' => {
			eco => 'B35h',
			# TRANSLATORS: B35h: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 Nf6 7. Bc4 O-O 8. O-O
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 7. Bc4 O-O 8.O-O'),
			moves => {
			},
		},
		'r1bq1rk1/pp1pppbp/2n2np1/8/3NP3/1BN1B3/PPP2PPP/R2QK2R b KQ' => {
			eco => 'B35i',
			# TRANSLATORS: B35i: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 Nf6 7. Bc4 O-O 8. Bb3
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 7. Bc4 O-O 8. Bb3'),
			moves => {
				'a7a5' => 1,
				'd7d6' => 1,
				'd8a5' => 1,
				'f6g4' => 1,
			},
		},
		'r1bq1rk1/pp1pppbp/2n3p1/8/3NP1n1/1BN1B3/PPP2PPP/R2QK2R w KQ' => {
			eco => 'B35j',
			# TRANSLATORS: B35j: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 Nf6 7. Bc4 O-O 8. Bb3 Ng4
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 7. Bc4 O-O 8. Bb3 Ng4'),
			moves => {
			},
		},
		'r1b2rk1/pp1pppbp/2n2np1/q7/3NP3/1BN1B3/PPP2PPP/R2QK2R w KQ' => {
			eco => 'B35k',
			# TRANSLATORS: B35k: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 Nf6 7. Bc4 O-O 8. Bb3 Qa5
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 7. Bc4 O-O 8. Bb3 Qa5'),
			moves => {
			},
		},
		'r1bq1rk1/1p1pppbp/2n2np1/p7/3NP3/1BN1B3/PPP2PPP/R2QK2R w KQ' => {
			eco => 'B35l',
			# TRANSLATORS: B35l: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 Nf6 7. Bc4 O-O 8. Bb3 a5
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 7. Bc4 O-O 8. Bb3 a5'),
			moves => {
				'a2a4' => 1,
				'f2f3' => 1,
			},
		},
		'r1bq1rk1/1p1pppbp/2n2np1/p7/P2NP3/1BN1B3/1PP2PPP/R2QK2R b KQ' => {
			eco => 'B35m',
			# TRANSLATORS: B35m: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 Nf6 7. Bc4 O-O 8. Bb3 a5 9. a4
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 7. Bc4 O-O 8. Bb3 a5 9. a4'),
			moves => {
			},
		},
		'r1bq1rk1/1p1pppbp/2n2np1/p7/3NP3/1BN1BP2/PPP3PP/R2QK2R b KQ' => {
			eco => 'B35n',
			# TRANSLATORS: B35n: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 Nf6 7. Bc4 O-O 8. Bb3 a5 9. f3
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 7. Bc4 O-O 8. Bb3 a5 9. f3'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/8/3NP3/1BN1B3/PPP2PPP/R2QK2R w KQ' => {
			eco => 'B35o',
			# TRANSLATORS: B35o: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 Nf6 7. Bc4 O-O 8. Bb3 d6
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 7. Bc4 O-O 8. Bb3 d6'),
			moves => {
				'f2f3' => 1,
				'h2h3' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/8/3NP3/1BN1B2P/PPP2PP1/R2QK2R b KQ' => {
			eco => 'B35o',
			# TRANSLATORS: B35o: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 Nf6 7. Bc4 O-O 8. Bb3 d6 9. h3
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 7. Bc4 O-O 8. Bb3 d6 9. h3'),
			moves => {
				'c8d7' => 1,
			},
		},
		'r2q1rk1/pp1bppbp/2np1np1/8/3NP3/1BN1B2P/PPP2PP1/R2QK2R w KQ' => {
			eco => 'B35p',
			# TRANSLATORS: B35p: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 Nf6 7. Bc4 O-O 8. Bb3 d6 9. h3 Bd7
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 7. Bc4 O-O 8. Bb3 d6 9. h3 Bd7'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/8/3NP3/1BN1BP2/PPP3PP/R2QK2R b KQ' => {
			eco => 'B35q',
			# TRANSLATORS: B35q: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 Nf6 7. Bc4 O-O 8. Bb3 d6 9. f3
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 7. Bc4 O-O 8. Bb3 d6 9. f3'),
			moves => {
				'c8d7' => 1,
			},
		},
		'r2q1rk1/pp1bppbp/2np1np1/8/3NP3/1BN1BP2/PPP3PP/R2QK2R w KQ' => {
			eco => 'B35r',
			# TRANSLATORS: B35r: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. Nc3 Bg7 6. Be3 Nf6 7. Bc4 O-O 8. Bb3 d6 9. f3 Bd7
			variation => N__('Sicilian: Accelerated Fianchetto, Modern, 7. Bc4 O-O 8. Bb3 d6 9. f3 Bd7'),
			moves => {
			},
		},
		'r1bqkbnr/pp1ppp1p/2n3p1/8/2PNP3/8/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'B36a',
			# TRANSLATORS: B36a: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4
			variation => N__('Sicilian: Maroczy Bind'),
			moves => {
				'd7d6' => 1,
				'f8g7' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkbnr/pp2pp1p/2np2p1/8/2PNP3/8/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'B36b',
			# TRANSLATORS: B36b: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 d6
			variation => N__('Sicilian: Maroczy Bind, 5... d6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r1bqkbnr/pp2pp1p/2np2p1/8/2PNP3/2N5/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'B36b',
			# TRANSLATORS: B36b: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 d6 6. Nc3
			variation => N__('Sicilian: Maroczy Bind, 5... d6 6. Nc3'),
			moves => {
				'f8g7' => 1,
			},
		},
		'r1bqk1nr/pp2ppbp/2np2p1/8/2PNP3/2N5/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'B36b',
			# TRANSLATORS: B36b: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 d6 6. Nc3 Bg7
			variation => N__('Sicilian: Maroczy Bind, 5... d6 6. Nc3 Bg7'),
			moves => {
			},
		},
		'r1bqkb1r/pp1ppp1p/2n2np1/8/2PNP3/8/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'B36c',
			# TRANSLATORS: B36c: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Nf6
			variation => N__('Sicilian: Maroczy Bind, 5... Nf6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r1bqkb1r/pp1ppp1p/2n2np1/8/2PNP3/2N5/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'B36d',
			# TRANSLATORS: B36d: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Nf6 6. Nc3
			variation => N__('Sicilian: Maroczy Bind, 5... Nf6 6. Nc3'),
			moves => {
				'c6d4' => 1,
				'd7d6' => 1,
			},
		},
		'r1bqkb1r/pp1ppp1p/5np1/8/2PnP3/2N5/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'B36e',
			# TRANSLATORS: B36e: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Nf6 6. Nc3 Nxd4
			variation => N__('Sicilian: Maroczy Bind, 5... Nf6 6. Nc3 Nxd4'),
			moves => {
				'd1d4' => 1,
			},
		},
		'r1bqkb1r/pp1ppp1p/5np1/8/2PQP3/2N5/PP3PPP/R1B1KB1R b KQkq' => {
			eco => 'B36e',
			# TRANSLATORS: B36e: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Nf6 6. Nc3 Nxd4 7. Qxd4
			variation => N__('Sicilian: Maroczy Bind, 5... Nf6 6. Nc3 Nxd4'),
			moves => {
				'd7d6' => 1,
			},
		},
		'r1bqkb1r/pp2pp1p/3p1np1/8/2PQP3/2N5/PP3PPP/R1B1KB1R w KQkq' => {
			eco => 'B36f',
			# TRANSLATORS: B36f: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Nf6 6. Nc3 Nxd4 7. Qxd4 d6
			variation => N__('Sicilian: Maroczy Bind, Gurgenidze Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pp2pp1p/2np1np1/8/2PNP3/2N5/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'B36g',
			# TRANSLATORS: B36g: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Nf6 6. Nc3 d6
			variation => N__('Sicilian: Maroczy Bind, 5... Nf6 6. Nc3 d6'),
			moves => {
				'f1e2' => 1,
			},
		},
		'r1bqkb1r/pp2pp1p/2np1np1/8/2PNP3/2N5/PP2BPPP/R1BQK2R b KQkq' => {
			eco => 'B36h',
			# TRANSLATORS: B36h: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Nf6 6. Nc3 d6 7. Be2
			variation => N__('Sicilian: Maroczy Bind, 5... Nf6 6. Nc3 d6 7. Be2'),
			moves => {
				'c6d4' => 1,
			},
		},
		'r1bqkb1r/pp2pp1p/3p1np1/8/2PnP3/2N5/PP2BPPP/R1BQK2R w KQkq' => {
			eco => 'B36i',
			# TRANSLATORS: B36i: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Nf6 6. Nc3 d6 7. Be2 Nxd4
			variation => N__('Sicilian: Maroczy Bind, 5... Nf6 6. Nc3 d6 7. Be2 Nxd4'),
			moves => {
				'd1d4' => 1,
			},
		},
		'r1bqkb1r/pp2pp1p/3p1np1/8/2PQP3/2N5/PP2BPPP/R1B1K2R b KQkq' => {
			eco => 'B36i',
			# TRANSLATORS: B36i: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Nf6 6. Nc3 d6 7. Be2 Nxd4 8. Qxd4
			variation => N__('Sicilian: Maroczy Bind, 5... Nf6 6. Nc3 d6 7. Be2 Nxd4'),
			moves => {
				'f8g7' => 1,
			},
		},
		'r1bqk2r/pp2ppbp/3p1np1/8/2PQP3/2N5/PP2BPPP/R1B1K2R w KQkq' => {
			eco => 'B36i',
			# TRANSLATORS: B36i: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Nf6 6. Nc3 d6 7. Be2 Nxd4 8. Qxd4 Bg7
			variation => N__('Sicilian: Maroczy Bind, 5... Nf6 6. Nc3 d6 7. Be2 Nxd4 8.Qxd4 Bg7'),
			moves => {
				'c1e3' => 1,
				'c1g5' => 1,
				'e1g1' => 1,
			},
		},
		'r1bqk2r/pp2ppbp/3p1np1/8/2PQP3/2N5/PP2BPPP/R1B2RK1 b kq' => {
			eco => 'B36j',
			# TRANSLATORS: B36j: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Nf6 6. Nc3 d6 7. Be2 Nxd4 8. Qxd4 Bg7 9. O-O
			variation => N__('Sicilian: Maroczy Bind, 5... Nf6 6. Nc3 d6 7. Be2 Nxd4 8.Qxd4 Bg7 9.O-O'),
			moves => {
			},
		},
		'r1bqk2r/pp2ppbp/3p1np1/6B1/2PQP3/2N5/PP2BPPP/R3K2R b KQkq' => {
			eco => 'B36k',
			# TRANSLATORS: B36k: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Nf6 6. Nc3 d6 7. Be2 Nxd4 8. Qxd4 Bg7 9. Bg5
			variation => N__('Sicilian: Maroczy Bind, 5... Nf6 6. Nc3 d6 7. Be2 Nxd4 8.Qxd4 Bg7 9. Bg5'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/3p1np1/6B1/2PQP3/2N5/PP2BPPP/R3K2R w KQ' => {
			eco => 'B36l',
			# TRANSLATORS: B36l: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Nf6 6. Nc3 d6 7. Be2 Nxd4 8. Qxd4 Bg7 9. Bg5 O-O
			variation => N__('Sicilian: Maroczy Bind, 5... Nf6 6. Nc3 d6 7. Be2 Nxd4 8.Qxd4 Bg7 9. Bg5 O-O'),
			moves => {
				'd4d2' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/3p1np1/6B1/2P1P3/2N5/PP1QBPPP/R3K2R b KQ' => {
			eco => 'B36m',
			# TRANSLATORS: B36m: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Nf6 6. Nc3 d6 7. Be2 Nxd4 8. Qxd4 Bg7 9. Bg5 O-O 10. Qd2
			variation => N__('Sicilian: Maroczy Bind, 5... Nf6 6. Nc3 d6 7. Be2 Nxd4 8.Qxd4 Bg7 9. Bg5 O-O 10. Qd2'),
			moves => {
			},
		},
		'r1bqk2r/pp2ppbp/3p1np1/8/2PQP3/2N1B3/PP2BPPP/R3K2R b KQkq' => {
			eco => 'B36n',
			# TRANSLATORS: B36n: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Nf6 6. Nc3 d6 7. Be2 Nxd4 8. Qxd4 Bg7 9. Be3
			variation => N__('Sicilian: Maroczy Bind, 5... Nf6 6. Nc3 d6 7. Be2 Nxd4 8.Qxd4 Bg7 9. Be3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/3p1np1/8/2PQP3/2N1B3/PP2BPPP/R3K2R w KQ' => {
			eco => 'B36n',
			# TRANSLATORS: B36n: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Nf6 6. Nc3 d6 7. Be2 Nxd4 8. Qxd4 Bg7 9. Be3 O-O
			variation => N__('Sicilian: Maroczy Bind, 5... Nf6 6. Nc3 d6 7. Be2 Nxd4 8.Qxd4 Bg7 9. Be3 O-O'),
			moves => {
				'd4d2' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/3p1np1/8/2P1P3/2N1B3/PP1QBPPP/R3K2R b KQ' => {
			eco => 'B36o',
			# TRANSLATORS: B36o: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Nf6 6. Nc3 d6 7. Be2 Nxd4 8. Qxd4 Bg7 9. Be3 O-O 10. Qd2
			variation => N__('Sicilian: Maroczy Bind, 5... Nf6 6. Nc3 d6 7. Be2 Nxd4 8.Qxd4 Bg7 9. Be3 O-O 10. Qd2'),
			moves => {
				'c8e6' => 1,
			},
		},
		'r2q1rk1/pp2ppbp/3pbnp1/8/2P1P3/2N1B3/PP1QBPPP/R3K2R w KQ' => {
			eco => 'B36p',
			# TRANSLATORS: B36p: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Nf6 6. Nc3 d6 7. Be2 Nxd4 8. Qxd4 Bg7 9. Be3 O-O 10. Qd2 Be6
			variation => N__('Sicilian: Maroczy Bind, 5... Nf6 6. Nc3 d6 7. Be2 Nxd4 8.Qxd4 Bg7 9. Be3 O-O 10. Qd2 Be6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r2q1rk1/pp2ppbp/3pbnp1/8/2P1P3/2N1B3/PP1QBPPP/R4RK1 b -' => {
			eco => 'B36q',
			# TRANSLATORS: B36q: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Nf6 6. Nc3 d6 7. Be2 Nxd4 8. Qxd4 Bg7 9. Be3 O-O 10. Qd2 Be6 11. O-O
			variation => N__('Sicilian: Maroczy Bind, 5... Nf6 6. Nc3 d6 7. Be2 Nxd4 8.Qxd4 Bg7 9. Be3 O-O 10. Qd2 Be6 11.O-O'),
			moves => {
			},
		},
		'r1bqk1nr/pp1pppbp/2n3p1/8/2PNP3/8/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'B37a',
			# TRANSLATORS: B37a: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7
			variation => N__('Sicilian: Maroczy Bind, 5... Bg7'),
			moves => {
				'c1e3' => 1,
				'd4b3' => 1,
				'd4c2' => 1,
			},
		},
		'r1bqk1nr/pp1pppbp/2n3p1/8/2P1P3/1N6/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'B37b',
			# TRANSLATORS: B37b: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Nb3
			variation => N__('Sicilian: Maroczy Bind, 6. Nb3'),
			moves => {
			},
		},
		'r1bqk1nr/pp1pppbp/2n3p1/8/2P1P3/8/PPN2PPP/RNBQKB1R b KQkq' => {
			eco => 'B37c',
			# TRANSLATORS: B37c: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Nc2
			variation => N__('Sicilian: Maroczy Bind, 6. Nc2'),
			moves => {
				'd7d6' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqk1nr/pp2ppbp/2np2p1/8/2P1P3/8/PPN2PPP/RNBQKB1R w KQkq' => {
			eco => 'B37d',
			# TRANSLATORS: B37d: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Nc2 d6
			variation => N__('Sicilian: Maroczy Bind, 6. Nc2 d6'),
			moves => {
				'f1e2' => 1,
			},
		},
		'r1bqk1nr/pp2ppbp/2np2p1/8/2P1P3/8/PPN1BPPP/RNBQK2R b KQkq' => {
			eco => 'B37e',
			# TRANSLATORS: B37e: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Nc2 d6 7. Be2
			variation => N__('Sicilian: Maroczy Bind, 6. Nc2 d6 7. Be2'),
			moves => {
				'g8h6' => 1,
			},
		},
		'r1bqk2r/pp2ppbp/2np2pn/8/2P1P3/8/PPN1BPPP/RNBQK2R w KQkq' => {
			eco => 'B37f',
			# TRANSLATORS: B37f: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Nc2 d6 7. Be2 Nh6
			variation => N__('Sicilian: Maroczy Bind, Simagin Variation'),
			moves => {
			},
		},
		'r1bqk2r/pp1pppbp/2n2np1/8/2P1P3/8/PPN2PPP/RNBQKB1R w KQkq' => {
			eco => 'B37g',
			# TRANSLATORS: B37g: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Nc2 Nf6
			variation => N__('Sicilian: Maroczy Bind, 6. Nc2 Nf6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r1bqk2r/pp1pppbp/2n2np1/8/2P1P3/2N5/PPN2PPP/R1BQKB1R b KQkq' => {
			eco => 'B37g',
			# TRANSLATORS: B37g: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Nc2 Nf6 7. Nc3
			variation => N__('Sicilian: Maroczy Bind, 6. Nc2 Nf6 7. Nc3'),
			moves => {
				'd7d6' => 1,
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp1pppbp/2n2np1/8/2P1P3/2N5/PPN2PPP/R1BQKB1R w KQ' => {
			eco => 'B37h',
			# TRANSLATORS: B37h: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Nc2 Nf6 7. Nc3 O-O
			variation => N__('Sicilian: Maroczy Bind, 6. Nc2 Nf6 7. Nc3 O-O'),
			moves => {
			},
		},
		'r1bqk2r/pp2ppbp/2np1np1/8/2P1P3/2N5/PPN2PPP/R1BQKB1R w KQkq' => {
			eco => 'B37i',
			# TRANSLATORS: B37i: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Nc2 Nf6 7. Nc3 d6
			variation => N__('Sicilian: Maroczy Bind, 6. Nc2 Nf6 7. Nc3 d6'),
			moves => {
				'f1e2' => 1,
			},
		},
		'r1bqk2r/pp2ppbp/2np1np1/8/2P1P3/2N5/PPN1BPPP/R1BQK2R b KQkq' => {
			eco => 'B37i',
			# TRANSLATORS: B37i: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Nc2 Nf6 7. Nc3 d6 8. Be2
			variation => N__('Sicilian: Maroczy Bind, 6. Nc2 Nf6 7. Nc3 d6 8. Be2'),
			moves => {
				'e8g8' => 1,
				'f6d7' => 1,
			},
		},
		'r1bqk2r/pp1nppbp/2np2p1/8/2P1P3/2N5/PPN1BPPP/R1BQK2R w KQkq' => {
			eco => 'B37j',
			# TRANSLATORS: B37j: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Nc2 Nf6 7. Nc3 d6 8. Be2 Nd7
			variation => N__('Sicilian: Maroczy Bind, 6. Nc2 Nf6 7. Nc3 d6 8. Be2 Nd7'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/8/2P1P3/2N5/PPN1BPPP/R1BQK2R w KQ' => {
			eco => 'B37k',
			# TRANSLATORS: B37k: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Nc2 Nf6 7. Nc3 d6 8. Be2 O-O
			variation => N__('Sicilian: Maroczy Bind, 6. Nc2 Nf6 7. Nc3 d6 8. Be2 O-O'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/8/2P1P3/2N5/PPN1BPPP/R1BQ1RK1 b -' => {
			eco => 'B37l',
			# TRANSLATORS: B37l: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Nc2 Nf6 7. Nc3 d6 8. Be2 O-O 9. O-O
			variation => N__('Sicilian: Maroczy Bind, 6. Nc2 Nf6 7. Nc3 d6 8. Be2 O-O 9.O-O'),
			moves => {
				'c8e6' => 1,
				'f6d7' => 1,
			},
		},
		'r2q1rk1/pp2ppbp/2npbnp1/8/2P1P3/2N5/PPN1BPPP/R1BQ1RK1 w -' => {
			eco => 'B37m',
			# TRANSLATORS: B37m: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Nc2 Nf6 7. Nc3 d6 8. Be2 O-O 9. O-O Be6
			variation => N__('Sicilian: Maroczy Bind, 6. Nc2 Nf6 7. Nc3 d6 8. Be2 O-O 9.O-O Be6'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nppbp/2np2p1/8/2P1P3/2N5/PPN1BPPP/R1BQ1RK1 w -' => {
			eco => 'B37n',
			# TRANSLATORS: B37n: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Nc2 Nf6 7. Nc3 d6 8. Be2 O-O 9. O-O Nd7
			variation => N__('Sicilian: Maroczy Bind, 6. Nc2 Nf6 7. Nc3 d6 8. Be2 O-O 9.O-O Nd7'),
			moves => {
				'c1d2' => 1,
			},
		},
		'r1bq1rk1/pp1nppbp/2np2p1/8/2P1P3/2N5/PPNBBPPP/R2Q1RK1 b -' => {
			eco => 'B37o',
			# TRANSLATORS: B37o: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Nc2 Nf6 7. Nc3 d6 8. Be2 O-O 9. O-O Nd7 10. Bd2
			variation => N__('Sicilian: Maroczy Bind, 6. Nc2 Nf6 7. Nc3 d6 8. Be2 O-O 9.O-O Nd7 10. Bd2'),
			moves => {
				'a7a5' => 1,
				'd7c5' => 1,
			},
		},
		'r1bq1rk1/1p1nppbp/2np2p1/p7/2P1P3/2N5/PPNBBPPP/R2Q1RK1 w -' => {
			eco => 'B37o',
			# TRANSLATORS: B37o: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Nc2 Nf6 7. Nc3 d6 8. Be2 O-O 9. O-O Nd7 10. Bd2 a5
			variation => N__('Sicilian: Maroczy Bind, 6. Nc2 Nf6 7. Nc3 d6 8. Be2 O-O 9.O-O Nd7 10. Bd2 a5'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/2np2p1/2n5/2P1P3/2N5/PPNBBPPP/R2Q1RK1 w -' => {
			eco => 'B37p',
			# TRANSLATORS: B37p: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Nc2 Nf6 7. Nc3 d6 8. Be2 O-O 9. O-O Nd7 10. Bd2 Nc5
			variation => N__('Sicilian: Maroczy Bind, 6. Nc2 Nf6 7. Nc3 d6 8. Be2 O-O 9.O-O Nd7 10. Bd2 Nc5'),
			moves => {
				'b2b4' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2np2p1/2n5/1PP1P3/2N5/P1NBBPPP/R2Q1RK1 b -' => {
			eco => 'B37q',
			# TRANSLATORS: B37q: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Nc2 Nf6 7. Nc3 d6 8. Be2 O-O 9. O-O Nd7 10. Bd2 Nc5 11. b4
			variation => N__('Sicilian: Maroczy Bind, 6. Nc2 Nf6 7. Nc3 d6 8. Be2 O-O 9.O-O Nd7 10. Bd2 Nc5 11. b4'),
			moves => {
			},
		},
		'r1bqk1nr/pp1pppbp/2n3p1/8/2PNP3/4B3/PP3PPP/RN1QKB1R b KQkq' => {
			eco => 'B38a',
			# TRANSLATORS: B38a: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3
			variation => N__('Sicilian: Maroczy Bind, 6. Be3'),
			moves => {
				'd7d6' => 1,
				'g8f6' => 1,
				'g8h6' => 1,
			},
		},
		'r1bqk2r/pp1pppbp/2n3pn/8/2PNP3/4B3/PP3PPP/RN1QKB1R w KQkq' => {
			eco => 'B38b',
			# TRANSLATORS: B38b: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nh6
			variation => N__('Sicilian: Maroczy Bind, 6. Be3 Nh6'),
			moves => {
			},
		},
		'r1bqk1nr/pp2ppbp/2np2p1/8/2PNP3/4B3/PP3PPP/RN1QKB1R w KQkq' => {
			eco => 'B38c',
			# TRANSLATORS: B38c: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 d6
			variation => N__('Sicilian: Maroczy Bind, 6. Be3 d6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r1bqk1nr/pp2ppbp/2np2p1/8/2PNP3/2N1B3/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'B38c',
			# TRANSLATORS: B38c: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 d6 7. Nc3
			variation => N__('Sicilian: Maroczy Bind, 6. Be3 d6'),
			moves => {
				'g8h6' => 1,
			},
		},
		'r1bqk2r/pp2ppbp/2np2pn/8/2PNP3/2N1B3/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'B38c',
			# TRANSLATORS: B38c: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 d6 7. Nc3 Nh6
			variation => N__('Sicilian: Maroczy Bind, 6. Be3 d6 7. Nc3 Nh6'),
			moves => {
			},
		},
		'r1bqk2r/pp1pppbp/2n2np1/8/2PNP3/4B3/PP3PPP/RN1QKB1R w KQkq' => {
			eco => 'B38d',
			# TRANSLATORS: B38d: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6
			variation => N__('Sicilian: Maroczy Bind, 6. Be3 Nf6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r1bqk2r/pp1pppbp/2n2np1/8/2PNP3/2N1B3/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'B38d',
			# TRANSLATORS: B38d: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3
			variation => N__('Sicilian: Maroczy Bind, 6. Be3 Nf6 7. Nc3'),
			moves => {
				'd7d6' => 1,
				'e8g8' => 1,
				'f6g4' => 1,
			},
		},
		'r1bqk2r/pp2ppbp/2np1np1/8/2PNP3/2N1B3/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'B38e',
			# TRANSLATORS: B38e: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 d6
			variation => N__('Sicilian: Maroczy Bind, 6. Be3 Nf6 7. Nc3 d6'),
			moves => {
				'f1e2' => 1,
			},
		},
		'r1bqk2r/pp2ppbp/2np1np1/8/2PNP3/2N1B3/PP2BPPP/R2QK2R b KQkq' => {
			eco => 'B38f',
			# TRANSLATORS: B38f: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 d6 8. Be2
			variation => N__('Sicilian: Maroczy Bind, 6. Be3 Nf6 7. Nc3 d6 8. Be2'),
			moves => {
			},
		},
		'r1bq1rk1/pp1pppbp/2n2np1/8/2PNP3/2N1B3/PP3PPP/R2QKB1R w KQ' => {
			eco => 'B38g',
			# TRANSLATORS: B38g: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 O-O
			variation => N__('Sicilian: Maroczy Bind, 7. Nc3 O-O'),
			moves => {
				'f1e2' => 1,
			},
		},
		'r1bq1rk1/pp1pppbp/2n2np1/8/2PNP3/2N1B3/PP2BPPP/R2QK2R b KQ' => {
			eco => 'B38g',
			# TRANSLATORS: B38g: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 O-O 8. Be2
			variation => N__('Sicilian: Maroczy Bind, 7. Nc3 O-O 8. Be2'),
			moves => {
				'b7b6' => 1,
				'd7d6' => 1,
			},
		},
		'r1bq1rk1/p2pppbp/1pn2np1/8/2PNP3/2N1B3/PP2BPPP/R2QK2R w KQ' => {
			eco => 'B38h',
			# TRANSLATORS: B38h: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 O-O 8. Be2 b6
			variation => N__('Sicilian: Maroczy Bind, 7. Nc3 O-O 8. Be2 b6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bq1rk1/p2pppbp/1pn2np1/8/2PNP3/2N1B3/PP2BPPP/R2Q1RK1 b -' => {
			eco => 'B38i',
			# TRANSLATORS: B38i: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 O-O 8. Be2 b6 9. O-O
			variation => N__('Sicilian: Maroczy Bind, 7. Nc3 O-O 8. Be2 b6 9.O-O'),
			moves => {
				'c8b7' => 1,
			},
		},
		'r2q1rk1/pb1pppbp/1pn2np1/8/2PNP3/2N1B3/PP2BPPP/R2Q1RK1 w -' => {
			eco => 'B38i',
			# TRANSLATORS: B38i: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 O-O 8. Be2 b6 9. O-O Bb7
			variation => N__('Sicilian: Maroczy Bind, 7. Nc3 O-O 8. Be2 b6 9.O-O Bb7'),
			moves => {
				'f2f3' => 1,
			},
		},
		'r2q1rk1/pb1pppbp/1pn2np1/8/2PNP3/2N1BP2/PP2B1PP/R2Q1RK1 b -' => {
			eco => 'B38j',
			# TRANSLATORS: B38j: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 O-O 8. Be2 b6 9. O-O Bb7 10. f3
			variation => N__('Sicilian: Maroczy Bind, 7. Nc3 O-O 8. Be2 b6 9.O-O Bb7 10. f3'),
			moves => {
				'd8b8' => 1,
			},
		},
		'rq3rk1/pb1pppbp/1pn2np1/8/2PNP3/2N1BP2/PP2B1PP/R2Q1RK1 w -' => {
			eco => 'B38k',
			# TRANSLATORS: B38k: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 O-O 8. Be2 b6 9. O-O Bb7 10. f3 Qb8
			variation => N__('Sicilian: Maroczy Bind, 7. Nc3 O-O 8. Be2 b6 9.O-O Bb7 10. f3 Qb8'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/8/2PNP3/2N1B3/PP2BPPP/R2QK2R w KQ' => {
			eco => 'B38l',
			# TRANSLATORS: B38l: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 O-O 8. Be2 d6
			variation => N__('Sicilian: Maroczy Bind, 7. Nc3 O-O 8. Be2 d6'),
			moves => {
				'e1g1' => 1,
				'f2f3' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/8/2PNP3/2N1BP2/PP2B1PP/R2QK2R b KQ' => {
			eco => 'B38m',
			# TRANSLATORS: B38m: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 O-O 8. Be2 d6 9. f3
			variation => N__('Sicilian: Maroczy Bind, 7. Nc3 O-O 8. Be2 d6 9. f3'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/8/2PNP3/2N1B3/PP2BPPP/R2Q1RK1 b -' => {
			eco => 'B38n',
			# TRANSLATORS: B38n: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 O-O 8. Be2 d6 9. O-O
			variation => N__('Sicilian: Maroczy Bind, 7. Nc3 O-O 8. Be2 d6 9.O-O'),
			moves => {
				'a7a6' => 1,
				'c6d4' => 1,
				'c8d7' => 1,
				'f6d7' => 1,
			},
		},
		'r1bq1rk1/pp1nppbp/2np2p1/8/2PNP3/2N1B3/PP2BPPP/R2Q1RK1 w -' => {
			eco => 'B38o',
			# TRANSLATORS: B38o: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 O-O 8. Be2 d6 9. O-O Nd7
			variation => N__('Sicilian: Maroczy Bind, 7. Nc3 O-O 8. Be2 d6 9.O-O Nd7'),
			moves => {
			},
		},
		'r1bq1rk1/1p2ppbp/p1np1np1/8/2PNP3/2N1B3/PP2BPPP/R2Q1RK1 w -' => {
			eco => 'B38p',
			# TRANSLATORS: B38p: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 O-O 8. Be2 d6 9. O-O a6
			variation => N__('Sicilian: Maroczy Bind, 7. Nc3 O-O 8. Be2 d6 9.O-O a6'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/3p1np1/8/2PnP3/2N1B3/PP2BPPP/R2Q1RK1 w -' => {
			eco => 'B38q',
			# TRANSLATORS: B38q: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 O-O 8. Be2 d6 9. O-O Nxd4
			variation => N__('Sicilian: Maroczy Bind, 7. Nc3 O-O 8. Be2 d6 9.O-O Nxd4'),
			moves => {
			},
		},
		'r2q1rk1/pp1bppbp/2np1np1/8/2PNP3/2N1B3/PP2BPPP/R2Q1RK1 w -' => {
			eco => 'B38r',
			# TRANSLATORS: B38r: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 O-O 8. Be2 d6 9. O-O Bd7
			variation => N__('Sicilian: Maroczy Bind, 7. Nc3 O-O 8. Be2 d6 9.O-O Bd7'),
			moves => {
				'a1c1' => 1,
				'd1d2' => 1,
				'd4c2' => 1,
				'f2f3' => 1,
			},
		},
		'r2q1rk1/pp1bppbp/2np1np1/8/2P1P3/2N1B3/PPN1BPPP/R2Q1RK1 b -' => {
			eco => 'B38s',
			# TRANSLATORS: B38s: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 O-O 8. Be2 d6 9. O-O Bd7 10. Nc2
			variation => N__('Sicilian: Maroczy Bind, 7. Nc3 O-O 8. Be2 d6 9.O-O Bd7 10. Nc2'),
			moves => {
			},
		},
		'r2q1rk1/pp1bppbp/2np1np1/8/2PNP3/2N1BP2/PP2B1PP/R2Q1RK1 b -' => {
			eco => 'B38t',
			# TRANSLATORS: B38t: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 O-O 8. Be2 d6 9. O-O Bd7 10. f3
			variation => N__('Sicilian: Maroczy Bind, 7. Nc3 O-O 8. Be2 d6 9.O-O Bd7 10. f3'),
			moves => {
			},
		},
		'r2q1rk1/pp1bppbp/2np1np1/8/2PNP3/2N1B3/PP2BPPP/2RQ1RK1 b -' => {
			eco => 'B38u',
			# TRANSLATORS: B38u: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 O-O 8. Be2 d6 9. O-O Bd7 10. Rc1
			variation => N__('Sicilian: Maroczy Bind, 7. Nc3 O-O 8. Be2 d6 9.O-O Bd7 10. Rc1'),
			moves => {
			},
		},
		'r2q1rk1/pp1bppbp/2np1np1/8/2PNP3/2N1B3/PP1QBPPP/R4RK1 b -' => {
			eco => 'B38v',
			# TRANSLATORS: B38v: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 O-O 8. Be2 d6 9. O-O Bd7 10. Qd2
			variation => N__('Sicilian: Maroczy Bind, 7. Nc3 O-O 8. Be2 d6 9.O-O Bd7 10. Qd2'),
			moves => {
				'c6d4' => 1,
			},
		},
		'r2q1rk1/pp1bppbp/3p1np1/8/2PnP3/2N1B3/PP1QBPPP/R4RK1 w -' => {
			eco => 'B38w',
			# TRANSLATORS: B38w: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 O-O 8. Be2 d6 9. O-O Bd7 10. Qd2 Nxd4
			variation => N__('Sicilian: Maroczy Bind, 7. Nc3 O-O 8. Be2 d6 9.O-O Bd7 10. Qd2 Nxd4'),
			moves => {
				'e3d4' => 1,
			},
		},
		'r2q1rk1/pp1bppbp/3p1np1/8/2PBP3/2N5/PP1QBPPP/R4RK1 b -' => {
			eco => 'B38w',
			# TRANSLATORS: B38w: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 O-O 8. Be2 d6 9. O-O Bd7 10. Qd2 Nxd4 11. Bxd4
			variation => N__('Sicilian: Maroczy Bind, 7. Nc3 O-O 8. Be2 d6 9.O-O Bd7 10. Qd2 Nxd4 11.Bxd4'),
			moves => {
				'd7c6' => 1,
			},
		},
		'r2q1rk1/pp2ppbp/2bp1np1/8/2PBP3/2N5/PP1QBPPP/R4RK1 w -' => {
			eco => 'B38w',
			# TRANSLATORS: B38w: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 O-O 8. Be2 d6 9. O-O Bd7 10. Qd2 Nxd4 11. Bxd4 Bc6
			variation => N__('Sicilian: Maroczy Bind, 7. Nc3 O-O 8. Be2 d6 9.O-O Bd7 10. Qd2 Nxd4 11.Bxd4'),
			moves => {
				'f2f3' => 1,
			},
		},
		'r2q1rk1/pp2ppbp/2bp1np1/8/2PBP3/2N2P2/PP1QB1PP/R4RK1 b -' => {
			eco => 'B38x',
			# TRANSLATORS: B38x: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 O-O 8. Be2 d6 9. O-O Bd7 10. Qd2 Nxd4 11. Bxd4 Bc6 12. f3
			variation => N__('Sicilian: Maroczy Bind, 7. Nc3 O-O 8. Be2 d6 9.O-O Bd7 10. Qd2 Nxd4, 12. f3'),
			moves => {
				'a7a5' => 1,
			},
		},
		'r2q1rk1/1p2ppbp/2bp1np1/p7/2PBP3/2N2P2/PP1QB1PP/R4RK1 w -' => {
			eco => 'B38y',
			# TRANSLATORS: B38y: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 O-O 8. Be2 d6 9. O-O Bd7 10. Qd2 Nxd4 11. Bxd4 Bc6 12. f3 a5
			variation => N__('Sicilian: Maroczy Bind, 7. Nc3 O-O 8. Be2 d6 9.O-O Bd7 10. Qd2 Nxd4, 12. f3 a5'),
			moves => {
				'b2b3' => 1,
			},
		},
		'r2q1rk1/1p2ppbp/2bp1np1/p7/2PBP3/1PN2P2/P2QB1PP/R4RK1 b -' => {
			eco => 'B38z',
			# TRANSLATORS: B38z: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 O-O 8. Be2 d6 9. O-O Bd7 10. Qd2 Nxd4 11. Bxd4 Bc6 12. f3 a5 13. b3
			variation => N__('Sicilian: Maroczy Bind, 7. Nc3 O-O 8. Be2 d6 9.O-O Bd7 10. Qd2 Nxd4, 12. f3 a5 13. b3'),
			moves => {
			},
		},
		'r1bqk2r/pp1pppbp/2n3p1/8/2PNP1n1/2N1B3/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'B39a',
			# TRANSLATORS: B39a: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 Ng4
			variation => N__('Sicilian: Maroczy Bind, Breyer Variation'),
			moves => {
				'd1g4' => 1,
			},
		},
		'r1bqk2r/pp1pppbp/2n3p1/8/2PNP1Q1/2N1B3/PP3PPP/R3KB1R b KQkq' => {
			eco => 'B39b',
			# TRANSLATORS: B39b: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 Ng4 8. Qxg4
			variation => N__('Sicilian: Maroczy Bind, Breyer, 8.Qxg4'),
			moves => {
				'c6d4' => 1,
			},
		},
		'r1bqk2r/pp1pppbp/6p1/8/2PnP1Q1/2N1B3/PP3PPP/R3KB1R w KQkq' => {
			eco => 'B39c',
			# TRANSLATORS: B39c: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 Ng4 8. Qxg4 Nxd4
			variation => N__('Sicilian: Maroczy Bind, Breyer, 8.Qxg4 Nxd4'),
			moves => {
				'g4d1' => 1,
			},
		},
		'r1bqk2r/pp1pppbp/6p1/8/2PnP3/2N1B3/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'B39d',
			# TRANSLATORS: B39d: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 Ng4 8. Qxg4 Nxd4 9. Qd1
			variation => N__('Sicilian: Maroczy Bind, Breyer, 8.Qxg4 Nxd4 9. Qd1'),
			moves => {
				'd4e6' => 1,
				'e7e5' => 1,
			},
		},
		'r1bqk2r/pp1p1pbp/6p1/4p3/2PnP3/2N1B3/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'B39e',
			# TRANSLATORS: B39e: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 Ng4 8. Qxg4 Nxd4 9. Qd1 e5
			variation => N__('Sicilian: Maroczy Bind, Breyer, 8.Qxg4 Nxd4 9. Qd1 e5'),
			moves => {
				'c3b5' => 1,
				'f1d3' => 1,
			},
		},
		'r1bqk2r/pp1p1pbp/6p1/1N2p3/2PnP3/4B3/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'B39f',
			# TRANSLATORS: B39f: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 Ng4 8. Qxg4 Nxd4 9. Qd1 e5 10. Nb5
			variation => N__('Sicilian: Maroczy Bind, Breyer, 8.Qxg4 Nxd4 9. Qd1 e5 10. Nb5'),
			moves => {
			},
		},
		'r1bqk2r/pp1p1pbp/6p1/4p3/2PnP3/2NBB3/PP3PPP/R2QK2R b KQkq' => {
			eco => 'B39g',
			# TRANSLATORS: B39g: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 Ng4 8. Qxg4 Nxd4 9. Qd1 e5 10. Bd3
			variation => N__('Sicilian: Maroczy Bind, Breyer, 8.Qxg4 Nxd4 9. Qd1 e5 10. Bd3'),
			moves => {
			},
		},
		'r1bqk2r/pp1pppbp/4n1p1/8/2P1P3/2N1B3/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'B39h',
			# TRANSLATORS: B39h: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 Ng4 8. Qxg4 Nxd4 9. Qd1 Ne6
			variation => N__('Sicilian: Maroczy Bind, Breyer, 8.Qxg4 Nxd4 9. Qd1 Ne6'),
			moves => {
				'a1c1' => 1,
				'd1d2' => 1,
			},
		},
		'r1bqk2r/pp1pppbp/4n1p1/8/2P1P3/2N1B3/PP1Q1PPP/R3KB1R b KQkq' => {
			eco => 'B39i',
			# TRANSLATORS: B39i: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 Ng4 8. Qxg4 Nxd4 9. Qd1 Ne6 10. Qd2
			variation => N__('Sicilian: Maroczy Bind, Breyer, 8.Qxg4 Nxd4 9. Qd1 Ne6 10. Qd2'),
			moves => {
			},
		},
		'r1bqk2r/pp1pppbp/4n1p1/8/2P1P3/2N1B3/PP3PPP/2RQKB1R b Kkq' => {
			eco => 'B39j',
			# TRANSLATORS: B39j: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 Ng4 8. Qxg4 Nxd4 9. Qd1 Ne6 10. Rc1
			variation => N__('Sicilian: Maroczy Bind, Breyer, 8.Qxg4 Nxd4 9. Qd1 Ne6 10. Rc1'),
			moves => {
				'd8a5' => 1,
			},
		},
		'r1b1k2r/pp1pppbp/4n1p1/q7/2P1P3/2N1B3/PP3PPP/2RQKB1R w Kkq' => {
			eco => 'B39k',
			# TRANSLATORS: B39k: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 Ng4 8. Qxg4 Nxd4 9. Qd1 Ne6 10. Rc1 Qa5
			variation => N__('Sicilian: Maroczy Bind, Breyer, 8.Qxg4 Nxd4 9. Qd1 Ne6 10. Rc1 Qa5'),
			moves => {
				'd1d2' => 1,
			},
		},
		'r1b1k2r/pp1pppbp/4n1p1/q7/2P1P3/2N1B3/PP1Q1PPP/2R1KB1R b Kkq' => {
			eco => 'B39l',
			# TRANSLATORS: B39l: 1. e4 c5 2. Nf3 Nc6 3. d4 cxd4 4. Nxd4 g6 5. c4 Bg7 6. Be3 Nf6 7. Nc3 Ng4 8. Qxg4 Nxd4 9. Qd1 Ne6 10. Rc1 Qa5 11. Qd2
			variation => N__('Sicilian: Maroczy Bind, Breyer, 8.Qxg4 Nxd4 9. Qd1 Ne6 10. Rc1 Qa5 11. Qd2'),
			moves => {
			},
		},
		'rnbqkbnr/pp1p1ppp/4p3/2p5/4P3/5N2/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'B40a',
			# TRANSLATORS: B40a: 1. e4 c5 2. Nf3 e6
			variation => N__('Sicilian: 2... e6'),
			moves => {
				'b1c3' => 1,
				'b2b3' => 1,
				'c2c4' => 1,
				'd2d3' => 1,
				'd2d4' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/pp1p1ppp/4p3/2p5/2P1P3/5N2/PP1P1PPP/RNBQKB1R b KQkq' => {
			eco => 'B40b',
			# TRANSLATORS: B40b: 1. e4 c5 2. Nf3 e6 3. c4
			variation => N__('Sicilian: 2... e6 3. c4'),
			moves => {
			},
		},
		'rnbqkbnr/pp1p1ppp/4p3/2p5/4P3/1P3N2/P1PP1PPP/RNBQKB1R b KQkq' => {
			eco => 'B40c',
			# TRANSLATORS: B40c: 1. e4 c5 2. Nf3 e6 3. b3
			variation => N__('Sicilian: 2... e6 3. b3'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkbnr/pp1p1ppp/2n1p3/2p5/4P3/1P3N2/P1PP1PPP/RNBQKB1R w KQkq' => {
			eco => 'B40d',
			# TRANSLATORS: B40d: 1. e4 c5 2. Nf3 e6 3. b3 Nc6
			variation => N__('Sicilian: 2... e6 3. b3 Nc6'),
			moves => {
			},
		},
		'rnbqkbnr/pp1p1ppp/4p3/2p5/4P3/5NP1/PPPP1P1P/RNBQKB1R b KQkq' => {
			eco => 'B40e',
			# TRANSLATORS: B40e: 1. e4 c5 2. Nf3 e6 3. g3
			variation => N__('Sicilian: 2... e6 3. g3'),
			moves => {
			},
		},
		'rnbqkbnr/pp1p1ppp/4p3/2p5/4P3/3P1N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B40f',
			# TRANSLATORS: B40f: 1. e4 c5 2. Nf3 e6 3. d3
			variation => N__('Sicilian: 2... e6 3. d3'),
			moves => {
			},
		},
		'rnbqkbnr/pp1p1ppp/4p3/2p5/4P3/2N2N2/PPPP1PPP/R1BQKB1R b KQkq' => {
			eco => 'B40g',
			# TRANSLATORS: B40g: 1. e4 c5 2. Nf3 e6 3. Nc3
			variation => N__('Sicilian: 2... e6 3. Nc3'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkbnr/pp1p1ppp/2n1p3/2p5/4P3/2N2N2/PPPP1PPP/R1BQKB1R w KQkq' => {
			eco => 'B40h',
			# TRANSLATORS: B40h: 1. e4 c5 2. Nf3 e6 3. Nc3 Nc6
			variation => N__('Sicilian: 2... e6 3. Nc3 Nc6'),
			moves => {
			},
		},
		'rnbqkbnr/pp1p1ppp/4p3/2p5/3PP3/5N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B40i',
			# TRANSLATORS: B40i: 1. e4 c5 2. Nf3 e6 3. d4
			variation => N__('Sicilian: 2... e6 3. d4'),
			moves => {
				'c5d4' => 1,
				'd7d5' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/4p3/2pp4/3PP3/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B40j',
			# TRANSLATORS: B40j: 1. e4 c5 2. Nf3 e6 3. d4 d5
			variation => N__('Sicilian: Marshall Variation'),
			moves => {
			},
		},
		'rnbqkbnr/pp1p1ppp/4p3/8/3pP3/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B40k',
			# TRANSLATORS: B40k: 1. e4 c5 2. Nf3 e6 3. d4 cxd4
			variation => N__('Sicilian: Open, 2... e6'),
			moves => {
				'f3d4' => 1,
			},
		},
		'rnbqkbnr/pp1p1ppp/4p3/8/3NP3/8/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B40l',
			# TRANSLATORS: B40l: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4
			variation => N__('Sicilian: Open, 2... e6, 4.Nxd4'),
			moves => {
				'a7a6' => 1,
				'b8c6' => 1,
				'd7d6' => 1,
				'd8b6' => 1,
				'f8c5' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/3pp3/8/3NP3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B40l',
			# TRANSLATORS: B40l: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 d6
			variation => N__('Sicilian: Open, 2... e6, 4.Nxd4 d6'),
			moves => {
			},
		},
		'rnbqk1nr/pp1p1ppp/4p3/2b5/3NP3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B40m',
			# TRANSLATORS: B40m: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Bc5
			variation => N__('Sicilian: Open, 2... e6, 4.Nxd4 Bc5'),
			moves => {
			},
		},
		'rnb1kbnr/pp1p1ppp/1q2p3/8/3NP3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B40n',
			# TRANSLATORS: B40n: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Qb6
			variation => N__('Sicilian: Kveinys Variation'),
			moves => {
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/8/3NP3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B40o',
			# TRANSLATORS: B40o: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nf6
			variation => N__('Sicilian: Open, 2... e6, 4.Nxd4 Nf6'),
			moves => {
				'b1c3' => 1,
				'f1d3' => 1,
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/8/3NP3/3B4/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'B40p',
			# TRANSLATORS: B40p: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nf6 5. Bd3
			variation => N__('Sicilian: Open, 2... e6, 4.Nxd4 Nf6 5. Bd3'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkb1r/pp1p1ppp/2n1pn2/8/3NP3/3B4/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'B40p',
			# TRANSLATORS: B40p: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nf6 5. Bd3 Nc6
			variation => N__('Sicilian: Open, 2... e6, 4.Nxd4 Nf6 5. Bd3 Nc6'),
			moves => {
				'd4c6' => 1,
			},
		},
		'r1bqkb1r/pp1p1ppp/2N1pn2/8/4P3/3B4/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'B40q',
			# TRANSLATORS: B40q: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nf6 5. Bd3 Nc6 6. Nxc6
			variation => N__('Sicilian: Open, 2... e6, 4.Nxd4 Nf6 5. Bd3 Nc6 6.Nxc6'),
			moves => {
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/8/3NP3/2N5/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B40r',
			# TRANSLATORS: B40r: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3
			variation => N__('Sicilian: Open, 2... e6, 4.Nxd4 Nf6 5. Nc3'),
			moves => {
				'f8b4' => 1,
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/8/1b1NP3/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B40s',
			# TRANSLATORS: B40s: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Bb4
			variation => N__('Sicilian: Pin Variation'),
			moves => {
				'e4e5' => 1,
				'f1d3' => 1,
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/8/1b1NP3/2NB4/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'B40s',
			# TRANSLATORS: B40s: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Bb4 6. Bd3
			variation => N__('Sicilian: Pin Variation'),
			moves => {
				'e6e5' => 1,
			},
		},
		'rnbqk2r/pp1p1ppp/5n2/4p3/1b1NP3/2NB4/PPP2PPP/R1BQK2R w KQkq' => {
			eco => 'B40t',
			# TRANSLATORS: B40t: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Bb4 6. Bd3 e5
			variation => N__('Sicilian: Pin, Jaffe Variation'),
			moves => {
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/4P3/1b1N4/2N5/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B40u',
			# TRANSLATORS: B40u: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Bb4 6. e5
			variation => N__('Sicilian: Pin, Koch Variation'),
			moves => {
			},
		},
		'rnbqkbnr/1p1p1ppp/p3p3/8/3NP3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B41a',
			# TRANSLATORS: B41a: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6
			variation => N__('Sicilian: Kan (Paulsen)'),
			moves => {
				'b1c3' => 1,
				'c1e3' => 1,
				'c2c4' => 1,
				'f1d3' => 1,
				'f1e2' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/1p1p1ppp/p3p3/8/3NP3/6P1/PPP2P1P/RNBQKB1R b KQkq' => {
			eco => 'B41b',
			# TRANSLATORS: B41b: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. g3
			variation => N__('Sicilian: Kan, 5. g3'),
			moves => {
			},
		},
		'rnbqkbnr/1p1p1ppp/p3p3/8/3NP3/4B3/PPP2PPP/RN1QKB1R b KQkq' => {
			eco => 'B41c',
			# TRANSLATORS: B41c: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Be3
			variation => N__('Sicilian: Kan, 5. Be3'),
			moves => {
			},
		},
		'rnbqkbnr/1p1p1ppp/p3p3/8/3NP3/8/PPP1BPPP/RNBQK2R b KQkq' => {
			eco => 'B41d',
			# TRANSLATORS: B41d: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Be2
			variation => N__('Sicilian: Kan, 5. Be2'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/1p1p1ppp/p3pn2/8/3NP3/8/PPP1BPPP/RNBQK2R w KQkq' => {
			eco => 'B41e',
			# TRANSLATORS: B41e: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Be2 Nf6
			variation => N__('Sicilian: Kan, 5. Be2 Nf6'),
			moves => {
			},
		},
		'rnbqkbnr/1p1p1ppp/p3p3/8/2PNP3/8/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'B41f',
			# TRANSLATORS: B41f: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. c4
			variation => N__('Sicilian: Kan, 5. c4'),
			moves => {
				'd8c7' => 1,
				'g8f6' => 1,
			},
		},
		'rnb1kbnr/1pqp1ppp/p3p3/8/2PNP3/8/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'B41g',
			# TRANSLATORS: B41g: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. c4 Qc7
			variation => N__('Sicilian: Kan, 5. c4 Qc7'),
			moves => {
			},
		},
		'rnbqkb1r/1p1p1ppp/p3pn2/8/2PNP3/8/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'B41h',
			# TRANSLATORS: B41h: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. c4 Nf6
			variation => N__('Sicilian: Kan, 5. c4 Nf6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkb1r/1p1p1ppp/p3pn2/8/2PNP3/2N5/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'B41i',
			# TRANSLATORS: B41i: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. c4 Nf6 6. Nc3
			variation => N__('Sicilian: Kan, 5. c4 Nf6 6. Nc3'),
			moves => {
				'd7d6' => 1,
				'd8c7' => 1,
				'f8b4' => 1,
			},
		},
		'rnbqkb1r/1p3ppp/p2ppn2/8/2PNP3/2N5/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'B41j',
			# TRANSLATORS: B41j: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. c4 Nf6 6. Nc3 d6
			variation => N__('Sicilian: Kan, 5. c4 Nf6 6. Nc3 d6'),
			moves => {
			},
		},
		'rnbqk2r/1p1p1ppp/p3pn2/8/1bPNP3/2N5/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'B41k',
			# TRANSLATORS: B41k: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. c4 Nf6 6. Nc3 Bb4
			variation => N__('Sicilian: Kan, 5. c4 Nf6 6. Nc3 Bb4'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rnbqk2r/1p1p1ppp/p3pn2/8/1bPNP3/2NB4/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'B41k',
			# TRANSLATORS: B41k: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. c4 Nf6 6. Nc3 Bb4 7. Bd3
			variation => N__('Sicilian: Kan, 5. c4 Nf6 6. Nc3 Bb4'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqk2r/1p1p1ppp/p1n1pn2/8/1bPNP3/2NB4/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'B41k',
			# TRANSLATORS: B41k: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. c4 Nf6 6. Nc3 Bb4 7. Bd3 Nc6
			variation => N__('Sicilian: Kan, 5. c4 Nf6 6. Nc3 Bb4'),
			moves => {
				'd3c2' => 1,
			},
		},
		'r1bqk2r/1p1p1ppp/p1n1pn2/8/1bPNP3/2N5/PPB2PPP/R1BQK2R b KQkq' => {
			eco => 'B41k',
			# TRANSLATORS: B41k: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. c4 Nf6 6. Nc3 Bb4 7. Bd3 Nc6 8. Bc2
			variation => N__('Sicilian: Kan, 5. c4 Nf6, Bronstein Variation'),
			moves => {
			},
		},
		'rnb1kb1r/1pqp1ppp/p3pn2/8/2PNP3/2N5/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'B41l',
			# TRANSLATORS: B41l: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. c4 Nf6 6. Nc3 Qc7
			variation => N__('Sicilian: Kan, 5. c4 Nf6 6. Nc3 Qc7'),
			moves => {
				'f1e2' => 1,
			},
		},
		'rnb1kb1r/1pqp1ppp/p3pn2/8/2PNP3/2N5/PP2BPPP/R1BQK2R b KQkq' => {
			eco => 'B41m',
			# TRANSLATORS: B41m: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. c4 Nf6 6. Nc3 Qc7 7. Be2
			variation => N__('Sicilian: Kan, 5. c4 Nf6 6. Nc3 Qc7 7. Be2'),
			moves => {
			},
		},
		'rnbqkbnr/1p1p1ppp/p3p3/8/3NP3/3B4/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'B42a',
			# TRANSLATORS: B42a: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Bd3
			variation => N__('Sicilian: Kan, 5. Bd3'),
			moves => {
				'b8c6' => 1,
				'd8b6' => 1,
				'd8c7' => 1,
				'f8c5' => 1,
				'g7g6' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/1p1p1p1p/p3p1p1/8/3NP3/3B4/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'B42b',
			# TRANSLATORS: B42b: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Bd3 g6
			variation => N__('Sicilian: Kan, Swiss Cheese Variation'),
			moves => {
			},
		},
		'rnb1kbnr/1p1p1ppp/pq2p3/8/3NP3/3B4/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'B42c',
			# TRANSLATORS: B42c: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Bd3 Qb6
			variation => N__('Sicilian: Kan, 5. Bd3 Qb6'),
			moves => {
			},
		},
		'rnb1kbnr/1pqp1ppp/p3p3/8/3NP3/3B4/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'B42d',
			# TRANSLATORS: B42d: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Bd3 Qc7
			variation => N__('Sicilian: Kan, 5. Bd3 Qc7'),
			moves => {
			},
		},
		'r1bqkbnr/1p1p1ppp/p1n1p3/8/3NP3/3B4/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'B42e',
			# TRANSLATORS: B42e: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Bd3 Nc6
			variation => N__('Sicilian: Kan, 5. Bd3 Nc6'),
			moves => {
			},
		},
		'rnbqk1nr/1p1p1ppp/p3p3/2b5/3NP3/3B4/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'B42f',
			# TRANSLATORS: B42f: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Bd3 Bc5
			variation => N__('Sicilian: Kan, Polugaevsky Variation'),
			moves => {
				'd4b3' => 1,
			},
		},
		'rnbqk1nr/1p1p1ppp/p3p3/2b5/4P3/1N1B4/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'B42f',
			# TRANSLATORS: B42f: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Bd3 Bc5 6. Nb3
			variation => N__('Sicilian: Kan, Polugaevsky Variation'),
			moves => {
				'c5a7' => 1,
			},
		},
		'rnbqk1nr/bp1p1ppp/p3p3/8/4P3/1N1B4/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'B42g',
			# TRANSLATORS: B42g: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Bd3 Bc5 6. Nb3 Ba7
			variation => N__('Sicilian: Kan, Polugaevsky, 6. Nb3 Ba7'),
			moves => {
			},
		},
		'rnbqkb1r/1p1p1ppp/p3pn2/8/3NP3/3B4/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'B42h',
			# TRANSLATORS: B42h: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Bd3 Nf6
			variation => N__('Sicilian: Kan, 5. Bd3 Nf6'),
			moves => {
				'c2c4' => 1,
				'e1g1' => 1,
			},
		},
		'rnbqkb1r/1p1p1ppp/p3pn2/8/2PNP3/3B4/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'B42h',
			# TRANSLATORS: B42h: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Bd3 Nf6 6. c4
			variation => N__('Sicilian: Kan, 5. Bd3 Nf6 6. c4'),
			moves => {
			},
		},
		'rnbqkb1r/1p1p1ppp/p3pn2/8/3NP3/3B4/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'B42h',
			# TRANSLATORS: B42h: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Bd3 Nf6 6. O-O
			variation => N__('Sicilian: Kan, 5. Bd3 Nf6 6.O-O'),
			moves => {
				'd7d6' => 1,
				'd8c7' => 1,
			},
		},
		'rnbqkb1r/1p3ppp/p2ppn2/8/3NP3/3B4/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'B42i',
			# TRANSLATORS: B42i: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Bd3 Nf6 6. O-O d6
			variation => N__('Sicilian: Kan, 5. Bd3 Nf6 6.O-O d6'),
			moves => {
				'c2c4' => 1,
			},
		},
		'rnbqkb1r/1p3ppp/p2ppn2/8/2PNP3/3B4/PP3PPP/RNBQ1RK1 b kq' => {
			eco => 'B42j',
			# TRANSLATORS: B42j: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Bd3 Nf6 6. O-O d6 7. c4
			variation => N__('Sicilian: Kan, 5. Bd3 Nf6 6.O-O d6 7. c4'),
			moves => {
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/1p3p1p/p2ppnp1/8/2PNP3/3B4/PP3PPP/RNBQ1RK1 w kq' => {
			eco => 'B42k',
			# TRANSLATORS: B42k: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Bd3 Nf6 6. O-O d6 7. c4 g6
			variation => N__('Sicilian: Kan, Gipslis Variation'),
			moves => {
			},
		},
		'rnb1kb1r/1pqp1ppp/p3pn2/8/3NP3/3B4/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'B42l',
			# TRANSLATORS: B42l: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Bd3 Nf6 6. O-O Qc7
			variation => N__('Sicilian: Kan, 5. Bd3 Nf6 6.O-O Qc7'),
			moves => {
				'c2c4' => 1,
				'd1e2' => 1,
			},
		},
		'rnb1kb1r/1pqp1ppp/p3pn2/8/2PNP3/3B4/PP3PPP/RNBQ1RK1 b kq' => {
			eco => 'B42m',
			# TRANSLATORS: B42m: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Bd3 Nf6 6. O-O Qc7 7. c4
			variation => N__('Sicilian: Kan, 5. Bd3 Nf6 6.O-O Qc7 7. c4'),
			moves => {
			},
		},
		'rnb1kb1r/1pqp1ppp/p3pn2/8/3NP3/3B4/PPP1QPPP/RNB2RK1 b kq' => {
			eco => 'B42n',
			# TRANSLATORS: B42n: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Bd3 Nf6 6. O-O Qc7 7. Qe2
			variation => N__('Sicilian: Kan, 5. Bd3 Nf6 6.O-O Qc7 7. Qe2'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rnb1kb1r/1pq2ppp/p2ppn2/8/3NP3/3B4/PPP1QPPP/RNB2RK1 w kq' => {
			eco => 'B42n',
			# TRANSLATORS: B42n: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Bd3 Nf6 6. O-O Qc7 7. Qe2 d6
			variation => N__('Sicilian: Kan, 5. Bd3 Nf6 6.O-O Qc7 7. Qe2'),
			moves => {
				'c2c4' => 1,
			},
		},
		'rnb1kb1r/1pq2ppp/p2ppn2/8/2PNP3/3B4/PP2QPPP/RNB2RK1 b kq' => {
			eco => 'B42o',
			# TRANSLATORS: B42o: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Bd3 Nf6 6. O-O Qc7 7. Qe2 d6 8. c4
			variation => N__('Sicilian: Kan, 5. Bd3 Nf6 6.O-O Qc7 7. Qe2 d6 8. c4'),
			moves => {
			},
		},
		'rnbqkbnr/1p1p1ppp/p3p3/8/3NP3/2N5/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B43a',
			# TRANSLATORS: B43a: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Nc3
			variation => N__('Sicilian: Kan, 5. Nc3'),
			moves => {
				'b7b5' => 1,
				'd7d6' => 1,
				'd8c7' => 1,
			},
		},
		'rnbqkbnr/1p3ppp/p2pp3/8/3NP3/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B43b',
			# TRANSLATORS: B43b: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Nc3 d6
			variation => N__('Sicilian: Kan, 5. Nc3 d6'),
			moves => {
			},
		},
		'rnbqkbnr/3p1ppp/p3p3/1p6/3NP3/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B43c',
			# TRANSLATORS: B43c: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Nc3 b5
			variation => N__('Sicilian: Kan, 5. Nc3 b5'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rnbqkbnr/3p1ppp/p3p3/1p6/3NP3/2NB4/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'B43d',
			# TRANSLATORS: B43d: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Nc3 b5 6. Bd3
			variation => N__('Sicilian: Kan, 5. Nc3 b5 6. Bd3'),
			moves => {
				'd8b6' => 1,
			},
		},
		'rnb1kbnr/3p1ppp/pq2p3/1p6/3NP3/2NB4/PPP2PPP/R1BQK2R w KQkq' => {
			eco => 'B43e',
			# TRANSLATORS: B43e: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Nc3 b5 6. Bd3 Qb6
			variation => N__('Sicilian: Kan, 5. Nc3 b5 6. Bd3 Qb6'),
			moves => {
				'd4b3' => 1,
			},
		},
		'rnb1kbnr/3p1ppp/pq2p3/1p6/4P3/1NNB4/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'B43f',
			# TRANSLATORS: B43f: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Nc3 b5 6. Bd3 Qb6 7. Nb3
			variation => N__('Sicilian: Kan, 5. Nc3 b5 6. Bd3 Qb6 7. Nb3'),
			moves => {
			},
		},
		'rnb1kbnr/1pqp1ppp/p3p3/8/3NP3/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B43g',
			# TRANSLATORS: B43g: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Nc3 Qc7
			variation => N__('Sicilian: Kan, 5. Nc3 Qc7'),
			moves => {
				'f1d3' => 1,
				'f1e2' => 1,
				'g2g3' => 1,
			},
		},
		'rnb1kbnr/1pqp1ppp/p3p3/8/3NP3/2N3P1/PPP2P1P/R1BQKB1R b KQkq' => {
			eco => 'B43h',
			# TRANSLATORS: B43h: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Nc3 Qc7 6. g3
			variation => N__('Sicilian: Kan, 5. Nc3 Qc7 6. g3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnb1kb1r/1pqp1ppp/p3pn2/8/3NP3/2N3P1/PPP2P1P/R1BQKB1R w KQkq' => {
			eco => 'B43i',
			# TRANSLATORS: B43i: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Nc3 Qc7 6. g3 Nf6
			variation => N__('Sicilian: Kan, 5. Nc3 Qc7 6. g3 Nf6'),
			moves => {
			},
		},
		'rnb1kbnr/1pqp1ppp/p3p3/8/3NP3/2N5/PPP1BPPP/R1BQK2R b KQkq' => {
			eco => 'B43j',
			# TRANSLATORS: B43j: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Nc3 Qc7 6. Be2
			variation => N__('Sicilian: Kan, 5. Nc3 Qc7 6. Be2'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnb1kb1r/1pqp1ppp/p3pn2/8/3NP3/2N5/PPP1BPPP/R1BQK2R w KQkq' => {
			eco => 'B43k',
			# TRANSLATORS: B43k: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Nc3 Qc7 6. Be2 Nf6
			variation => N__('Sicilian: Kan, 5. Nc3 Qc7 6. Be2 Nf6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnb1kb1r/1pqp1ppp/p3pn2/8/3NP3/2N5/PPP1BPPP/R1BQ1RK1 b kq' => {
			eco => 'B43l',
			# TRANSLATORS: B43l: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Nc3 Qc7 6. Be2 Nf6 7. O-O
			variation => N__('Sicilian: Kan, 5. Nc3 Qc7 6. Be2 Nf6 7.O-O'),
			moves => {
			},
		},
		'rnb1kbnr/1pqp1ppp/p3p3/8/3NP3/2NB4/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'B43m',
			# TRANSLATORS: B43m: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Nc3 Qc7 6. Bd3
			variation => N__('Sicilian: Kan, 5. Nc3 Qc7 6. Bd3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnb1kb1r/1pqp1ppp/p3pn2/8/3NP3/2NB4/PPP2PPP/R1BQK2R w KQkq' => {
			eco => 'B43n',
			# TRANSLATORS: B43n: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Nc3 Qc7 6. Bd3 Nf6
			variation => N__('Sicilian: Kan, 5. Nc3 Qc7 6. Bd3 Nf6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnb1kb1r/1pqp1ppp/p3pn2/8/3NP3/2NB4/PPP2PPP/R1BQ1RK1 b kq' => {
			eco => 'B43o',
			# TRANSLATORS: B43o: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 a6 5. Nc3 Qc7 6. Bd3 Nf6 7. O-O
			variation => N__('Sicilian: Kan, 5. Nc3 Qc7 6. Bd3 Nf6 7.O-O'),
			moves => {
			},
		},
		'r1bqkbnr/pp1p1ppp/2n1p3/8/3NP3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B44a',
			# TRANSLATORS: B44a: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6
			variation => N__('Sicilian: Taimanov'),
			moves => {
				'b1c3' => 1,
				'c1e3' => 1,
				'c2c4' => 1,
				'd4b5' => 1,
				'd4c6' => 1,
				'f1e2' => 1,
				'g2g3' => 1,
			},
		},
		'r1bqkbnr/pp1p1ppp/2n1p3/8/3NP3/6P1/PPP2P1P/RNBQKB1R b KQkq' => {
			eco => 'B44b',
			# TRANSLATORS: B44b: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. g3
			variation => N__('Sicilian: Taimanov, 5. g3'),
			moves => {
			},
		},
		'r1bqkbnr/pp1p1ppp/2n1p3/8/3NP3/8/PPP1BPPP/RNBQK2R b KQkq' => {
			eco => 'B44c',
			# TRANSLATORS: B44c: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Be2
			variation => N__('Sicilian: Taimanov, 5. Be2'),
			moves => {
			},
		},
		'r1bqkbnr/pp1p1ppp/2n1p3/8/2PNP3/8/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'B44d',
			# TRANSLATORS: B44d: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. c4
			variation => N__('Sicilian: Taimanov, 5. c4'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r1bqkb1r/pp1p1ppp/2n1pn2/8/2PNP3/8/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'B44d',
			# TRANSLATORS: B44d: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. c4 Nf6
			variation => N__('Sicilian: Taimanov, 5. c4 Nf6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r1bqkb1r/pp1p1ppp/2n1pn2/8/2PNP3/2N5/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'B44e',
			# TRANSLATORS: B44e: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. c4 Nf6 6. Nc3
			variation => N__('Sicilian: Taimanov, 5. c4 Nf6 6. Nc3'),
			moves => {
				'f8b4' => 1,
			},
		},
		'r1bqk2r/pp1p1ppp/2n1pn2/8/1bPNP3/2N5/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'B44e',
			# TRANSLATORS: B44e: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. c4 Nf6 6. Nc3 Bb4
			variation => N__('Sicilian: Taimanov, 5. c4 Nf6 6. Nc3 Bb4'),
			moves => {
				'd4c6' => 1,
			},
		},
		'r1bqk2r/pp1p1ppp/2N1pn2/8/1bP1P3/2N5/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'B44e',
			# TRANSLATORS: B44e: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. c4 Nf6 6. Nc3 Bb4 7. Nxc6
			variation => N__('Sicilian: Taimanov, 5. c4 Nf6 6. Nc3 Bb4 7.Nxc6'),
			moves => {
				'b7c6' => 1,
			},
		},
		'r1bqk2r/p2p1ppp/2p1pn2/8/1bP1P3/2N5/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'B44f',
			# TRANSLATORS: B44f: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. c4 Nf6 6. Nc3 Bb4 7. Nxc6 bxc6
			variation => N__('Sicilian: Taimanov, 5. c4 Nf6 6. Nc3 Bb4 7.Nxc6 bxc6'),
			moves => {
			},
		},
		'r1bqkbnr/pp1p1ppp/2n1p3/8/3NP3/4B3/PPP2PPP/RN1QKB1R b KQkq' => {
			eco => 'B44g',
			# TRANSLATORS: B44g: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Be3
			variation => N__('Sicilian: Taimanov, 5. Be3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r1bqkb1r/pp1p1ppp/2n1pn2/8/3NP3/4B3/PPP2PPP/RN1QKB1R w KQkq' => {
			eco => 'B44h',
			# TRANSLATORS: B44h: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Be3 Nf6
			variation => N__('Sicilian: Taimanov, 5. Be3 Nf6'),
			moves => {
			},
		},
		'r1bqkbnr/pp1p1ppp/2N1p3/8/4P3/8/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B44i',
			# TRANSLATORS: B44i: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nxc6
			variation => N__('Sicilian: Taimanov, 5.Nxc6'),
			moves => {
				'b7c6' => 1,
			},
		},
		'r1bqkbnr/p2p1ppp/2p1p3/8/4P3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B44i',
			# TRANSLATORS: B44i: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nxc6 bxc6
			variation => N__('Sicilian: Taimanov, 5.Nxc6'),
			moves => {
				'f1d3' => 1,
			},
		},
		'r1bqkbnr/p2p1ppp/2p1p3/8/4P3/3B4/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'B44j',
			# TRANSLATORS: B44j: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nxc6 bxc6 6. Bd3
			variation => N__('Sicilian: Taimanov, 5.Nxc6 bxc6 6. Bd3'),
			moves => {
			},
		},
		'r1bqkbnr/pp1p1ppp/2n1p3/1N6/4P3/8/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B44k',
			# TRANSLATORS: B44k: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nb5
			variation => N__('Sicilian, Taimanov, Szen Variation'),
			moves => {
				'd7d6' => 1,
			},
		},
		'r1bqkbnr/pp3ppp/2npp3/1N6/4P3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B44k',
			# TRANSLATORS: B44k: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nb5 d6
			variation => N__('Sicilian, Taimanov, Szen, 5... d6'),
			moves => {
				'c1f4' => 1,
				'c2c4' => 1,
			},
		},
		'r1bqkbnr/pp3ppp/2npp3/1N6/4PB2/8/PPP2PPP/RN1QKB1R b KQkq' => {
			eco => 'B44l',
			# TRANSLATORS: B44l: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nb5 d6 6. Bf4
			variation => N__('Sicilian, Taimanov, Szen, 6. Bf4'),
			moves => {
				'e6e5' => 1,
			},
		},
		'r1bqkbnr/pp3ppp/2np4/1N2p3/4PB2/8/PPP2PPP/RN1QKB1R w KQkq' => {
			eco => 'B44l',
			# TRANSLATORS: B44l: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nb5 d6 6. Bf4 e5
			variation => N__('Sicilian, Taimanov, Szen, 6. Bf4'),
			moves => {
				'f4e3' => 1,
			},
		},
		'r1bqkbnr/pp3ppp/2np4/1N2p3/4P3/4B3/PPP2PPP/RN1QKB1R b KQkq' => {
			eco => 'B44l',
			# TRANSLATORS: B44l: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nb5 d6 6. Bf4 e5 7. Be3
			variation => N__('Sicilian, Taimanov, Szen, 6. Bf4'),
			moves => {
				'a7a6' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkbnr/1p3ppp/p1np4/1N2p3/4P3/4B3/PPP2PPP/RN1QKB1R w KQkq' => {
			eco => 'B44m',
			# TRANSLATORS: B44m: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nb5 d6 6. Bf4 e5 7. Be3 a6
			variation => N__('Sicilian, Taimanov, Szen, 6. Bf4 e5 7. Be3 a6'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2np1n2/1N2p3/4P3/4B3/PPP2PPP/RN1QKB1R w KQkq' => {
			eco => 'B44n',
			# TRANSLATORS: B44n: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nb5 d6 6. Bf4 e5 7. Be3 Nf6
			variation => N__('Sicilian, Taimanov, Szen, 6. Bf4 e5 7. Be3 Nf6'),
			moves => {
			},
		},
		'r1bqkbnr/pp3ppp/2npp3/1N6/2P1P3/8/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'B44o',
			# TRANSLATORS: B44o: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nb5 d6 6. c4
			variation => N__('Sicilian, Taimanov, Szen, 6. c4'),
			moves => {
				'a7a6' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkbnr/1p3ppp/p1npp3/1N6/2P1P3/8/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'B44o',
			# TRANSLATORS: B44o: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nb5 d6 6. c4 a6
			variation => N__('Sicilian, Taimanov, Szen, 6. c4 a6'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2nppn2/1N6/2P1P3/8/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'B44o',
			# TRANSLATORS: B44o: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nb5 d6 6. c4 Nf6
			variation => N__('Sicilian, Taimanov, Szen, 6. c4 Nf6'),
			moves => {
				'b1c3' => 1,
				'b5c3' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2nppn2/8/2P1P3/2N5/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'B44p',
			# TRANSLATORS: B44p: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nb5 d6 6. c4 Nf6 7. N5c3
			variation => N__('Sicilian, Taimanov, Szen, 7.N5c3'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2nppn2/1N6/2P1P3/2N5/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'B44q',
			# TRANSLATORS: B44q: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nb5 d6 6. c4 Nf6 7. N1c3
			variation => N__('Sicilian, Taimanov, Szen, 7.N1c3'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r1bqkb1r/1p3ppp/p1nppn2/1N6/2P1P3/2N5/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'B44q',
			# TRANSLATORS: B44q: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nb5 d6 6. c4 Nf6 7. N1c3 a6
			variation => N__('Sicilian, Taimanov, Szen, 7.N1c3 a6'),
			moves => {
				'b5a3' => 1,
			},
		},
		'r1bqkb1r/1p3ppp/p1nppn2/8/2P1P3/N1N5/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'B44r',
			# TRANSLATORS: B44r: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nb5 d6 6. c4 Nf6 7. N1c3 a6 8. Na3
			variation => N__('Sicilian, Taimanov, Szen, 7.N1c3 a6 8. Na3'),
			moves => {
				'b7b6' => 1,
				'd6d5' => 1,
				'f8e7' => 1,
			},
		},
		'r1bqkb1r/1p3ppp/p1n1pn2/3p4/2P1P3/N1N5/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'B44r',
			# TRANSLATORS: B44r: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nb5 d6 6. c4 Nf6 7. N1c3 a6 8. Na3 d5
			variation => N__('Sicilian: Taimanov, Szen, Kasparov Gambit'),
			moves => {
			},
		},
		'r1bqkb1r/5ppp/ppnppn2/8/2P1P3/N1N5/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'B44s',
			# TRANSLATORS: B44s: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nb5 d6 6. c4 Nf6 7. N1c3 a6 8. Na3 b6
			variation => N__('Sicilian, Taimanov, Szen, 7.N1c3 a6 8. Na3 b6'),
			moves => {
			},
		},
		'r1bqk2r/1p2bppp/p1nppn2/8/2P1P3/N1N5/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'B44t',
			# TRANSLATORS: B44t: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nb5 d6 6. c4 Nf6 7. N1c3 a6 8. Na3 Be7
			variation => N__('Sicilian, Taimanov, Szen, 7.N1c3 a6 8. Na3 Be7'),
			moves => {
				'f1e2' => 1,
			},
		},
		'r1bqk2r/1p2bppp/p1nppn2/8/2P1P3/N1N5/PP2BPPP/R1BQK2R b KQkq' => {
			eco => 'B44u',
			# TRANSLATORS: B44u: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nb5 d6 6. c4 Nf6 7. N1c3 a6 8. Na3 Be7 9. Be2
			variation => N__('Sicilian, Taimanov, Szen, 7.N1c3 a6 8. Na3 Be7 9. Be2'),
			moves => {
				'b7b6' => 1,
				'e8g8' => 1,
			},
		},
		'r1bqk2r/4bppp/ppnppn2/8/2P1P3/N1N5/PP2BPPP/R1BQK2R w KQkq' => {
			eco => 'B44u',
			# TRANSLATORS: B44u: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nb5 d6 6. c4 Nf6 7. N1c3 a6 8. Na3 Be7 9. Be2 b6
			variation => N__('Sicilian, Taimanov, Szen, 7.N1c3 a6 8. Na3 Be7 9. Be2 b6'),
			moves => {
			},
		},
		'r1bq1rk1/1p2bppp/p1nppn2/8/2P1P3/N1N5/PP2BPPP/R1BQK2R w KQ' => {
			eco => 'B44v',
			# TRANSLATORS: B44v: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nb5 d6 6. c4 Nf6 7. N1c3 a6 8. Na3 Be7 9. Be2 O-O
			variation => N__('Sicilian, Taimanov, Szen, 7.N1c3 a6 8. Na3 Be7 9. Be2 O-O'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bq1rk1/1p2bppp/p1nppn2/8/2P1P3/N1N5/PP2BPPP/R1BQ1RK1 b -' => {
			eco => 'B44v',
			# TRANSLATORS: B44v: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nb5 d6 6. c4 Nf6 7. N1c3 a6 8. Na3 Be7 9. Be2 O-O 10. O-O
			variation => N__('Sicilian, Taimanov, Szen, 7.N1c3 a6 8. Na3 Be7 9. Be2 O-O'),
			moves => {
				'b7b6' => 1,
			},
		},
		'r1bq1rk1/4bppp/ppnppn2/8/2P1P3/N1N5/PP2BPPP/R1BQ1RK1 w -' => {
			eco => 'B44w',
			# TRANSLATORS: B44w: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nb5 d6 6. c4 Nf6 7. N1c3 a6 8. Na3 Be7 9. Be2 O-O 10. O-O b6
			variation => N__('Sicilian: Taimanov, Szen, Hedgehog Variation'),
			moves => {
				'c1e3' => 1,
			},
		},
		'r1bq1rk1/4bppp/ppnppn2/8/2P1P3/N1N1B3/PP2BPPP/R2Q1RK1 b -' => {
			eco => 'B44x',
			# TRANSLATORS: B44x: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nb5 d6 6. c4 Nf6 7. N1c3 a6 8. Na3 Be7 9. Be2 O-O 10. O-O b6 11. Be3
			variation => N__('Sicilian: Taimanov, Szen, Hedgehog, 11. Be3'),
			moves => {
				'c6e5' => 1,
				'c8b7' => 1,
				'c8d7' => 1,
			},
		},
		'r1bq1rk1/4bppp/pp1ppn2/4n3/2P1P3/N1N1B3/PP2BPPP/R2Q1RK1 w -' => {
			eco => 'B44x',
			# TRANSLATORS: B44x: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nb5 d6 6. c4 Nf6 7. N1c3 a6 8. Na3 Be7 9. Be2 O-O 10. O-O b6 11. Be3 Ne5
			variation => N__('Sicilian: Taimanov, Szen, Hedgehog, 11. Be3 Ne5'),
			moves => {
			},
		},
		'r2q1rk1/3bbppp/ppnppn2/8/2P1P3/N1N1B3/PP2BPPP/R2Q1RK1 w -' => {
			eco => 'B44x',
			# TRANSLATORS: B44x: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nb5 d6 6. c4 Nf6 7. N1c3 a6 8. Na3 Be7 9. Be2 O-O 10. O-O b6 11. Be3 Bd7
			variation => N__('Sicilian: Taimanov, Szen, Hedgehog, 11. Be3 Bd7'),
			moves => {
			},
		},
		'r2q1rk1/1b2bppp/ppnppn2/8/2P1P3/N1N1B3/PP2BPPP/R2Q1RK1 w -' => {
			eco => 'B44y',
			# TRANSLATORS: B44y: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nb5 d6 6. c4 Nf6 7. N1c3 a6 8. Na3 Be7 9. Be2 O-O 10. O-O b6 11. Be3 Bb7
			variation => N__('Sicilian: Taimanov, Szen, Hedgehog, 11. Be3 Bb7'),
			moves => {
				'd1b3' => 1,
			},
		},
		'r2q1rk1/1b2bppp/ppnppn2/8/2P1P3/NQN1B3/PP2BPPP/R4RK1 b -' => {
			eco => 'B44z',
			# TRANSLATORS: B44z: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nb5 d6 6. c4 Nf6 7. N1c3 a6 8. Na3 Be7 9. Be2 O-O 10. O-O b6 11. Be3 Bb7 12. Qb3
			variation => N__('Sicilian: Taimanov, Szen, Hedgehog, 11. Be3 Bb7 12. Qb3'),
			moves => {
			},
		},
		'r1bqkbnr/pp1p1ppp/2n1p3/8/3NP3/2N5/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B45a',
			# TRANSLATORS: B45a: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3
			variation => N__('Sicilian: Taimanov, 5. Nc3'),
			moves => {
				'a7a6' => 1,
				'd7d6' => 1,
				'd8c7' => 1,
				'f8b4' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqk1nr/pp1p1ppp/2n1p3/8/1b1NP3/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B45b',
			# TRANSLATORS: B45b: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Bb4
			variation => N__('Sicilian: Taimanov, 5. Nc3 Bb4'),
			moves => {
			},
		},
		'r1bqkbnr/pp3ppp/2npp3/8/3NP3/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B45c',
			# TRANSLATORS: B45c: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 d6
			variation => N__('Sicilian: Taimanov, 5. Nc3 d6'),
			moves => {
				'g2g4' => 1,
			},
		},
		'r1bqkbnr/pp3ppp/2npp3/8/3NP1P1/2N5/PPP2P1P/R1BQKB1R b KQkq' => {
			eco => 'B45c',
			# TRANSLATORS: B45c: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 d6 6. g4
			variation => N__('Sicilian: Taimanov, 5. Nc3 d6 6. g4'),
			moves => {
			},
		},
		'r1bqkb1r/pp1p1ppp/2n1pn2/8/3NP3/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B45d',
			# TRANSLATORS: B45d: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Nf6
			variation => N__('Sicilian: Taimanov, Four Knights'),
			moves => {
				'a2a3' => 1,
				'c1e3' => 1,
				'c1g5' => 1,
				'd4b5' => 1,
				'd4c6' => 1,
				'f1e2' => 1,
				'g2g3' => 1,
			},
		},
		'r1bqkb1r/pp1p1ppp/2n1pn2/6B1/3NP3/2N5/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'B45e',
			# TRANSLATORS: B45e: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Nf6 6. Bg5
			variation => N__('Sicilian: Taimanov, Four Knights, 6. Bg5'),
			moves => {
			},
		},
		'r1bqkb1r/pp1p1ppp/2n1pn2/8/3NP3/P1N5/1PP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B45f',
			# TRANSLATORS: B45f: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Nf6 6. a3
			variation => N__('Sicilian: Taimanov, Four Knights, 6. a3'),
			moves => {
			},
		},
		'r1bqkb1r/pp1p1ppp/2n1pn2/8/3NP3/2N3P1/PPP2P1P/R1BQKB1R b KQkq' => {
			eco => 'B45g',
			# TRANSLATORS: B45g: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Nf6 6. g3
			variation => N__('Sicilian: Taimanov, Four Knights, 6. g3'),
			moves => {
			},
		},
		'r1bqkb1r/pp1p1ppp/2n1pn2/8/3NP3/2N5/PPP1BPPP/R1BQK2R b KQkq' => {
			eco => 'B45h',
			# TRANSLATORS: B45h: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Nf6 6. Be2
			variation => N__('Sicilian: Taimanov, Four Knights, 6. Be2'),
			moves => {
			},
		},
		'r1bqkb1r/pp1p1ppp/2n1pn2/8/3NP3/2N1B3/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'B45i',
			# TRANSLATORS: B45i: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Nf6 6. Be3
			variation => N__('Sicilian: Taimanov, Four Knights, 6. Be3'),
			moves => {
				'f8b4' => 1,
			},
		},
		'r1bqk2r/pp1p1ppp/2n1pn2/8/1b1NP3/2N1B3/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B45i',
			# TRANSLATORS: B45i: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Nf6 6. Be3 Bb4
			variation => N__('Sicilian: Taimanov, Four Knights, 6. Be3 Bb4'),
			moves => {
				'f1d3' => 1,
			},
		},
		'r1bqk2r/pp1p1ppp/2n1pn2/8/1b1NP3/2NBB3/PPP2PPP/R2QK2R b KQkq' => {
			eco => 'B45j',
			# TRANSLATORS: B45j: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Nf6 6. Be3 Bb4 7. Bd3
			variation => N__('Sicilian: Taimanov, Four Knights, 6. Be3 Bb4 7. Bd3'),
			moves => {
			},
		},
		'r1bqkb1r/pp1p1ppp/2N1pn2/8/4P3/2N5/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B45k',
			# TRANSLATORS: B45k: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Nf6 6. Nxc6
			variation => N__('Sicilian: Taimanov, Four Knights, 6.Nxc6'),
			moves => {
				'b7c6' => 1,
			},
		},
		'r1bqkb1r/p2p1ppp/2p1pn2/8/4P3/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B45k',
			# TRANSLATORS: B45k: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Nf6 6. Nxc6 bxc6
			variation => N__('Sicilian: Taimanov, Four Knights, 6.Nxc6'),
			moves => {
				'e4e5' => 1,
			},
		},
		'r1bqkb1r/p2p1ppp/2p1pn2/4P3/8/2N5/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B45l',
			# TRANSLATORS: B45l: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Nf6 6. Nxc6 bxc6 7. e5
			variation => N__('Sicilian: Taimanov, Four Knights, 6.Nxc6 bxc6 7. e5'),
			moves => {
				'f6d5' => 1,
			},
		},
		'r1bqkb1r/p2p1ppp/2p1p3/3nP3/8/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B45l',
			# TRANSLATORS: B45l: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Nf6 6. Nxc6 bxc6 7. e5 Nd5
			variation => N__('Sicilian: Taimanov, Four Knights, 6.Nxc6 bxc6 7. e5 Nd5'),
			moves => {
				'c3e4' => 1,
			},
		},
		'r1bqkb1r/p2p1ppp/2p1p3/3nP3/4N3/8/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B45m',
			# TRANSLATORS: B45m: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Nf6 6. Nxc6 bxc6 7. e5 Nd5 8. Ne4
			variation => N__('Sicilian: Taimanov, Four Knights, 6.Nxc6 bxc6 7. e5 Nd5 8. Ne4'),
			moves => {
				'd8c7' => 1,
			},
		},
		'r1b1kb1r/p1qp1ppp/2p1p3/3nP3/4N3/8/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B45n',
			# TRANSLATORS: B45n: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Nf6 6. Nxc6 bxc6 7. e5 Nd5 8. Ne4 Qc7
			variation => N__('Sicilian: Taimanov, Four Knights, 6.Nxc6 bxc6 7. e5 Nd5 8. Ne4 Qc7'),
			moves => {
			},
		},
		'r1bqkb1r/pp1p1ppp/2n1pn2/1N6/4P3/2N5/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B45o',
			# TRANSLATORS: B45o: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Nf6 6. Ndb5
			variation => N__('Sicilian: Taimanov, Four Knights, 6.Ndb5'),
			moves => {
				'd7d6' => 1,
				'f8b4' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2nppn2/1N6/4P3/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B45o',
			# TRANSLATORS: B45o: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Nf6 6. Ndb5 d6
			variation => N__('Sicilian: Taimanov, Four Knights, 6.Ndb5 d6'),
			moves => {
				'c1f4' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2nppn2/1N6/4PB2/2N5/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'B45o',
			# TRANSLATORS: B45o: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Nf6 6. Ndb5 d6 7. Bf4
			variation => N__('Sicilian: Taimanov, Four Knights, 6.Ndb5 d6 7. Bf4'),
			moves => {
			},
		},
		'r1bqk2r/pp1p1ppp/2n1pn2/1N6/1b2P3/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B45p',
			# TRANSLATORS: B45p: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Nf6 6. Ndb5 Bb4
			variation => N__('Sicilian: Taimanov, Four Knights, 6.Ndb5 Bb4'),
			moves => {
				'a2a3' => 1,
				'b5d6' => 1,
			},
		},
		'r1bqk2r/pp1p1ppp/2nNpn2/8/1b2P3/2N5/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B45q',
			# TRANSLATORS: B45q: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Nf6 6. Ndb5 Bb4 7. Nd6+
			variation => N__('Sicilian: Taimanov, Four Knights, American Attack'),
			moves => {
			},
		},
		'r1bqk2r/pp1p1ppp/2n1pn2/1N6/1b2P3/P1N5/1PP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B45r',
			# TRANSLATORS: B45r: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Nf6 6. Ndb5 Bb4 7. a3
			variation => N__('Sicilian: Taimanov, Four Knights, 6.Ndb5 Bb4 7. a3'),
			moves => {
				'b4c3' => 1,
			},
		},
		'r1bqk2r/pp1p1ppp/2n1pn2/1N6/4P3/P1b5/1PP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B45r',
			# TRANSLATORS: B45r: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Nf6 6. Ndb5 Bb4 7. a3 Bxc3+
			variation => N__('Sicilian: Taimanov, Four Knights, 6.Ndb5 Bb4 7. a3'),
			moves => {
				'b5c3' => 1,
			},
		},
		'r1bqk2r/pp1p1ppp/2n1pn2/8/4P3/P1N5/1PP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B45r',
			# TRANSLATORS: B45r: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Nf6 6. Ndb5 Bb4 7. a3 Bxc3+ 8. Nxc3
			variation => N__('Sicilian: Taimanov, Four Knights, 6.Ndb5 Bb4 7. a3'),
			moves => {
				'd7d5' => 1,
			},
		},
		'r1bqk2r/pp3ppp/2n1pn2/3p4/4P3/P1N5/1PP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B45s',
			# TRANSLATORS: B45s: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Nf6 6. Ndb5 Bb4 7. a3 Bxc3+ 8. Nxc3 d5
			variation => N__('Sicilian: Taimanov, Four Knights, 6.Ndb5 Bb4 7. a3 Bxc3+ 8.Nxc3 d5'),
			moves => {
				'e4d5' => 1,
			},
		},
		'r1bqk2r/pp3ppp/2n1pn2/3P4/8/P1N5/1PP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B45s',
			# TRANSLATORS: B45s: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Nf6 6. Ndb5 Bb4 7. a3 Bxc3+ 8. Nxc3 d5 9. exd5
			variation => N__('Sicilian: Taimanov, Four Knights, 6.Ndb5 Bb4 7. a3 Bxc3+ 8.Nxc3 d5'),
			moves => {
				'e6d5' => 1,
			},
		},
		'r1bqk2r/pp3ppp/2n2n2/3p4/8/P1N5/1PP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B45t',
			# TRANSLATORS: B45t: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Nf6 6. Ndb5 Bb4 7. a3 Bxc3+ 8. Nxc3 d5 9. exd5 exd5
			variation => N__('Sicilian: Taimanov, Four Knights, 6.Ndb5 Bb4 7. a3, 9.ed5 ed5'),
			moves => {
				'f1d3' => 1,
			},
		},
		'r1bqk2r/pp3ppp/2n2n2/3p4/8/P1NB4/1PP2PPP/R1BQK2R b KQkq' => {
			eco => 'B45t',
			# TRANSLATORS: B45t: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Nf6 6. Ndb5 Bb4 7. a3 Bxc3+ 8. Nxc3 d5 9. exd5 exd5 10. Bd3
			variation => N__('Sicilian: Taimanov, Four Knights, 6.Ndb5 Bb4 7. a3, 9.ed5 ed5'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp3ppp/2n2n2/3p4/8/P1NB4/1PP2PPP/R1BQK2R w KQ' => {
			eco => 'B45u',
			# TRANSLATORS: B45u: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Nf6 6. Ndb5 Bb4 7. a3 Bxc3+ 8. Nxc3 d5 9. exd5 exd5 10. Bd3 O-O
			variation => N__('Sicilian: Taimanov, Four Knights, 6.Ndb5 Bb4 7. a3, 9.ed5 ed5 10. Bd3 O-O'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bq1rk1/pp3ppp/2n2n2/3p4/8/P1NB4/1PP2PPP/R1BQ1RK1 b -' => {
			eco => 'B45u',
			# TRANSLATORS: B45u: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Nf6 6. Ndb5 Bb4 7. a3 Bxc3+ 8. Nxc3 d5 9. exd5 exd5 10. Bd3 O-O 11. O-O
			variation => N__('Sicilian: Taimanov, Four Knights, 6.Ndb5 Bb4 7. a3, 9.ed5 ed5 10. Bd3 O-O'),
			moves => {
				'd5d4' => 1,
			},
		},
		'r1bq1rk1/pp3ppp/2n2n2/8/3p4/P1NB4/1PP2PPP/R1BQ1RK1 w -' => {
			eco => 'B45v',
			# TRANSLATORS: B45v: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Nf6 6. Ndb5 Bb4 7. a3 Bxc3+ 8. Nxc3 d5 9. exd5 exd5 10. Bd3 O-O 11. O-O d4
			variation => N__('Sicilian: Taimanov, Four Knights, 6.Ndb5 Bb4 7. a3, 10. Bd3 O-O 11.O-O d4'),
			moves => {
				'c3e2' => 1,
			},
		},
		'r1bq1rk1/pp3ppp/2n2n2/8/3p4/P2B4/1PP1NPPP/R1BQ1RK1 b -' => {
			eco => 'B45w',
			# TRANSLATORS: B45w: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Nf6 6. Ndb5 Bb4 7. a3 Bxc3+ 8. Nxc3 d5 9. exd5 exd5 10. Bd3 O-O 11. O-O d4 12. Ne2
			variation => N__('Sicilian: Taimanov, Four Knights, 6.Ndb5 Bb4 7. a3, 10. Bd3 O-O 11.O-O d4 12. Ne2'),
			moves => {
			},
		},
		'r1bqkbnr/1p1p1ppp/p1n1p3/8/3NP3/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B46a',
			# TRANSLATORS: B46a: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 a6
			variation => N__('Sicilian: Taimanov, 5... a6'),
			moves => {
				'c1e3' => 1,
				'd4c6' => 1,
				'f1e2' => 1,
				'f2f4' => 1,
				'g2g3' => 1,
			},
		},
		'r1bqkbnr/1p1p1ppp/p1n1p3/8/3NPP2/2N5/PPP3PP/R1BQKB1R b KQkq' => {
			eco => 'B46b',
			# TRANSLATORS: B46b: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 a6 6. f4
			variation => N__('Sicilian: Taimanov, 5... a6 6. f4'),
			moves => {
			},
		},
		'r1bqkbnr/1p1p1ppp/p1N1p3/8/4P3/2N5/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B46c',
			# TRANSLATORS: B46c: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 a6 6. Nxc6
			variation => N__('Sicilian: Taimanov, 5... a6 6.Nxc6'),
			moves => {
				'b7c6' => 1,
			},
		},
		'r1bqkbnr/3p1ppp/p1p1p3/8/4P3/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B46c',
			# TRANSLATORS: B46c: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 a6 6. Nxc6 bxc6
			variation => N__('Sicilian: Taimanov, 5... a6 6.Nxc6'),
			moves => {
				'f1d3' => 1,
			},
		},
		'r1bqkbnr/3p1ppp/p1p1p3/8/4P3/2NB4/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'B46d',
			# TRANSLATORS: B46d: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 a6 6. Nxc6 bxc6 7. Bd3
			variation => N__('Sicilian: Taimanov, 5... a6 6.Nxc6 bxc6 7. Bd3'),
			moves => {
				'd7d5' => 1,
			},
		},
		'r1bqkbnr/5ppp/p1p1p3/3p4/4P3/2NB4/PPP2PPP/R1BQK2R w KQkq' => {
			eco => 'B46e',
			# TRANSLATORS: B46e: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 a6 6. Nxc6 bxc6 7. Bd3 d5
			variation => N__('Sicilian: Taimanov, 5... a6 6.Nxc6 bxc6 7. Bd3 d5'),
			moves => {
			},
		},
		'r1bqkbnr/1p1p1ppp/p1n1p3/8/3NP3/2N3P1/PPP2P1P/R1BQKB1R b KQkq' => {
			eco => 'B46f',
			# TRANSLATORS: B46f: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 a6 6. g3
			variation => N__('Sicilian: Taimanov, 5... a6 6. g3'),
			moves => {
				'd7d6' => 1,
				'g8e7' => 1,
			},
		},
		'r1bqkb1r/1p1pnppp/p1n1p3/8/3NP3/2N3P1/PPP2P1P/R1BQKB1R w KQkq' => {
			eco => 'B46g',
			# TRANSLATORS: B46g: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 a6 6. g3 Nge7
			variation => N__('Sicilian: Taimanov, 5... a6 6. g3 Nge7'),
			moves => {
			},
		},
		'r1bqkbnr/1p3ppp/p1npp3/8/3NP3/2N3P1/PPP2P1P/R1BQKB1R w KQkq' => {
			eco => 'B46h',
			# TRANSLATORS: B46h: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 a6 6. g3 d6
			variation => N__('Sicilian: Taimanov, 5... a6 6. g3 d6'),
			moves => {
			},
		},
		'r1bqkbnr/1p1p1ppp/p1n1p3/8/3NP3/2N1B3/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'B46i',
			# TRANSLATORS: B46i: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 a6 6. Be3
			variation => N__('Sicilian: Taimanov, 5... a6 6. Be3'),
			moves => {
				'd7d6' => 1,
				'g8e7' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkbnr/1p3ppp/p1npp3/8/3NP3/2N1B3/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B46j',
			# TRANSLATORS: B46j: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 a6 6. Be3 d6
			variation => N__('Sicilian: Taimanov, 5... a6 6. Be3 d6'),
			moves => {
			},
		},
		'r1bqkb1r/1p1pnppp/p1n1p3/8/3NP3/2N1B3/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B46k',
			# TRANSLATORS: B46k: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 a6 6. Be3 Nge7
			variation => N__('Sicilian: Taimanov, 5... a6 6. Be3 Nge7'),
			moves => {
			},
		},
		'r1bqkb1r/1p1p1ppp/p1n1pn2/8/3NP3/2N1B3/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B46l',
			# TRANSLATORS: B46l: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 a6 6. Be3 Nf6
			variation => N__('Sicilian: Taimanov, 5... a6 6. Be3 Nf6'),
			moves => {
			},
		},
		'r1bqkbnr/1p1p1ppp/p1n1p3/8/3NP3/2N5/PPP1BPPP/R1BQK2R b KQkq' => {
			eco => 'B46m',
			# TRANSLATORS: B46m: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 a6 6. Be2
			variation => N__('Sicilian: Taimanov, 5... a6 6. Be2'),
			moves => {
				'd7d6' => 1,
				'g8e7' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkb1r/1p1p1ppp/p1n1pn2/8/3NP3/2N5/PPP1BPPP/R1BQK2R w KQkq' => {
			eco => 'B46n',
			# TRANSLATORS: B46n: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 a6 6. Be2 Nf6
			variation => N__('Sicilian: Taimanov, 5... a6 6. Be2 Nf6'),
			moves => {
			},
		},
		'r1bqkb1r/1p1pnppp/p1n1p3/8/3NP3/2N5/PPP1BPPP/R1BQK2R w KQkq' => {
			eco => 'B46o',
			# TRANSLATORS: B46o: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 a6 6. Be2 Nge7
			variation => N__('Sicilian: Taimanov, 5... a6 6. Be2 Nge7'),
			moves => {
				'c1e3' => 1,
				'e1g1' => 1,
			},
		},
		'r1bqkb1r/1p1pnppp/p1n1p3/8/3NP3/2N5/PPP1BPPP/R1BQ1RK1 b kq' => {
			eco => 'B46p',
			# TRANSLATORS: B46p: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 a6 6. Be2 Nge7 7. O-O
			variation => N__('Sicilian: Taimanov, 5... a6 6. Be2 Nge7 7.O-O'),
			moves => {
			},
		},
		'r1bqkb1r/1p1pnppp/p1n1p3/8/3NP3/2N1B3/PPP1BPPP/R2QK2R b KQkq' => {
			eco => 'B46q',
			# TRANSLATORS: B46q: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 a6 6. Be2 Nge7 7. Be3
			variation => N__('Sicilian: Taimanov, 5... a6 6. Be2 Nge7 7. Be3'),
			moves => {
			},
		},
		'r1bqkbnr/1p3ppp/p1npp3/8/3NP3/2N5/PPP1BPPP/R1BQK2R w KQkq' => {
			eco => 'B46r',
			# TRANSLATORS: B46r: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 a6 6. Be2 d6
			variation => N__('Sicilian: Taimanov, 5... a6 6. Be2 d6'),
			moves => {
			},
		},
		'r1b1kbnr/ppqp1ppp/2n1p3/8/3NP3/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B47a',
			# TRANSLATORS: B47a: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7
			variation => N__('Sicilian: Taimanov, Bastrikov Variation'),
			moves => {
				'c1e3' => 1,
				'd4b5' => 1,
				'd4c6' => 1,
				'f1e2' => 1,
				'f2f4' => 1,
				'g2g3' => 1,
			},
		},
		'r1b1kbnr/ppqp1ppp/2N1p3/8/4P3/2N5/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B47b',
			# TRANSLATORS: B47b: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Nxc6
			variation => N__('Sicilian: Taimanov, 6.Nxc6'),
			moves => {
			},
		},
		'r1b1kbnr/ppqp1ppp/2n1p3/1N6/4P3/2N5/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B47c',
			# TRANSLATORS: B47c: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Ndb5
			variation => N__('Sicilian: Taimanov, 6.Ndb5'),
			moves => {
			},
		},
		'r1b1kbnr/ppqp1ppp/2n1p3/8/3NPP2/2N5/PPP3PP/R1BQKB1R b KQkq' => {
			eco => 'B47d',
			# TRANSLATORS: B47d: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. f4
			variation => N__('Sicilian: Taimanov, 6. f4'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r1b1kbnr/1pqp1ppp/p1n1p3/8/3NPP2/2N5/PPP3PP/R1BQKB1R w KQkq' => {
			eco => 'B47e',
			# TRANSLATORS: B47e: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. f4 a6
			variation => N__('Sicilian: Taimanov, 6. f4 a6'),
			moves => {
				'd4c6' => 1,
			},
		},
		'r1b1kbnr/1pqp1ppp/p1N1p3/8/4PP2/2N5/PPP3PP/R1BQKB1R b KQkq' => {
			eco => 'B47f',
			# TRANSLATORS: B47f: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. f4 a6 7. Nxc6
			variation => N__('Sicilian: Taimanov, 6. f4 a6 7.Nxc6'),
			moves => {
			},
		},
		'r1b1kbnr/ppqp1ppp/2n1p3/8/3NP3/2N3P1/PPP2P1P/R1BQKB1R b KQkq' => {
			eco => 'B47g',
			# TRANSLATORS: B47g: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. g3
			variation => N__('Sicilian: Taimanov, 6. g3'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r1b1kbnr/1pqp1ppp/p1n1p3/8/3NP3/2N3P1/PPP2P1P/R1BQKB1R w KQkq' => {
			eco => 'B47h',
			# TRANSLATORS: B47h: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. g3 a6
			variation => N__('Sicilian: Taimanov, 6. g3 a6'),
			moves => {
				'f1g2' => 1,
			},
		},
		'r1b1kbnr/1pqp1ppp/p1n1p3/8/3NP3/2N3P1/PPP2PBP/R1BQK2R b KQkq' => {
			eco => 'B47h',
			# TRANSLATORS: B47h: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. g3 a6 7. Bg2
			variation => N__('Sicilian: Taimanov, 6. g3 a6 7. Bg2'),
			moves => {
				'd7d6' => 1,
				'g8f6' => 1,
			},
		},
		'r1b1kbnr/1pq2ppp/p1npp3/8/3NP3/2N3P1/PPP2PBP/R1BQK2R w KQkq' => {
			eco => 'B47i',
			# TRANSLATORS: B47i: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. g3 a6 7. Bg2 d6
			variation => N__('Sicilian: Taimanov, 6. g3 a6 7. Bg2 d6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1b1kbnr/1pq2ppp/p1npp3/8/3NP3/2N3P1/PPP2PBP/R1BQ1RK1 b kq' => {
			eco => 'B47i',
			# TRANSLATORS: B47i: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. g3 a6 7. Bg2 d6 8. O-O
			variation => N__('Sicilian: Taimanov, 6. g3 a6 7. Bg2 d6 8.O-O'),
			moves => {
				'c8d7' => 1,
			},
		},
		'r3kbnr/1pqb1ppp/p1npp3/8/3NP3/2N3P1/PPP2PBP/R1BQ1RK1 w kq' => {
			eco => 'B47j',
			# TRANSLATORS: B47j: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. g3 a6 7. Bg2 d6 8. O-O Bd7
			variation => N__('Sicilian: Taimanov, 6. g3 a6 7. Bg2 d6 8.O-O Bd7'),
			moves => {
				'f1e1' => 1,
			},
		},
		'r3kbnr/1pqb1ppp/p1npp3/8/3NP3/2N3P1/PPP2PBP/R1BQR1K1 b kq' => {
			eco => 'B47k',
			# TRANSLATORS: B47k: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. g3 a6 7. Bg2 d6 8. O-O Bd7 9. Re1
			variation => N__('Sicilian: Taimanov, 6. g3 a6 7. Bg2 d6 8.O-O Bd7 9. Re1'),
			moves => {
			},
		},
		'r1b1kb1r/1pqp1ppp/p1n1pn2/8/3NP3/2N3P1/PPP2PBP/R1BQK2R w KQkq' => {
			eco => 'B47l',
			# TRANSLATORS: B47l: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. g3 a6 7. Bg2 Nf6
			variation => N__('Sicilian: Taimanov, 6. g3 a6 7. Bg2 Nf6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1b1kb1r/1pqp1ppp/p1n1pn2/8/3NP3/2N3P1/PPP2PBP/R1BQ1RK1 b kq' => {
			eco => 'B47m',
			# TRANSLATORS: B47m: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. g3 a6 7. Bg2 Nf6 8. O-O
			variation => N__('Sicilian: Taimanov, 6. g3 a6 7. Bg2 Nf6 8.O-O'),
			moves => {
				'f8c5' => 1,
				'f8e7' => 1,
			},
		},
		'r1b1k2r/1pqp1ppp/p1n1pn2/2b5/3NP3/2N3P1/PPP2PBP/R1BQ1RK1 w kq' => {
			eco => 'B47n',
			# TRANSLATORS: B47n: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. g3 a6 7. Bg2 Nf6 8. O-O Bc5
			variation => N__('Sicilian: Taimanov, 6. g3 a6 7. Bg2 Nf6 8.O-O Bc5'),
			moves => {
			},
		},
		'r1b1k2r/1pqpbppp/p1n1pn2/8/3NP3/2N3P1/PPP2PBP/R1BQ1RK1 w kq' => {
			eco => 'B47o',
			# TRANSLATORS: B47o: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. g3 a6 7. Bg2 Nf6 8. O-O Be7
			variation => N__('Sicilian: Taimanov, 6. g3 a6 7. Bg2 Nf6 8.O-O Be7'),
			moves => {
				'f1e1' => 1,
			},
		},
		'r1b1k2r/1pqpbppp/p1n1pn2/8/3NP3/2N3P1/PPP2PBP/R1BQR1K1 b kq' => {
			eco => 'B47p',
			# TRANSLATORS: B47p: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. g3 a6 7. Bg2 Nf6 8. O-O Be7 9. Re1
			variation => N__('Sicilian: Taimanov, 6. g3 a6 7. Bg2 Nf6 8.O-O Be7 9. Re1'),
			moves => {
			},
		},
		'r1b1kbnr/ppqp1ppp/2n1p3/8/3NP3/2N5/PPP1BPPP/R1BQK2R b KQkq' => {
			eco => 'B47q',
			# TRANSLATORS: B47q: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be2
			variation => N__('Sicilian: Taimanov, 6. Be2'),
			moves => {
				'a7a6' => 1,
				'g8f6' => 1,
			},
		},
		'r1b1kb1r/ppqp1ppp/2n1pn2/8/3NP3/2N5/PPP1BPPP/R1BQK2R w KQkq' => {
			eco => 'B47q',
			# TRANSLATORS: B47q: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be2 Nf6
			variation => N__('Sicilian: Taimanov, 6. Be2 Nf6'),
			moves => {
			},
		},
		'r1b1kbnr/1pqp1ppp/p1n1p3/8/3NP3/2N5/PPP1BPPP/R1BQK2R w KQkq' => {
			eco => 'B47r',
			# TRANSLATORS: B47r: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be2 a6
			variation => N__('Sicilian: Taimanov, 6. Be2 a6'),
			moves => {
				'e1g1' => 1,
				'f2f4' => 1,
			},
		},
		'r1b1kbnr/1pqp1ppp/p1n1p3/8/3NPP2/2N5/PPP1B1PP/R1BQK2R b KQkq' => {
			eco => 'B47s',
			# TRANSLATORS: B47s: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be2 a6 7. f4
			variation => N__('Sicilian: Taimanov, 6. Be2 a6 7. f4'),
			moves => {
			},
		},
		'r1b1kbnr/1pqp1ppp/p1n1p3/8/3NP3/2N5/PPP1BPPP/R1BQ1RK1 b kq' => {
			eco => 'B47t',
			# TRANSLATORS: B47t: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be2 a6 7. O-O
			variation => N__('Sicilian: Taimanov, 6. Be2 a6 7.O-O'),
			moves => {
				'b7b5' => 1,
				'g8f6' => 1,
			},
		},
		'r1b1kbnr/2qp1ppp/p1n1p3/1p6/3NP3/2N5/PPP1BPPP/R1BQ1RK1 w kq' => {
			eco => 'B47u',
			# TRANSLATORS: B47u: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be2 a6 7. O-O b5
			variation => N__('Sicilian: Taimanov, 6. Be2 a6 7.O-O b5'),
			moves => {
			},
		},
		'r1b1kb1r/1pqp1ppp/p1n1pn2/8/3NP3/2N5/PPP1BPPP/R1BQ1RK1 w kq' => {
			eco => 'B47v',
			# TRANSLATORS: B47v: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be2 a6 7. O-O Nf6
			variation => N__('Sicilian: Taimanov, 6. Be2 a6 7.O-O Nf6'),
			moves => {
				'a2a3' => 1,
				'g1h1' => 1,
			},
		},
		'r1b1kb1r/1pqp1ppp/p1n1pn2/8/3NP3/P1N5/1PP1BPPP/R1BQ1RK1 b kq' => {
			eco => 'B47v',
			# TRANSLATORS: B47v: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be2 a6 7. O-O Nf6 8. a3
			variation => N__('Sicilian: Taimanov, 6. Be2 a6 7.O-O Nf6 8. a3'),
			moves => {
			},
		},
		'r1b1kb1r/1pqp1ppp/p1n1pn2/8/3NP3/2N5/PPP1BPPP/R1BQ1R1K b kq' => {
			eco => 'B47w',
			# TRANSLATORS: B47w: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be2 a6 7. O-O Nf6 8. Kh1
			variation => N__('Sicilian: Taimanov, 6. Be2 a6 7.O-O Nf6 8. Kh1'),
			moves => {
				'c6d4' => 1,
				'f8e7' => 1,
			},
		},
		'r1b1k2r/1pqpbppp/p1n1pn2/8/3NP3/2N5/PPP1BPPP/R1BQ1R1K w kq' => {
			eco => 'B47x',
			# TRANSLATORS: B47x: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be2 a6 7. O-O Nf6 8. Kh1 Be7
			variation => N__('Sicilian: Taimanov, 6. Be2 a6 7.O-O Nf6 8. Kh1 Be7'),
			moves => {
			},
		},
		'r1b1kb1r/1pqp1ppp/p3pn2/8/3nP3/2N5/PPP1BPPP/R1BQ1R1K w kq' => {
			eco => 'B47y',
			# TRANSLATORS: B47y: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be2 a6 7. O-O Nf6 8. Kh1 Nxd4
			variation => N__('Sicilian: Taimanov, 6. Be2 a6 7.O-O Nf6 8. Kh1 Nxd4'),
			moves => {
				'd1d4' => 1,
			},
		},
		'r1b1kb1r/1pqp1ppp/p3pn2/8/3QP3/2N5/PPP1BPPP/R1B2R1K b kq' => {
			eco => 'B47y',
			# TRANSLATORS: B47y: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be2 a6 7. O-O Nf6 8. Kh1 Nxd4 9. Qxd4
			variation => N__('Sicilian: Taimanov, 6. Be2 a6 7.O-O Nf6 8. Kh1 Nxd4'),
			moves => {
				'f8c5' => 1,
			},
		},
		'r1b1k2r/1pqp1ppp/p3pn2/2b5/3QP3/2N5/PPP1BPPP/R1B2R1K w kq' => {
			eco => 'B47y',
			# TRANSLATORS: B47y: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be2 a6 7. O-O Nf6 8. Kh1 Nxd4 9. Qxd4 Bc5
			variation => N__('Sicilian: Taimanov, 6. Be2 a6 7.O-O Nf6 8. Kh1 Nxd4'),
			moves => {
				'd4d3' => 1,
			},
		},
		'r1b1k2r/1pqp1ppp/p3pn2/2b5/4P3/2NQ4/PPP1BPPP/R1B2R1K b kq' => {
			eco => 'B47y',
			# TRANSLATORS: B47y: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be2 a6 7. O-O Nf6 8. Kh1 Nxd4 9. Qxd4 Bc5 10. Qd3
			variation => N__('Sicilian: Taimanov, 6. Be2 a6 7.O-O Nf6 8. Kh1 Nxd4, 10. Qd3'),
			moves => {
				'b7b5' => 1,
			},
		},
		'r1b1k2r/2qp1ppp/p3pn2/1pb5/4P3/2NQ4/PPP1BPPP/R1B2R1K w kq' => {
			eco => 'B47y',
			# TRANSLATORS: B47y: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be2 a6 7. O-O Nf6 8. Kh1 Nxd4 9. Qxd4 Bc5 10. Qd3 b5
			variation => N__('Sicilian: Taimanov, 6. Be2 a6 7.O-O Nf6 8. Kh1 Nxd4, 10. Qd3 b5'),
			moves => {
				'f2f4' => 1,
			},
		},
		'r1b1k2r/2qp1ppp/p3pn2/1pb5/4PP2/2NQ4/PPP1B1PP/R1B2R1K b kq' => {
			eco => 'B47z',
			# TRANSLATORS: B47z: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be2 a6 7. O-O Nf6 8. Kh1 Nxd4 9. Qxd4 Bc5 10. Qd3 b5 11. f4
			variation => N__('Sicilian: Taimanov, 6. Be2 a6 7.O-O Nf6 8. Kh1 Nxd4, 10. Qd3 b5 11. f4'),
			moves => {
			},
		},
		'r1b1kbnr/ppqp1ppp/2n1p3/8/3NP3/2N1B3/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'B48a',
			# TRANSLATORS: B48a: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3
			variation => N__('Sicilian: Taimanov, 6. Be3'),
			moves => {
				'a7a6' => 1,
				'g8f6' => 1,
			},
		},
		'r1b1kb1r/ppqp1ppp/2n1pn2/8/3NP3/2N1B3/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B48b',
			# TRANSLATORS: B48b: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 Nf6
			variation => N__('Sicilian: Taimanov, 6. Be3 Nf6'),
			moves => {
			},
		},
		'r1b1kbnr/1pqp1ppp/p1n1p3/8/3NP3/2N1B3/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B48c',
			# TRANSLATORS: B48c: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6
			variation => N__('Sicilian: Taimanov, 6. Be3 a6'),
			moves => {
				'a2a3' => 1,
				'd1d2' => 1,
				'f1d3' => 1,
				'f1e2' => 1,
				'f2f4' => 1,
			},
		},
		'r1b1kbnr/1pqp1ppp/p1n1p3/8/3NP3/P1N1B3/1PP2PPP/R2QKB1R b KQkq' => {
			eco => 'B48d',
			# TRANSLATORS: B48d: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. a3
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. a3'),
			moves => {
			},
		},
		'r1b1kbnr/1pqp1ppp/p1n1p3/8/3NPP2/2N1B3/PPP3PP/R2QKB1R b KQkq' => {
			eco => 'B48e',
			# TRANSLATORS: B48e: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. f4
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. f4'),
			moves => {
				'b7b5' => 1,
			},
		},
		'r1b1kbnr/2qp1ppp/p1n1p3/1p6/3NPP2/2N1B3/PPP3PP/R2QKB1R w KQkq' => {
			eco => 'B48f',
			# TRANSLATORS: B48f: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. f4 b5
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. f4 b5'),
			moves => {
			},
		},
		'r1b1kbnr/1pqp1ppp/p1n1p3/8/3NP3/2N1B3/PPPQ1PPP/R3KB1R b KQkq' => {
			eco => 'B48g',
			# TRANSLATORS: B48g: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Qd2
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Qd2'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r1b1kb1r/1pqp1ppp/p1n1pn2/8/3NP3/2N1B3/PPPQ1PPP/R3KB1R w KQkq' => {
			eco => 'B48g',
			# TRANSLATORS: B48g: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Qd2 Nf6
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Qd2'),
			moves => {
				'f2f3' => 1,
			},
		},
		'r1b1kb1r/1pqp1ppp/p1n1pn2/8/3NP3/2N1BP2/PPPQ2PP/R3KB1R b KQkq' => {
			eco => 'B48h',
			# TRANSLATORS: B48h: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Qd2 Nf6 8. f3
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Qd2 Nf6 8. f3'),
			moves => {
			},
		},
		'r1b1kbnr/1pqp1ppp/p1n1p3/8/3NP3/2NBB3/PPP2PPP/R2QK2R b KQkq' => {
			eco => 'B48i',
			# TRANSLATORS: B48i: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Bd3
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Bd3'),
			moves => {
				'b7b5' => 1,
				'g8f6' => 1,
			},
		},
		'r1b1kbnr/2qp1ppp/p1n1p3/1p6/3NP3/2NBB3/PPP2PPP/R2QK2R w KQkq' => {
			eco => 'B48j',
			# TRANSLATORS: B48j: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Bd3 b5
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Bd3 b5'),
			moves => {
				'd4c6' => 1,
				'e1g1' => 1,
			},
		},
		'r1b1kbnr/2qp1ppp/p1N1p3/1p6/4P3/2NBB3/PPP2PPP/R2QK2R b KQkq' => {
			eco => 'B48k',
			# TRANSLATORS: B48k: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Bd3 b5 8. Nxc6
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Bd3 b5 8.Nxc6'),
			moves => {
			},
		},
		'r1b1kbnr/2qp1ppp/p1n1p3/1p6/3NP3/2NBB3/PPP2PPP/R2Q1RK1 b kq' => {
			eco => 'B48l',
			# TRANSLATORS: B48l: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Bd3 b5 8. O-O
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Bd3 b5 8.O-O'),
			moves => {
			},
		},
		'r1b1kb1r/1pqp1ppp/p1n1pn2/8/3NP3/2NBB3/PPP2PPP/R2QK2R w KQkq' => {
			eco => 'B48m',
			# TRANSLATORS: B48m: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Bd3 Nf6
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Bd3 Nf6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1b1kb1r/1pqp1ppp/p1n1pn2/8/3NP3/2NBB3/PPP2PPP/R2Q1RK1 b kq' => {
			eco => 'B48n',
			# TRANSLATORS: B48n: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Bd3 Nf6 8. O-O
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Bd3 Nf6 8.O-O'),
			moves => {
				'b7b5' => 1,
				'c6d4' => 1,
				'c6e5' => 1,
				'f8d6' => 1,
				'h7h5' => 1,
			},
		},
		'r1b1kb1r/1pqp1ppp/p3pn2/8/3nP3/2NBB3/PPP2PPP/R2Q1RK1 w kq' => {
			eco => 'B48o',
			# TRANSLATORS: B48o: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Bd3 Nf6 8. O-O Nxd4
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Bd3 Nf6 8.O-O Nxd4'),
			moves => {
			},
		},
		'r1b1kb1r/1pqp1pp1/p1n1pn2/7p/3NP3/2NBB3/PPP2PPP/R2Q1RK1 w kq' => {
			eco => 'B48p',
			# TRANSLATORS: B48p: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Bd3 Nf6 8. O-O h5
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Bd3 Nf6 8.O-O h5'),
			moves => {
			},
		},
		'r1b1kb1r/2qp1ppp/p1n1pn2/1p6/3NP3/2NBB3/PPP2PPP/R2Q1RK1 w kq' => {
			eco => 'B48q',
			# TRANSLATORS: B48q: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Bd3 Nf6 8. O-O b5
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Bd3 Nf6 8.O-O b5'),
			moves => {
			},
		},
		'r1b1k2r/1pqp1ppp/p1nbpn2/8/3NP3/2NBB3/PPP2PPP/R2Q1RK1 w kq' => {
			eco => 'B48r',
			# TRANSLATORS: B48r: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Bd3 Nf6 8. O-O Bd6
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Bd3 Nf6 8.O-O Bd6'),
			moves => {
			},
		},
		'r1b1kb1r/1pqp1ppp/p3pn2/4n3/3NP3/2NBB3/PPP2PPP/R2Q1RK1 w kq' => {
			eco => 'B48s',
			# TRANSLATORS: B48s: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Bd3 Nf6 8. O-O Ne5
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Bd3 Nf6 8.O-O Ne5'),
			moves => {
				'h2h3' => 1,
			},
		},
		'r1b1kb1r/1pqp1ppp/p3pn2/4n3/3NP3/2NBB2P/PPP2PP1/R2Q1RK1 b kq' => {
			eco => 'B48t',
			# TRANSLATORS: B48t: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Bd3 Nf6 8. O-O Ne5 9. h3
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Bd3 Nf6 8.O-O Ne5 9. h3'),
			moves => {
				'f8c5' => 1,
			},
		},
		'r1b1k2r/1pqp1ppp/p3pn2/2b1n3/3NP3/2NBB2P/PPP2PP1/R2Q1RK1 w kq' => {
			eco => 'B48u',
			# TRANSLATORS: B48u: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Bd3 Nf6 8. O-O Ne5 9. h3 Bc5
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Bd3 Nf6 8.O-O Ne5 9. h3 Bc5'),
			moves => {
				'g1h1' => 1,
			},
		},
		'r1b1k2r/1pqp1ppp/p3pn2/2b1n3/3NP3/2NBB2P/PPP2PP1/R2Q1R1K b kq' => {
			eco => 'B48v',
			# TRANSLATORS: B48v: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Bd3 Nf6 8. O-O Ne5 9. h3 Bc5 10. Kh1
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Bd3 Nf6 8.O-O Ne5 9. h3 Bc5 10. Kh1'),
			moves => {
			},
		},
		'r1b1kbnr/1pqp1ppp/p1n1p3/8/3NP3/2N1B3/PPP1BPPP/R2QK2R b KQkq' => {
			eco => 'B49a',
			# TRANSLATORS: B49a: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Be2
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Be2'),
			moves => {
				'b7b5' => 1,
				'g8e7' => 1,
				'g8f6' => 1,
			},
		},
		'r1b1kb1r/1pqpnppp/p1n1p3/8/3NP3/2N1B3/PPP1BPPP/R2QK2R w KQkq' => {
			eco => 'B49a',
			# TRANSLATORS: B49a: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Be2 Nge7
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Be2 Nge7'),
			moves => {
			},
		},
		'r1b1kbnr/2qp1ppp/p1n1p3/1p6/3NP3/2N1B3/PPP1BPPP/R2QK2R w KQkq' => {
			eco => 'B49b',
			# TRANSLATORS: B49b: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Be2 b5
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Be2 b5'),
			moves => {
				'd4c6' => 1,
			},
		},
		'r1b1kbnr/2qp1ppp/p1N1p3/1p6/4P3/2N1B3/PPP1BPPP/R2QK2R b KQkq' => {
			eco => 'B49b',
			# TRANSLATORS: B49b: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Be2 b5 8. Nxc6
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Be2 b5 8.Nxc6'),
			moves => {
			},
		},
		'r1b1kb1r/1pqp1ppp/p1n1pn2/8/3NP3/2N1B3/PPP1BPPP/R2QK2R w KQkq' => {
			eco => 'B49c',
			# TRANSLATORS: B49c: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Be2 Nf6
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Be2 Nf6'),
			moves => {
				'a2a3' => 1,
				'e1g1' => 1,
			},
		},
		'r1b1kb1r/1pqp1ppp/p1n1pn2/8/3NP3/P1N1B3/1PP1BPPP/R2QK2R b KQkq' => {
			eco => 'B49d',
			# TRANSLATORS: B49d: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Be2 Nf6 8. a3
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Be2 Nf6 8. a3'),
			moves => {
				'b7b5' => 1,
				'f8e7' => 1,
			},
		},
		'r1b1kb1r/2qp1ppp/p1n1pn2/1p6/3NP3/P1N1B3/1PP1BPPP/R2QK2R w KQkq' => {
			eco => 'B49d',
			# TRANSLATORS: B49d: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Be2 Nf6 8. a3 b5
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Be2 Nf6 8. a3 b5'),
			moves => {
			},
		},
		'r1b1k2r/1pqpbppp/p1n1pn2/8/3NP3/P1N1B3/1PP1BPPP/R2QK2R w KQkq' => {
			eco => 'B49e',
			# TRANSLATORS: B49e: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Be2 Nf6 8. a3 Be7
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Be2 Nf6 8. a3 Be7'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1b1k2r/1pqpbppp/p1n1pn2/8/3NP3/P1N1B3/1PP1BPPP/R2Q1RK1 b kq' => {
			eco => 'B49e',
			# TRANSLATORS: B49e: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Be2 Nf6 8. a3 Be7 9. O-O
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Be2 Nf6 8. a3 Be7 9.O-O'),
			moves => {
			},
		},
		'r1b1kb1r/1pqp1ppp/p1n1pn2/8/3NP3/2N1B3/PPP1BPPP/R2Q1RK1 b kq' => {
			eco => 'B49f',
			# TRANSLATORS: B49f: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Be2 Nf6 8. O-O
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Be2 Nf6 8.O-O'),
			moves => {
				'b7b5' => 1,
				'f8b4' => 1,
				'f8e7' => 1,
			},
		},
		'r1b1kb1r/2qp1ppp/p1n1pn2/1p6/3NP3/2N1B3/PPP1BPPP/R2Q1RK1 w kq' => {
			eco => 'B49f',
			# TRANSLATORS: B49f: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Be2 Nf6 8. O-O b5
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Be2 Nf6 8.O-O b5'),
			moves => {
			},
		},
		'r1b1k2r/1pqpbppp/p1n1pn2/8/3NP3/2N1B3/PPP1BPPP/R2Q1RK1 w kq' => {
			eco => 'B49g',
			# TRANSLATORS: B49g: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Be2 Nf6 8. O-O Be7
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Be2 Nf6 8.O-O Be7'),
			moves => {
			},
		},
		'r1b1k2r/1pqp1ppp/p1n1pn2/8/1b1NP3/2N1B3/PPP1BPPP/R2Q1RK1 w kq' => {
			eco => 'B49h',
			# TRANSLATORS: B49h: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Be2 Nf6 8. O-O Bb4
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Be2 Nf6 8.O-O Bb4'),
			moves => {
				'c3a4' => 1,
				'd4c6' => 1,
			},
		},
		'r1b1k2r/1pqp1ppp/p1N1pn2/8/1b2P3/2N1B3/PPP1BPPP/R2Q1RK1 b kq' => {
			eco => 'B49i',
			# TRANSLATORS: B49i: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Be2 Nf6 8. O-O Bb4 9. Nxc6
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Be2 Nf6 8.O-O Bb4 9.Nxc6'),
			moves => {
			},
		},
		'r1b1k2r/1pqp1ppp/p1n1pn2/8/Nb1NP3/4B3/PPP1BPPP/R2Q1RK1 b kq' => {
			eco => 'B49j',
			# TRANSLATORS: B49j: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Be2 Nf6 8. O-O Bb4 9. Na4
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Be2 Nf6 8.O-O Bb4 9. Na4'),
			moves => {
				'b4e7' => 1,
				'e8g8' => 1,
			},
		},
		'r1b2rk1/1pqp1ppp/p1n1pn2/8/Nb1NP3/4B3/PPP1BPPP/R2Q1RK1 w -' => {
			eco => 'B49k',
			# TRANSLATORS: B49k: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Be2 Nf6 8. O-O Bb4 9. Na4 O-O
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Be2 Nf6 8.O-O Bb4 9. Na4 O-O'),
			moves => {
			},
		},
		'r1b1k2r/1pqpbppp/p1n1pn2/8/N2NP3/4B3/PPP1BPPP/R2Q1RK1 w kq' => {
			eco => 'B49l',
			# TRANSLATORS: B49l: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Be2 Nf6 8. O-O Bb4 9. Na4 Be7
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Be2 Nf6 8.O-O Bb4 9. Na4 Be7'),
			moves => {
				'd4c6' => 1,
			},
		},
		'r1b1k2r/1pqpbppp/p1N1pn2/8/N3P3/4B3/PPP1BPPP/R2Q1RK1 b kq' => {
			eco => 'B49m',
			# TRANSLATORS: B49m: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Be2 Nf6 8. O-O Bb4 9. Na4 Be7 10. Nxc6
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Be2 Nf6 8.O-O Bb4 9. Na4 Be7 10.Nxc6'),
			moves => {
				'b7c6' => 1,
			},
		},
		'r1b1k2r/2qpbppp/p1p1pn2/8/N3P3/4B3/PPP1BPPP/R2Q1RK1 w kq' => {
			eco => 'B49m',
			# TRANSLATORS: B49m: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Be2 Nf6 8. O-O Bb4 9. Na4 Be7 10. Nxc6 bxc6
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Be2 Nf6 8.O-O Bb4 9. Na4 Be7 10.Nxc6 bxc6'),
			moves => {
				'a4b6' => 1,
			},
		},
		'r1b1k2r/2qpbppp/pNp1pn2/8/4P3/4B3/PPP1BPPP/R2Q1RK1 b kq' => {
			eco => 'B49n',
			# TRANSLATORS: B49n: 1. e4 c5 2. Nf3 e6 3. d4 cxd4 4. Nxd4 Nc6 5. Nc3 Qc7 6. Be3 a6 7. Be2 Nf6 8. O-O Bb4 9. Na4 Be7 10. Nxc6 bxc6 11. Nb6
			variation => N__('Sicilian: Taimanov, 6. Be3 a6 7. Be2 Nf6 8.O-O Bb4 9. Na4 Be7 10.Nxc6 bxc6 11. Nb6'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/3p4/2p5/4P3/5N2/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'B50a',
			# TRANSLATORS: B50a: 1. e4 c5 2. Nf3 d6
			variation => N__('Sicilian: 2. Nf3 d6'),
			moves => {
				'b1c3' => 1,
				'b2b3' => 1,
				'b2b4' => 1,
				'c2c3' => 1,
				'd2d3' => 1,
				'd2d4' => 1,
				'f1b5' => 1,
				'f1c4' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/3p4/2p5/1P2P3/5N2/P1PP1PPP/RNBQKB1R b KQkq' => {
			eco => 'B50b',
			# TRANSLATORS: B50b: 1. e4 c5 2. Nf3 d6 3. b4
			variation => N__('Sicilian: Wing Gambit deferred'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/3p4/2p5/4P3/1P3N2/P1PP1PPP/RNBQKB1R b KQkq' => {
			eco => 'B50c',
			# TRANSLATORS: B50c: 1. e4 c5 2. Nf3 d6 3. b3
			variation => N__('Sicilian: 2. Nf3 d6 3. b3'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/3pp3/2p5/4P3/1P3N2/P1PP1PPP/RNBQKB1R w KQkq' => {
			eco => 'B50d',
			# TRANSLATORS: B50d: 1. e4 c5 2. Nf3 d6 3. b3 e6
			variation => N__('Sicilian: 2. Nf3 d6 3. b3 e6'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/3p4/2p5/4P3/3P1N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B50e',
			# TRANSLATORS: B50e: 1. e4 c5 2. Nf3 d6 3. d3
			variation => N__('Sicilian: 2. Nf3 d6 3. d3'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/3p4/2p5/4P3/5NP1/PPPP1P1P/RNBQKB1R b KQkq' => {
			eco => 'B50f',
			# TRANSLATORS: B50f: 1. e4 c5 2. Nf3 d6 3. g3
			variation => N__('Sicilian: 2. Nf3 d6 3. g3'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/3p4/2p5/2B1P3/5N2/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'B50g',
			# TRANSLATORS: B50g: 1. e4 c5 2. Nf3 d6 3. Bc4
			variation => N__('Sicilian: 2. Nf3 d6 3. Bc4'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/3p1n2/2p5/2B1P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'B50g',
			# TRANSLATORS: B50g: 1. e4 c5 2. Nf3 d6 3. Bc4 Nf6
			variation => N__('Sicilian: 2. Nf3 d6 3. Bc4'),
			moves => {
				'd2d3' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/3p1n2/2p5/2B1P3/3P1N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'B50h',
			# TRANSLATORS: B50h: 1. e4 c5 2. Nf3 d6 3. Bc4 Nf6 4. d3
			variation => N__('Sicilian: 2. Nf3 d6 3. Bc4 Nf6 4. d3'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/3p4/2p5/4P3/2N2N2/PPPP1PPP/R1BQKB1R b KQkq' => {
			eco => 'B50i',
			# TRANSLATORS: B50i: 1. e4 c5 2. Nf3 d6 3. Nc3
			variation => N__('Sicilian: 2. Nf3 d6 3. Nc3'),
			moves => {
				'e7e6' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/3pp3/2p5/4P3/2N2N2/PPPP1PPP/R1BQKB1R w KQkq' => {
			eco => 'B50j',
			# TRANSLATORS: B50j: 1. e4 c5 2. Nf3 d6 3. Nc3 e6
			variation => N__('Sicilian: 2. Nf3 d6 3. Nc3 e6'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/3p1n2/2p5/4P3/2N2N2/PPPP1PPP/R1BQKB1R w KQkq' => {
			eco => 'B50k',
			# TRANSLATORS: B50k: 1. e4 c5 2. Nf3 d6 3. Nc3 Nf6
			variation => N__('Sicilian: 2. Nf3 d6 3. Nc3 Nf6'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/3p4/2p5/4P3/2P2N2/PP1P1PPP/RNBQKB1R b KQkq' => {
			eco => 'B50l',
			# TRANSLATORS: B50l: 1. e4 c5 2. Nf3 d6 3. c3
			variation => N__('Sicilian: 2. Nf3 d6 3. c3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/3p1n2/2p5/4P3/2P2N2/PP1P1PPP/RNBQKB1R w KQkq' => {
			eco => 'B50m',
			# TRANSLATORS: B50m: 1. e4 c5 2. Nf3 d6 3. c3 Nf6
			variation => N__('Sicilian: 2. Nf3 d6 3. c3 Nf6'),
			moves => {
				'f1c4' => 1,
				'f1d3' => 1,
				'f1e2' => 1,
				'h2h3' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/3p1n2/2p5/4P3/2P2N1P/PP1P1PP1/RNBQKB1R b KQkq' => {
			eco => 'B50n',
			# TRANSLATORS: B50n: 1. e4 c5 2. Nf3 d6 3. c3 Nf6 4. h3
			variation => N__('Sicilian: 2. Nf3 d6 3. c3 Nf6 4. h3'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkb1r/pp2pppp/2np1n2/2p5/4P3/2P2N1P/PP1P1PP1/RNBQKB1R w KQkq' => {
			eco => 'B50o',
			# TRANSLATORS: B50o: 1. e4 c5 2. Nf3 d6 3. c3 Nf6 4. h3 Nc6
			variation => N__('Sicilian: 2. Nf3 d6 3. c3 Nf6 4. h3 Nc6'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/3p1n2/2p5/2B1P3/2P2N2/PP1P1PPP/RNBQK2R b KQkq' => {
			eco => 'B50p',
			# TRANSLATORS: B50p: 1. e4 c5 2. Nf3 d6 3. c3 Nf6 4. Bc4
			variation => N__('Sicilian: 2. Nf3 d6 3. c3 Nf6 4. Bc4'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/3p1n2/2p5/4P3/2PB1N2/PP1P1PPP/RNBQK2R b KQkq' => {
			eco => 'B50q',
			# TRANSLATORS: B50q: 1. e4 c5 2. Nf3 d6 3. c3 Nf6 4. Bd3
			variation => N__('Sicilian: 2. Nf3 d6 3. c3 Nf6 4. Bd3'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkb1r/pp2pppp/2np1n2/2p5/4P3/2PB1N2/PP1P1PPP/RNBQK2R w KQkq' => {
			eco => 'B50r',
			# TRANSLATORS: B50r: 1. e4 c5 2. Nf3 d6 3. c3 Nf6 4. Bd3 Nc6
			variation => N__('Sicilian: 2. Nf3 d6 3. c3 Nf6 4. Bd3 Nc6'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/3p1n2/2p5/4P3/2P2N2/PP1PBPPP/RNBQK2R b KQkq' => {
			eco => 'B50s',
			# TRANSLATORS: B50s: 1. e4 c5 2. Nf3 d6 3. c3 Nf6 4. Be2
			variation => N__('Sicilian: 2. Nf3 d6 3. c3 Nf6 4. Be2'),
			moves => {
				'b8c6' => 1,
				'b8d7' => 1,
				'g7g6' => 1,
			},
		},
		'r1bqkb1r/pp2pppp/2np1n2/2p5/4P3/2P2N2/PP1PBPPP/RNBQK2R w KQkq' => {
			eco => 'B50t',
			# TRANSLATORS: B50t: 1. e4 c5 2. Nf3 d6 3. c3 Nf6 4. Be2 Nc6
			variation => N__('Sicilian: 2. Nf3 d6 3. c3 Nf6 4. Be2 Nc6'),
			moves => {
			},
		},
		'r1bqkb1r/pp1npppp/3p1n2/2p5/4P3/2P2N2/PP1PBPPP/RNBQK2R w KQkq' => {
			eco => 'B50u',
			# TRANSLATORS: B50u: 1. e4 c5 2. Nf3 d6 3. c3 Nf6 4. Be2 Nbd7
			variation => N__('Sicilian: 2. Nf3 d6 3. c3 Nf6 4. Be2 Nbd7'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pp1p/3p1np1/2p5/4P3/2P2N2/PP1PBPPP/RNBQK2R w KQkq' => {
			eco => 'B50v',
			# TRANSLATORS: B50v: 1. e4 c5 2. Nf3 d6 3. c3 Nf6 4. Be2 g6
			variation => N__('Sicilian: 2. Nf3 d6 3. c3 Nf6 4. Be2 g6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbqkb1r/pp2pp1p/3p1np1/2p5/4P3/2P2N2/PP1PBPPP/RNBQ1RK1 b kq' => {
			eco => 'B50v',
			# TRANSLATORS: B50v: 1. e4 c5 2. Nf3 d6 3. c3 Nf6 4. Be2 g6 5. O-O
			variation => N__('Sicilian: 2. Nf3 d6 3. c3 Nf6 4. Be2 g6'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/3p1np1/2p5/4P3/2P2N2/PP1PBPPP/RNBQ1RK1 w kq' => {
			eco => 'B50v',
			# TRANSLATORS: B50v: 1. e4 c5 2. Nf3 d6 3. c3 Nf6 4. Be2 g6 5. O-O Bg7
			variation => N__('Sicilian: 2. Nf3 d6 3. c3 Nf6 4. Be2 g6'),
			moves => {
				'e2b5' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/3p1np1/1Bp5/4P3/2P2N2/PP1P1PPP/RNBQ1RK1 b kq' => {
			eco => 'B50w',
			# TRANSLATORS: B50w: 1. e4 c5 2. Nf3 d6 3. c3 Nf6 4. Be2 g6 5. O-O Bg7 6. Bb5+
			variation => N__('Sicilian: 2. Nf3 d6 3. c3, Torre Variation'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/3p4/1Bp5/4P3/5N2/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'B51a',
			# TRANSLATORS: B51a: 1. e4 c5 2. Nf3 d6 3. Bb5+
			variation => N__('Sicilian: 3. Bb5+'),
			moves => {
				'b8c6' => 1,
				'b8d7' => 1,
				'c8d7' => 1,
			},
		},
		'r1bqkbnr/pp1npppp/3p4/1Bp5/4P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'B51a',
			# TRANSLATORS: B51a: 1. e4 c5 2. Nf3 d6 3. Bb5+ Nd7
			variation => N__('Sicilian: 3. Bb5+ Nd7'),
			moves => {
				'c2c3' => 1,
				'd2d4' => 1,
				'e1g1' => 1,
			},
		},
		'r1bqkbnr/pp1npppp/3p4/1Bp5/4P3/2P2N2/PP1P1PPP/RNBQK2R b KQkq' => {
			eco => 'B51b',
			# TRANSLATORS: B51b: 1. e4 c5 2. Nf3 d6 3. Bb5+ Nd7 4. c3
			variation => N__('Sicilian: 3. Bb5+ Nd7 4. c3'),
			moves => {
			},
		},
		'r1bqkbnr/pp1npppp/3p4/1Bp5/4P3/5N2/PPPP1PPP/RNBQ1RK1 b kq' => {
			eco => 'B51c',
			# TRANSLATORS: B51c: 1. e4 c5 2. Nf3 d6 3. Bb5+ Nd7 4. O-O
			variation => N__('Sicilian: 3. Bb5+ Nd7 4.O-O'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r1bqkb1r/pp1npppp/3p1n2/1Bp5/4P3/5N2/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'B51d',
			# TRANSLATORS: B51d: 1. e4 c5 2. Nf3 d6 3. Bb5+ Nd7 4. O-O Nf6
			variation => N__('Sicilian: 3. Bb5+ Nd7 4.O-O Nf6'),
			moves => {
				'f1e1' => 1,
			},
		},
		'r1bqkb1r/pp1npppp/3p1n2/1Bp5/4P3/5N2/PPPP1PPP/RNBQR1K1 b kq' => {
			eco => 'B51d',
			# TRANSLATORS: B51d: 1. e4 c5 2. Nf3 d6 3. Bb5+ Nd7 4. O-O Nf6 5. Re1
			variation => N__('Sicilian: 3. Bb5+ Nd7 4.O-O Nf6'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r1bqkb1r/1p1npppp/p2p1n2/1Bp5/4P3/5N2/PPPP1PPP/RNBQR1K1 w kq' => {
			eco => 'B51d',
			# TRANSLATORS: B51d: 1. e4 c5 2. Nf3 d6 3. Bb5+ Nd7 4. O-O Nf6 5. Re1 a6
			variation => N__('Sicilian: 3. Bb5+ Nd7 4.O-O Nf6'),
			moves => {
				'b5f1' => 1,
			},
		},
		'r1bqkb1r/1p1npppp/p2p1n2/2p5/4P3/5N2/PPPP1PPP/RNBQRBK1 b kq' => {
			eco => 'B51e',
			# TRANSLATORS: B51e: 1. e4 c5 2. Nf3 d6 3. Bb5+ Nd7 4. O-O Nf6 5. Re1 a6 6. Bf1
			variation => N__('Sicilian: 3. Bb5+ Nd7 4.O-O Nf6 5. Re1 a6 6. Bf1'),
			moves => {
			},
		},
		'r1bqkbnr/pp1npppp/3p4/1Bp5/3PP3/5N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'B51f',
			# TRANSLATORS: B51f: 1. e4 c5 2. Nf3 d6 3. Bb5+ Nd7 4. d4
			variation => N__('Sicilian: 3. Bb5+ Nd7 4. d4'),
			moves => {
				'c5d4' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkbnr/pp1npppp/3p4/1B6/3pP3/5N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'B51f',
			# TRANSLATORS: B51f: 1. e4 c5 2. Nf3 d6 3. Bb5+ Nd7 4. d4 cxd4
			variation => N__('Sicilian: 3. Bb5+ Nd7 4. d4 cxd4'),
			moves => {
			},
		},
		'r1bqkb1r/pp1npppp/3p1n2/1Bp5/3PP3/5N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'B51g',
			# TRANSLATORS: B51g: 1. e4 c5 2. Nf3 d6 3. Bb5+ Nd7 4. d4 Nf6
			variation => N__('Sicilian: 3. Bb5+ Nd7 4. d4 Nf6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r1bqkb1r/pp1npppp/3p1n2/1Bp5/3PP3/2N2N2/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'B51h',
			# TRANSLATORS: B51h: 1. e4 c5 2. Nf3 d6 3. Bb5+ Nd7 4. d4 Nf6 5. Nc3
			variation => N__('Sicilian: 3. Bb5+ Nd7 4. d4 Nf6 5. Nc3'),
			moves => {
				'c5d4' => 1,
			},
		},
		'r1bqkb1r/pp1npppp/3p1n2/1B6/3pP3/2N2N2/PPP2PPP/R1BQK2R w KQkq' => {
			eco => 'B51i',
			# TRANSLATORS: B51i: 1. e4 c5 2. Nf3 d6 3. Bb5+ Nd7 4. d4 Nf6 5. Nc3 cxd4
			variation => N__('Sicilian: 3. Bb5+ Nd7 4. d4 Nf6 5. Nc3 cxd4'),
			moves => {
				'd1d4' => 1,
			},
		},
		'r1bqkb1r/pp1npppp/3p1n2/1B6/3QP3/2N2N2/PPP2PPP/R1B1K2R b KQkq' => {
			eco => 'B51i',
			# TRANSLATORS: B51i: 1. e4 c5 2. Nf3 d6 3. Bb5+ Nd7 4. d4 Nf6 5. Nc3 cxd4 6. Qxd4
			variation => N__('Sicilian: 3. Bb5+ Nd7 4. d4 Nf6 5. Nc3 cxd4 6.Qxd4'),
			moves => {
				'e7e5' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/3p1n2/1B2p3/3QP3/2N2N2/PPP2PPP/R1B1K2R w KQkq' => {
			eco => 'B51j',
			# TRANSLATORS: B51j: 1. e4 c5 2. Nf3 d6 3. Bb5+ Nd7 4. d4 Nf6 5. Nc3 cxd4 6. Qxd4 e5
			variation => N__('Sicilian: 3. Bb5+ Nd7 4. d4 Nf6 5. Nc3 cxd4 6.Qxd4 e5'),
			moves => {
			},
		},
		'r1bqkbnr/pp2pppp/2np4/1Bp5/4P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'B51k',
			# TRANSLATORS: B51k: 1. e4 c5 2. Nf3 d6 3. Bb5+ Nc6
			variation => N__('Sicilian: 3. Bb5+ Nc6'),
			moves => {
				'b5c6' => 1,
				'e1g1' => 1,
			},
		},
		'r1bqkbnr/pp2pppp/2Bp4/2p5/4P3/5N2/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'B51l',
			# TRANSLATORS: B51l: 1. e4 c5 2. Nf3 d6 3. Bb5+ Nc6 4. Bxc6+
			variation => N__('Sicilian: 3. Bb5+ Nc6 4.Bxc6+'),
			moves => {
			},
		},
		'r1bqkbnr/pp2pppp/2np4/1Bp5/4P3/5N2/PPPP1PPP/RNBQ1RK1 b kq' => {
			eco => 'B51m',
			# TRANSLATORS: B51m: 1. e4 c5 2. Nf3 d6 3. Bb5+ Nc6 4. O-O
			variation => N__('Sicilian: 3. Bb5+ Nc6 4.O-O'),
			moves => {
				'c8d7' => 1,
			},
		},
		'r2qkbnr/pp1bpppp/2np4/1Bp5/4P3/5N2/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'B51n',
			# TRANSLATORS: B51n: 1. e4 c5 2. Nf3 d6 3. Bb5+ Nc6 4. O-O Bd7
			variation => N__('Sicilian: 3. Bb5+ Nc6 4.O-O Bd7'),
			moves => {
				'f1e1' => 1,
			},
		},
		'r2qkbnr/pp1bpppp/2np4/1Bp5/4P3/5N2/PPPP1PPP/RNBQR1K1 b kq' => {
			eco => 'B51o',
			# TRANSLATORS: B51o: 1. e4 c5 2. Nf3 d6 3. Bb5+ Nc6 4. O-O Bd7 5. Re1
			variation => N__('Sicilian: 3. Bb5+ Nc6 4.O-O Bd7 5. Re1'),
			moves => {
				'a7a6' => 1,
				'g8f6' => 1,
			},
		},
		'r2qkbnr/1p1bpppp/p1np4/1Bp5/4P3/5N2/PPPP1PPP/RNBQR1K1 w kq' => {
			eco => 'B51p',
			# TRANSLATORS: B51p: 1. e4 c5 2. Nf3 d6 3. Bb5+ Nc6 4. O-O Bd7 5. Re1 a6
			variation => N__('Sicilian: 3. Bb5+ Nc6 4.O-O Bd7 5. Re1 a6'),
			moves => {
			},
		},
		'r2qkb1r/pp1bpppp/2np1n2/1Bp5/4P3/5N2/PPPP1PPP/RNBQR1K1 w kq' => {
			eco => 'B51q',
			# TRANSLATORS: B51q: 1. e4 c5 2. Nf3 d6 3. Bb5+ Nc6 4. O-O Bd7 5. Re1 Nf6
			variation => N__('Sicilian: 3. Bb5+ Nc6 4.O-O Bd7 5. Re1 Nf6'),
			moves => {
				'c2c3' => 1,
			},
		},
		'r2qkb1r/pp1bpppp/2np1n2/1Bp5/4P3/2P2N2/PP1P1PPP/RNBQR1K1 b kq' => {
			eco => 'B51r',
			# TRANSLATORS: B51r: 1. e4 c5 2. Nf3 d6 3. Bb5+ Nc6 4. O-O Bd7 5. Re1 Nf6 6. c3
			variation => N__('Sicilian: 3. Bb5+ Nc6 4.O-O Bd7 5. Re1 Nf6 6. c3'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r2qkb1r/1p1bpppp/p1np1n2/1Bp5/4P3/2P2N2/PP1P1PPP/RNBQR1K1 w kq' => {
			eco => 'B51r',
			# TRANSLATORS: B51r: 1. e4 c5 2. Nf3 d6 3. Bb5+ Nc6 4. O-O Bd7 5. Re1 Nf6 6. c3 a6
			variation => N__('Sicilian: 3. Bb5+ Nc6 4.O-O Bd7 5. Re1 Nf6 6. c3'),
			moves => {
				'b5a4' => 1,
				'b5f1' => 1,
			},
		},
		'r2qkb1r/1p1bpppp/p1np1n2/2p5/B3P3/2P2N2/PP1P1PPP/RNBQR1K1 b kq' => {
			eco => 'B51s',
			# TRANSLATORS: B51s: 1. e4 c5 2. Nf3 d6 3. Bb5+ Nc6 4. O-O Bd7 5. Re1 Nf6 6. c3 a6 7. Ba4
			variation => N__('Sicilian: 3. Bb5+ Nc6 4.O-O Bd7 5. Re1 Nf6 6. c3 a6 7. Ba4'),
			moves => {
			},
		},
		'r2qkb1r/1p1bpppp/p1np1n2/2p5/4P3/2P2N2/PP1P1PPP/RNBQRBK1 b kq' => {
			eco => 'B51t',
			# TRANSLATORS: B51t: 1. e4 c5 2. Nf3 d6 3. Bb5+ Nc6 4. O-O Bd7 5. Re1 Nf6 6. c3 a6 7. Bf1
			variation => N__('Sicilian: 3. Bb5+ Nc6 4.O-O Bd7 5. Re1 Nf6 6. c3 a6 7. Bf1'),
			moves => {
				'd7g4' => 1,
			},
		},
		'r2qkb1r/1p2pppp/p1np1n2/2p5/4P1b1/2P2N2/PP1P1PPP/RNBQRBK1 w kq' => {
			eco => 'B51t',
			# TRANSLATORS: B51t: 1. e4 c5 2. Nf3 d6 3. Bb5+ Nc6 4. O-O Bd7 5. Re1 Nf6 6. c3 a6 7. Bf1 Bg4
			variation => N__('Sicilian: 3. Bb5+ Nc6 4.O-O Bd7 5. Re1 Nf6 6. c3 a6 7. Bf1'),
			moves => {
				'h2h3' => 1,
			},
		},
		'r2qkb1r/1p2pppp/p1np1n2/2p5/4P1b1/2P2N1P/PP1P1PP1/RNBQRBK1 b kq' => {
			eco => 'B51u',
			# TRANSLATORS: B51u: 1. e4 c5 2. Nf3 d6 3. Bb5+ Nc6 4. O-O Bd7 5. Re1 Nf6 6. c3 a6 7. Bf1 Bg4 8. h3
			variation => N__('Sicilian: 3. Bb5+ Nc6 4.O-O Bd7 5. Re1 Nf6 6. c3 a6 7. Bf1 Bg4 8. h3'),
			moves => {
			},
		},
		'rn1qkbnr/pp1bpppp/3p4/1Bp5/4P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'B52a',
			# TRANSLATORS: B52a: 1. e4 c5 2. Nf3 d6 3. Bb5+ Bd7
			variation => N__('Sicilian: 3. Bb5+ Bd7'),
			moves => {
				'b5d7' => 1,
			},
		},
		'rn1qkbnr/pp1Bpppp/3p4/2p5/4P3/5N2/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'B52a',
			# TRANSLATORS: B52a: 1. e4 c5 2. Nf3 d6 3. Bb5+ Bd7 4. Bxd7+
			variation => N__('Sicilian: 3. Bb5+ Bd7'),
			moves => {
				'b8d7' => 1,
				'd8d7' => 1,
			},
		},
		'r2qkbnr/pp1npppp/3p4/2p5/4P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'B52b',
			# TRANSLATORS: B52b: 1. e4 c5 2. Nf3 d6 3. Bb5+ Bd7 4. Bxd7+ Nxd7
			variation => N__('Sicilian: 3. Bb5+ Bd7 4.Bxd7+ Nxd7'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r2qkbnr/pp1npppp/3p4/2p5/4P3/5N2/PPPP1PPP/RNBQ1RK1 b kq' => {
			eco => 'B52c',
			# TRANSLATORS: B52c: 1. e4 c5 2. Nf3 d6 3. Bb5+ Bd7 4. Bxd7+ Nxd7 5. O-O
			variation => N__('Sicilian: 3. Bb5+ Bd7 4.Bxd7+ Nxd7 5.O-O'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r2qkb1r/pp1npppp/3p1n2/2p5/4P3/5N2/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'B52d',
			# TRANSLATORS: B52d: 1. e4 c5 2. Nf3 d6 3. Bb5+ Bd7 4. Bxd7+ Nxd7 5. O-O Ngf6
			variation => N__('Sicilian: 3. Bb5+ Bd7 4.Bxd7+ Nxd7 5.O-O Ngf6'),
			moves => {
				'd1e2' => 1,
			},
		},
		'r2qkb1r/pp1npppp/3p1n2/2p5/4P3/5N2/PPPPQPPP/RNB2RK1 b kq' => {
			eco => 'B52e',
			# TRANSLATORS: B52e: 1. e4 c5 2. Nf3 d6 3. Bb5+ Bd7 4. Bxd7+ Nxd7 5. O-O Ngf6 6. Qe2
			variation => N__('Sicilian: 3. Bb5+ Bd7 4.Bxd7+ Nxd7 5.O-O Ngf6 6. Qe2'),
			moves => {
			},
		},
		'rn2kbnr/pp1qpppp/3p4/2p5/4P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'B52f',
			# TRANSLATORS: B52f: 1. e4 c5 2. Nf3 d6 3. Bb5+ Bd7 4. Bxd7+ Qxd7
			variation => N__('Sicilian: 3. Bb5+ Bd7 4.Bxd7+ Qxd7'),
			moves => {
				'c2c4' => 1,
				'e1g1' => 1,
			},
		},
		'rn2kbnr/pp1qpppp/3p4/2p5/2P1P3/5N2/PP1P1PPP/RNBQK2R b KQkq' => {
			eco => 'B52g',
			# TRANSLATORS: B52g: 1. e4 c5 2. Nf3 d6 3. Bb5+ Bd7 4. Bxd7+ Qxd7 5. c4
			variation => N__('Sicilian: 3. Bb5+, Sokolsky Variation'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r3kbnr/pp1qpppp/2np4/2p5/2P1P3/5N2/PP1P1PPP/RNBQK2R w KQkq' => {
			eco => 'B52h',
			# TRANSLATORS: B52h: 1. e4 c5 2. Nf3 d6 3. Bb5+ Bd7 4. Bxd7+ Qxd7 5. c4 Nc6
			variation => N__('Sicilian: 3. Bb5+, Sokolsky, 5... Nc6'),
			moves => {
				'b1c3' => 1,
				'e1g1' => 1,
			},
		},
		'r3kbnr/pp1qpppp/2np4/2p5/2P1P3/5N2/PP1P1PPP/RNBQ1RK1 b kq' => {
			eco => 'B52i',
			# TRANSLATORS: B52i: 1. e4 c5 2. Nf3 d6 3. Bb5+ Bd7 4. Bxd7+ Qxd7 5. c4 Nc6 6. O-O
			variation => N__('Sicilian: 3. Bb5+, Sokolsky, 5... Nc6 6.O-O'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r3kb1r/pp1qpppp/2np1n2/2p5/2P1P3/5N2/PP1P1PPP/RNBQ1RK1 w kq' => {
			eco => 'B52j',
			# TRANSLATORS: B52j: 1. e4 c5 2. Nf3 d6 3. Bb5+ Bd7 4. Bxd7+ Qxd7 5. c4 Nc6 6. O-O Nf6
			variation => N__('Sicilian: 3. Bb5+, Sokolsky, 5... Nc6 6.O-O Nf6'),
			moves => {
			},
		},
		'r3kbnr/pp1qpppp/2np4/2p5/2P1P3/2N2N2/PP1P1PPP/R1BQK2R b KQkq' => {
			eco => 'B52k',
			# TRANSLATORS: B52k: 1. e4 c5 2. Nf3 d6 3. Bb5+ Bd7 4. Bxd7+ Qxd7 5. c4 Nc6 6. Nc3
			variation => N__('Sicilian: 3. Bb5+, Sokolsky, 5... Nc6 6. Nc3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r3kb1r/pp1qpppp/2np1n2/2p5/2P1P3/2N2N2/PP1P1PPP/R1BQK2R w KQkq' => {
			eco => 'B52l',
			# TRANSLATORS: B52l: 1. e4 c5 2. Nf3 d6 3. Bb5+ Bd7 4. Bxd7+ Qxd7 5. c4 Nc6 6. Nc3 Nf6
			variation => N__('Sicilian: 3. Bb5+, Sokolsky, 5... Nc6 6. Nc3 Nf6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r3kb1r/pp1qpppp/2np1n2/2p5/2P1P3/2N2N2/PP1P1PPP/R1BQ1RK1 b kq' => {
			eco => 'B52m',
			# TRANSLATORS: B52m: 1. e4 c5 2. Nf3 d6 3. Bb5+ Bd7 4. Bxd7+ Qxd7 5. c4 Nc6 6. Nc3 Nf6 7. O-O
			variation => N__('Sicilian: 3. Bb5+, Sokolsky, 5... Nc6 6. Nc3 Nf6 7.O-O'),
			moves => {
			},
		},
		'rn2kbnr/pp1qpppp/3p4/2p5/4P3/5N2/PPPP1PPP/RNBQ1RK1 b kq' => {
			eco => 'B52n',
			# TRANSLATORS: B52n: 1. e4 c5 2. Nf3 d6 3. Bb5+ Bd7 4. Bxd7+ Qxd7 5. O-O
			variation => N__('Sicilian: 3. Bb5+ Bd7 4.Bxd7+ Qxd7 5.O-O'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r3kbnr/pp1qpppp/2np4/2p5/4P3/5N2/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'B52o',
			# TRANSLATORS: B52o: 1. e4 c5 2. Nf3 d6 3. Bb5+ Bd7 4. Bxd7+ Qxd7 5. O-O Nc6
			variation => N__('Sicilian: 3. Bb5+ Bd7 4.Bxd7+ Qxd7 5.O-O Nc6'),
			moves => {
				'c2c3' => 1,
				'f1e1' => 1,
			},
		},
		'r3kbnr/pp1qpppp/2np4/2p5/4P3/5N2/PPPP1PPP/RNBQR1K1 b kq' => {
			eco => 'B52p',
			# TRANSLATORS: B52p: 1. e4 c5 2. Nf3 d6 3. Bb5+ Bd7 4. Bxd7+ Qxd7 5. O-O Nc6 6. Re1
			variation => N__('Sicilian: 3. Bb5+ Bd7 4.Bxd7+ Qxd7 5.O-O Nc6 6. Re1'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r3kb1r/pp1qpppp/2np1n2/2p5/4P3/5N2/PPPP1PPP/RNBQR1K1 w kq' => {
			eco => 'B52q',
			# TRANSLATORS: B52q: 1. e4 c5 2. Nf3 d6 3. Bb5+ Bd7 4. Bxd7+ Qxd7 5. O-O Nc6 6. Re1 Nf6
			variation => N__('Sicilian: 3. Bb5+ Bd7 4.Bxd7+ Qxd7 5.O-O Nc6 6. Re1 Nf6'),
			moves => {
			},
		},
		'r3kbnr/pp1qpppp/2np4/2p5/4P3/2P2N2/PP1P1PPP/RNBQ1RK1 b kq' => {
			eco => 'B52r',
			# TRANSLATORS: B52r: 1. e4 c5 2. Nf3 d6 3. Bb5+ Bd7 4. Bxd7+ Qxd7 5. O-O Nc6 6. c3
			variation => N__('Sicilian: 3. Bb5+ Bd7 4.Bxd7+ Qxd7 5.O-O Nc6 6. c3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r3kb1r/pp1qpppp/2np1n2/2p5/4P3/2P2N2/PP1P1PPP/RNBQ1RK1 w kq' => {
			eco => 'B52s',
			# TRANSLATORS: B52s: 1. e4 c5 2. Nf3 d6 3. Bb5+ Bd7 4. Bxd7+ Qxd7 5. O-O Nc6 6. c3 Nf6
			variation => N__('Sicilian: 3. Bb5+ Bd7 4.Bxd7+ Qxd7 5.O-O Nc6 6. c3 Nf6'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r3kb1r/pp1qpppp/2np1n2/2p5/3PP3/2P2N2/PP3PPP/RNBQ1RK1 b kq' => {
			eco => 'B52t',
			# TRANSLATORS: B52t: 1. e4 c5 2. Nf3 d6 3. Bb5+ Bd7 4. Bxd7+ Qxd7 5. O-O Nc6 6. c3 Nf6 7. d4
			variation => N__('Sicilian: 3. Bb5+, Bronstein Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/3p4/2p5/3PP3/5N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B53a',
			# TRANSLATORS: B53a: 1. e4 c5 2. Nf3 d6 3. d4
			variation => N__('Sicilian: 2... d6 3. d4'),
			moves => {
				'c5d4' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/3p1n2/2p5/3PP3/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B53b',
			# TRANSLATORS: B53b: 1. e4 c5 2. Nf3 d6 3. d4 Nf6
			variation => N__('Sicilian: 2... d6 3. d4 Nf6'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/3p4/8/3pP3/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B53c',
			# TRANSLATORS: B53c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4
			variation => N__('Sicilian: 2... d6 3. d4 cxd4'),
			moves => {
				'd1d4' => 1,
				'f3d4' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/3p4/8/3QP3/5N2/PPP2PPP/RNB1KB1R b KQkq' => {
			eco => 'B53d',
			# TRANSLATORS: B53d: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Qxd4
			variation => N__('Sicilian, Chekhover Variation'),
			moves => {
				'a7a6' => 1,
				'b8c6' => 1,
				'c8d7' => 1,
				'g8f6' => 1,
			},
		},
		'rn1qkbnr/pp1bpppp/3p4/8/3QP3/5N2/PPP2PPP/RNB1KB1R w KQkq' => {
			eco => 'B53e',
			# TRANSLATORS: B53e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Qxd4 Bd7
			variation => N__('Sicilian, Chekhover, 4... Bd7'),
			moves => {
			},
		},
		'rnbqkbnr/1p2pppp/p2p4/8/3QP3/5N2/PPP2PPP/RNB1KB1R w KQkq' => {
			eco => 'B53f',
			# TRANSLATORS: B53f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Qxd4 a6
			variation => N__('Sicilian, Chekhover, 4... a6'),
			moves => {
				'c1e3' => 1,
				'c2c4' => 1,
			},
		},
		'rnbqkbnr/1p2pppp/p2p4/8/3QP3/4BN2/PPP2PPP/RN2KB1R b KQkq' => {
			eco => 'B53g',
			# TRANSLATORS: B53g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Qxd4 a6 5. Be3
			variation => N__('Sicilian, Chekhover, 4... a6 5. Be3'),
			moves => {
			},
		},
		'rnbqkbnr/1p2pppp/p2p4/8/2PQP3/5N2/PP3PPP/RNB1KB1R b KQkq' => {
			eco => 'B53h',
			# TRANSLATORS: B53h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Qxd4 a6 5. c4
			variation => N__('Sicilian, Chekhover, 4... a6 5. c4'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkbnr/1p2pppp/p1np4/8/2PQP3/5N2/PP3PPP/RNB1KB1R w KQkq' => {
			eco => 'B53h',
			# TRANSLATORS: B53h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Qxd4 a6 5. c4 Nc6
			variation => N__('Sicilian, Chekhover, 4... a6 5. c4'),
			moves => {
				'd4d2' => 1,
			},
		},
		'r1bqkbnr/1p2pppp/p1np4/8/2P1P3/5N2/PP1Q1PPP/RNB1KB1R b KQkq' => {
			eco => 'B53i',
			# TRANSLATORS: B53i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Qxd4 a6 5. c4 Nc6 6. Qd2
			variation => N__('Sicilian, Chekhover, 4... a6 5. c4 Nc6 6. Qd2'),
			moves => {
				'g7g6' => 1,
			},
		},
		'r1bqkbnr/1p2pp1p/p1np2p1/8/2P1P3/5N2/PP1Q1PPP/RNB1KB1R w KQkq' => {
			eco => 'B53j',
			# TRANSLATORS: B53j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Qxd4 a6 5. c4 Nc6 6. Qd2 g6
			variation => N__('Sicilian, Chekhover, 4... a6 5. c4 Nc6 6. Qd2 g6'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/3p1n2/8/3QP3/5N2/PPP2PPP/RNB1KB1R w KQkq' => {
			eco => 'B53k',
			# TRANSLATORS: B53k: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Qxd4 Nf6
			variation => N__('Sicilian, Chekhover, 4... Nf6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/3p1n2/8/3QP3/2N2N2/PPP2PPP/R1B1KB1R b KQkq' => {
			eco => 'B53k',
			# TRANSLATORS: B53k: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Qxd4 Nf6 5. Nc3
			variation => N__('Sicilian, Chekhover, 4... Nf6 5. Nc3'),
			moves => {
			},
		},
		'r1bqkbnr/pp2pppp/2np4/8/3QP3/5N2/PPP2PPP/RNB1KB1R w KQkq' => {
			eco => 'B53l',
			# TRANSLATORS: B53l: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Qxd4 Nc6
			variation => N__('Sicilian, Chekhover, 4... Nc6'),
			moves => {
				'f1b5' => 1,
			},
		},
		'r1bqkbnr/pp2pppp/2np4/1B6/3QP3/5N2/PPP2PPP/RNB1K2R b KQkq' => {
			eco => 'B53l',
			# TRANSLATORS: B53l: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Qxd4 Nc6 5. Bb5
			variation => N__('Sicilian, Chekhover, 4... Nc6'),
			moves => {
				'c8d7' => 1,
				'd8d7' => 1,
			},
		},
		'r1b1kbnr/pp1qpppp/2np4/1B6/3QP3/5N2/PPP2PPP/RNB1K2R w KQkq' => {
			eco => 'B53m',
			# TRANSLATORS: B53m: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Qxd4 Nc6 5. Bb5 Qd7
			variation => N__('Sicilian: Chekhover, Zaitsev Variation'),
			moves => {
			},
		},
		'r2qkbnr/pp1bpppp/2np4/1B6/3QP3/5N2/PPP2PPP/RNB1K2R w KQkq' => {
			eco => 'B53n',
			# TRANSLATORS: B53n: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Qxd4 Nc6 5. Bb5 Bd7
			variation => N__('Sicilian, Chekhover, 4... Nc6 5. Bb5 Bd7'),
			moves => {
				'b5c6' => 1,
			},
		},
		'r2qkbnr/pp1bpppp/2Bp4/8/3QP3/5N2/PPP2PPP/RNB1K2R b KQkq' => {
			eco => 'B53n',
			# TRANSLATORS: B53n: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Qxd4 Nc6 5. Bb5 Bd7 6. Bxc6
			variation => N__('Sicilian, Chekhover, 4... Nc6 5. Bb5 Bd7'),
			moves => {
				'd7c6' => 1,
			},
		},
		'r2qkbnr/pp2pppp/2bp4/8/3QP3/5N2/PPP2PPP/RNB1K2R w KQkq' => {
			eco => 'B53o',
			# TRANSLATORS: B53o: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Qxd4 Nc6 5. Bb5 Bd7 6. Bxc6 Bxc6
			variation => N__('Sicilian, Chekhover, 4... Nc6 5. Bb5 Bd7 6.Bxc6 Bxc6'),
			moves => {
				'b1c3' => 1,
				'c2c4' => 1,
			},
		},
		'r2qkbnr/pp2pppp/2bp4/8/2PQP3/5N2/PP3PPP/RNB1K2R b KQkq' => {
			eco => 'B53p',
			# TRANSLATORS: B53p: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Qxd4 Nc6 5. Bb5 Bd7 6. Bxc6 Bxc6 7. c4
			variation => N__('Sicilian, Chekhover, 7. c4'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r2qkb1r/pp2pppp/2bp1n2/8/2PQP3/5N2/PP3PPP/RNB1K2R w KQkq' => {
			eco => 'B53p',
			# TRANSLATORS: B53p: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Qxd4 Nc6 5. Bb5 Bd7 6. Bxc6 Bxc6 7. c4 Nf6
			variation => N__('Sicilian, Chekhover, 7. c4'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r2qkb1r/pp2pppp/2bp1n2/8/2PQP3/2N2N2/PP3PPP/R1B1K2R b KQkq' => {
			eco => 'B53p',
			# TRANSLATORS: B53p: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Qxd4 Nc6 5. Bb5 Bd7 6. Bxc6 Bxc6 7. c4 Nf6 8. Nc3
			variation => N__('Sicilian, Chekhover, 7. c4'),
			moves => {
				'g7g6' => 1,
			},
		},
		'r2qkb1r/pp2pp1p/2bp1np1/8/2PQP3/2N2N2/PP3PPP/R1B1K2R w KQkq' => {
			eco => 'B53q',
			# TRANSLATORS: B53q: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Qxd4 Nc6 5. Bb5 Bd7 6. Bxc6 Bxc6 7. c4 Nf6 8. Nc3 g6
			variation => N__('Sicilian, Chekhover, 7. c4 Nf6 8. Nc3 g6'),
			moves => {
			},
		},
		'r2qkbnr/pp2pppp/2bp4/8/3QP3/2N2N2/PPP2PPP/R1B1K2R b KQkq' => {
			eco => 'B53r',
			# TRANSLATORS: B53r: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Qxd4 Nc6 5. Bb5 Bd7 6. Bxc6 Bxc6 7. Nc3
			variation => N__('Sicilian, Chekhover, 7. Nc3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r2qkb1r/pp2pppp/2bp1n2/8/3QP3/2N2N2/PPP2PPP/R1B1K2R w KQkq' => {
			eco => 'B53r',
			# TRANSLATORS: B53r: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Qxd4 Nc6 5. Bb5 Bd7 6. Bxc6 Bxc6 7. Nc3 Nf6
			variation => N__('Sicilian, Chekhover, 7. Nc3'),
			moves => {
				'c1g5' => 1,
			},
		},
		'r2qkb1r/pp2pppp/2bp1n2/6B1/3QP3/2N2N2/PPP2PPP/R3K2R b KQkq' => {
			eco => 'B53s',
			# TRANSLATORS: B53s: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Qxd4 Nc6 5. Bb5 Bd7 6. Bxc6 Bxc6 7. Nc3 Nf6 8. Bg5
			variation => N__('Sicilian, Chekhover, 7. Nc3 Nf6 8. Bg5'),
			moves => {
				'e7e6' => 1,
			},
		},
		'r2qkb1r/pp3ppp/2bppn2/6B1/3QP3/2N2N2/PPP2PPP/R3K2R w KQkq' => {
			eco => 'B53t',
			# TRANSLATORS: B53t: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Qxd4 Nc6 5. Bb5 Bd7 6. Bxc6 Bxc6 7. Nc3 Nf6 8. Bg5 e6
			variation => N__('Sicilian, Chekhover, 7. Nc3 Nf6 8. Bg5 e6'),
			moves => {
				'e1c1' => 1,
			},
		},
		'r2qkb1r/pp3ppp/2bppn2/6B1/3QP3/2N2N2/PPP2PPP/2KR3R b kq' => {
			eco => 'B53t',
			# TRANSLATORS: B53t: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Qxd4 Nc6 5. Bb5 Bd7 6. Bxc6 Bxc6 7. Nc3 Nf6 8. Bg5 e6 9. O-O-O
			variation => N__('Sicilian, Chekhover, 7. Nc3 Nf6 8. Bg5 e6'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r2qk2r/pp2bppp/2bppn2/6B1/3QP3/2N2N2/PPP2PPP/2KR3R w kq' => {
			eco => 'B53t',
			# TRANSLATORS: B53t: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Qxd4 Nc6 5. Bb5 Bd7 6. Bxc6 Bxc6 7. Nc3 Nf6 8. Bg5 e6 9. O-O-O Be7
			variation => N__('Sicilian, Chekhover, 7. Nc3 Nf6 8. Bg5 e6'),
			moves => {
				'd4d3' => 1,
				'h1e1' => 1,
			},
		},
		'r2qk2r/pp2bppp/2bppn2/6B1/4P3/2NQ1N2/PPP2PPP/2KR3R b kq' => {
			eco => 'B53u',
			# TRANSLATORS: B53u: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Qxd4 Nc6 5. Bb5 Bd7 6. Bxc6 Bxc6 7. Nc3 Nf6 8. Bg5 e6 9. O-O-O Be7 10. Qd3
			variation => N__('Sicilian, Chekhover, Main Line, 10. Qd3'),
			moves => {
			},
		},
		'r2qk2r/pp2bppp/2bppn2/6B1/3QP3/2N2N2/PPP2PPP/2KRR3 b kq' => {
			eco => 'B53v',
			# TRANSLATORS: B53v: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Qxd4 Nc6 5. Bb5 Bd7 6. Bxc6 Bxc6 7. Nc3 Nf6 8. Bg5 e6 9. O-O-O Be7 10. Rhe1
			variation => N__('Sicilian, Chekhover, Main Line, 10.Rhe1'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r2q1rk1/pp2bppp/2bppn2/6B1/3QP3/2N2N2/PPP2PPP/2KRR3 w -' => {
			eco => 'B53w',
			# TRANSLATORS: B53w: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Qxd4 Nc6 5. Bb5 Bd7 6. Bxc6 Bxc6 7. Nc3 Nf6 8. Bg5 e6 9. O-O-O Be7 10. Rhe1 O-O
			variation => N__('Sicilian, Chekhover, Main Line, 10.Rhe1 O-O'),
			moves => {
				'd4d2' => 1,
			},
		},
		'r2q1rk1/pp2bppp/2bppn2/6B1/4P3/2N2N2/PPPQ1PPP/2KRR3 b -' => {
			eco => 'B53x',
			# TRANSLATORS: B53x: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Qxd4 Nc6 5. Bb5 Bd7 6. Bxc6 Bxc6 7. Nc3 Nf6 8. Bg5 e6 9. O-O-O Be7 10. Rhe1 O-O 11. Qd2
			variation => N__('Sicilian, Chekhover, Main Line, 11. Qd2'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/3p4/8/3NP3/8/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'B54a',
			# TRANSLATORS: B54a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4
			variation => N__('Sicilian: Open, 2... d6'),
			moves => {
				'a7a6' => 1,
				'e7e5' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/3p4/4p3/3NP3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B54b',
			# TRANSLATORS: B54b: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 e5
			variation => N__('Sicilian: Open, 2... d6, 4... e5'),
			moves => {
			},
		},
		'rnbqkbnr/1p2pppp/p2p4/8/3NP3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B54c',
			# TRANSLATORS: B54c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 a6
			variation => N__('Sicilian: Open, 2... d6, 4... a6'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/3p1n2/8/3NP3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'B54d',
			# TRANSLATORS: B54d: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6
			variation => N__('Sicilian: Open, 2... d6, 4... Nf6'),
			moves => {
				'b1c3' => 1,
				'f1d3' => 1,
				'f2f3' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/3p1n2/8/3NP3/3B4/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'B54e',
			# TRANSLATORS: B54e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Bd3
			variation => N__('Sicilian: Open, 2... d6, 4... Nf6 5. Bd3'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/3p1n2/8/3NP3/5P2/PPP3PP/RNBQKB1R b KQkq' => {
			eco => 'B54f',
			# TRANSLATORS: B54f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. f3
			variation => N__('Sicilian: Prins (Moscow) Variation'),
			moves => {
				'a7a6' => 1,
				'b8c6' => 1,
				'e7e5' => 1,
				'e7e6' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/3ppn2/8/3NP3/5P2/PPP3PP/RNBQKB1R w KQkq' => {
			eco => 'B54g',
			# TRANSLATORS: B54g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. f3 e6
			variation => N__('Sicilian: Prins (Moscow), 5... e6'),
			moves => {
			},
		},
		'rnbqkb1r/1p2pppp/p2p1n2/8/3NP3/5P2/PPP3PP/RNBQKB1R w KQkq' => {
			eco => 'B54h',
			# TRANSLATORS: B54h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. f3 a6
			variation => N__('Sicilian: Prins (Moscow), 5... a6'),
			moves => {
			},
		},
		'r1bqkb1r/pp2pppp/2np1n2/8/3NP3/5P2/PPP3PP/RNBQKB1R w KQkq' => {
			eco => 'B54i',
			# TRANSLATORS: B54i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. f3 Nc6
			variation => N__('Sicilian: Prins (Moscow), 5... Nc6'),
			moves => {
				'c2c4' => 1,
			},
		},
		'r1bqkb1r/pp2pppp/2np1n2/8/2PNP3/5P2/PP4PP/RNBQKB1R b KQkq' => {
			eco => 'B54i',
			# TRANSLATORS: B54i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. f3 Nc6 6. c4
			variation => N__('Sicilian: Prins (Moscow), 5... Nc6'),
			moves => {
				'c6d4' => 1,
				'd8b6' => 1,
			},
		},
		'r1bqkb1r/pp2pppp/3p1n2/8/2PnP3/5P2/PP4PP/RNBQKB1R w KQkq' => {
			eco => 'B54j',
			# TRANSLATORS: B54j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. f3 Nc6 6. c4 Nxd4
			variation => N__('Sicilian: Prins (Moscow), 5... Nc6 6. c4 Nxd4'),
			moves => {
			},
		},
		'r1b1kb1r/pp2pppp/1qnp1n2/8/2PNP3/5P2/PP4PP/RNBQKB1R w KQkq' => {
			eco => 'B54k',
			# TRANSLATORS: B54k: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. f3 Nc6 6. c4 Qb6
			variation => N__('Sicilian: Prins (Moscow), 5... Nc6 6. c4 Qb6'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/3p1n2/4p3/3NP3/5P2/PPP3PP/RNBQKB1R w KQkq' => {
			eco => 'B54l',
			# TRANSLATORS: B54l: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. f3 e5
			variation => N__('Sicilian: Prins (Moscow), 5... e5'),
			moves => {
				'd4b3' => 1,
				'f1b5' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/3p1n2/4p3/4P3/1N3P2/PPP3PP/RNBQKB1R b KQkq' => {
			eco => 'B54m',
			# TRANSLATORS: B54m: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. f3 e5 6. Nb3
			variation => N__('Sicilian: Prins (Moscow), 5... e5 6. Nb3'),
			moves => {
				'c8e6' => 1,
				'd6d5' => 1,
			},
		},
		'rn1qkb1r/pp3ppp/3pbn2/4p3/4P3/1N3P2/PPP3PP/RNBQKB1R w KQkq' => {
			eco => 'B54n',
			# TRANSLATORS: B54n: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. f3 e5 6. Nb3 Be6
			variation => N__('Sicilian: Prins (Moscow), 5... e5 6. Nb3 Be6'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/5n2/3pp3/4P3/1N3P2/PPP3PP/RNBQKB1R w KQkq' => {
			eco => 'B54o',
			# TRANSLATORS: B54o: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. f3 e5 6. Nb3 d5
			variation => N__('Sicilian: Prins (Moscow), 5... e5 6. Nb3 d5'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/3p1n2/1B2p3/3NP3/5P2/PPP3PP/RNBQK2R b KQkq' => {
			eco => 'B55',
			# TRANSLATORS: B55: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. f3 e5 6. Bb5+
			variation => N__('Sicilian: Prins, Venice Attack'),
			moves => {
				'b8d7' => 1,
				'c8d7' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/3p1n2/1B2p3/3NP3/5P2/PPP3PP/RNBQK2R w KQkq' => {
			eco => 'B55',
			# TRANSLATORS: B55: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. f3 e5 6. Bb5+ Nbd7
			variation => N__('Sicilian: Prins, Venice Attack, 6...Nbd7'),
			moves => {
				'd4f5' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/3p1n2/1B2pN2/4P3/5P2/PPP3PP/RNBQK2R b KQkq' => {
			eco => 'B55',
			# TRANSLATORS: B55: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. f3 e5 6. Bb5+ Nbd7 7. Nf5
			variation => N__('Sicilian: Prins, Venice Attack, 6...Nbd7 7. Nf5'),
			moves => {
				'd6d5' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/5n2/1B1ppN2/4P3/5P2/PPP3PP/RNBQK2R w KQkq' => {
			eco => 'B55',
			# TRANSLATORS: B55: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. f3 e5 6. Bb5+ Nbd7 7. Nf5 d5
			variation => N__('Sicilian: Prins, Venice Attack, 6...Nbd7 7. Nf5 d5'),
			moves => {
			},
		},
		'rn1qkb1r/pp1b1ppp/3p1n2/1B2p3/3NP3/5P2/PPP3PP/RNBQK2R w KQkq' => {
			eco => 'B55',
			# TRANSLATORS: B55: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. f3 e5 6. Bb5+ Bd7
			variation => N__('Sicilian: Prins, Venice Attack, 6... Bd7'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/3p1n2/8/3NP3/2N5/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B56a',
			# TRANSLATORS: B56a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3
			variation => N__('Sicilian: Open, 2... d6, 5. Nc3'),
			moves => {
				'a7a6' => 1,
				'b8c6' => 1,
				'b8d7' => 1,
				'c8d7' => 1,
				'e7e5' => 1,
				'e7e6' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/3p1n2/4p3/3NP3/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B56b',
			# TRANSLATORS: B56b: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5
			variation => N__('Sicilian: Open, 2... d6, 5. Nc3 e5'),
			moves => {
				'f1b5' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/3p1n2/1B2p3/3NP3/2N5/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'B56c',
			# TRANSLATORS: B56c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e5 6. Bb5+
			variation => N__('Sicilian: Venice Attack'),
			moves => {
			},
		},
		'r1bqkb1r/pp1npppp/3p1n2/8/3NP3/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B56d',
			# TRANSLATORS: B56d: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nbd7
			variation => N__('Sicilian: Open, 2... d6, 5. Nc3 Nbd7'),
			moves => {
				'f1c4' => 1,
			},
		},
		'r1bqkb1r/pp1npppp/3p1n2/8/2BNP3/2N5/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'B56e',
			# TRANSLATORS: B56e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nbd7 6. Bc4
			variation => N__('Sicilian: Open, 2... d6, 5. Nc3 Nbd7 6. Bc4'),
			moves => {
			},
		},
		'rn1qkb1r/pp1bpppp/3p1n2/8/3NP3/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B56f',
			# TRANSLATORS: B56f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Bd7
			variation => N__('Sicilian: Open, 2... d6, 5. Nc3 Bd7'),
			moves => {
				'c1g5' => 1,
			},
		},
		'rn1qkb1r/pp1bpppp/3p1n2/6B1/3NP3/2N5/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'B56g',
			# TRANSLATORS: B56g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Bd7 6. Bg5
			variation => N__('Sicilian: Open, 2... d6, 5. Nc3 Bd7 6. Bg5'),
			moves => {
			},
		},
		'r1bqkb1r/pp2pppp/2np1n2/8/3NP3/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B56h',
			# TRANSLATORS: B56h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6
			variation => N__('Sicilian: Open, 2... d6 5. Nc3 Nc6'),
			moves => {
				'c1e3' => 1,
				'c1g5' => 1,
				'f1c4' => 1,
				'f1e2' => 1,
				'f2f3' => 1,
				'f2f4' => 1,
				'g2g3' => 1,
				'h2h3' => 1,
			},
		},
		'r1bqkb1r/pp2pppp/2np1n2/8/3NP3/2N4P/PPP2PP1/R1BQKB1R b KQkq' => {
			eco => 'B56i',
			# TRANSLATORS: B56i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. h3
			variation => N__('Sicilian: Open, 2... d6, 5. Nc3 Nc6 6. h3'),
			moves => {
			},
		},
		'r1bqkb1r/pp2pppp/2np1n2/8/3NP3/2N3P1/PPP2P1P/R1BQKB1R b KQkq' => {
			eco => 'B56j',
			# TRANSLATORS: B56j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. g3
			variation => N__('Sicilian: Open, 2... d6, 5. Nc3 Nc6 6. g3'),
			moves => {
			},
		},
		'r1bqkb1r/pp2pppp/2np1n2/8/3NPP2/2N5/PPP3PP/R1BQKB1R b KQkq' => {
			eco => 'B56k',
			# TRANSLATORS: B56k: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. f4
			variation => N__('Sicilian: Open, 2... d6, 5. Nc3 Nc6 6. f4'),
			moves => {
			},
		},
		'r1bqkb1r/pp2pppp/2np1n2/8/3NP3/2N2P2/PPP3PP/R1BQKB1R b KQkq' => {
			eco => 'B56l',
			# TRANSLATORS: B56l: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. f3
			variation => N__('Sicilian: Open, 2... d6, 5. Nc3 Nc6 6. f3'),
			moves => {
				'e7e5' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2np1n2/4p3/3NP3/2N2P2/PPP3PP/R1BQKB1R w KQkq' => {
			eco => 'B56m',
			# TRANSLATORS: B56m: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. f3 e5
			variation => N__('Sicilian: Open, 2... d6, 5. Nc3 Nc6 6. f3 e5'),
			moves => {
				'd4b3' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2np1n2/4p3/4P3/1NN2P2/PPP3PP/R1BQKB1R b KQkq' => {
			eco => 'B56m',
			# TRANSLATORS: B56m: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. f3 e5 7. Nb3
			variation => N__('Sicilian: Open, 2... d6, 5. Nc3 Nc6 6. f3 e5 7. Nb3'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2np1n2/4p3/4P3/1NN2P2/PPP3PP/R1BQKB1R w KQkq' => {
			eco => 'B56n',
			# TRANSLATORS: B56n: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. f3 e5 7. Nb3 Be7
			variation => N__('Sicilian: Open, 2... d6, 5. Nc3 Nc6 6. f3 e5 7. Nb3 Be7'),
			moves => {
			},
		},
		'r1bqkb1r/pp2pppp/2np1n2/8/3NP3/2N1B3/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'B56o',
			# TRANSLATORS: B56o: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be3
			variation => N__('Sicilian: Open, 2... d6, 5. Nc3 Nc6 6. Be3'),
			moves => {
				'e7e5' => 1,
				'f6g4' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2np1n2/4p3/3NP3/2N1B3/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B56p',
			# TRANSLATORS: B56p: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be3 e5
			variation => N__('Sicilian: Open, 2... d6, 5. Nc3 Nc6 6. Be3 e5'),
			moves => {
			},
		},
		'r1bqkb1r/pp2pppp/2np4/8/3NP1n1/2N1B3/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B56q',
			# TRANSLATORS: B56q: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be3 Ng4
			variation => N__('Sicilian: Open, 2... d6, 5. Nc3 Nc6 6. Be3 Ng4'),
			moves => {
				'f1b5' => 1,
			},
		},
		'r1bqkb1r/pp2pppp/2np4/1B6/3NP1n1/2N1B3/PPP2PPP/R2QK2R b KQkq' => {
			eco => 'B56r',
			# TRANSLATORS: B56r: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be3 Ng4 7. Bb5
			variation => N__('Sicilian: Open, 2... d6, 5. Nc3 Nc6 6. Be3 Ng4 7. Bb5'),
			moves => {
			},
		},
		'r1bqkb1r/pp2pppp/2np1n2/8/2BNP3/2N5/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'B57a',
			# TRANSLATORS: B57a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bc4
			variation => N__('Sicilian: Sozin'),
			moves => {
				'c8d7' => 1,
				'd8b6' => 1,
				'g7g6' => 1,
			},
		},
		'r1bqkb1r/pp2pp1p/2np1np1/8/2BNP3/2N5/PPP2PPP/R1BQK2R w KQkq' => {
			eco => 'B57a',
			# TRANSLATORS: B57a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bc4 g6
			variation => N__('Sicilian: Sozin'),
			moves => {
				'd4c6' => 1,
			},
		},
		'r1bqkb1r/pp2pp1p/2Np1np1/8/2B1P3/2N5/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'B57a',
			# TRANSLATORS: B57a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bc4 g6 7. Nxc6
			variation => N__('Sicilian: Sozin'),
			moves => {
				'b7c6' => 1,
			},
		},
		'r1bqkb1r/p3pp1p/2pp1np1/8/2B1P3/2N5/PPP2PPP/R1BQK2R w KQkq' => {
			eco => 'B57a',
			# TRANSLATORS: B57a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bc4 g6 7. Nxc6 bxc6
			variation => N__('Sicilian: Sozin'),
			moves => {
				'e4e5' => 1,
			},
		},
		'r1bqkb1r/p3pp1p/2pp1np1/4P3/2B5/2N5/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'B57a',
			# TRANSLATORS: B57a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bc4 g6 7. Nxc6 bxc6 8. e5
			variation => N__('Sicilian: Sozin, Magnus Smith Trap'),
			moves => {
			},
		},
		'r2qkb1r/pp1bpppp/2np1n2/8/2BNP3/2N5/PPP2PPP/R1BQK2R w KQkq' => {
			eco => 'B57b',
			# TRANSLATORS: B57b: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bc4 Bd7
			variation => N__('Sicilian: Sozin, 6... Bd7'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r2qkb1r/pp1bpppp/2np1n2/8/2BNP3/2N5/PPP2PPP/R1BQ1RK1 b kq' => {
			eco => 'B57c',
			# TRANSLATORS: B57c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bc4 Bd7 7. O-O
			variation => N__('Sicilian: Sozin, 6... Bd7 7.O-O'),
			moves => {
			},
		},
		'r1b1kb1r/pp2pppp/1qnp1n2/8/2BNP3/2N5/PPP2PPP/R1BQK2R w KQkq' => {
			eco => 'B57d',
			# TRANSLATORS: B57d: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bc4 Qb6
			variation => N__('Sicilian: Sozin, Benko Variation'),
			moves => {
				'd4b3' => 1,
				'd4b5' => 1,
				'd4c6' => 1,
				'd4e2' => 1,
			},
		},
		'r1b1kb1r/pp2pppp/1qnp1n2/8/2B1P3/2N5/PPP1NPPP/R1BQK2R b KQkq' => {
			eco => 'B57e',
			# TRANSLATORS: B57e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bc4 Qb6 7. Nde2
			variation => N__('Sicilian: Sozin, Benko, 7.Nde2'),
			moves => {
			},
		},
		'r1b1kb1r/pp2pppp/1qnp1n2/1N6/2B1P3/2N5/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'B57f',
			# TRANSLATORS: B57f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bc4 Qb6 7. Ndb5
			variation => N__('Sicilian: Sozin, Benko, 7.Ndb5'),
			moves => {
			},
		},
		'r1b1kb1r/pp2pppp/1qNp1n2/8/2B1P3/2N5/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'B57g',
			# TRANSLATORS: B57g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bc4 Qb6 7. Nxc6
			variation => N__('Sicilian: Sozin, Benko, 7.Nxc6'),
			moves => {
				'b7c6' => 1,
			},
		},
		'r1b1kb1r/p3pppp/1qpp1n2/8/2B1P3/2N5/PPP2PPP/R1BQK2R w KQkq' => {
			eco => 'B57g',
			# TRANSLATORS: B57g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bc4 Qb6 7. Nxc6 bxc6
			variation => N__('Sicilian: Sozin, Benko, 7.Nxc6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1b1kb1r/p3pppp/1qpp1n2/8/2B1P3/2N5/PPP2PPP/R1BQ1RK1 b kq' => {
			eco => 'B57g',
			# TRANSLATORS: B57g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bc4 Qb6 7. Nxc6 bxc6 8. O-O
			variation => N__('Sicilian: Sozin, Benko, 7.Nxc6'),
			moves => {
				'g7g6' => 1,
			},
		},
		'r1b1kb1r/p3pp1p/1qpp1np1/8/2B1P3/2N5/PPP2PPP/R1BQ1RK1 w kq' => {
			eco => 'B57h',
			# TRANSLATORS: B57h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bc4 Qb6 7. Nxc6 bxc6 8. O-O g6
			variation => N__('Sicilian: Sozin, Benko, 7.Nxc6 bxc6 8.O-O g6'),
			moves => {
			},
		},
		'r1b1kb1r/pp2pppp/1qnp1n2/8/2B1P3/1NN5/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'B57i',
			# TRANSLATORS: B57i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bc4 Qb6 7. Nb3
			variation => N__('Sicilian: Sozin, Benko, 7. Nb3'),
			moves => {
				'e7e6' => 1,
			},
		},
		'r1b1kb1r/pp3ppp/1qnppn2/8/2B1P3/1NN5/PPP2PPP/R1BQK2R w KQkq' => {
			eco => 'B57j',
			# TRANSLATORS: B57j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bc4 Qb6 7. Nb3 e6
			variation => N__('Sicilian: Sozin, Benko, 7. Nb3 e6'),
			moves => {
				'c1e3' => 1,
				'c1f4' => 1,
				'e1g1' => 1,
			},
		},
		'r1b1kb1r/pp3ppp/1qnppn2/8/2B1P3/1NN1B3/PPP2PPP/R2QK2R b KQkq' => {
			eco => 'B57k',
			# TRANSLATORS: B57k: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bc4 Qb6 7. Nb3 e6 8. Be3
			variation => N__('Sicilian: Sozin, Benko, 7. Nb3 e6 8. Be3'),
			moves => {
			},
		},
		'r1b1kb1r/pp3ppp/1qnppn2/8/2B1PB2/1NN5/PPP2PPP/R2QK2R b KQkq' => {
			eco => 'B57l',
			# TRANSLATORS: B57l: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bc4 Qb6 7. Nb3 e6 8. Bf4
			variation => N__('Sicilian: Sozin, Benko, 7. Nb3 e6 8. Bf4'),
			moves => {
			},
		},
		'r1b1kb1r/pp3ppp/1qnppn2/8/2B1P3/1NN5/PPP2PPP/R1BQ1RK1 b kq' => {
			eco => 'B57m',
			# TRANSLATORS: B57m: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bc4 Qb6 7. Nb3 e6 8. O-O
			variation => N__('Sicilian: Sozin, Benko, 7. Nb3 e6 8.O-O'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r1b1k2r/pp2bppp/1qnppn2/8/2B1P3/1NN5/PPP2PPP/R1BQ1RK1 w kq' => {
			eco => 'B57n',
			# TRANSLATORS: B57n: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bc4 Qb6 7. Nb3 e6 8. O-O Be7
			variation => N__('Sicilian: Sozin, Benko, 7. Nb3 e6 8.O-O Be7'),
			moves => {
				'c1e3' => 1,
			},
		},
		'r1b1k2r/pp2bppp/1qnppn2/8/2B1P3/1NN1B3/PPP2PPP/R2Q1RK1 b kq' => {
			eco => 'B57o',
			# TRANSLATORS: B57o: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bc4 Qb6 7. Nb3 e6 8. O-O Be7 9. Be3
			variation => N__('Sicilian: Sozin, Benko, 7. Nb3 e6 8.O-O Be7 9. Be3'),
			moves => {
			},
		},
		'r1bqkb1r/pp2pppp/2np1n2/8/3NP3/2N5/PPP1BPPP/R1BQK2R b KQkq' => {
			eco => 'B58a',
			# TRANSLATORS: B58a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2
			variation => N__('Sicilian: Boleslavsky Variation'),
			moves => {
				'a7a6' => 1,
				'c6d4' => 1,
				'c8d7' => 1,
				'e7e5' => 1,
			},
		},
		'r2qkb1r/pp1bpppp/2np1n2/8/3NP3/2N5/PPP1BPPP/R1BQK2R w KQkq' => {
			eco => 'B58b',
			# TRANSLATORS: B58b: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 Bd7
			variation => N__('Sicilian: Boleslavsky, 6... Bd7'),
			moves => {
			},
		},
		'r1bqkb1r/1p2pppp/p1np1n2/8/3NP3/2N5/PPP1BPPP/R1BQK2R w KQkq' => {
			eco => 'B58c',
			# TRANSLATORS: B58c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 a6
			variation => N__('Sicilian: Boleslavsky, 6... a6'),
			moves => {
			},
		},
		'r1bqkb1r/pp2pppp/3p1n2/8/3nP3/2N5/PPP1BPPP/R1BQK2R w KQkq' => {
			eco => 'B58d',
			# TRANSLATORS: B58d: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 Nxd4
			variation => N__('Sicilian: Boleslavsky, 6...Nxd4'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2np1n2/4p3/3NP3/2N5/PPP1BPPP/R1BQK2R w KQkq' => {
			eco => 'B58e',
			# TRANSLATORS: B58e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 e5
			variation => N__('Sicilian: Boleslavsky, 6... e5'),
			moves => {
				'd4b3' => 1,
				'd4b5' => 1,
				'd4c6' => 1,
				'd4f3' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2np1n2/1N2p3/4P3/2N5/PPP1BPPP/R1BQK2R b KQkq' => {
			eco => 'B58f',
			# TRANSLATORS: B58f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 e5 7. Ndb5
			variation => N__('Sicilian: Boleslavsky, 7.Ndb5'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2Np1n2/4p3/4P3/2N5/PPP1BPPP/R1BQK2R b KQkq' => {
			eco => 'B58g',
			# TRANSLATORS: B58g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 e5 7. Nxc6
			variation => N__('Sicilian: Boleslavsky, Louma Variation'),
			moves => {
				'b7c6' => 1,
			},
		},
		'r1bqkb1r/p4ppp/2pp1n2/4p3/4P3/2N5/PPP1BPPP/R1BQK2R w KQkq' => {
			eco => 'B58g',
			# TRANSLATORS: B58g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 e5 7. Nxc6 bxc6
			variation => N__('Sicilian: Boleslavsky, Louma Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2np1n2/4p3/4P3/2N2N2/PPP1BPPP/R1BQK2R b KQkq' => {
			eco => 'B58h',
			# TRANSLATORS: B58h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 e5 7. Nf3
			variation => N__('Sicilian: Boleslavsky, 7. Nf3'),
			moves => {
				'h7h6' => 1,
			},
		},
		'r1bqkb1r/pp3pp1/2np1n1p/4p3/4P3/2N2N2/PPP1BPPP/R1BQK2R w KQkq' => {
			eco => 'B58i',
			# TRANSLATORS: B58i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 e5 7. Nf3 h6
			variation => N__('Sicilian: Boleslavsky, 7. Nf3 h6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqkb1r/pp3pp1/2np1n1p/4p3/4P3/2N2N2/PPP1BPPP/R1BQ1RK1 b kq' => {
			eco => 'B58j',
			# TRANSLATORS: B58j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 e5 7. Nf3 h6 8. O-O
			variation => N__('Sicilian: Boleslavsky, 7. Nf3 h6 8.O-O'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r1bqk2r/pp2bpp1/2np1n1p/4p3/4P3/2N2N2/PPP1BPPP/R1BQ1RK1 w kq' => {
			eco => 'B58k',
			# TRANSLATORS: B58k: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 e5 7. Nf3 h6 8. O-O Be7
			variation => N__('Sicilian: Boleslavsky, 7. Nf3 h6 8.O-O Be7'),
			moves => {
				'f1e1' => 1,
				'h2h3' => 1,
			},
		},
		'r1bqk2r/pp2bpp1/2np1n1p/4p3/4P3/2N2N1P/PPP1BPP1/R1BQ1RK1 b kq' => {
			eco => 'B58l',
			# TRANSLATORS: B58l: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 e5 7. Nf3 h6 8. O-O Be7 9. h3
			variation => N__('Sicilian: Boleslavsky, 7. Nf3 h6 8.O-O Be7 9. h3'),
			moves => {
			},
		},
		'r1bqk2r/pp2bpp1/2np1n1p/4p3/4P3/2N2N2/PPP1BPPP/R1BQR1K1 b kq' => {
			eco => 'B58m',
			# TRANSLATORS: B58m: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 e5 7. Nf3 h6 8. O-O Be7 9. Re1
			variation => N__('Sicilian: Boleslavsky, 7. Nf3 h6 8.O-O Be7 9. Re1'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp2bpp1/2np1n1p/4p3/4P3/2N2N2/PPP1BPPP/R1BQR1K1 w -' => {
			eco => 'B58m',
			# TRANSLATORS: B58m: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 e5 7. Nf3 h6 8. O-O Be7 9. Re1 O-O
			variation => N__('Sicilian: Boleslavsky, 7. Nf3 h6 8.O-O Be7 9. Re1'),
			moves => {
				'h2h3' => 1,
			},
		},
		'r1bq1rk1/pp2bpp1/2np1n1p/4p3/4P3/2N2N1P/PPP1BPP1/R1BQR1K1 b -' => {
			eco => 'B58n',
			# TRANSLATORS: B58n: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 e5 7. Nf3 h6 8. O-O Be7 9. Re1 O-O 10. h3
			variation => N__('Sicilian: Boleslavsky, 7. Nf3, 9. Re1 O-O 10. h3'),
			moves => {
				'a7a6' => 1,
				'c8e6' => 1,
			},
		},
		'r1bq1rk1/1p2bpp1/p1np1n1p/4p3/4P3/2N2N1P/PPP1BPP1/R1BQR1K1 w -' => {
			eco => 'B58o',
			# TRANSLATORS: B58o: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 e5 7. Nf3 h6 8. O-O Be7 9. Re1 O-O 10. h3 a6
			variation => N__('Sicilian: Boleslavsky, 7. Nf3, 9. Re1 O-O 10. h3 a6'),
			moves => {
			},
		},
		'r2q1rk1/pp2bpp1/2npbn1p/4p3/4P3/2N2N1P/PPP1BPP1/R1BQR1K1 w -' => {
			eco => 'B58p',
			# TRANSLATORS: B58p: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 e5 7. Nf3 h6 8. O-O Be7 9. Re1 O-O 10. h3 Be6
			variation => N__('Sicilian: Boleslavsky, 7. Nf3, 9. Re1 O-O 10. h3 Be6'),
			moves => {
				'e2f1' => 1,
			},
		},
		'r2q1rk1/pp2bpp1/2npbn1p/4p3/4P3/2N2N1P/PPP2PP1/R1BQRBK1 b -' => {
			eco => 'B58p',
			# TRANSLATORS: B58p: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 e5 7. Nf3 h6 8. O-O Be7 9. Re1 O-O 10. h3 Be6 11. Bf1
			variation => N__('Sicilian: Boleslavsky, 7. Nf3, 9. Re1 O-O 10. h3 Be6 11. Bf1'),
			moves => {
				'c6b8' => 1,
				'd8a5' => 1,
			},
		},
		'r4rk1/pp2bpp1/2npbn1p/q3p3/4P3/2N2N1P/PPP2PP1/R1BQRBK1 w -' => {
			eco => 'B58q',
			# TRANSLATORS: B58q: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 e5 7. Nf3 h6 8. O-O Be7 9. Re1 O-O 10. h3 Be6 11. Bf1 Qa5
			variation => N__('Sicilian: Boleslavsky, 7. Nf3, 9. Re1 O-O 10. h3 Be6 11. Bf1 Qa5'),
			moves => {
			},
		},
		'rn1q1rk1/pp2bpp1/3pbn1p/4p3/4P3/2N2N1P/PPP2PP1/R1BQRBK1 w -' => {
			eco => 'B58r',
			# TRANSLATORS: B58r: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 e5 7. Nf3 h6 8. O-O Be7 9. Re1 O-O 10. h3 Be6 11. Bf1 Nb8
			variation => N__('Sicilian: Boleslavsky, 7. Nf3, 9. Re1 O-O 10. h3 Be6 11. Bf1 Nb8'),
			moves => {
				'a2a4' => 1,
				'b2b3' => 1,
			},
		},
		'rn1q1rk1/pp2bpp1/3pbn1p/4p3/P3P3/2N2N1P/1PP2PP1/R1BQRBK1 b -' => {
			eco => 'B58s',
			# TRANSLATORS: B58s: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 e5 7. Nf3 h6 8. O-O Be7 9. Re1 O-O 10. h3 Be6 11. Bf1 Nb8 12. a4
			variation => N__('Sicilian: Boleslavsky, 7. Nf3, 9. Re1 O-O 10. h3 Be6 11. Bf1 Nb8 12. a4'),
			moves => {
			},
		},
		'rn1q1rk1/pp2bpp1/3pbn1p/4p3/4P3/1PN2N1P/P1P2PP1/R1BQRBK1 b -' => {
			eco => 'B58t',
			# TRANSLATORS: B58t: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 e5 7. Nf3 h6 8. O-O Be7 9. Re1 O-O 10. h3 Be6 11. Bf1 Nb8 12. b3
			variation => N__('Sicilian: Boleslavsky, 7. Nf3, 9. Re1 O-O 10. h3 Be6 11. Bf1 Nb8 12. b3'),
			moves => {
				'a7a6' => 1,
			},
		},
		'rn1q1rk1/1p2bpp1/p2pbn1p/4p3/4P3/1PN2N1P/P1P2PP1/R1BQRBK1 w -' => {
			eco => 'B58u',
			# TRANSLATORS: B58u: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 e5 7. Nf3 h6 8. O-O Be7 9. Re1 O-O 10. h3 Be6 11. Bf1 Nb8 12. b3 a6
			variation => N__('Sicilian: Boleslavsky, 7. Nf3, 9. Re1 O-O 10. h3 Be6 11. Bf1 Nb8 12. b3 a6'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2np1n2/4p3/4P3/1NN5/PPP1BPPP/R1BQK2R b KQkq' => {
			eco => 'B59a',
			# TRANSLATORS: B59a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 e5 7. Nb3
			variation => N__('Sicilian: Boleslavsky, 7. Nb3'),
			moves => {
				'c8e6' => 1,
				'f8e7' => 1,
			},
		},
		'r2qkb1r/pp3ppp/2npbn2/4p3/4P3/1NN5/PPP1BPPP/R1BQK2R w KQkq' => {
			eco => 'B59b',
			# TRANSLATORS: B59b: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 e5 7. Nb3 Be6
			variation => N__('Sicilian: Boleslavsky, 7. Nb3 Be6'),
			moves => {
			},
		},
		'r1bqk2r/pp2bppp/2np1n2/4p3/4P3/1NN5/PPP1BPPP/R1BQK2R w KQkq' => {
			eco => 'B59c',
			# TRANSLATORS: B59c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 e5 7. Nb3 Be7
			variation => N__('Sicilian: Boleslavsky, 7. Nb3 Be7'),
			moves => {
				'c1e3' => 1,
				'c1g5' => 1,
				'e1g1' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2np1n2/4p1B1/4P3/1NN5/PPP1BPPP/R2QK2R b KQkq' => {
			eco => 'B59d',
			# TRANSLATORS: B59d: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 e5 7. Nb3 Be7 8. Bg5
			variation => N__('Sicilian: Boleslavsky, 7. Nb3 Be7 8. Bg5'),
			moves => {
			},
		},
		'r1bqk2r/pp2bppp/2np1n2/4p3/4P3/1NN1B3/PPP1BPPP/R2QK2R b KQkq' => {
			eco => 'B59e',
			# TRANSLATORS: B59e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 e5 7. Nb3 Be7 8. Be3
			variation => N__('Sicilian: Boleslavsky, 7. Nb3 Be7 8. Be3'),
			moves => {
			},
		},
		'r1bqk2r/pp2bppp/2np1n2/4p3/4P3/1NN5/PPP1BPPP/R1BQ1RK1 b kq' => {
			eco => 'B59f',
			# TRANSLATORS: B59f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 e5 7. Nb3 Be7 8. O-O
			variation => N__('Sicilian: Boleslavsky, 7. Nb3 Be7 8.O-O'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2np1n2/4p3/4P3/1NN5/PPP1BPPP/R1BQ1RK1 w -' => {
			eco => 'B59g',
			# TRANSLATORS: B59g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 e5 7. Nb3 Be7 8. O-O O-O
			variation => N__('Sicilian: Boleslavsky, 7. Nb3 Be7 8.O-O O-O'),
			moves => {
				'c1e3' => 1,
				'c1g5' => 1,
				'f2f4' => 1,
				'g1h1' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2np1n2/4p1B1/4P3/1NN5/PPP1BPPP/R2Q1RK1 b -' => {
			eco => 'B59h',
			# TRANSLATORS: B59h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 e5 7. Nb3 Be7 8. O-O O-O 9. Bg5
			variation => N__('Sicilian: Boleslavsky, 7. Nb3 Be7 8.O-O O-O 9. Bg5'),
			moves => {
			},
		},
		'r1bq1rk1/pp2bppp/2np1n2/4p3/4P3/1NN5/PPP1BPPP/R1BQ1R1K b -' => {
			eco => 'B59i',
			# TRANSLATORS: B59i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 e5 7. Nb3 Be7 8. O-O O-O 9. Kh1
			variation => N__('Sicilian: Boleslavsky, 7. Nb3 Be7 8.O-O O-O 9. Kh1'),
			moves => {
			},
		},
		'r1bq1rk1/pp2bppp/2np1n2/4p3/4PP2/1NN5/PPP1B1PP/R1BQ1RK1 b -' => {
			eco => 'B59j',
			# TRANSLATORS: B59j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 e5 7. Nb3 Be7 8. O-O O-O 9. f4
			variation => N__('Sicilian: Boleslavsky, 7. Nb3 Be7 8.O-O O-O 9. f4'),
			moves => {
			},
		},
		'r1bq1rk1/pp2bppp/2np1n2/4p3/4P3/1NN1B3/PPP1BPPP/R2Q1RK1 b -' => {
			eco => 'B59k',
			# TRANSLATORS: B59k: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 e5 7. Nb3 Be7 8. O-O O-O 9. Be3
			variation => N__('Sicilian: Boleslavsky, 7. Nb3 Be7 8.O-O O-O 9. Be3'),
			moves => {
				'a7a5' => 1,
				'c8e6' => 1,
			},
		},
		'r2q1rk1/pp2bppp/2npbn2/4p3/4P3/1NN1B3/PPP1BPPP/R2Q1RK1 w -' => {
			eco => 'B59l',
			# TRANSLATORS: B59l: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 e5 7. Nb3 Be7 8. O-O O-O 9. Be3 Be6
			variation => N__('Sicilian: Boleslavsky, 7. Nb3 Be7 8.O-O O-O 9. Be3 Be6'),
			moves => {
				'e2f3' => 1,
			},
		},
		'r2q1rk1/pp2bppp/2npbn2/4p3/4P3/1NN1BB2/PPP2PPP/R2Q1RK1 b -' => {
			eco => 'B59m',
			# TRANSLATORS: B59m: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 e5 7. Nb3 Be7 8. O-O O-O 9. Be3 Be6 10. Bf3
			variation => N__('Sicilian: Boleslavsky, 7. Nb3 Be7 8.O-O O-O 9. Be3 Be6 10. Bf3'),
			moves => {
			},
		},
		'r1bq1rk1/1p2bppp/2np1n2/p3p3/4P3/1NN1B3/PPP1BPPP/R2Q1RK1 w -' => {
			eco => 'B59n',
			# TRANSLATORS: B59n: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 e5 7. Nb3 Be7 8. O-O O-O 9. Be3 a5
			variation => N__('Sicilian: Boleslavsky, 7. Nb3 Be7 8.O-O O-O 9. Be3 a5'),
			moves => {
				'a2a4' => 1,
			},
		},
		'r1bq1rk1/1p2bppp/2np1n2/p3p3/P3P3/1NN1B3/1PP1BPPP/R2Q1RK1 b -' => {
			eco => 'B59o',
			# TRANSLATORS: B59o: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Be2 e5 7. Nb3 Be7 8. O-O O-O 9. Be3 a5 10. a4
			variation => N__('Sicilian: Boleslavsky, 7. Nb3 Be7 8.O-O O-O 9. Be3 a5 10. a4'),
			moves => {
			},
		},
		'r1bqkb1r/pp2pppp/2np1n2/6B1/3NP3/2N5/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'B60a',
			# TRANSLATORS: B60a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5
			variation => N__('Sicilian: Richter-Rauzer'),
			moves => {
				'a7a6' => 1,
				'c8d7' => 1,
				'd8a5' => 1,
				'd8b6' => 1,
				'e7e6' => 1,
				'g7g6' => 1,
			},
		},
		'r1bqkb1r/pp2pp1p/2np1np1/6B1/3NP3/2N5/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B60b',
			# TRANSLATORS: B60b: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 g6
			variation => N__('Sicilian: Richter-Rauzer, Bondarevsky Variation'),
			moves => {
			},
		},
		'r1b1kb1r/pp2pppp/2np1n2/q5B1/3NP3/2N5/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B60c',
			# TRANSLATORS: B60c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 Qa5
			variation => N__('Sicilian: Richter-Rauzer, 6... Qa5'),
			moves => {
			},
		},
		'r1b1kb1r/pp2pppp/1qnp1n2/6B1/3NP3/2N5/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B60d',
			# TRANSLATORS: B60d: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 Qb6
			variation => N__('Sicilian: Richter-Rauzer, 6... Qb6'),
			moves => {
			},
		},
		'r1bqkb1r/1p2pppp/p1np1n2/6B1/3NP3/2N5/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B60e',
			# TRANSLATORS: B60e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 a6
			variation => N__('Sicilian: Richter-Rauzer, 6... a6'),
			moves => {
			},
		},
		'r2qkb1r/pp1bpppp/2np1n2/6B1/3NP3/2N5/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B60f',
			# TRANSLATORS: B60f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 Bd7
			variation => N__('Sicilian: Richter-Rauzer, Larsen Variation'),
			moves => {
				'd1d2' => 1,
				'd4b3' => 1,
				'f1e2' => 1,
				'g5f6' => 1,
			},
		},
		'r2qkb1r/pp1bpppp/2np1n2/6B1/4P3/1NN5/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'B60g',
			# TRANSLATORS: B60g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 Bd7 7. Nb3
			variation => N__('Sicilian: Richter-Rauzer, Larsen, 7. Nb3'),
			moves => {
			},
		},
		'r2qkb1r/pp1bpppp/2np1B2/8/3NP3/2N5/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'B60h',
			# TRANSLATORS: B60h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 Bd7 7. Bxf6
			variation => N__('Sicilian: Richter-Rauzer, Larsen, 7.Bxf6'),
			moves => {
			},
		},
		'r2qkb1r/pp1bpppp/2np1n2/6B1/3NP3/2N5/PPP1BPPP/R2QK2R b KQkq' => {
			eco => 'B60i',
			# TRANSLATORS: B60i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 Bd7 7. Be2
			variation => N__('Sicilian: Richter-Rauzer, Larsen, 7. Be2'),
			moves => {
				'a7a6' => 1,
				'd8a5' => 1,
			},
		},
		'r2qkb1r/1p1bpppp/p1np1n2/6B1/3NP3/2N5/PPP1BPPP/R2QK2R w KQkq' => {
			eco => 'B60j',
			# TRANSLATORS: B60j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 Bd7 7. Be2 a6
			variation => N__('Sicilian: Richter-Rauzer, Larsen, 7. Be2 a6'),
			moves => {
			},
		},
		'r3kb1r/pp1bpppp/2np1n2/q5B1/3NP3/2N5/PPP1BPPP/R2QK2R w KQkq' => {
			eco => 'B60k',
			# TRANSLATORS: B60k: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 Bd7 7. Be2 Qa5
			variation => N__('Sicilian: Richter-Rauzer, Larsen, 7. Be2 Qa5'),
			moves => {
			},
		},
		'r2qkb1r/pp1bpppp/2np1n2/6B1/3NP3/2N5/PPPQ1PPP/R3KB1R b KQkq' => {
			eco => 'B61a',
			# TRANSLATORS: B61a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 Bd7 7. Qd2
			variation => N__('Sicilian: Richter-Rauzer, Larsen, 7. Qd2'),
			moves => {
				'a7a6' => 1,
				'a8c8' => 1,
				'c6d4' => 1,
			},
		},
		'r2qkb1r/1p1bpppp/p1np1n2/6B1/3NP3/2N5/PPPQ1PPP/R3KB1R w KQkq' => {
			eco => 'B61b',
			# TRANSLATORS: B61b: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 Bd7 7. Qd2 a6
			variation => N__('Sicilian: Richter-Rauzer, Larsen, 7. Qd2 a6'),
			moves => {
			},
		},
		'r2qkb1r/pp1bpppp/3p1n2/6B1/3nP3/2N5/PPPQ1PPP/R3KB1R w KQkq' => {
			eco => 'B61c',
			# TRANSLATORS: B61c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 Bd7 7. Qd2 Nxd4
			variation => N__('Sicilian: Richter-Rauzer, Larsen, 7. Qd2 Nxd4'),
			moves => {
			},
		},
		'2rqkb1r/pp1bpppp/2np1n2/6B1/3NP3/2N5/PPPQ1PPP/R3KB1R w KQk' => {
			eco => 'B61d',
			# TRANSLATORS: B61d: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 Bd7 7. Qd2 Rc8
			variation => N__('Sicilian: Richter-Rauzer, Larsen, 7. Qd2 Rc8'),
			moves => {
				'e1c1' => 1,
				'f2f4' => 1,
			},
		},
		'2rqkb1r/pp1bpppp/2np1n2/6B1/3NPP2/2N5/PPPQ2PP/R3KB1R b KQk' => {
			eco => 'B61e',
			# TRANSLATORS: B61e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 Bd7 7. Qd2 Rc8 8. f4
			variation => N__('Sicilian: Richter-Rauzer, Larsen, 7. Qd2 Rc8 8. f4'),
			moves => {
			},
		},
		'2rqkb1r/pp1bpppp/2np1n2/6B1/3NP3/2N5/PPPQ1PPP/2KR1B1R b k' => {
			eco => 'B61f',
			# TRANSLATORS: B61f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 Bd7 7. Qd2 Rc8 8. O-O-O
			variation => N__('Sicilian: Richter-Rauzer, Larsen, 7. Qd2 Rc8 8.O-O-O'),
			moves => {
				'c6d4' => 1,
			},
		},
		'2rqkb1r/pp1bpppp/3p1n2/6B1/3nP3/2N5/PPPQ1PPP/2KR1B1R w k' => {
			eco => 'B61f',
			# TRANSLATORS: B61f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 Bd7 7. Qd2 Rc8 8. O-O-O Nxd4
			variation => N__('Sicilian: Richter-Rauzer, Larsen, 7. Qd2 Rc8 8.O-O-O'),
			moves => {
				'd2d4' => 1,
			},
		},
		'2rqkb1r/pp1bpppp/3p1n2/6B1/3QP3/2N5/PPP2PPP/2KR1B1R b k' => {
			eco => 'B61f',
			# TRANSLATORS: B61f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 Bd7 7. Qd2 Rc8 8. O-O-O Nxd4 9. Qxd4
			variation => N__('Sicilian: Richter-Rauzer, Larsen, 7. Qd2 Rc8 8.O-O-O'),
			moves => {
				'd8a5' => 1,
			},
		},
		'2r1kb1r/pp1bpppp/3p1n2/q5B1/3QP3/2N5/PPP2PPP/2KR1B1R w k' => {
			eco => 'B61g',
			# TRANSLATORS: B61g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 Bd7 7. Qd2 Rc8 8. O-O-O Nxd4 9. Qxd4 Qa5
			variation => N__('Sicilian: Richter-Rauzer, Larsen, Main Line'),
			moves => {
				'f2f4' => 1,
				'g5d2' => 1,
			},
		},
		'2r1kb1r/pp1bpppp/3p1n2/q7/3QP3/2N5/PPPB1PPP/2KR1B1R b k' => {
			eco => 'B61h',
			# TRANSLATORS: B61h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 Bd7 7. Qd2 Rc8 8. O-O-O Nxd4 9. Qxd4 Qa5 10. Bd2
			variation => N__('Sicilian: Richter-Rauzer, Larsen, Main Line, 10. Bd2'),
			moves => {
			},
		},
		'2r1kb1r/pp1bpppp/3p1n2/q5B1/3QPP2/2N5/PPP3PP/2KR1B1R b k' => {
			eco => 'B61i',
			# TRANSLATORS: B61i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 Bd7 7. Qd2 Rc8 8. O-O-O Nxd4 9. Qxd4 Qa5 10. f4
			variation => N__('Sicilian: Richter-Rauzer, Larsen, Main Line, 10. f4'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2nppn2/6B1/3NP3/2N5/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B62a',
			# TRANSLATORS: B62a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6
			variation => N__('Sicilian: Richter-Rauzer, 6... e6'),
			moves => {
				'd1d2' => 1,
				'd1d3' => 1,
				'd4b3' => 1,
				'd4c6' => 1,
				'f1b5' => 1,
				'f1e2' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2nppn2/6B1/3NP3/2N5/PPP1BPPP/R2QK2R b KQkq' => {
			eco => 'B62b',
			# TRANSLATORS: B62b: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Be2
			variation => N__('Sicilian: Richter-Rauzer, 6... e6 7. Be2'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2nppn2/6B1/3NP3/2N5/PPP1BPPP/R2QK2R w KQkq' => {
			eco => 'B62c',
			# TRANSLATORS: B62c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Be2 Be7
			variation => N__('Sicilian: Richter-Rauzer, 6... e6 7. Be2 Be7'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2nppn2/6B1/4P3/1NN5/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'B62d',
			# TRANSLATORS: B62d: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Nb3
			variation => N__('Sicilian: Richter-Rauzer, Podebrady Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2Nppn2/6B1/4P3/2N5/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'B62e',
			# TRANSLATORS: B62e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Nxc6
			variation => N__('Sicilian: Richter-Rauzer, Richter Attack'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2nppn2/6B1/3NP3/2NQ4/PPP2PPP/R3KB1R b KQkq' => {
			eco => 'B62f',
			# TRANSLATORS: B62f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd3
			variation => N__('Sicilian: Richter-Rauzer, Keres Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2nppn2/1B4B1/3NP3/2N5/PPP2PPP/R2QK2R b KQkq' => {
			eco => 'B62g',
			# TRANSLATORS: B62g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Bb5
			variation => N__('Sicilian: Richter-Rauzer, Margate (Alekhine) Variation'),
			moves => {
				'c8d7' => 1,
			},
		},
		'r2qkb1r/pp1b1ppp/2nppn2/1B4B1/3NP3/2N5/PPP2PPP/R2QK2R w KQkq' => {
			eco => 'B62h',
			# TRANSLATORS: B62h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Bb5 Bd7
			variation => N__('Sicilian: Richter-Rauzer, Margate, 7... Bd7'),
			moves => {
				'b5c6' => 1,
			},
		},
		'r2qkb1r/pp1b1ppp/2Bppn2/6B1/3NP3/2N5/PPP2PPP/R2QK2R b KQkq' => {
			eco => 'B62i',
			# TRANSLATORS: B62i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Bb5 Bd7 8. Bxc6
			variation => N__('Sicilian: Richter-Rauzer, Margate, 7... Bd7 8.Bxc6'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2nppn2/6B1/3NP3/2N5/PPPQ1PPP/R3KB1R b KQkq' => {
			eco => 'B63a',
			# TRANSLATORS: B63a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2
			variation => N__('Sicilian: Richter-Rauzer, Rauzer Attack (7. Qd2)'),
			moves => {
				'a7a6' => 1,
				'c6d4' => 1,
				'd8b6' => 1,
				'f8e7' => 1,
				'h7h6' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/3ppn2/6B1/3nP3/2N5/PPPQ1PPP/R3KB1R w KQkq' => {
			eco => 'B63b',
			# TRANSLATORS: B63b: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 Nxd4
			variation => N__('Sicilian: Richter-Rauzer, 7. Qd2 Nxd4'),
			moves => {
			},
		},
		'r1b1kb1r/pp3ppp/1qnppn2/6B1/3NP3/2N5/PPPQ1PPP/R3KB1R w KQkq' => {
			eco => 'B63c',
			# TRANSLATORS: B63c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 Qb6
			variation => N__('Sicilian: Richter-Rauzer, 7. Qd2 Qb6'),
			moves => {
				'd4b3' => 1,
			},
		},
		'r1b1kb1r/pp3ppp/1qnppn2/6B1/4P3/1NN5/PPPQ1PPP/R3KB1R b KQkq' => {
			eco => 'B63d',
			# TRANSLATORS: B63d: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 Qb6 8. Nb3
			variation => N__('Sicilian: Richter-Rauzer, 7. Qd2 Qb6 8. Nb3'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r1b1kb1r/1p3ppp/pqnppn2/6B1/4P3/1NN5/PPPQ1PPP/R3KB1R w KQkq' => {
			eco => 'B63e',
			# TRANSLATORS: B63e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 Qb6 8. Nb3 a6
			variation => N__('Sicilian: Richter-Rauzer, 7. Qd2 Qb6 8. Nb3 a6'),
			moves => {
				'e1c1' => 1,
			},
		},
		'r1b1kb1r/1p3ppp/pqnppn2/6B1/4P3/1NN5/PPPQ1PPP/2KR1B1R b kq' => {
			eco => 'B63f',
			# TRANSLATORS: B63f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 Qb6 8. Nb3 a6 9. O-O-O
			variation => N__('Sicilian: Richter-Rauzer, 7. Qd2 Qb6 8. Nb3 a6 9.O-O-O'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r1b1k2r/1p2bppp/pqnppn2/6B1/4P3/1NN5/PPPQ1PPP/2KR1B1R w kq' => {
			eco => 'B63g',
			# TRANSLATORS: B63g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 Qb6 8. Nb3 a6 9. O-O-O Be7
			variation => N__('Sicilian: Richter-Rauzer, 7. Qd2 Qb6 8. Nb3 a6 9.O-O-O Be7'),
			moves => {
			},
		},
		'r1bqkb1r/pp3pp1/2nppn1p/6B1/3NP3/2N5/PPPQ1PPP/R3KB1R w KQkq' => {
			eco => 'B63h',
			# TRANSLATORS: B63h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 h6
			variation => N__('Sicilian: Richter-Rauzer, 7. Qd2 h6'),
			moves => {
				'g5f6' => 1,
			},
		},
		'r1bqkb1r/pp3pp1/2nppB1p/8/3NP3/2N5/PPPQ1PPP/R3KB1R b KQkq' => {
			eco => 'B63h',
			# TRANSLATORS: B63h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 h6 8. Bxf6
			variation => N__('Sicilian: Richter-Rauzer, 7. Qd2 h6'),
			moves => {
				'g7f6' => 1,
			},
		},
		'r1bqkb1r/pp3p2/2nppp1p/8/3NP3/2N5/PPPQ1PPP/R3KB1R w KQkq' => {
			eco => 'B63h',
			# TRANSLATORS: B63h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 h6 8. Bxf6 gxf6
			variation => N__('Sicilian: Richter-Rauzer, 7. Qd2 h6'),
			moves => {
				'e1c1' => 1,
			},
		},
		'r1bqkb1r/pp3p2/2nppp1p/8/3NP3/2N5/PPPQ1PPP/2KR1B1R b kq' => {
			eco => 'B63h',
			# TRANSLATORS: B63h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 h6 8. Bxf6 gxf6 9. O-O-O
			variation => N__('Sicilian: Richter-Rauzer, 7. Qd2 h6'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r1bqkb1r/1p3p2/p1nppp1p/8/3NP3/2N5/PPPQ1PPP/2KR1B1R w kq' => {
			eco => 'B63i',
			# TRANSLATORS: B63i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 h6 8. Bxf6 gxf6 9. O-O-O a6
			variation => N__('Sicilian: Richter-Rauzer, 7. Qd2 h6 8.Bxf6 gxf6 9.O-O-O a6'),
			moves => {
				'f2f4' => 1,
			},
		},
		'r1bqkb1r/1p3p2/p1nppp1p/8/3NPP2/2N5/PPPQ2PP/2KR1B1R b kq' => {
			eco => 'B63j',
			# TRANSLATORS: B63j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 h6 8. Bxf6 gxf6 9. O-O-O a6 10. f4
			variation => N__('Sicilian: Richter-Rauzer, 7. Qd2 h6 8.Bxf6 gxf6 9.O-O-O a6 10. f4'),
			moves => {
			},
		},
		'r1bqk2r/pp2bppp/2nppn2/6B1/3NP3/2N5/PPPQ1PPP/R3KB1R w KQkq' => {
			eco => 'B63k',
			# TRANSLATORS: B63k: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 Be7
			variation => N__('Sicilian: Richter-Rauzer, 7. Qd2 Be7'),
			moves => {
				'e1c1' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2nppn2/6B1/3NP3/2N5/PPPQ1PPP/2KR1B1R b kq' => {
			eco => 'B63l',
			# TRANSLATORS: B63l: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 Be7 8. O-O-O
			variation => N__('Sicilian: Richter-Rauzer, 7. Qd2 Be7 8.O-O-O'),
			moves => {
				'c6d4' => 1,
				'e8g8' => 1,
			},
		},
		'r1bqk2r/pp2bppp/3ppn2/6B1/3nP3/2N5/PPPQ1PPP/2KR1B1R w kq' => {
			eco => 'B63m',
			# TRANSLATORS: B63m: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 Be7 8. O-O-O Nxd4
			variation => N__('Sicilian: Richter-Rauzer, 7. Qd2 Be7 8.O-O-O Nxd4'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bqk2r/pp2bppp/3ppn2/6B1/3QP3/2N5/PPP2PPP/2KR1B1R b kq' => {
			eco => 'B63m',
			# TRANSLATORS: B63m: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 Be7 8. O-O-O Nxd4 9. Qxd4
			variation => N__('Sicilian: Richter-Rauzer, 7. Qd2 Be7 8.O-O-O Nxd4'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/3ppn2/6B1/3QP3/2N5/PPP2PPP/2KR1B1R w -' => {
			eco => 'B63n',
			# TRANSLATORS: B63n: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 Be7 8. O-O-O Nxd4 9. Qxd4 O-O
			variation => N__('Sicilian: Richter-Rauzer, 7. Qd2 Be7 8.O-O-O Nxd4 9.Qxd4 O-O'),
			moves => {
			},
		},
		'r1bq1rk1/pp2bppp/2nppn2/6B1/3NP3/2N5/PPPQ1PPP/2KR1B1R w -' => {
			eco => 'B63o',
			# TRANSLATORS: B63o: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 Be7 8. O-O-O O-O
			variation => N__('Sicilian: Richter-Rauzer, 7. Qd2 Be7 8.O-O-O O-O'),
			moves => {
				'd4b3' => 1,
				'f2f3' => 1,
				'f2f4' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2nppn2/6B1/3NP3/2N2P2/PPPQ2PP/2KR1B1R b -' => {
			eco => 'B63p',
			# TRANSLATORS: B63p: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 Be7 8. O-O-O O-O 9. f3
			variation => N__('Sicilian: Richter-Rauzer, 7. Qd2 Be7, 9. f3'),
			moves => {
			},
		},
		'r1bq1rk1/pp2bppp/2nppn2/6B1/4P3/1NN5/PPPQ1PPP/2KR1B1R b -' => {
			eco => 'B63q',
			# TRANSLATORS: B63q: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 Be7 8. O-O-O O-O 9. Nb3
			variation => N__('Sicilian: Richter-Rauzer, 7. Qd2 Be7, 9. Nb3'),
			moves => {
				'a7a5' => 1,
				'a7a6' => 1,
				'd8b6' => 1,
			},
		},
		'r1bq1rk1/1p2bppp/2nppn2/p5B1/4P3/1NN5/PPPQ1PPP/2KR1B1R w -' => {
			eco => 'B63r',
			# TRANSLATORS: B63r: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 Be7 8. O-O-O O-O 9. Nb3 a5
			variation => N__('Sicilian: Richter-Rauzer, 7. Qd2 Be7, 9. Nb3 a5'),
			moves => {
			},
		},
		'r1bq1rk1/1p2bppp/p1nppn2/6B1/4P3/1NN5/PPPQ1PPP/2KR1B1R w -' => {
			eco => 'B63s',
			# TRANSLATORS: B63s: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 Be7 8. O-O-O O-O 9. Nb3 a6
			variation => N__('Sicilian: Richter-Rauzer, 7. Qd2 Be7, 9. Nb3 a6'),
			moves => {
			},
		},
		'r1b2rk1/pp2bppp/1qnppn2/6B1/4P3/1NN5/PPPQ1PPP/2KR1B1R w -' => {
			eco => 'B63t',
			# TRANSLATORS: B63t: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 Be7 8. O-O-O O-O 9. Nb3 Qb6
			variation => N__('Sicilian: Richter-Rauzer, Podebrad Variation'),
			moves => {
				'f2f3' => 1,
			},
		},
		'r1b2rk1/pp2bppp/1qnppn2/6B1/4P3/1NN2P2/PPPQ2PP/2KR1B1R b -' => {
			eco => 'B63u',
			# TRANSLATORS: B63u: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 Be7 8. O-O-O O-O 9. Nb3 Qb6 10. f3
			variation => N__('Sicilian: Richter-Rauzer, Podebrad, 10. f3'),
			moves => {
				'f8d8' => 1,
			},
		},
		'r1br2k1/pp2bppp/1qnppn2/6B1/4P3/1NN2P2/PPPQ2PP/2KR1B1R w -' => {
			eco => 'B63v',
			# TRANSLATORS: B63v: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 Be7 8. O-O-O O-O 9. Nb3 Qb6 10. f3 Rd8
			variation => N__('Sicilian: Richter-Rauzer, Podebrad, 10. f3 Rd8'),
			moves => {
				'c1b1' => 1,
			},
		},
		'r1br2k1/pp2bppp/1qnppn2/6B1/4P3/1NN2P2/PPPQ2PP/1K1R1B1R b -' => {
			eco => 'B63w',
			# TRANSLATORS: B63w: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 Be7 8. O-O-O O-O 9. Nb3 Qb6 10. f3 Rd8 11. Kb1
			variation => N__('Sicilian: Richter-Rauzer, Podebrad, 10. f3 Rd8 11. Kb1'),
			moves => {
			},
		},
		'r1bq1rk1/pp2bppp/2nppn2/6B1/3NPP2/2N5/PPPQ2PP/2KR1B1R b -' => {
			eco => 'B64a',
			# TRANSLATORS: B64a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 Be7 8. O-O-O O-O 9. f4
			variation => N__('Sicilian: Richter-Rauzer, 7. Qd2 Be7, 9. f4'),
			moves => {
				'c6d4' => 1,
				'e6e5' => 1,
				'h7h6' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2np1n2/4p1B1/3NPP2/2N5/PPPQ2PP/2KR1B1R w -' => {
			eco => 'B64b',
			# TRANSLATORS: B64b: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 Be7 8. O-O-O O-O 9. f4 e5
			variation => N__('Sicilian: Richter-Rauzer, Geller Variation'),
			moves => {
			},
		},
		'r1bq1rk1/pp2bpp1/2nppn1p/6B1/3NPP2/2N5/PPPQ2PP/2KR1B1R w -' => {
			eco => 'B64c',
			# TRANSLATORS: B64c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 Be7 8. O-O-O O-O 9. f4 h6
			variation => N__('Sicilian: Richter-Rauzer, 7. Qd2 Be7, 9. f4 h6'),
			moves => {
				'g5h4' => 1,
			},
		},
		'r1bq1rk1/pp2bpp1/2nppn1p/8/3NPP1B/2N5/PPPQ2PP/2KR1B1R b -' => {
			eco => 'B64d',
			# TRANSLATORS: B64d: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 Be7 8. O-O-O O-O 9. f4 h6 10. Bh4
			variation => N__('Sicilian: Richter-Rauzer, 7. Qd2 Be7, 9. f4 h6 10. Bh4'),
			moves => {
				'c8d7' => 1,
				'e6e5' => 1,
			},
		},
		'r2q1rk1/pp1bbpp1/2nppn1p/8/3NPP1B/2N5/PPPQ2PP/2KR1B1R w -' => {
			eco => 'B64e',
			# TRANSLATORS: B64e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 Be7 8. O-O-O O-O 9. f4 h6 10. Bh4 Bd7
			variation => N__('Sicilian: Richter-Rauzer, 7. Qd2 Be7, 9. f4 h6 10. Bh4 Bd7'),
			moves => {
			},
		},
		'r1bq1rk1/pp2bpp1/2np1n1p/4p3/3NPP1B/2N5/PPPQ2PP/2KR1B1R w -' => {
			eco => 'B64f',
			# TRANSLATORS: B64f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 Be7 8. O-O-O O-O 9. f4 h6 10. Bh4 e5
			variation => N__('Sicilian: Richter-Rauzer, 7. Qd2 Be7, 9. f4 h6 10. Bh4 e5'),
			moves => {
			},
		},
		'r1bq1rk1/pp2bppp/3ppn2/6B1/3nPP2/2N5/PPPQ2PP/2KR1B1R w -' => {
			eco => 'B65a',
			# TRANSLATORS: B65a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 Be7 8. O-O-O O-O 9. f4 Nxd4
			variation => N__('Sicilian: Richter-Rauzer, 7... Be7, 9. f4 Nxd4'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/3ppn2/6B1/3QPP2/2N5/PPP3PP/2KR1B1R b -' => {
			eco => 'B65a',
			# TRANSLATORS: B65a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 Be7 8. O-O-O O-O 9. f4 Nxd4 10. Qxd4
			variation => N__('Sicilian: Richter-Rauzer, 7... Be7, 9. f4 Nxd4'),
			moves => {
				'd8a5' => 1,
				'h7h6' => 1,
			},
		},
		'r1bq1rk1/pp2bpp1/3ppn1p/6B1/3QPP2/2N5/PPP3PP/2KR1B1R w -' => {
			eco => 'B65b',
			# TRANSLATORS: B65b: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 Be7 8. O-O-O O-O 9. f4 Nxd4 10. Qxd4 h6
			variation => N__('Sicilian: Richter-Rauzer, 7... Be7, 9. f4 Nxd4 10.Qxd4 h6'),
			moves => {
			},
		},
		'r1b2rk1/pp2bppp/3ppn2/q5B1/3QPP2/2N5/PPP3PP/2KR1B1R w -' => {
			eco => 'B65c',
			# TRANSLATORS: B65c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 Be7 8. O-O-O O-O 9. f4 Nxd4 10. Qxd4 Qa5
			variation => N__('Sicilian: Richter-Rauzer, 7... Be7, 9. f4 Nxd4 10.Qxd4 Qa5'),
			moves => {
				'c1b1' => 1,
				'f1c4' => 1,
			},
		},
		'r1b2rk1/pp2bppp/3ppn2/q5B1/3QPP2/2N5/PPP3PP/1K1R1B1R b -' => {
			eco => 'B65d',
			# TRANSLATORS: B65d: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 Be7 8. O-O-O O-O 9. f4 Nxd4 10. Qxd4 Qa5 11. Kb1
			variation => N__('Sicilian: Richter-Rauzer, 7... Be7, 9. f4 Nxd4 10.Qxd4 Qa5 11. Kb1'),
			moves => {
			},
		},
		'r1b2rk1/pp2bppp/3ppn2/q5B1/2BQPP2/2N5/PPP3PP/2KR3R b -' => {
			eco => 'B65e',
			# TRANSLATORS: B65e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 Be7 8. O-O-O O-O 9. f4 Nxd4 10. Qxd4 Qa5 11. Bc4
			variation => N__('Sicilian: Richter-Rauzer, 7... Be7, 9. f4 Nxd4 10.Qxd4 Qa5 11. Bc4'),
			moves => {
				'c8d7' => 1,
			},
		},
		'r4rk1/pp1bbppp/3ppn2/q5B1/2BQPP2/2N5/PPP3PP/2KR3R w -' => {
			eco => 'B65f',
			# TRANSLATORS: B65f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 Be7 8. O-O-O O-O 9. f4 Nxd4 10. Qxd4 Qa5 11. Bc4 Bd7
			variation => N__('Sicilian: Richter-Rauzer, 7... Be7, 9. f4 Nxd4 10.Qxd4 Qa5 11. Bc4 Bd7'),
			moves => {
				'e4e5' => 1,
			},
		},
		'r4rk1/pp1bbppp/3ppn2/q3P1B1/2BQ1P2/2N5/PPP3PP/2KR3R b -' => {
			eco => 'B65g',
			# TRANSLATORS: B65g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 Be7 8. O-O-O O-O 9. f4 Nxd4 10. Qxd4 Qa5 11. Bc4 Bd7 12. e5
			variation => N__('Sicilian: Richter-Rauzer, 7... Be7, 9. f4 Nxd4 10.Qxd4 Qa5 11. Bc4 Bd7 12. e5'),
			moves => {
			},
		},
		'r1bqkb1r/1p3ppp/p1nppn2/6B1/3NP3/2N5/PPPQ1PPP/R3KB1R w KQkq' => {
			eco => 'B66a',
			# TRANSLATORS: B66a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6
			variation => N__('Sicilian: Richter-Rauzer, 7... a6'),
			moves => {
				'e1c1' => 1,
				'f1e2' => 1,
			},
		},
		'r1bqkb1r/1p3ppp/p1nppn2/6B1/3NP3/2N5/PPPQBPPP/R3K2R b KQkq' => {
			eco => 'B66b',
			# TRANSLATORS: B66b: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. Be2
			variation => N__('Sicilian: Richter-Rauzer, 7... a6 8. Be2'),
			moves => {
			},
		},
		'r1bqkb1r/1p3ppp/p1nppn2/6B1/3NP3/2N5/PPPQ1PPP/2KR1B1R b kq' => {
			eco => 'B66c',
			# TRANSLATORS: B66c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O
			variation => N__('Sicilian: Richter-Rauzer, 7... a6 8.O-O-O'),
			moves => {
				'c6d4' => 1,
				'c8d7' => 1,
				'f8e7' => 1,
				'h7h6' => 1,
			},
		},
		'r1bqk2r/1p2bppp/p1nppn2/6B1/3NP3/2N5/PPPQ1PPP/2KR1B1R w kq' => {
			eco => 'B66d',
			# TRANSLATORS: B66d: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O Be7
			variation => N__('Sicilian: Richter-Rauzer, 7... a6 8.O-O-O Be7'),
			moves => {
			},
		},
		'r1bqkb1r/1p3ppp/p2ppn2/6B1/3nP3/2N5/PPPQ1PPP/2KR1B1R w kq' => {
			eco => 'B66e',
			# TRANSLATORS: B66e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O Nxd4
			variation => N__('Sicilian: Richter-Rauzer, 7... a6 8.O-O-O Nxd4'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bqkb1r/1p3ppp/p2ppn2/6B1/3QP3/2N5/PPP2PPP/2KR1B1R b kq' => {
			eco => 'B66e',
			# TRANSLATORS: B66e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O Nxd4 9. Qxd4
			variation => N__('Sicilian: Richter-Rauzer, 7... a6 8.O-O-O Nxd4 9.Qxd4'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r1bqk2r/1p2bppp/p2ppn2/6B1/3QP3/2N5/PPP2PPP/2KR1B1R w kq' => {
			eco => 'B66e',
			# TRANSLATORS: B66e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O Nxd4 9. Qxd4 Be7
			variation => N__('Sicilian: Richter-Rauzer, 7... a6 8.O-O-O Nxd4 9.Qxd4 Be7'),
			moves => {
			},
		},
		'r1bqkb1r/1p3pp1/p1nppn1p/6B1/3NP3/2N5/PPPQ1PPP/2KR1B1R w kq' => {
			eco => 'B66f',
			# TRANSLATORS: B66f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O h6
			variation => N__('Sicilian: Richter-Rauzer, 7... a6 8.O-O-O h6'),
			moves => {
				'g5e3' => 1,
				'g5f4' => 1,
			},
		},
		'r1bqkb1r/1p3pp1/p1nppn1p/8/3NPB2/2N5/PPPQ1PPP/2KR1B1R b kq' => {
			eco => 'B66g',
			# TRANSLATORS: B66g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O h6 9. Bf4
			variation => N__('Sicilian: Richter-Rauzer, 7... a6 8.O-O-O h6 9. Bf4'),
			moves => {
				'c8d7' => 1,
			},
		},
		'r2qkb1r/1p1b1pp1/p1nppn1p/8/3NPB2/2N5/PPPQ1PPP/2KR1B1R w kq' => {
			eco => 'B66g',
			# TRANSLATORS: B66g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O h6 9. Bf4 Bd7
			variation => N__('Sicilian: Richter-Rauzer, 7... a6 8.O-O-O h6 9. Bf4'),
			moves => {
				'd4c6' => 1,
			},
		},
		'r2qkb1r/1p1b1pp1/p1Nppn1p/8/4PB2/2N5/PPPQ1PPP/2KR1B1R b kq' => {
			eco => 'B66g',
			# TRANSLATORS: B66g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O h6 9. Bf4 Bd7 10. Nxc6
			variation => N__('Sicilian: Richter-Rauzer, 7... a6 8.O-O-O h6 9. Bf4'),
			moves => {
				'd7c6' => 1,
			},
		},
		'r2qkb1r/1p3pp1/p1bppn1p/8/4PB2/2N5/PPPQ1PPP/2KR1B1R w kq' => {
			eco => 'B66g',
			# TRANSLATORS: B66g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O h6 9. Bf4 Bd7 10. Nxc6 Bxc6
			variation => N__('Sicilian: Richter-Rauzer, 7... a6 8.O-O-O h6 9. Bf4'),
			moves => {
				'f2f3' => 1,
			},
		},
		'r2qkb1r/1p3pp1/p1bppn1p/8/4PB2/2N2P2/PPPQ2PP/2KR1B1R b kq' => {
			eco => 'B66h',
			# TRANSLATORS: B66h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O h6 9. Bf4 Bd7 10. Nxc6 Bxc6 11. f3
			variation => N__('Sicilian: Richter-Rauzer, 7... a6 8.O-O-O h6 9. Bf4, 11. f3'),
			moves => {
			},
		},
		'r1bqkb1r/1p3pp1/p1nppn1p/8/3NP3/2N1B3/PPPQ1PPP/2KR1B1R b kq' => {
			eco => 'B66i',
			# TRANSLATORS: B66i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O h6 9. Be3
			variation => N__('Sicilian: Richter-Rauzer, 7... a6 8.O-O-O h6 9. Be3'),
			moves => {
				'c8d7' => 1,
				'd8c7' => 1,
				'f8e7' => 1,
			},
		},
		'r1b1kb1r/1pq2pp1/p1nppn1p/8/3NP3/2N1B3/PPPQ1PPP/2KR1B1R w kq' => {
			eco => 'B66j',
			# TRANSLATORS: B66j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O h6 9. Be3 Qc7
			variation => N__('Sicilian: Richter-Rauzer, 7... a6 8.O-O-O h6 9. Be3 Qc7'),
			moves => {
			},
		},
		'r2qkb1r/1p1b1pp1/p1nppn1p/8/3NP3/2N1B3/PPPQ1PPP/2KR1B1R w kq' => {
			eco => 'B66k',
			# TRANSLATORS: B66k: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O h6 9. Be3 Bd7
			variation => N__('Sicilian: Richter-Rauzer, 7... a6 8.O-O-O h6 9. Be3 Bd7'),
			moves => {
				'f2f3' => 1,
			},
		},
		'r2qkb1r/1p1b1pp1/p1nppn1p/8/3NP3/2N1BP2/PPPQ2PP/2KR1B1R b kq' => {
			eco => 'B66l',
			# TRANSLATORS: B66l: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O h6 9. Be3 Bd7 10. f3
			variation => N__('Sicilian: Richter-Rauzer, 7... a6 8.O-O-O h6 9. Be3 Bd7 10. f3'),
			moves => {
			},
		},
		'r1bqk2r/1p2bpp1/p1nppn1p/8/3NP3/2N1B3/PPPQ1PPP/2KR1B1R w kq' => {
			eco => 'B66m',
			# TRANSLATORS: B66m: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O h6 9. Be3 Be7
			variation => N__('Sicilian: Richter-Rauzer, 7... a6 8.O-O-O h6 9. Be3 Be7'),
			moves => {
				'f2f3' => 1,
				'f2f4' => 1,
			},
		},
		'r1bqk2r/1p2bpp1/p1nppn1p/8/3NP3/2N1BP2/PPPQ2PP/2KR1B1R b kq' => {
			eco => 'B66m',
			# TRANSLATORS: B66m: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O h6 9. Be3 Be7 10. f3
			variation => N__('Sicilian: Richter-Rauzer, 7... a6 8.O-O-O h6 9. Be3 Be7 10. f3'),
			moves => {
				'c6d4' => 1,
			},
		},
		'r1bqk2r/1p2bpp1/p2ppn1p/8/3nP3/2N1BP2/PPPQ2PP/2KR1B1R w kq' => {
			eco => 'B66m',
			# TRANSLATORS: B66m: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O h6 9. Be3 Be7 10. f3 Nxd4
			variation => N__('Sicilian: Richter-Rauzer, 7... a6 8.O-O-O h6 9. Be3 Be7 10. f3 Nxd4'),
			moves => {
				'e3d4' => 1,
			},
		},
		'r1bqk2r/1p2bpp1/p2ppn1p/8/3BP3/2N2P2/PPPQ2PP/2KR1B1R b kq' => {
			eco => 'B66n',
			# TRANSLATORS: B66n: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O h6 9. Be3 Be7 10. f3 Nxd4 11. Bxd4
			variation => N__('Sicilian: Richter-Rauzer, 7... a6 8.O-O-O h6 9. Be3 Be7 10. f3 Nxd4 11.Bxd4'),
			moves => {
			},
		},
		'r1bqk2r/1p2bpp1/p1nppn1p/8/3NPP2/2N1B3/PPPQ2PP/2KR1B1R b kq' => {
			eco => 'B66o',
			# TRANSLATORS: B66o: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O h6 9. Be3 Be7 10. f4
			variation => N__('Sicilian: Richter-Rauzer, 7... a6 8.O-O-O h6 9. Be3 Be7 10. f4'),
			moves => {
				'c6d4' => 1,
			},
		},
		'r1bqk2r/1p2bpp1/p2ppn1p/8/3nPP2/2N1B3/PPPQ2PP/2KR1B1R w kq' => {
			eco => 'B66p',
			# TRANSLATORS: B66p: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O h6 9. Be3 Be7 10. f4 Nxd4
			variation => N__('Sicilian: Richter-Rauzer, 7... a6 8.O-O-O h6 9. Be3 Be7 10. f4 Nxd4'),
			moves => {
			},
		},
		'r2qkb1r/1p1b1ppp/p1nppn2/6B1/3NP3/2N5/PPPQ1PPP/2KR1B1R w kq' => {
			eco => 'B67a',
			# TRANSLATORS: B67a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O Bd7
			variation => N__('Sicilian: Richter-Rauzer, 7... a6 8.O-O-O Bd7'),
			moves => {
				'f1e2' => 1,
				'f2f3' => 1,
				'f2f4' => 1,
			},
		},
		'r2qkb1r/1p1b1ppp/p1nppn2/6B1/3NP3/2N5/PPPQBPPP/2KR3R b kq' => {
			eco => 'B67b',
			# TRANSLATORS: B67b: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O Bd7 9. Be2
			variation => N__('Sicilian: Richter-Rauzer, 7... a6, 9. Be2'),
			moves => {
			},
		},
		'r2qkb1r/1p1b1ppp/p1nppn2/6B1/3NP3/2N2P2/PPPQ2PP/2KR1B1R b kq' => {
			eco => 'B67c',
			# TRANSLATORS: B67c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O Bd7 9. f3
			variation => N__('Sicilian: Richter-Rauzer, 7... a6, 9. f3'),
			moves => {
				'a8c8' => 1,
				'f8e7' => 1,
			},
		},
		'2rqkb1r/1p1b1ppp/p1nppn2/6B1/3NP3/2N2P2/PPPQ2PP/2KR1B1R w k' => {
			eco => 'B67d',
			# TRANSLATORS: B67d: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O Bd7 9. f3 Rc8
			variation => N__('Sicilian: Richter-Rauzer, 7... a6, 9. f3 Rc8'),
			moves => {
			},
		},
		'r2qk2r/1p1bbppp/p1nppn2/6B1/3NP3/2N2P2/PPPQ2PP/2KR1B1R w kq' => {
			eco => 'B67e',
			# TRANSLATORS: B67e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O Bd7 9. f3 Be7
			variation => N__('Sicilian: Richter-Rauzer, 7... a6, 9. f3 Be7'),
			moves => {
				'h2h4' => 1,
			},
		},
		'r2qk2r/1p1bbppp/p1nppn2/6B1/3NP2P/2N2P2/PPPQ2P1/2KR1B1R b kq' => {
			eco => 'B67f',
			# TRANSLATORS: B67f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O Bd7 9. f3 Be7 10. h4
			variation => N__('Sicilian: Richter-Rauzer, 7... a6, 9. f3 Be7 10. h4'),
			moves => {
			},
		},
		'r2qkb1r/1p1b1ppp/p1nppn2/6B1/3NPP2/2N5/PPPQ2PP/2KR1B1R b kq' => {
			eco => 'B67g',
			# TRANSLATORS: B67g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O Bd7 9. f4
			variation => N__('Sicilian: Richter-Rauzer, 7... a6, 9. f4'),
			moves => {
				'b7b5' => 1,
				'f8e7' => 1,
				'h7h6' => 1,
			},
		},
		'r2qkb1r/1p1b1pp1/p1nppn1p/6B1/3NPP2/2N5/PPPQ2PP/2KR1B1R w kq' => {
			eco => 'B67h',
			# TRANSLATORS: B67h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O Bd7 9. f4 h6
			variation => N__('Sicilian: Richter-Rauzer, 7... a6, 9. f4 h6'),
			moves => {
				'g5h4' => 1,
			},
		},
		'r2qkb1r/1p1b1pp1/p1nppn1p/8/3NPP1B/2N5/PPPQ2PP/2KR1B1R b kq' => {
			eco => 'B67i',
			# TRANSLATORS: B67i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O Bd7 9. f4 h6 10. Bh4
			variation => N__('Sicilian: Richter-Rauzer, 7... a6, 9. f4 h6 10. Bh4'),
			moves => {
				'g7g5' => 1,
			},
		},
		'r2qkb1r/1p1b1p2/p1nppn1p/6p1/3NPP1B/2N5/PPPQ2PP/2KR1B1R w kq' => {
			eco => 'B67j',
			# TRANSLATORS: B67j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O Bd7 9. f4 h6 10. Bh4 g5
			variation => N__('Sicilian: Richter-Rauzer, 7... a6, 9. f4 h6 10. Bh4 g5'),
			moves => {
			},
		},
		'r2qkb1r/3b1ppp/p1nppn2/1p4B1/3NPP2/2N5/PPPQ2PP/2KR1B1R w kq' => {
			eco => 'B67k',
			# TRANSLATORS: B67k: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O Bd7 9. f4 b5
			variation => N__('Sicilian: Richter-Rauzer, 7... a6, 9. f4 b5'),
			moves => {
				'd4c6' => 1,
				'g5f6' => 1,
			},
		},
		'r2qkb1r/3b1ppp/p1Nppn2/1p4B1/4PP2/2N5/PPPQ2PP/2KR1B1R b kq' => {
			eco => 'B67l',
			# TRANSLATORS: B67l: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O Bd7 9. f4 b5 10. Nxc6
			variation => N__('Sicilian: Richter-Rauzer, 7... a6, 9. f4 b5 10.Nxc6'),
			moves => {
			},
		},
		'r2qkb1r/3b1ppp/p1nppB2/1p6/3NPP2/2N5/PPPQ2PP/2KR1B1R b kq' => {
			eco => 'B67m',
			# TRANSLATORS: B67m: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O Bd7 9. f4 b5 10. Bxf6
			variation => N__('Sicilian: Richter-Rauzer, 7... a6, 9. f4 b5 10.Bxf6'),
			moves => {
				'g7f6' => 1,
			},
		},
		'r2qkb1r/3b1p1p/p1nppp2/1p6/3NPP2/2N5/PPPQ2PP/2KR1B1R w kq' => {
			eco => 'B67m',
			# TRANSLATORS: B67m: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O Bd7 9. f4 b5 10. Bxf6 gxf6
			variation => N__('Sicilian: Richter-Rauzer, 7... a6, 9. f4 b5 10.Bxf6 gxf6'),
			moves => {
				'c1b1' => 1,
				'd4c6' => 1,
				'f4f5' => 1,
			},
		},
		'r2qkb1r/3b1p1p/p1nppp2/1p3P2/3NP3/2N5/PPPQ2PP/2KR1B1R b kq' => {
			eco => 'B67n',
			# TRANSLATORS: B67n: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O Bd7 9. f4 b5 10. Bxf6 gxf6 11. f5
			variation => N__('Sicilian: Richter-Rauzer, 7... a6, 9. f4 b5 10.Bxf6 gxf6 11. f5'),
			moves => {
			},
		},
		'r2qkb1r/3b1p1p/p1Nppp2/1p6/4PP2/2N5/PPPQ2PP/2KR1B1R b kq' => {
			eco => 'B67o',
			# TRANSLATORS: B67o: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O Bd7 9. f4 b5 10. Bxf6 gxf6 11. Nxc6
			variation => N__('Sicilian: Richter-Rauzer, 7... a6, 9. f4 b5 10.Bxf6 gxf6 11.Nxc6'),
			moves => {
				'd7c6' => 1,
			},
		},
		'r2qkb1r/5p1p/p1bppp2/1p6/4PP2/2N5/PPPQ2PP/2KR1B1R w kq' => {
			eco => 'B67o',
			# TRANSLATORS: B67o: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O Bd7 9. f4 b5 10. Bxf6 gxf6 11. Nxc6 Bxc6
			variation => N__('Sicilian: Richter-Rauzer, 7... a6, 9. f4 b5 10.Bxf6 gxf6 11.Nxc6'),
			moves => {
				'd2e1' => 1,
			},
		},
		'r2qkb1r/5p1p/p1bppp2/1p6/4PP2/2N5/PPP3PP/2KRQB1R b kq' => {
			eco => 'B67p',
			# TRANSLATORS: B67p: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O Bd7 9. f4 b5 10. Bxf6 gxf6 11. Nxc6 Bxc6 12. Qe1
			variation => N__('Sicilian: Richter-Rauzer, 7... a6, 9. f4 b5 10.Bxf6 gxf6 11.Nxc6 Bxc6 12. Qe1'),
			moves => {
			},
		},
		'r2qkb1r/3b1p1p/p1nppp2/1p6/3NPP2/2N5/PPPQ2PP/1K1R1B1R b kq' => {
			eco => 'B67q',
			# TRANSLATORS: B67q: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O Bd7 9. f4 b5 10. Bxf6 gxf6 11. Kb1
			variation => N__('Sicilian: Richter-Rauzer, 7... a6, 9. f4 b5 10.Bxf6 gxf6 11. Kb1'),
			moves => {
				'd8b6' => 1,
			},
		},
		'r3kb1r/3b1p1p/pqnppp2/1p6/3NPP2/2N5/PPPQ2PP/1K1R1B1R w kq' => {
			eco => 'B67r',
			# TRANSLATORS: B67r: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O Bd7 9. f4 b5 10. Bxf6 gxf6 11. Kb1 Qb6
			variation => N__('Sicilian: Richter-Rauzer, 7... a6, 9. f4 b5 10.Bxf6 gxf6 11. Kb1 Qb6'),
			moves => {
				'd4c6' => 1,
			},
		},
		'r3kb1r/3b1p1p/pqNppp2/1p6/4PP2/2N5/PPPQ2PP/1K1R1B1R b kq' => {
			eco => 'B67s',
			# TRANSLATORS: B67s: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O Bd7 9. f4 b5 10. Bxf6 gxf6 11. Kb1 Qb6 12. Nxc6
			variation => N__('Sicilian: Richter-Rauzer, 7... a6, 9. f4 b5 10.Bxf6 gxf6 11. Kb1 Qb6 12.Nxc6'),
			moves => {
			},
		},
		'r2qk2r/1p1bbppp/p1nppn2/6B1/3NPP2/2N5/PPPQ2PP/2KR1B1R w kq' => {
			eco => 'B68',
			# TRANSLATORS: B68: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O Bd7 9. f4 Be7
			variation => N__('Sicilian: Richter-Rauzer, 7... a6, 9. f4 Be7'),
			moves => {
				'd4f3' => 1,
				'f1e2' => 1,
			},
		},
		'r2qk2r/1p1bbppp/p1nppn2/6B1/4PP2/2N2N2/PPPQ2PP/2KR1B1R b kq' => {
			eco => 'B68',
			# TRANSLATORS: B68: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O Bd7 9. f4 Be7 10. Nf3
			variation => N__('Sicilian: Richter-Rauzer, 7... a6, 9. f4 Be7 10. Nf3'),
			moves => {
				'b7b5' => 1,
			},
		},
		'r2qk2r/3bbppp/p1nppn2/1p4B1/4PP2/2N2N2/PPPQ2PP/2KR1B1R w kq' => {
			eco => 'B68',
			# TRANSLATORS: B68: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O Bd7 9. f4 Be7 10. Nf3 b5
			variation => N__('Sicilian: Richter-Rauzer, 7... a6, 9. f4 Be7 10. Nf3 b5'),
			moves => {
				'e4e5' => 1,
				'g5f6' => 1,
			},
		},
		'r2qk2r/3bbppp/p1nppn2/1p2P1B1/5P2/2N2N2/PPPQ2PP/2KR1B1R b kq' => {
			eco => 'B68',
			# TRANSLATORS: B68: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O Bd7 9. f4 Be7 10. Nf3 b5 11. e5
			variation => N__('Sicilian: Richter-Rauzer, 7... a6, 9. f4 Be7 10. Nf3 b5 11. e5'),
			moves => {
			},
		},
		'r2qk2r/1p1bbppp/p1nppn2/6B1/3NPP2/2N5/PPPQB1PP/2KR3R b kq' => {
			eco => 'B68',
			# TRANSLATORS: B68: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O Bd7 9. f4 Be7 10. Be2
			variation => N__('Sicilian: Richter-Rauzer, 7... a6, 9. f4 Be7 10. Be2'),
			moves => {
				'd8c7' => 1,
			},
		},
		'r3k2r/1pqbbppp/p1nppn2/6B1/3NPP2/2N5/PPPQB1PP/2KR3R w kq' => {
			eco => 'B68',
			# TRANSLATORS: B68: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O Bd7 9. f4 Be7 10. Be2 Qc7
			variation => N__('Sicilian: Richter-Rauzer, 7... a6, 9. f4 Be7 10. Be2 Qc7'),
			moves => {
			},
		},
		'r2qk2r/3bbppp/p1nppB2/1p6/4PP2/2N2N2/PPPQ2PP/2KR1B1R b kq' => {
			eco => 'B69',
			# TRANSLATORS: B69: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O Bd7 9. f4 Be7 10. Nf3 b5 11. Bxf6
			variation => N__('Sicilian: Richter-Rauzer, 7... a6, 9. f4 Be7 10. Nf3 b5 11.Bxf6'),
			moves => {
				'g7f6' => 1,
			},
		},
		'r2qk2r/3bbp1p/p1nppp2/1p6/4PP2/2N2N2/PPPQ2PP/2KR1B1R w kq' => {
			eco => 'B69',
			# TRANSLATORS: B69: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O Bd7 9. f4 Be7 10. Nf3 b5 11. Bxf6 gxf6
			variation => N__('Sicilian: Richter-Rauzer, 7... a6, 9. f4 Be7 10. Nf3 b5 11.Bxf6 gxf6'),
			moves => {
				'c1b1' => 1,
				'f4f5' => 1,
			},
		},
		'r2qk2r/3bbp1p/p1nppp2/1p6/4PP2/2N2N2/PPPQ2PP/1K1R1B1R b kq' => {
			eco => 'B69',
			# TRANSLATORS: B69: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O Bd7 9. f4 Be7 10. Nf3 b5 11. Bxf6 gxf6 12. Kb1
			variation => N__('Sicilian: Richter-Rauzer, 7... a6, 9. f4 Be7 10. Nf3 b5 11.Bxf6 gxf6 12. Kb1'),
			moves => {
			},
		},
		'r2qk2r/3bbp1p/p1nppp2/1p3P2/4P3/2N2N2/PPPQ2PP/2KR1B1R b kq' => {
			eco => 'B69',
			# TRANSLATORS: B69: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 Nc6 6. Bg5 e6 7. Qd2 a6 8. O-O-O Bd7 9. f4 Be7 10. Nf3 b5 11. Bxf6 gxf6 12. f5
			variation => N__('Sicilian: Richter-Rauzer, 7... a6, 9. f4 Be7 10. Nf3 b5 11.Bxf6 gxf6 12. f5'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pp1p/3p1np1/8/3NP3/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B70a',
			# TRANSLATORS: B70a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6
			variation => N__('Sicilian: Dragon'),
			moves => {
				'c1e3' => 1,
				'c1g5' => 1,
				'f1c4' => 1,
				'f1e2' => 1,
				'f2f3' => 1,
				'f2f4' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/pp2pp1p/3p1np1/8/3NP3/2N2P2/PPP3PP/R1BQKB1R b KQkq' => {
			eco => 'B70a',
			# TRANSLATORS: B70a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. f3
			variation => N__('Sicilian: Dragon, 6. f3'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pp1p/3p1np1/8/3NP3/2N3P1/PPP2P1P/R1BQKB1R b KQkq' => {
			eco => 'B70b',
			# TRANSLATORS: B70b: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. g3
			variation => N__('Sicilian: Dragon, 6. g3'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkb1r/pp2pp1p/2np1np1/8/3NP3/2N3P1/PPP2P1P/R1BQKB1R w KQkq' => {
			eco => 'B70c',
			# TRANSLATORS: B70c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. g3 Nc6
			variation => N__('Sicilian: Dragon, 6. g3 Nc6'),
			moves => {
				'd4e2' => 1,
				'f1g2' => 1,
			},
		},
		'r1bqkb1r/pp2pp1p/2np1np1/8/3NP3/2N3P1/PPP2PBP/R1BQK2R b KQkq' => {
			eco => 'B70c',
			# TRANSLATORS: B70c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. g3 Nc6 7. Bg2
			variation => N__('Sicilian: Dragon, 6. g3 Nc6 7. Bg2'),
			moves => {
			},
		},
		'r1bqkb1r/pp2pp1p/2np1np1/8/4P3/2N3P1/PPP1NP1P/R1BQKB1R b KQkq' => {
			eco => 'B70d',
			# TRANSLATORS: B70d: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. g3 Nc6 7. Nde2
			variation => N__('Sicilian: Dragon, 6. g3 Nc6 7.Nde2'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pp1p/3p1np1/6B1/3NP3/2N5/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'B70e',
			# TRANSLATORS: B70e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Bg5
			variation => N__('Sicilian: Dragon, 6. Bg5'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/3p1np1/6B1/3NP3/2N5/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B70e',
			# TRANSLATORS: B70e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Bg5 Bg7
			variation => N__('Sicilian: Dragon, 6. Bg5'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pp1p/3p1np1/8/2BNP3/2N5/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'B70f',
			# TRANSLATORS: B70f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Bc4
			variation => N__('Sicilian: Dragon, 6. Bc4'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/3p1np1/8/2BNP3/2N5/PPP2PPP/R1BQK2R w KQkq' => {
			eco => 'B70f',
			# TRANSLATORS: B70f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Bc4 Bg7
			variation => N__('Sicilian: Dragon, 6. Bc4 Bg7'),
			moves => {
				'e1g1' => 1,
				'h2h3' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/3p1np1/8/2BNP3/2N4P/PPP2PP1/R1BQK2R b KQkq' => {
			eco => 'B70g',
			# TRANSLATORS: B70g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Bc4 Bg7 7. h3
			variation => N__('Sicilian: Dragon, 6. Bc4 Bg7 7. h3'),
			moves => {
			},
		},
		'rnbqk2r/pp2ppbp/3p1np1/8/2BNP3/2N5/PPP2PPP/R1BQ1RK1 b kq' => {
			eco => 'B70h',
			# TRANSLATORS: B70h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Bc4 Bg7 7. O-O
			variation => N__('Sicilian: Dragon, 6. Bc4 Bg7 7.O-O'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pp1p/3p1np1/8/3NP3/2N5/PPP1BPPP/R1BQK2R b KQkq' => {
			eco => 'B70i',
			# TRANSLATORS: B70i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be2
			variation => N__('Sicilian: Dragon, 6. Be2'),
			moves => {
				'a7a6' => 1,
				'b8c6' => 1,
				'f8g7' => 1,
			},
		},
		'r1bqkb1r/pp2pp1p/2np1np1/8/3NP3/2N5/PPP1BPPP/R1BQK2R w KQkq' => {
			eco => 'B70i',
			# TRANSLATORS: B70i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be2 Nc6
			variation => N__('Sicilian: Dragon, 6. Be2 Nc6'),
			moves => {
			},
		},
		'rnbqkb1r/1p2pp1p/p2p1np1/8/3NP3/2N5/PPP1BPPP/R1BQK2R w KQkq' => {
			eco => 'B70j',
			# TRANSLATORS: B70j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be2 a6
			variation => N__('Sicilian: Dragon, 6. Be2 a6'),
			moves => {
				'a2a4' => 1,
			},
		},
		'rnbqkb1r/1p2pp1p/p2p1np1/8/P2NP3/2N5/1PP1BPPP/R1BQK2R b KQkq' => {
			eco => 'B70j',
			# TRANSLATORS: B70j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be2 a6 7. a4
			variation => N__('Sicilian: Dragon, 6. Be2 a6'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/1p2ppbp/p2p1np1/8/P2NP3/2N5/1PP1BPPP/R1BQK2R w KQkq' => {
			eco => 'B70j',
			# TRANSLATORS: B70j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be2 a6 7. a4 Bg7
			variation => N__('Sicilian: Dragon, 6. Be2 a6 7. a4 Bg7'),
			moves => {
			},
		},
		'rnbqk2r/pp2ppbp/3p1np1/8/3NP3/2N5/PPP1BPPP/R1BQK2R w KQkq' => {
			eco => 'B70k',
			# TRANSLATORS: B70k: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be2 Bg7
			variation => N__('Sicilian: Dragon, 6. Be2 Bg7'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/3p1np1/8/3NP3/2N5/PPP1BPPP/R1BQ1RK1 b kq' => {
			eco => 'B70l',
			# TRANSLATORS: B70l: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be2 Bg7 7. O-O
			variation => N__('Sicilian: Dragon, 6. Be2 Bg7 7.O-O'),
			moves => {
				'b8c6' => 1,
				'e8g8' => 1,
			},
		},
		'r1bqk2r/pp2ppbp/2np1np1/8/3NP3/2N5/PPP1BPPP/R1BQ1RK1 w kq' => {
			eco => 'B70l',
			# TRANSLATORS: B70l: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be2 Bg7 7. O-O Nc6
			variation => N__('Sicilian: Dragon, 6. Be2 Bg7 7.O-O Nc6'),
			moves => {
				'd4b3' => 1,
			},
		},
		'r1bqk2r/pp2ppbp/2np1np1/8/4P3/1NN5/PPP1BPPP/R1BQ1RK1 b kq' => {
			eco => 'B70m',
			# TRANSLATORS: B70m: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be2 Bg7 7. O-O Nc6 8. Nb3
			variation => N__('Sicilian: Dragon, 6. Be2 Bg7 7.O-O Nc6 8. Nb3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/8/4P3/1NN5/PPP1BPPP/R1BQ1RK1 w -' => {
			eco => 'B70n',
			# TRANSLATORS: B70n: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be2 Bg7 7. O-O Nc6 8. Nb3 O-O
			variation => N__('Sicilian: Dragon, 6. Be2 Bg7 7.O-O Nc6 8. Nb3 O-O'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/8/3NP3/2N5/PPP1BPPP/R1BQ1RK1 w -' => {
			eco => 'B70o',
			# TRANSLATORS: B70o: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be2 Bg7 7. O-O O-O
			variation => N__('Sicilian: Dragon, 6. Be2 Bg7 7.O-O O-O'),
			moves => {
				'c1g5' => 1,
				'f1e1' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/8/3NP3/2N5/PPP1BPPP/R1BQR1K1 b -' => {
			eco => 'B70p',
			# TRANSLATORS: B70p: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be2 Bg7 7. O-O O-O 8. Re1
			variation => N__('Sicilian: Dragon, 6. Be2 Bg7 7.O-O O-O 8. Re1'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/8/3NP3/2N5/PPP1BPPP/R1BQR1K1 w -' => {
			eco => 'B70p',
			# TRANSLATORS: B70p: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be2 Bg7 7. O-O O-O 8. Re1 Nc6
			variation => N__('Sicilian: Dragon, 6. Be2 Bg7 7.O-O O-O 8. Re1 Nc6'),
			moves => {
				'd4b3' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/8/4P3/1NN5/PPP1BPPP/R1BQR1K1 b -' => {
			eco => 'B70q',
			# TRANSLATORS: B70q: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be2 Bg7 7. O-O O-O 8. Re1 Nc6 9. Nb3
			variation => N__('Sicilian: Dragon, 6. Be2 Bg7 7.O-O O-O 8. Re1 Nc6 9. Nb3'),
			moves => {
				'c8e6' => 1,
			},
		},
		'r2q1rk1/pp2ppbp/2npbnp1/8/4P3/1NN5/PPP1BPPP/R1BQR1K1 w -' => {
			eco => 'B70r',
			# TRANSLATORS: B70r: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be2 Bg7 7. O-O O-O 8. Re1 Nc6 9. Nb3 Be6
			variation => N__('Sicilian: Dragon, 6. Be2 Bg7 7.O-O O-O 8. Re1 Nc6 9. Nb3 Be6'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/6B1/3NP3/2N5/PPP1BPPP/R2Q1RK1 b -' => {
			eco => 'B70s',
			# TRANSLATORS: B70s: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be2 Bg7 7. O-O O-O 8. Bg5
			variation => N__('Sicilian: Dragon, 6. Be2 Bg7 7.O-O O-O 8. Bg5'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/6B1/3NP3/2N5/PPP1BPPP/R2Q1RK1 w -' => {
			eco => 'B70s',
			# TRANSLATORS: B70s: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be2 Bg7 7. O-O O-O 8. Bg5 Nc6
			variation => N__('Sicilian: Dragon, 6. Be2 Bg7 7.O-O O-O 8. Bg5'),
			moves => {
				'd4b3' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/6B1/4P3/1NN5/PPP1BPPP/R2Q1RK1 b -' => {
			eco => 'B70t',
			# TRANSLATORS: B70t: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be2 Bg7 7. O-O O-O 8. Bg5 Nc6 9. Nb3
			variation => N__('Sicilian: Dragon, 6. Be2 Bg7 7.O-O O-O 8. Bg5 Nc6 9. Nb3'),
			moves => {
				'a7a6' => 1,
				'c8e6' => 1,
			},
		},
		'r1bq1rk1/1p2ppbp/p1np1np1/6B1/4P3/1NN5/PPP1BPPP/R2Q1RK1 w -' => {
			eco => 'B70u',
			# TRANSLATORS: B70u: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be2 Bg7 7. O-O O-O 8. Bg5 Nc6 9. Nb3 a6
			variation => N__('Sicilian: Dragon, 6. Be2 Bg7 7.O-O O-O 8. Bg5 Nc6 9. Nb3 a6'),
			moves => {
			},
		},
		'r2q1rk1/pp2ppbp/2npbnp1/6B1/4P3/1NN5/PPP1BPPP/R2Q1RK1 w -' => {
			eco => 'B70v',
			# TRANSLATORS: B70v: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be2 Bg7 7. O-O O-O 8. Bg5 Nc6 9. Nb3 Be6
			variation => N__('Sicilian: Dragon, 6. Be2 Bg7 7.O-O O-O 8. Bg5 Nc6 9. Nb3 Be6'),
			moves => {
				'g1h1' => 1,
			},
		},
		'r2q1rk1/pp2ppbp/2npbnp1/6B1/4P3/1NN5/PPP1BPPP/R2Q1R1K b -' => {
			eco => 'B70w',
			# TRANSLATORS: B70w: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be2 Bg7 7. O-O O-O 8. Bg5 Nc6 9. Nb3 Be6 10. Kh1
			variation => N__('Sicilian: Dragon, 6. Be2 Bg7 7.O-O O-O 8. Bg5 Nc6 9. Nb3 Be6 10. Kh1'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pp1p/3p1np1/8/3NPP2/2N5/PPP3PP/R1BQKB1R b KQkq' => {
			eco => 'B71',
			# TRANSLATORS: B71: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. f4
			variation => N__('Sicilian: Dragon, Levenfish Variation'),
			moves => {
				'b8c6' => 1,
				'b8d7' => 1,
				'f8g7' => 1,
			},
		},
		'r1bqkb1r/pp2pp1p/2np1np1/8/3NPP2/2N5/PPP3PP/R1BQKB1R w KQkq' => {
			eco => 'B71',
			# TRANSLATORS: B71: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. f4 Nc6
			variation => N__('Sicilian: Dragon, Levenfish, 6... Nc6'),
			moves => {
				'd4c6' => 1,
				'd4f3' => 1,
				'f1b5' => 1,
			},
		},
		'r1bqkb1r/pp2pp1p/2Np1np1/8/4PP2/2N5/PPP3PP/R1BQKB1R b KQkq' => {
			eco => 'B71',
			# TRANSLATORS: B71: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. f4 Nc6 7. Nxc6
			variation => N__('Sicilian: Dragon, Levenfish, 6... Nc6 7.Nxc6'),
			moves => {
			},
		},
		'r1bqkb1r/pp2pp1p/2np1np1/8/4PP2/2N2N2/PPP3PP/R1BQKB1R b KQkq' => {
			eco => 'B71',
			# TRANSLATORS: B71: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. f4 Nc6 7. Nf3
			variation => N__('Sicilian: Dragon, Levenfish, 6... Nc6 7. Nf3'),
			moves => {
			},
		},
		'r1bqkb1r/pp2pp1p/2np1np1/1B6/3NPP2/2N5/PPP3PP/R1BQK2R b KQkq' => {
			eco => 'B71',
			# TRANSLATORS: B71: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. f4 Nc6 7. Bb5
			variation => N__('Sicilian: Dragon, Levenfish, 6... Nc6 7. Bb5'),
			moves => {
			},
		},
		'r1bqkb1r/pp1npp1p/3p1np1/8/3NPP2/2N5/PPP3PP/R1BQKB1R w KQkq' => {
			eco => 'B71',
			# TRANSLATORS: B71: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. f4 Nbd7
			variation => N__('Sicilian: Dragon, Levenfish, 6...Nbd7'),
			moves => {
			},
		},
		'rnbqk2r/pp2ppbp/3p1np1/8/3NPP2/2N5/PPP3PP/R1BQKB1R w KQkq' => {
			eco => 'B71',
			# TRANSLATORS: B71: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. f4 Bg7
			variation => N__('Sicilian: Dragon, Levenfish, 6... Bg7'),
			moves => {
				'e4e5' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/3p1np1/4P3/3N1P2/2N5/PPP3PP/R1BQKB1R b KQkq' => {
			eco => 'B71',
			# TRANSLATORS: B71: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. f4 Bg7 7. e5
			variation => N__('Sicilian: Dragon, Levenfish, 6... Bg7 7. e5'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pp1p/3p1np1/8/3NP3/2N1B3/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'B72',
			# TRANSLATORS: B72: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3
			variation => N__('Sicilian: Dragon, 6. Be3'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/3p1np1/8/3NP3/2N1B3/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B72',
			# TRANSLATORS: B72: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7
			variation => N__('Sicilian: Dragon, 6. Be3 Bg7'),
			moves => {
				'd1d2' => 1,
				'f1c4' => 1,
				'f1e2' => 1,
				'f2f3' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/3p1np1/8/3NP3/2N1B3/PPPQ1PPP/R3KB1R b KQkq' => {
			eco => 'B72',
			# TRANSLATORS: B72: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Qd2
			variation => N__('Sicilian: Dragon, 6. Be3 Bg7 7. Qd2'),
			moves => {
			},
		},
		'rnbqk2r/pp2ppbp/3p1np1/8/2BNP3/2N1B3/PPP2PPP/R2QK2R b KQkq' => {
			eco => 'B72',
			# TRANSLATORS: B72: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Bc4
			variation => N__('Sicilian: Dragon, 6. Be3 Bg7 7. Bc4'),
			moves => {
				'b8c6' => 1,
				'e8g8' => 1,
			},
		},
		'r1bqk2r/pp2ppbp/2np1np1/8/2BNP3/2N1B3/PPP2PPP/R2QK2R w KQkq' => {
			eco => 'B72',
			# TRANSLATORS: B72: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Bc4 Nc6
			variation => N__('Sicilian: Dragon, 6. Be3 Bg7 7. Bc4 Nc6'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/8/2BNP3/2N1B3/PPP2PPP/R2QK2R w KQ' => {
			eco => 'B72',
			# TRANSLATORS: B72: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Bc4 O-O
			variation => N__('Sicilian: Dragon, 6. Be3 Bg7 7. Bc4 O-O'),
			moves => {
			},
		},
		'rnbqk2r/pp2ppbp/3p1np1/8/3NP3/2N1B3/PPP1BPPP/R2QK2R b KQkq' => {
			eco => 'B72',
			# TRANSLATORS: B72: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Be2
			variation => N__('Sicilian: Dragon, Classical Attack'),
			moves => {
				'b8c6' => 1,
				'e8g8' => 1,
			},
		},
		'r1bqk2r/pp2ppbp/2np1np1/8/3NP3/2N1B3/PPP1BPPP/R2QK2R w KQkq' => {
			eco => 'B72',
			# TRANSLATORS: B72: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Be2 Nc6
			variation => N__('Sicilian: Dragon, Classical Attack'),
			moves => {
				'd1d2' => 1,
				'd4b3' => 1,
				'e1g1' => 1,
			},
		},
		'r1bqk2r/pp2ppbp/2np1np1/8/3NP3/2N1B3/PPPQBPPP/R3K2R b KQkq' => {
			eco => 'B72',
			# TRANSLATORS: B72: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Be2 Nc6 8. Qd2
			variation => N__('Sicilian: Dragon, Classical, Amsterdam Variation'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/8/3NP3/2N1B3/PPPQBPPP/R3K2R w KQ' => {
			eco => 'B72',
			# TRANSLATORS: B72: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Be2 Nc6 8. Qd2 O-O
			variation => N__('Sicilian: Dragon, Classical, Amsterdam Variation'),
			moves => {
				'e1c1' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/8/3NP3/2N1B3/PPPQBPPP/2KR3R b -' => {
			eco => 'B72',
			# TRANSLATORS: B72: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Be2 Nc6 8. Qd2 O-O 9. O-O-O
			variation => N__('Sicilian: Dragon, Classical, Grigoriev Variation'),
			moves => {
			},
		},
		'r1bqk2r/pp2ppbp/2np1np1/8/4P3/1NN1B3/PPP1BPPP/R2QK2R b KQkq' => {
			eco => 'B72',
			# TRANSLATORS: B72: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Be2 Nc6 8. Nb3
			variation => N__('Sicilian: Dragon, Classical, Nottingham Variation'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/8/3NP3/2N1B3/PPP1BPPP/R2QK2R w KQ' => {
			eco => 'B72',
			# TRANSLATORS: B72: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Be2 O-O
			variation => N__('Sicilian: Dragon, Classical Attack'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/8/3NP3/2N1B3/PPP1BPPP/R2Q1RK1 b -' => {
			eco => 'B72',
			# TRANSLATORS: B72: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Be2 O-O 8. O-O
			variation => N__('Sicilian: Dragon, Classical Attack'),
			moves => {
			},
		},
		'r1bqk2r/pp2ppbp/2np1np1/8/3NP3/2N1B3/PPP1BPPP/R2Q1RK1 b kq' => {
			eco => 'B73',
			# TRANSLATORS: B73: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Be2 Nc6 8. O-O
			variation => N__('Sicilian: Dragon, Classical, 8.O-O'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/8/3NP3/2N1B3/PPP1BPPP/R2Q1RK1 w -' => {
			eco => 'B73',
			# TRANSLATORS: B73: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Be2 Nc6 8. O-O O-O
			variation => N__('Sicilian: Dragon, Classical, 8.O-O O-O'),
			moves => {
				'd1d2' => 1,
				'd4b3' => 1,
				'f2f4' => 1,
				'g1h1' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/8/3NP3/2N1B3/PPPQBPPP/R4RK1 b -' => {
			eco => 'B73',
			# TRANSLATORS: B73: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Be2 Nc6 8. O-O O-O 9. Qd2
			variation => N__('Sicilian: Dragon, Classical, Richter Variation'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/8/3NPP2/2N1B3/PPP1B1PP/R2Q1RK1 b -' => {
			eco => 'B73',
			# TRANSLATORS: B73: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Be2 Nc6 8. O-O O-O 9. f4
			variation => N__('Sicilian: Dragon, Classical, 9. f4'),
			moves => {
				'd8b6' => 1,
			},
		},
		'r1b2rk1/pp2ppbp/1qnp1np1/8/3NPP2/2N1B3/PPP1B1PP/R2Q1RK1 w -' => {
			eco => 'B73',
			# TRANSLATORS: B73: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Be2 Nc6 8. O-O O-O 9. f4 Qb6
			variation => N__('Sicilian: Dragon, Classical, 9. f4'),
			moves => {
				'e4e5' => 1,
			},
		},
		'r1b2rk1/pp2ppbp/1qnp1np1/4P3/3N1P2/2N1B3/PPP1B1PP/R2Q1RK1 b -' => {
			eco => 'B73',
			# TRANSLATORS: B73: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Be2 Nc6 8. O-O O-O 9. f4 Qb6 10. e5
			variation => N__('Sicilian: Dragon, Classical, Zollner Gambit'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/8/3NP3/2N1B3/PPP1BPPP/R2Q1R1K b -' => {
			eco => 'B73',
			# TRANSLATORS: B73: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Be2 Nc6 8. O-O O-O 9. Kh1
			variation => N__('Sicilian: Dragon, Classical, 9. Kh1'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/8/4P3/1NN1B3/PPP1BPPP/R2Q1RK1 b -' => {
			eco => 'B74',
			# TRANSLATORS: B74: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Be2 Nc6 8. O-O O-O 9. Nb3
			variation => N__('Sicilian: Dragon, Classical, 9. Nb3'),
			moves => {
				'a7a5' => 1,
				'a7a6' => 1,
				'b7b6' => 1,
				'c8e6' => 1,
			},
		},
		'r1bq1rk1/1p2ppbp/2np1np1/p7/4P3/1NN1B3/PPP1BPPP/R2Q1RK1 w -' => {
			eco => 'B74',
			# TRANSLATORS: B74: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Be2 Nc6 8. O-O O-O 9. Nb3 a5
			variation => N__('Sicilian: Dragon, Classical, Alekhine Variation'),
			moves => {
			},
		},
		'r1bq1rk1/1p2ppbp/p1np1np1/8/4P3/1NN1B3/PPP1BPPP/R2Q1RK1 w -' => {
			eco => 'B74',
			# TRANSLATORS: B74: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Be2 Nc6 8. O-O O-O 9. Nb3 a6
			variation => N__('Sicilian: Dragon, Classical, 9. Nb3 a6'),
			moves => {
			},
		},
		'r1bq1rk1/p3ppbp/1pnp1np1/8/4P3/1NN1B3/PPP1BPPP/R2Q1RK1 w -' => {
			eco => 'B74',
			# TRANSLATORS: B74: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Be2 Nc6 8. O-O O-O 9. Nb3 b6
			variation => N__('Sicilian: Dragon, Classical, 9. Nb3 b6'),
			moves => {
			},
		},
		'r2q1rk1/pp2ppbp/2npbnp1/8/4P3/1NN1B3/PPP1BPPP/R2Q1RK1 w -' => {
			eco => 'B74',
			# TRANSLATORS: B74: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Be2 Nc6 8. O-O O-O 9. Nb3 Be6
			variation => N__('Sicilian: Dragon, Classical, 9. Nb3 Be6'),
			moves => {
				'f2f4' => 1,
			},
		},
		'r2q1rk1/pp2ppbp/2npbnp1/8/4PP2/1NN1B3/PPP1B1PP/R2Q1RK1 b -' => {
			eco => 'B74',
			# TRANSLATORS: B74: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Be2 Nc6 8. O-O O-O 9. Nb3 Be6 10. f4
			variation => N__('Sicilian: Dragon, Classical, 9. Nb3 Be6 10. f4'),
			moves => {
				'a8c8' => 1,
				'c6a5' => 1,
				'd8c8' => 1,
			},
		},
		'2rq1rk1/pp2ppbp/2npbnp1/8/4PP2/1NN1B3/PPP1B1PP/R2Q1RK1 w -' => {
			eco => 'B74',
			# TRANSLATORS: B74: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Be2 Nc6 8. O-O O-O 9. Nb3 Be6 10. f4 Rc8
			variation => N__('Sicilian: Dragon, Classical, 9. Nb3 Be6 10. f4 Rc8'),
			moves => {
			},
		},
		'r2q1rk1/pp2ppbp/3pbnp1/n7/4PP2/1NN1B3/PPP1B1PP/R2Q1RK1 w -' => {
			eco => 'B74',
			# TRANSLATORS: B74: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Be2 Nc6 8. O-O O-O 9. Nb3 Be6 10. f4 Na5
			variation => N__('Sicilian: Dragon, Classical, Maroczy Variation'),
			moves => {
				'f4f5' => 1,
			},
		},
		'r2q1rk1/pp2ppbp/3pbnp1/n4P2/4P3/1NN1B3/PPP1B1PP/R2Q1RK1 b -' => {
			eco => 'B74',
			# TRANSLATORS: B74: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Be2 Nc6 8. O-O O-O 9. Nb3 Be6 10. f4 Na5 11. f5
			variation => N__('Sicilian: Dragon, Classical, Maroczy Variation'),
			moves => {
				'e6c4' => 1,
			},
		},
		'r2q1rk1/pp2ppbp/3p1np1/n4P2/2b1P3/1NN1B3/PPP1B1PP/R2Q1RK1 w -' => {
			eco => 'B74',
			# TRANSLATORS: B74: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Be2 Nc6 8. O-O O-O 9. Nb3 Be6 10. f4 Na5 11. f5 Bc4
			variation => N__('Sicilian: Dragon, Classical, Maroczy Variation'),
			moves => {
				'b3a5' => 1,
				'e2d3' => 1,
			},
		},
		'r2q1rk1/pp2ppbp/3p1np1/N4P2/2b1P3/2N1B3/PPP1B1PP/R2Q1RK1 b -' => {
			eco => 'B74',
			# TRANSLATORS: B74: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Be2 Nc6 8. O-O O-O 9. Nb3 Be6 10. f4 Na5 11. f5 Bc4 12. Nxa5
			variation => N__('Sicilian: Dragon, Classical, Maroczy Variation'),
			moves => {
				'c4e2' => 1,
			},
		},
		'r2q1rk1/pp2ppbp/3p1np1/N4P2/4P3/2N1B3/PPP1b1PP/R2Q1RK1 w -' => {
			eco => 'B74',
			# TRANSLATORS: B74: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Be2 Nc6 8. O-O O-O 9. Nb3 Be6 10. f4 Na5 11. f5 Bc4 12. Nxa5 Bxe2
			variation => N__('Sicilian: Dragon, Classical, Maroczy Variation'),
			moves => {
				'd1e2' => 1,
			},
		},
		'r2q1rk1/pp2ppbp/3p1np1/N4P2/4P3/2N1B3/PPP1Q1PP/R4RK1 b -' => {
			eco => 'B74',
			# TRANSLATORS: B74: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Be2 Nc6 8. O-O O-O 9. Nb3 Be6 10. f4 Na5 11. f5 Bc4 12. Nxa5 Bxe2 13. Qxe2
			variation => N__('Sicilian: Dragon, Classical, Maroczy Variation'),
			moves => {
				'd8a5' => 1,
			},
		},
		'r4rk1/pp2ppbp/3p1np1/q4P2/4P3/2N1B3/PPP1Q1PP/R4RK1 w -' => {
			eco => 'B74',
			# TRANSLATORS: B74: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Be2 Nc6 8. O-O O-O 9. Nb3 Be6 10. f4 Na5 11. f5 Bc4 12. Nxa5 Bxe2 13. Qxe2 Qxa5
			variation => N__('Sicilian: Dragon, Classical, Maroczy Variation'),
			moves => {
				'g2g4' => 1,
			},
		},
		'r4rk1/pp2ppbp/3p1np1/q4P2/4P1P1/2N1B3/PPP1Q2P/R4RK1 b -' => {
			eco => 'B74',
			# TRANSLATORS: B74: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Be2 Nc6 8. O-O O-O 9. Nb3 Be6 10. f4 Na5 11. f5 Bc4 12. Nxa5 Bxe2 13. Qxe2 Qxa5 14. g4
			variation => N__('Sicilian: Dragon, Classical, Stockholm Attack'),
			moves => {
			},
		},
		'r2q1rk1/pp2ppbp/3p1np1/n4P2/2b1P3/1NNBB3/PPP3PP/R2Q1RK1 b -' => {
			eco => 'B74',
			# TRANSLATORS: B74: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Be2 Nc6 8. O-O O-O 9. Nb3 Be6 10. f4 Na5 11. f5 Bc4 12. Bd3
			variation => N__('Sicilian: Dragon, Classical, Spielmann Variation'),
			moves => {
				'c4d3' => 1,
			},
		},
		'r2q1rk1/pp2ppbp/3p1np1/n4P2/4P3/1NNbB3/PPP3PP/R2Q1RK1 w -' => {
			eco => 'B74',
			# TRANSLATORS: B74: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Be2 Nc6 8. O-O O-O 9. Nb3 Be6 10. f4 Na5 11. f5 Bc4 12. Bd3 Bxd3
			variation => N__('Sicilian: Dragon, Classical, Spielmann Variation'),
			moves => {
				'c2d3' => 1,
			},
		},
		'r2q1rk1/pp2ppbp/3p1np1/n4P2/4P3/1NNPB3/PP4PP/R2Q1RK1 b -' => {
			eco => 'B74',
			# TRANSLATORS: B74: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Be2 Nc6 8. O-O O-O 9. Nb3 Be6 10. f4 Na5 11. f5 Bc4 12. Bd3 Bxd3 13. cxd3
			variation => N__('Sicilian: Dragon, Classical, Spielmann Variation'),
			moves => {
				'd6d5' => 1,
			},
		},
		'r2q1rk1/pp2ppbp/5np1/n2p1P2/4P3/1NNPB3/PP4PP/R2Q1RK1 w -' => {
			eco => 'B74',
			# TRANSLATORS: B74: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Be2 Nc6 8. O-O O-O 9. Nb3 Be6 10. f4 Na5 11. f5 Bc4 12. Bd3 Bxd3 13. cxd3 d5
			variation => N__('Sicilian: Dragon, Classical, Bernard Defence'),
			moves => {
			},
		},
		'r1q2rk1/pp2ppbp/2npbnp1/8/4PP2/1NN1B3/PPP1B1PP/R2Q1RK1 w -' => {
			eco => 'B74',
			# TRANSLATORS: B74: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. Be2 Nc6 8. O-O O-O 9. Nb3 Be6 10. f4 Qc8
			variation => N__('Sicilian: Dragon, Classical, Tartakower Variation'),
			moves => {
			},
		},
		'rnbqk2r/pp2ppbp/3p1np1/8/3NP3/2N1BP2/PPP3PP/R2QKB1R b KQkq' => {
			eco => 'B75',
			# TRANSLATORS: B75: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3
			variation => N__('Sicilian: Dragon, Yugoslav Attack'),
			moves => {
				'a7a6' => 1,
				'b8c6' => 1,
				'e8g8' => 1,
			},
		},
		'rnbqk2r/1p2ppbp/p2p1np1/8/3NP3/2N1BP2/PPP3PP/R2QKB1R w KQkq' => {
			eco => 'B75',
			# TRANSLATORS: B75: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 a6
			variation => N__('Sicilian: Dragon, Yugoslav, 7... a6'),
			moves => {
			},
		},
		'r1bqk2r/pp2ppbp/2np1np1/8/3NP3/2N1BP2/PPP3PP/R2QKB1R w KQkq' => {
			eco => 'B75',
			# TRANSLATORS: B75: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 Nc6
			variation => N__('Sicilian: Dragon, Yugoslav, 7... Nc6'),
			moves => {
				'd1d2' => 1,
				'f1c4' => 1,
			},
		},
		'r1bqk2r/pp2ppbp/2np1np1/8/3NP3/2N1BP2/PPPQ2PP/R3KB1R b KQkq' => {
			eco => 'B75',
			# TRANSLATORS: B75: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 Nc6 8. Qd2
			variation => N__('Sicilian: Dragon, Yugoslav, 7... Nc6 8. Qd2'),
			moves => {
				'c8d7' => 1,
			},
		},
		'r2qk2r/pp1bppbp/2np1np1/8/3NP3/2N1BP2/PPPQ2PP/R3KB1R w KQkq' => {
			eco => 'B75',
			# TRANSLATORS: B75: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 Nc6 8. Qd2 Bd7
			variation => N__('Sicilian: Dragon, Yugoslav, 7... Nc6 8. Qd2 Bd7'),
			moves => {
				'e1c1' => 1,
			},
		},
		'r2qk2r/pp1bppbp/2np1np1/8/3NP3/2N1BP2/PPPQ2PP/2KR1B1R b kq' => {
			eco => 'B75',
			# TRANSLATORS: B75: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 Nc6 8. Qd2 Bd7 9. O-O-O
			variation => N__('Sicilian: Dragon, Yugoslav, 7... Nc6 8. Qd2 Bd7 9.O-O-O'),
			moves => {
				'a8c8' => 1,
			},
		},
		'2rqk2r/pp1bppbp/2np1np1/8/3NP3/2N1BP2/PPPQ2PP/2KR1B1R w k' => {
			eco => 'B75',
			# TRANSLATORS: B75: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 Nc6 8. Qd2 Bd7 9. O-O-O Rc8
			variation => N__('Sicilian: Dragon, Yugoslav, 7... Nc6 8. Qd2 Bd7 9.O-O-O Rc8'),
			moves => {
			},
		},
		'r1bqk2r/pp2ppbp/2np1np1/8/2BNP3/2N1BP2/PPP3PP/R2QK2R b KQkq' => {
			eco => 'B75',
			# TRANSLATORS: B75: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 Nc6 8. Bc4
			variation => N__('Sicilian: Dragon, Yugoslav, 7... Nc6 8. Bc4'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/8/3NP3/2N1BP2/PPP3PP/R2QKB1R w KQ' => {
			eco => 'B76a',
			# TRANSLATORS: B76a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O
			variation => N__('Sicilian: Dragon, Yugoslav, 7. f3 O-O'),
			moves => {
				'd1d2' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/8/3NP3/2N1BP2/PPPQ2PP/R3KB1R b KQ' => {
			eco => 'B76b',
			# TRANSLATORS: B76b: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2
			variation => N__('Sicilian: Dragon, Yugoslav, 7. f3 O-O 8. Qd2'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/8/3NP3/2N1BP2/PPPQ2PP/R3KB1R w KQ' => {
			eco => 'B76c',
			# TRANSLATORS: B76c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6
			variation => N__('Sicilian: Dragon, Yugoslav, 8. Qd2 Nc6'),
			moves => {
				'e1c1' => 1,
				'f1c4' => 1,
				'g2g4' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/8/3NP1P1/2N1BP2/PPPQ3P/R3KB1R b KQ' => {
			eco => 'B76d',
			# TRANSLATORS: B76d: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. g4
			variation => N__('Sicilian: Dragon, Yugoslav, 9. g4'),
			moves => {
				'c6d4' => 1,
				'c8e6' => 1,
			},
		},
		'r2q1rk1/pp2ppbp/2npbnp1/8/3NP1P1/2N1BP2/PPPQ3P/R3KB1R w KQ' => {
			eco => 'B76e',
			# TRANSLATORS: B76e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. g4 Be6
			variation => N__('Sicilian: Dragon, Yugoslav, 9. g4 Be6'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/3p1np1/8/3nP1P1/2N1BP2/PPPQ3P/R3KB1R w KQ' => {
			eco => 'B76f',
			# TRANSLATORS: B76f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. g4 Nxd4
			variation => N__('Sicilian: Dragon, Yugoslav, 9. g4 Nxd4'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/8/3NP3/2N1BP2/PPPQ2PP/2KR1B1R b -' => {
			eco => 'B76g',
			# TRANSLATORS: B76g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. O-O-O
			variation => N__('Sicilian: Dragon, Yugoslav, 9.O-O-O'),
			moves => {
				'c6d4' => 1,
				'c8d7' => 1,
				'd6d5' => 1,
			},
		},
		'r2q1rk1/pp1bppbp/2np1np1/8/3NP3/2N1BP2/PPPQ2PP/2KR1B1R w -' => {
			eco => 'B76h',
			# TRANSLATORS: B76h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. O-O-O Bd7
			variation => N__('Sicilian: Dragon, Yugoslav, 9.O-O-O Bd7'),
			moves => {
				'g2g4' => 1,
			},
		},
		'r2q1rk1/pp1bppbp/2np1np1/8/3NP1P1/2N1BP2/PPPQ3P/2KR1B1R b -' => {
			eco => 'B76i',
			# TRANSLATORS: B76i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. O-O-O Bd7 10. g4
			variation => N__('Sicilian: Dragon, Yugoslav, 9.O-O-O Bd7 10. g4'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/3p1np1/8/3nP3/2N1BP2/PPPQ2PP/2KR1B1R w -' => {
			eco => 'B76j',
			# TRANSLATORS: B76j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. O-O-O Nxd4
			variation => N__('Sicilian: Dragon, Yugoslav, 9.O-O-O Nxd4'),
			moves => {
				'e3d4' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/3p1np1/8/3BP3/2N2P2/PPPQ2PP/2KR1B1R b -' => {
			eco => 'B76j',
			# TRANSLATORS: B76j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. O-O-O Nxd4 10. Bxd4
			variation => N__('Sicilian: Dragon, Yugoslav, 9.O-O-O Nxd4'),
			moves => {
				'c8e6' => 1,
			},
		},
		'r2q1rk1/pp2ppbp/3pbnp1/8/3BP3/2N2P2/PPPQ2PP/2KR1B1R w -' => {
			eco => 'B76k',
			# TRANSLATORS: B76k: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. O-O-O Nxd4 10. Bxd4 Be6
			variation => N__('Sicilian: Dragon, Yugoslav, 9.O-O-O Nxd4 10.Bxd4 Be6'),
			moves => {
				'c1b1' => 1,
			},
		},
		'r2q1rk1/pp2ppbp/3pbnp1/8/3BP3/2N2P2/PPPQ2PP/1K1R1B1R b -' => {
			eco => 'B76l',
			# TRANSLATORS: B76l: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. O-O-O Nxd4 10. Bxd4 Be6 11. Kb1
			variation => N__('Sicilian: Dragon, Yugoslav, 9.O-O-O Nxd4: 11. Kb1'),
			moves => {
				'd8c7' => 1,
			},
		},
		'r4rk1/ppq1ppbp/3pbnp1/8/3BP3/2N2P2/PPPQ2PP/1K1R1B1R w -' => {
			eco => 'B76m',
			# TRANSLATORS: B76m: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. O-O-O Nxd4 10. Bxd4 Be6 11. Kb1 Qc7
			variation => N__('Sicilian: Dragon, Yugoslav, 9.O-O-O Nxd4: 11. Kb1 Qc7'),
			moves => {
				'g2g4' => 1,
			},
		},
		'r4rk1/ppq1ppbp/3pbnp1/8/3BP1P1/2N2P2/PPPQ3P/1K1R1B1R b -' => {
			eco => 'B76n',
			# TRANSLATORS: B76n: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. O-O-O Nxd4 10. Bxd4 Be6 11. Kb1 Qc7 12. g4
			variation => N__('Sicilian: Dragon, Yugoslav, 9.O-O-O Nxd4: 11. Kb1 Qc7 12. g4'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/2n2np1/3p4/3NP3/2N1BP2/PPPQ2PP/2KR1B1R w -' => {
			eco => 'B76o',
			# TRANSLATORS: B76o: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. O-O-O d5
			variation => N__('Sicilian: Dragon, Yugoslav, 9.O-O-O d5'),
			moves => {
				'd2e1' => 1,
				'e4d5' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2n2np1/3p4/3NP3/2N1BP2/PPP3PP/2KRQB1R b -' => {
			eco => 'B76p',
			# TRANSLATORS: B76p: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. O-O-O d5 10. Qe1
			variation => N__('Sicilian: Dragon, Yugoslav, 9.O-O-O d5 10. Qe1'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/2n2np1/3P4/3N4/2N1BP2/PPPQ2PP/2KR1B1R b -' => {
			eco => 'B76q',
			# TRANSLATORS: B76q: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. O-O-O d5 10. exd5
			variation => N__('Sicilian: Dragon, Yugoslav, 9.O-O-O d5 10.exd5'),
			moves => {
				'f6d5' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2n3p1/3n4/3N4/2N1BP2/PPPQ2PP/2KR1B1R w -' => {
			eco => 'B76q',
			# TRANSLATORS: B76q: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. O-O-O d5 10. exd5 Nxd5
			variation => N__('Sicilian: Dragon, Yugoslav, 9.O-O-O d5 10.exd5'),
			moves => {
				'd4c6' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2N3p1/3n4/8/2N1BP2/PPPQ2PP/2KR1B1R b -' => {
			eco => 'B76q',
			# TRANSLATORS: B76q: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. O-O-O d5 10. exd5 Nxd5 11. Nxc6
			variation => N__('Sicilian: Dragon, Yugoslav, 9.O-O-O d5 10.exd5 Nxd5 11.Nxc6'),
			moves => {
				'b7c6' => 1,
			},
		},
		'r1bq1rk1/p3ppbp/2p3p1/3n4/8/2N1BP2/PPPQ2PP/2KR1B1R w -' => {
			eco => 'B76q',
			# TRANSLATORS: B76q: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. O-O-O d5 10. exd5 Nxd5 11. Nxc6 bxc6
			variation => N__('Sicilian: Dragon, Yugoslav, 9.O-O-O d5 10.exd5 Nxd5 11.Nxc6'),
			moves => {
				'c3d5' => 1,
				'e3d4' => 1,
			},
		},
		'r1bq1rk1/p3ppbp/2p3p1/3N4/8/4BP2/PPPQ2PP/2KR1B1R b -' => {
			eco => 'B76r',
			# TRANSLATORS: B76r: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. O-O-O d5 10. exd5 Nxd5 11. Nxc6 bxc6 12. Nxd5
			variation => N__('Sicilian: Dragon, Yugoslav, 9.O-O-O d5: 12.Nxd5'),
			moves => {
			},
		},
		'r1bq1rk1/p3ppbp/2p3p1/3n4/3B4/2N2P2/PPPQ2PP/2KR1B1R b -' => {
			eco => 'B76s',
			# TRANSLATORS: B76s: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. O-O-O d5 10. exd5 Nxd5 11. Nxc6 bxc6 12. Bd4
			variation => N__('Sicilian: Dragon, Yugoslav, 9.O-O-O d5: 12. Bd4'),
			moves => {
				'e7e5' => 1,
			},
		},
		'r1bq1rk1/p4pbp/2p3p1/3np3/3B4/2N2P2/PPPQ2PP/2KR1B1R w -' => {
			eco => 'B76t',
			# TRANSLATORS: B76t: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. O-O-O d5 10. exd5 Nxd5 11. Nxc6 bxc6 12. Bd4 e5
			variation => N__('Sicilian: Dragon, Yugoslav, 9.O-O-O d5: 12. Bd4 e5'),
			moves => {
				'd4c5' => 1,
			},
		},
		'r1bq1rk1/p4pbp/2p3p1/2Bnp3/8/2N2P2/PPPQ2PP/2KR1B1R b -' => {
			eco => 'B76t',
			# TRANSLATORS: B76t: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. O-O-O d5 10. exd5 Nxd5 11. Nxc6 bxc6 12. Bd4 e5 13. Bc5
			variation => N__('Sicilian: Dragon, Yugoslav, 9.O-O-O d5: 12. Bd4 e5'),
			moves => {
				'c8e6' => 1,
			},
		},
		'r2q1rk1/p4pbp/2p1b1p1/2Bnp3/8/2N2P2/PPPQ2PP/2KR1B1R w -' => {
			eco => 'B76u',
			# TRANSLATORS: B76u: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. O-O-O d5 10. exd5 Nxd5 11. Nxc6 bxc6 12. Bd4 e5 13. Bc5 Be6
			variation => N__('Sicilian: Dragon, Yugoslav, 9.O-O-O d5: 12. Bd4 e5 13. Bc5 Be6'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/8/2BNP3/2N1BP2/PPPQ2PP/R3K2R b KQ' => {
			eco => 'B77a',
			# TRANSLATORS: B77a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4
			variation => N__('Sicilian: Dragon, Yugoslav, 9. Bc4'),
			moves => {
				'a7a5' => 1,
				'c6d4' => 1,
				'c6e5' => 1,
				'c8d7' => 1,
				'f6d7' => 1,
			},
		},
		'r1bq1rk1/1p2ppbp/2np1np1/p7/2BNP3/2N1BP2/PPPQ2PP/R3K2R w KQ' => {
			eco => 'B77b',
			# TRANSLATORS: B77b: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 a5
			variation => N__('Sicilian: Dragon, Yugoslav, Byrne Variation'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/3p1np1/4n3/2BNP3/2N1BP2/PPPQ2PP/R3K2R w KQ' => {
			eco => 'B77c',
			# TRANSLATORS: B77c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Ne5
			variation => N__('Sicilian: Dragon, Yugoslav, 9. Bc4 Ne5'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nppbp/2np2p1/8/2BNP3/2N1BP2/PPPQ2PP/R3K2R w KQ' => {
			eco => 'B77d',
			# TRANSLATORS: B77d: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Nd7
			variation => N__('Sicilian: Dragon, Yugoslav, 9. Bc4 Nd7'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/3p1np1/8/2BnP3/2N1BP2/PPPQ2PP/R3K2R w KQ' => {
			eco => 'B77e',
			# TRANSLATORS: B77e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Nxd4
			variation => N__('Sicilian: Dragon, Yugoslav, 9. Bc4 Nxd4'),
			moves => {
			},
		},
		'r2q1rk1/pp1bppbp/2np1np1/8/2BNP3/2N1BP2/PPPQ2PP/R3K2R w KQ' => {
			eco => 'B77f',
			# TRANSLATORS: B77f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7
			variation => N__('Sicilian: Dragon, Yugoslav, 9. Bc4 Bd7'),
			moves => {
				'c4b3' => 1,
				'e1c1' => 1,
				'g2g4' => 1,
				'h2h4' => 1,
			},
		},
		'r2q1rk1/pp1bppbp/2np1np1/8/3NP3/1BN1BP2/PPPQ2PP/R3K2R b KQ' => {
			eco => 'B77g',
			# TRANSLATORS: B77g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. Bb3
			variation => N__('Sicilian: Dragon, Yugoslav, 9. Bc4 Bd7 10. Bb3'),
			moves => {
			},
		},
		'r2q1rk1/pp1bppbp/2np1np1/8/2BNP1P1/2N1BP2/PPPQ3P/R3K2R b KQ' => {
			eco => 'B77h',
			# TRANSLATORS: B77h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. g4
			variation => N__('Sicilian: Dragon, Yugoslav, 9. Bc4 Bd7 10. g4'),
			moves => {
			},
		},
		'r2q1rk1/pp1bppbp/2np1np1/8/2BNP2P/2N1BP2/PPPQ2P1/R3K2R b KQ' => {
			eco => 'B77i',
			# TRANSLATORS: B77i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. h4
			variation => N__('Sicilian: Dragon, Yugoslav, 9. Bc4 Bd7 10. h4'),
			moves => {
				'a8c8' => 1,
			},
		},
		'2rq1rk1/pp1bppbp/2np1np1/8/2BNP2P/2N1BP2/PPPQ2P1/R3K2R w KQ' => {
			eco => 'B77j',
			# TRANSLATORS: B77j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. h4 Rc8
			variation => N__('Sicilian: Dragon, Yugoslav, 9. Bc4 Bd7 10. h4 Rc8'),
			moves => {
			},
		},
		'r2q1rk1/pp1bppbp/2np1np1/8/2BNP3/2N1BP2/PPPQ2PP/2KR3R b -' => {
			eco => 'B78a',
			# TRANSLATORS: B78a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O
			variation => N__('Sicilian: Dragon, Yugoslav, 10.O-O-O'),
			moves => {
				'a8c8' => 1,
				'c6e5' => 1,
				'd8a5' => 1,
			},
		},
		'r2q1rk1/pp1bppbp/3p1np1/4n3/2BNP3/2N1BP2/PPPQ2PP/2KR3R w -' => {
			eco => 'B78b',
			# TRANSLATORS: B78b: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O Ne5
			variation => N__('Sicilian: Dragon, Yugoslav, 10.O-O-O Ne5'),
			moves => {
			},
		},
		'2rq1rk1/pp1bppbp/2np1np1/8/2BNP3/2N1BP2/PPPQ2PP/2KR3R w -' => {
			eco => 'B78c',
			# TRANSLATORS: B78c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O Rc8
			variation => N__('Sicilian: Dragon, Yugoslav, 10.O-O-O Rc8'),
			moves => {
				'c4b3' => 1,
			},
		},
		'2rq1rk1/pp1bppbp/2np1np1/8/3NP3/1BN1BP2/PPPQ2PP/2KR3R b -' => {
			eco => 'B78c',
			# TRANSLATORS: B78c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O Rc8 11. Bb3
			variation => N__('Sicilian: Dragon, Yugoslav, 10.O-O-O Rc8 11. Bb3'),
			moves => {
				'c6e5' => 1,
			},
		},
		'2rq1rk1/pp1bppbp/3p1np1/4n3/3NP3/1BN1BP2/PPPQ2PP/2KR3R w -' => {
			eco => 'B78d',
			# TRANSLATORS: B78d: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O Rc8 11. Bb3 Ne5
			variation => N__('Sicilian: Dragon, Yugoslav, Modern Main Line'),
			moves => {
				'c1b1' => 1,
				'h2h4' => 1,
			},
		},
		'2rq1rk1/pp1bppbp/3p1np1/4n3/3NP3/1BN1BP2/PPPQ2PP/1K1R3R b -' => {
			eco => 'B78e',
			# TRANSLATORS: B78e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O Rc8 11. Bb3 Ne5 12. Kb1
			variation => N__('Sicilian: Dragon, Yugoslav, Main Line, 12. Kb1'),
			moves => {
				'e5c4' => 1,
			},
		},
		'2rq1rk1/pp1bppbp/3p1np1/8/2nNP3/1BN1BP2/PPPQ2PP/1K1R3R w -' => {
			eco => 'B78e',
			# TRANSLATORS: B78e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O Rc8 11. Bb3 Ne5 12. Kb1 Nc4
			variation => N__('Sicilian: Dragon, Yugoslav, Main Line, 12. Kb1'),
			moves => {
				'b3c4' => 1,
			},
		},
		'2rq1rk1/pp1bppbp/3p1np1/8/2BNP3/2N1BP2/PPPQ2PP/1K1R3R b -' => {
			eco => 'B78e',
			# TRANSLATORS: B78e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O Rc8 11. Bb3 Ne5 12. Kb1 Nc4 13. Bxc4
			variation => N__('Sicilian: Dragon, Yugoslav, Main Line, 12. Kb1'),
			moves => {
				'c8c4' => 1,
			},
		},
		'3q1rk1/pp1bppbp/3p1np1/8/2rNP3/2N1BP2/PPPQ2PP/1K1R3R w -' => {
			eco => 'B78e',
			# TRANSLATORS: B78e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O Rc8 11. Bb3 Ne5 12. Kb1 Nc4 13. Bxc4 Rxc4
			variation => N__('Sicilian: Dragon, Yugoslav, Main Line, 12. Kb1'),
			moves => {
				'g2g4' => 1,
			},
		},
		'3q1rk1/pp1bppbp/3p1np1/8/2rNP1P1/2N1BP2/PPPQ3P/1K1R3R b -' => {
			eco => 'B78e',
			# TRANSLATORS: B78e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O Rc8 11. Bb3 Ne5 12. Kb1 Nc4 13. Bxc4 Rxc4 14. g4
			variation => N__('Sicilian: Dragon, Yugoslav, Main Line, 12. Kb1'),
			moves => {
				'b7b5' => 1,
			},
		},
		'3q1rk1/p2bppbp/3p1np1/1p6/2rNP1P1/2N1BP2/PPPQ3P/1K1R3R w -' => {
			eco => 'B78f',
			# TRANSLATORS: B78f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O Rc8 11. Bb3 Ne5 12. Kb1 Nc4 13. Bxc4 Rxc4 14. g4 b5
			variation => N__('Sicilian: Dragon, Yugoslav, Main Line, 12. Kb1: 14. g4 b5'),
			moves => {
			},
		},
		'2rq1rk1/pp1bppbp/3p1np1/4n3/3NP2P/1BN1BP2/PPPQ2P1/2KR3R b -' => {
			eco => 'B78g',
			# TRANSLATORS: B78g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O Rc8 11. Bb3 Ne5 12. h4
			variation => N__('Sicilian: Dragon, Yugoslav, Main Line, 12. h4'),
			moves => {
				'e5c4' => 1,
				'h7h5' => 1,
			},
		},
		'2rq1rk1/pp1bppbp/3p1np1/8/2nNP2P/1BN1BP2/PPPQ2P1/2KR3R w -' => {
			eco => 'B78g',
			# TRANSLATORS: B78g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O Rc8 11. Bb3 Ne5 12. h4 Nc4
			variation => N__('Sicilian: Dragon, Yugoslav, Main Line, 12. h4 Nc4'),
			moves => {
				'b3c4' => 1,
			},
		},
		'2rq1rk1/pp1bppbp/3p1np1/8/2BNP2P/2N1BP2/PPPQ2P1/2KR3R b -' => {
			eco => 'B78g',
			# TRANSLATORS: B78g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O Rc8 11. Bb3 Ne5 12. h4 Nc4 13. Bxc4
			variation => N__('Sicilian: Dragon, Yugoslav, Main Line, 12. h4 Nc4'),
			moves => {
				'c8c4' => 1,
			},
		},
		'3q1rk1/pp1bppbp/3p1np1/8/2rNP2P/2N1BP2/PPPQ2P1/2KR3R w -' => {
			eco => 'B78g',
			# TRANSLATORS: B78g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O Rc8 11. Bb3 Ne5 12. h4 Nc4 13. Bxc4 Rxc4
			variation => N__('Sicilian: Dragon, Yugoslav, Main Line, 12. h4 Nc4'),
			moves => {
				'g2g4' => 1,
				'h4h5' => 1,
			},
		},
		'3q1rk1/pp1bppbp/3p1np1/8/2rNP1PP/2N1BP2/PPPQ4/2KR3R b -' => {
			eco => 'B78h',
			# TRANSLATORS: B78h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O Rc8 11. Bb3 Ne5 12. h4 Nc4 13. Bxc4 Rxc4 14. g4
			variation => N__('Sicilian: Dragon, Yugoslav, Main Line, 12. h4 Nc4: 14. g4'),
			moves => {
			},
		},
		'3q1rk1/pp1bppbp/3p1np1/7P/2rNP3/2N1BP2/PPPQ2P1/2KR3R b -' => {
			eco => 'B78i',
			# TRANSLATORS: B78i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O Rc8 11. Bb3 Ne5 12. h4 Nc4 13. Bxc4 Rxc4 14. h5
			variation => N__('Sicilian: Dragon, Yugoslav, Main Line, 12. h4 Nc4: 14. h5'),
			moves => {
			},
		},
		'2rq1rk1/pp1bppb1/3p1np1/4n2p/3NP2P/1BN1BP2/PPPQ2P1/2KR3R w -' => {
			eco => 'B78j',
			# TRANSLATORS: B78j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O Rc8 11. Bb3 Ne5 12. h4 h5
			variation => N__('Sicilian: Dragon, Yugoslav, Main Line, 12. h4 h5'),
			moves => {
				'c1b1' => 1,
				'e3g5' => 1,
				'e3h6' => 1,
			},
		},
		'2rq1rk1/pp1bppb1/3p1np1/4n2p/3NP2P/1BN1BP2/PPPQ2P1/1K1R3R b -' => {
			eco => 'B78k',
			# TRANSLATORS: B78k: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O Rc8 11. Bb3 Ne5 12. h4 h5 13. Kb1
			variation => N__('Sicilian: Dragon, Yugoslav, Main Line, 12. h4 h5 13. Kb1'),
			moves => {
			},
		},
		'2rq1rk1/pp1bppb1/3p1npB/4n2p/3NP2P/1BN2P2/PPPQ2P1/2KR3R b -' => {
			eco => 'B78l',
			# TRANSLATORS: B78l: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O Rc8 11. Bb3 Ne5 12. h4 h5 13. Bh6
			variation => N__('Sicilian: Dragon, Yugoslav, Main Line, 12. h4 h5 13. Bh6'),
			moves => {
				'g7h6' => 1,
			},
		},
		'2rq1rk1/pp1bpp2/3p1npb/4n2p/3NP2P/1BN2P2/PPPQ2P1/2KR3R w -' => {
			eco => 'B78m',
			# TRANSLATORS: B78m: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O Rc8 11. Bb3 Ne5 12. h4 h5 13. Bh6 Bxh6
			variation => N__('Sicilian: Dragon, Yugoslav, Main Line, 12. h4 h5 13. Bh6 Bxh6'),
			moves => {
			},
		},
		'2rq1rk1/pp1bppb1/3p1np1/4n1Bp/3NP2P/1BN2P2/PPPQ2P1/2KR3R b -' => {
			eco => 'B78n',
			# TRANSLATORS: B78n: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O Rc8 11. Bb3 Ne5 12. h4 h5 13. Bg5
			variation => N__('Sicilian: Dragon, Yugoslav, Main Line, 12. h4 h5 13. Bg5'),
			moves => {
				'c8c5' => 1,
			},
		},
		'3q1rk1/pp1bppb1/3p1np1/2r1n1Bp/3NP2P/1BN2P2/PPPQ2P1/2KR3R w -' => {
			eco => 'B78o',
			# TRANSLATORS: B78o: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O Rc8 11. Bb3 Ne5 12. h4 h5 13. Bg5 Rc5
			variation => N__('Sicilian: Dragon, Yugoslav, Main Line, 12. h4 h5 13. Bg5 Rc5'),
			moves => {
				'c1b1' => 1,
				'g2g4' => 1,
			},
		},
		'3q1rk1/pp1bppb1/3p1np1/2r1n1Bp/3NP1PP/1BN2P2/PPPQ4/2KR3R b -' => {
			eco => 'B78p',
			# TRANSLATORS: B78p: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O Rc8 11. Bb3 Ne5 12. h4 h5 13. Bg5 Rc5 14. g4
			variation => N__('Sicilian: Dragon, Yugoslav, Main Line, 12. h4 h5 13. Bg5 Rc5 14. g4'),
			moves => {
			},
		},
		'3q1rk1/pp1bppb1/3p1np1/2r1n1Bp/3NP2P/1BN2P2/PPPQ2P1/1K1R3R b -' => {
			eco => 'B78q',
			# TRANSLATORS: B78q: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O Rc8 11. Bb3 Ne5 12. h4 h5 13. Bg5 Rc5 14. Kb1
			variation => N__('Sicilian: Dragon, Yugoslav, Main Line, 12. h4 h5 13. Bg5 Rc5 14. Kb1'),
			moves => {
			},
		},
		'r4rk1/pp1bppbp/2np1np1/q7/2BNP3/2N1BP2/PPPQ2PP/2KR3R w -' => {
			eco => 'B78r',
			# TRANSLATORS: B78r: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O Qa5
			variation => N__('Sicilian: Dragon, Yugoslav, Old Main Line'),
			moves => {
				'c4b3' => 1,
			},
		},
		'r4rk1/pp1bppbp/2np1np1/q7/3NP3/1BN1BP2/PPPQ2PP/2KR3R b -' => {
			eco => 'B78r',
			# TRANSLATORS: B78r: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O Qa5 11. Bb3
			variation => N__('Sicilian: Dragon, Yugoslav, Old Main Line'),
			moves => {
				'a8c8' => 1,
				'f8c8' => 1,
			},
		},
		'2r2rk1/pp1bppbp/2np1np1/q7/3NP3/1BN1BP2/PPPQ2PP/2KR3R w -' => {
			eco => 'B78s',
			# TRANSLATORS: B78s: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O Qa5 11. Bb3 Rac8
			variation => N__('Sicilian: Dragon, Yugoslav, Old Main Line, 11. Bb3 Rac8'),
			moves => {
			},
		},
		'r1r3k1/pp1bppbp/2np1np1/q7/3NP3/1BN1BP2/PPPQ2PP/2KR3R w -' => {
			eco => 'B78t',
			# TRANSLATORS: B78t: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O Qa5 11. Bb3 Rfc8
			variation => N__('Sicilian: Dragon, Yugoslav, Old Main Line, 11. Bb3 Rfc8'),
			moves => {
				'h2h4' => 1,
			},
		},
		'r1r3k1/pp1bppbp/2np1np1/q7/3NP2P/1BN1BP2/PPPQ2P1/2KR3R b -' => {
			eco => 'B79a',
			# TRANSLATORS: B79a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O Qa5 11. Bb3 Rfc8 12. h4
			variation => N__('Sicilian: Dragon, Yugoslav, Old Main Line, 12. h4'),
			moves => {
				'c6e5' => 1,
				'h7h5' => 1,
			},
		},
		'r1r3k1/pp1bppb1/2np1np1/q6p/3NP2P/1BN1BP2/PPPQ2P1/2KR3R w -' => {
			eco => 'B79a',
			# TRANSLATORS: B79a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O Qa5 11. Bb3 Rfc8 12. h4 h5
			variation => N__('Sicilian: Dragon, Yugoslav, Old Main Line, 12. h4 h5'),
			moves => {
			},
		},
		'r1r3k1/pp1bppbp/3p1np1/q3n3/3NP2P/1BN1BP2/PPPQ2P1/2KR3R w -' => {
			eco => 'B79b',
			# TRANSLATORS: B79b: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O Qa5 11. Bb3 Rfc8 12. h4 Ne5
			variation => N__('Sicilian: Dragon, Yugoslav, Old Main Line, 12. h4 Ne5'),
			moves => {
				'c1b1' => 1,
				'g2g4' => 1,
				'h4h5' => 1,
			},
		},
		'r1r3k1/pp1bppbp/3p1np1/q3n3/3NP2P/1BN1BP2/PPPQ2P1/1K1R3R b -' => {
			eco => 'B79c',
			# TRANSLATORS: B79c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O Qa5 11. Bb3 Rfc8 12. h4 Ne5 13. Kb1
			variation => N__('Sicilian: Dragon, Yugoslav, Old Main Line, 12. h4 Ne5 13. Kb1'),
			moves => {
				'e5c4' => 1,
			},
		},
		'r1r3k1/pp1bppbp/3p1np1/q7/2nNP2P/1BN1BP2/PPPQ2P1/1K1R3R w -' => {
			eco => 'B79d',
			# TRANSLATORS: B79d: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O Qa5 11. Bb3 Rfc8 12. h4 Ne5 13. Kb1 Nc4
			variation => N__('Sicilian: Dragon, Yugoslav, Old Main Line, 12. h4 Ne5 13. Kb1 Nc4'),
			moves => {
			},
		},
		'r1r3k1/pp1bppbp/3p1np1/q3n3/3NP1PP/1BN1BP2/PPPQ4/2KR3R b -' => {
			eco => 'B79e',
			# TRANSLATORS: B79e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O Qa5 11. Bb3 Rfc8 12. h4 Ne5 13. g4
			variation => N__('Sicilian: Dragon, Yugoslav, Old Main Line, 12. h4 Ne5 13. g4'),
			moves => {
			},
		},
		'r1r3k1/pp1bppbp/3p1np1/q3n2P/3NP3/1BN1BP2/PPPQ2P1/2KR3R b -' => {
			eco => 'B79f',
			# TRANSLATORS: B79f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 g6 6. Be3 Bg7 7. f3 O-O 8. Qd2 Nc6 9. Bc4 Bd7 10. O-O-O Qa5 11. Bb3 Rfc8 12. h4 Ne5 13. h5
			variation => N__('Sicilian: Dragon, Yugoslav, Old Main Line, 12. h4 Ne5 13. h5'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/3ppn2/8/3NP3/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B80a',
			# TRANSLATORS: B80a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6
			variation => N__('Sicilian: Scheveningen'),
			moves => {
				'c1e3' => 1,
				'f1b5' => 1,
				'f1c4' => 1,
				'f1e2' => 1,
				'f2f4' => 1,
				'g2g3' => 1,
				'g2g4' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/3ppn2/8/3NP3/2N1B3/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'B80b',
			# TRANSLATORS: B80b: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be3
			variation => N__('Sicilian: Scheveningen, 6. Be3'),
			moves => {
				'a7a6' => 1,
				'b8c6' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2nppn2/8/3NP3/2N1B3/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B80c',
			# TRANSLATORS: B80c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be3 Nc6
			variation => N__('Sicilian: Scheveningen, 6. Be3 Nc6'),
			moves => {
				'f2f3' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2nppn2/8/3NP3/2N1BP2/PPP3PP/R2QKB1R b KQkq' => {
			eco => 'B80d',
			# TRANSLATORS: B80d: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be3 Nc6 7. f3
			variation => N__('Sicilian: Scheveningen, 6. Be3 Nc6'),
			moves => {
			},
		},
		'rnbqkb1r/1p3ppp/p2ppn2/8/3NP3/2N1B3/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B80e',
			# TRANSLATORS: B80e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be3 a6
			variation => N__('Sicilian: Scheveningen, 6. Be3 a6'),
			moves => {
				'd1d2' => 1,
				'f2f3' => 1,
			},
		},
		'rnbqkb1r/1p3ppp/p2ppn2/8/3NP3/2N1B3/PPPQ1PPP/R3KB1R b KQkq' => {
			eco => 'B80f',
			# TRANSLATORS: B80f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be3 a6 7. Qd2
			variation => N__('Sicilian: Scheveningen, 7. Qd2'),
			moves => {
			},
		},
		'rnbqkb1r/1p3ppp/p2ppn2/8/3NP3/2N1BP2/PPP3PP/R2QKB1R b KQkq' => {
			eco => 'B80g',
			# TRANSLATORS: B80g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be3 a6 7. f3
			variation => N__('Sicilian: Scheveningen, English Attack'),
			moves => {
				'b7b5' => 1,
				'b8c6' => 1,
			},
		},
		'r1bqkb1r/1p3ppp/p1nppn2/8/3NP3/2N1BP2/PPP3PP/R2QKB1R w KQkq' => {
			eco => 'B80h',
			# TRANSLATORS: B80h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be3 a6 7. f3 Nc6
			variation => N__('Sicilian: Scheveningen, English Attack, 7... Nc6'),
			moves => {
				'd1d2' => 1,
			},
		},
		'r1bqkb1r/1p3ppp/p1nppn2/8/3NP3/2N1BP2/PPPQ2PP/R3KB1R b KQkq' => {
			eco => 'B80h',
			# TRANSLATORS: B80h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be3 a6 7. f3 Nc6 8. Qd2
			variation => N__('Sicilian: Scheveningen, English, 7... Nc6 8. Qd2'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r1bqk2r/1p2bppp/p1nppn2/8/3NP3/2N1BP2/PPPQ2PP/R3KB1R w KQkq' => {
			eco => 'B80i',
			# TRANSLATORS: B80i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be3 a6 7. f3 Nc6 8. Qd2 Be7
			variation => N__('Sicilian: Scheveningen, English, 7... Nc6 8. Qd2'),
			moves => {
			},
		},
		'rnbqkb1r/5ppp/p2ppn2/1p6/3NP3/2N1BP2/PPP3PP/R2QKB1R w KQkq' => {
			eco => 'B80j',
			# TRANSLATORS: B80j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be3 a6 7. f3 b5
			variation => N__('Sicilian: Scheveningen, English Attack, 7... b5'),
			moves => {
				'd1d2' => 1,
			},
		},
		'rnbqkb1r/5ppp/p2ppn2/1p6/3NP3/2N1BP2/PPPQ2PP/R3KB1R b KQkq' => {
			eco => 'B80k',
			# TRANSLATORS: B80k: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be3 a6 7. f3 b5 8. Qd2
			variation => N__('Sicilian: Scheveningen, English, 7... b5 8. Qd2'),
			moves => {
				'b8d7' => 1,
				'c8b7' => 1,
			},
		},
		'rn1qkb1r/1b3ppp/p2ppn2/1p6/3NP3/2N1BP2/PPPQ2PP/R3KB1R w KQkq' => {
			eco => 'B80l',
			# TRANSLATORS: B80l: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be3 a6 7. f3 b5 8. Qd2 Bb7
			variation => N__('Sicilian: Scheveningen, English, 7... b5, 8. Qd2 Bb7'),
			moves => {
				'g2g4' => 1,
			},
		},
		'rn1qkb1r/1b3ppp/p2ppn2/1p6/3NP1P1/2N1BP2/PPPQ3P/R3KB1R b KQkq' => {
			eco => 'B80l',
			# TRANSLATORS: B80l: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be3 a6 7. f3 b5 8. Qd2 Bb7 9. g4
			variation => N__('Sicilian: Scheveningen, English, 7... b5 8. Qd2 Bb7'),
			moves => {
			},
		},
		'r1bqkb1r/3n1ppp/p2ppn2/1p6/3NP3/2N1BP2/PPPQ2PP/R3KB1R w KQkq' => {
			eco => 'B80m',
			# TRANSLATORS: B80m: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be3 a6 7. f3 b5 8. Qd2 Nbd7
			variation => N__('Sicilian: Scheveningen, English, 7... b5 8. Qd2 Nbd7'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/3ppn2/1B6/3NP3/2N5/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'B80n',
			# TRANSLATORS: B80n: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Bb5+
			variation => N__('Sicilian: Scheveningen, Vitolins Variation'),
			moves => {
				'c8d7' => 1,
			},
		},
		'rn1qkb1r/pp1b1ppp/3ppn2/1B6/3NP3/2N5/PPP2PPP/R1BQK2R w KQkq' => {
			eco => 'B80n',
			# TRANSLATORS: B80n: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Bb5+ Bd7
			variation => N__('Sicilian: Scheveningen, Vitolins, 6... Bd7'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/3ppn2/8/3NP3/2N3P1/PPP2P1P/R1BQKB1R b KQkq' => {
			eco => 'B80o',
			# TRANSLATORS: B80o: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g3
			variation => N__('Sicilian: Scheveningen, Fianchetto Variation'),
			moves => {
				'a7a6' => 1,
				'b8c6' => 1,
			},
		},
		'rnbqkb1r/1p3ppp/p2ppn2/8/3NP3/2N3P1/PPP2P1P/R1BQKB1R w KQkq' => {
			eco => 'B80p',
			# TRANSLATORS: B80p: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g3 a6
			variation => N__('Sicilian: Scheveningen, Fianchetto Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2nppn2/8/3NP3/2N3P1/PPP2P1P/R1BQKB1R w KQkq' => {
			eco => 'B80q',
			# TRANSLATORS: B80q: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g3 Nc6
			variation => N__('Sicilian: Scheveningen, Fianchetto Variation'),
			moves => {
				'f1g2' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2nppn2/8/3NP3/2N3P1/PPP2PBP/R1BQK2R b KQkq' => {
			eco => 'B80q',
			# TRANSLATORS: B80q: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g3 Nc6 7. Bg2
			variation => N__('Sicilian: Scheveningen, Fianchetto Variation'),
			moves => {
				'a7a6' => 1,
				'd8c7' => 1,
			},
		},
		'r1bqkb1r/1p3ppp/p1nppn2/8/3NP3/2N3P1/PPP2PBP/R1BQK2R w KQkq' => {
			eco => 'B80r',
			# TRANSLATORS: B80r: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g3 Nc6 7. Bg2 a6
			variation => N__('Sicilian: Scheveningen, Fianchetto Variation'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqkb1r/1p3ppp/p1nppn2/8/3NP3/2N3P1/PPP2PBP/R1BQ1RK1 b kq' => {
			eco => 'B80r',
			# TRANSLATORS: B80r: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g3 Nc6 7. Bg2 a6 8. O-O
			variation => N__('Sicilian: Scheveningen, Fianchetto Variation'),
			moves => {
				'c8d7' => 1,
			},
		},
		'r2qkb1r/1p1b1ppp/p1nppn2/8/3NP3/2N3P1/PPP2PBP/R1BQ1RK1 w kq' => {
			eco => 'B80r',
			# TRANSLATORS: B80r: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g3 Nc6 7. Bg2 a6 8. O-O Bd7
			variation => N__('Sicilian: Scheveningen, Fianchetto Variation'),
			moves => {
			},
		},
		'r1b1kb1r/ppq2ppp/2nppn2/8/3NP3/2N3P1/PPP2PBP/R1BQK2R w KQkq' => {
			eco => 'B80s',
			# TRANSLATORS: B80s: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g3 Nc6 7. Bg2 Qc7
			variation => N__('Sicilian: Scheveningen, Fianchetto Variation'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1b1kb1r/ppq2ppp/2nppn2/8/3NP3/2N3P1/PPP2PBP/R1BQ1RK1 b kq' => {
			eco => 'B80s',
			# TRANSLATORS: B80s: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g3 Nc6 7. Bg2 Qc7 8. O-O
			variation => N__('Sicilian: Scheveningen, Fianchetto Variation'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r1b1kb1r/1pq2ppp/p1nppn2/8/3NP3/2N3P1/PPP2PBP/R1BQ1RK1 w kq' => {
			eco => 'B80t',
			# TRANSLATORS: B80t: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g3 Nc6 7. Bg2 Qc7 8. O-O a6
			variation => N__('Sicilian: Scheveningen, Fianchetto Variation'),
			moves => {
				'f1e1' => 1,
			},
		},
		'r1b1kb1r/1pq2ppp/p1nppn2/8/3NP3/2N3P1/PPP2PBP/R1BQR1K1 b kq' => {
			eco => 'B80t',
			# TRANSLATORS: B80t: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g3 Nc6 7. Bg2 Qc7 8. O-O a6 9. Re1
			variation => N__('Sicilian: Scheveningen, Fianchetto Variation'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r1b1k2r/1pq1bppp/p1nppn2/8/3NP3/2N3P1/PPP2PBP/R1BQR1K1 w kq' => {
			eco => 'B80u',
			# TRANSLATORS: B80u: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g3 Nc6 7. Bg2 Qc7 8. O-O a6 9. Re1 Be7
			variation => N__('Sicilian: Scheveningen, Fianchetto Variation'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/3ppn2/8/3NP1P1/2N5/PPP2P1P/R1BQKB1R b KQkq' => {
			eco => 'B81a',
			# TRANSLATORS: B81a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g4
			variation => N__('Sicilian: Scheveningen, Keres Attack'),
			moves => {
				'a7a6' => 1,
				'b8c6' => 1,
				'e6e5' => 1,
				'h7h6' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/3p1n2/4p3/3NP1P1/2N5/PPP2P1P/R1BQKB1R w KQkq' => {
			eco => 'B81b',
			# TRANSLATORS: B81b: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g4 e5
			variation => N__('Sicilian: Scheveningen, Keres, 6... e5'),
			moves => {
			},
		},
		'rnbqkb1r/1p3ppp/p2ppn2/8/3NP1P1/2N5/PPP2P1P/R1BQKB1R w KQkq' => {
			eco => 'B81c',
			# TRANSLATORS: B81c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g4 a6
			variation => N__('Sicilian: Scheveningen, Keres, 6... a6'),
			moves => {
				'c1e3' => 1,
			},
		},
		'rnbqkb1r/1p3ppp/p2ppn2/8/3NP1P1/2N1B3/PPP2P1P/R2QKB1R b KQkq' => {
			eco => 'B81d',
			# TRANSLATORS: B81d: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g4 a6 7. Be3
			variation => N__('Sicilian: Scheveningen, Keres, Perenyi Attack'),
			moves => {
				'e6e5' => 1,
				'h7h6' => 1,
			},
		},
		'rnbqkb1r/1p3ppp/p2p1n2/4p3/3NP1P1/2N1B3/PPP2P1P/R2QKB1R w KQkq' => {
			eco => 'B81e',
			# TRANSLATORS: B81e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g4 a6 7. Be3 e5
			variation => N__('Sicilian: Scheveningen, Keres, Perenyi Attack, 7... e5'),
			moves => {
			},
		},
		'rnbqkb1r/1p3pp1/p2ppn1p/8/3NP1P1/2N1B3/PPP2P1P/R2QKB1R w KQkq' => {
			eco => 'B81f',
			# TRANSLATORS: B81f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g4 a6 7. Be3 h6
			variation => N__('Sicilian: Scheveningen, Keres, Perenyi Attack, 7... h6'),
			moves => {
				'f2f4' => 1,
			},
		},
		'rnbqkb1r/1p3pp1/p2ppn1p/8/3NPPP1/2N1B3/PPP4P/R2QKB1R b KQkq' => {
			eco => 'B81g',
			# TRANSLATORS: B81g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g4 a6 7. Be3 h6 8. f4
			variation => N__('Sicilian: Scheveningen, Keres, Perenyi Attack, 7... h6 8. f4'),
			moves => {
			},
		},
		'rnbqkb1r/pp3pp1/3ppn1p/8/3NP1P1/2N5/PPP2P1P/R1BQKB1R w KQkq' => {
			eco => 'B81h',
			# TRANSLATORS: B81h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g4 h6
			variation => N__('Sicilian: Scheveningen, Keres, 6... h6'),
			moves => {
				'g4g5' => 1,
				'h1g1' => 1,
				'h2h3' => 1,
				'h2h4' => 1,
			},
		},
		'rnbqkb1r/pp3pp1/3ppn1p/8/3NP1P1/2N4P/PPP2P2/R1BQKB1R b KQkq' => {
			eco => 'B81i',
			# TRANSLATORS: B81i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g4 h6 7. h3
			variation => N__('Sicilian: Scheveningen, Keres, 6... h6 7. h3'),
			moves => {
				'a7a6' => 1,
				'b8c6' => 1,
			},
		},
		'rnbqkb1r/1p3pp1/p2ppn1p/8/3NP1P1/2N4P/PPP2P2/R1BQKB1R w KQkq' => {
			eco => 'B81i',
			# TRANSLATORS: B81i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g4 h6 7. h3 a6
			variation => N__('Sicilian: Scheveningen, Keres, 6... h6 7. h3'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkb1r/1p3pp1/p2ppn1p/8/3NP1P1/2N4P/PPP2PB1/R1BQK2R b KQkq' => {
			eco => 'B81i',
			# TRANSLATORS: B81i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g4 h6 7. h3 a6 8. Bg2
			variation => N__('Sicilian: Scheveningen, Keres, 6... h6 7. h3'),
			moves => {
			},
		},
		'r1bqkb1r/pp3pp1/2nppn1p/8/3NP1P1/2N4P/PPP2P2/R1BQKB1R w KQkq' => {
			eco => 'B81i',
			# TRANSLATORS: B81i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g4 h6 7. h3 Nc6
			variation => N__('Sicilian: Scheveningen, Keres, 6... h6 7. h3'),
			moves => {
				'f1g2' => 1,
			},
		},
		'r1bqkb1r/pp3pp1/2nppn1p/8/3NP1P1/2N4P/PPP2PB1/R1BQK2R b KQkq' => {
			eco => 'B81i',
			# TRANSLATORS: B81i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g4 h6 7. h3 Nc6 8. Bg2
			variation => N__('Sicilian: Scheveningen, Keres, 6... h6 7. h3'),
			moves => {
			},
		},
		'rnbqkb1r/pp3pp1/3ppn1p/8/3NP1PP/2N5/PPP2P2/R1BQKB1R b KQkq' => {
			eco => 'B81j',
			# TRANSLATORS: B81j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g4 h6 7. h4
			variation => N__('Sicilian: Scheveningen, Keres, 6... h6 7. h4'),
			moves => {
				'b8c6' => 1,
				'f8e7' => 1,
			},
		},
		'rnbqk2r/pp2bpp1/3ppn1p/8/3NP1PP/2N5/PPP2P2/R1BQKB1R w KQkq' => {
			eco => 'B81k',
			# TRANSLATORS: B81k: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g4 h6 7. h4 Be7
			variation => N__('Sicilian: Scheveningen, Keres, 6... h6 7. h4 Be7'),
			moves => {
			},
		},
		'r1bqkb1r/pp3pp1/2nppn1p/8/3NP1PP/2N5/PPP2P2/R1BQKB1R w KQkq' => {
			eco => 'B81l',
			# TRANSLATORS: B81l: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g4 h6 7. h4 Nc6
			variation => N__('Sicilian: Scheveningen, Keres, 6... h6 7. h4 Nc6'),
			moves => {
				'h1g1' => 1,
			},
		},
		'r1bqkb1r/pp3pp1/2nppn1p/8/3NP1PP/2N5/PPP2P2/R1BQKBR1 b Qkq' => {
			eco => 'B81m',
			# TRANSLATORS: B81m: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g4 h6 7. h4 Nc6 8. Rg1
			variation => N__('Sicilian: Scheveningen, Keres, 6... h6 7. h4 Nc6 8. Rg1'),
			moves => {
				'h6h5' => 1,
			},
		},
		'r1bqkb1r/pp3pp1/2nppn2/7p/3NP1PP/2N5/PPP2P2/R1BQKBR1 w Qkq' => {
			eco => 'B81n',
			# TRANSLATORS: B81n: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g4 h6 7. h4 Nc6 8. Rg1 h5
			variation => N__('Sicilian: Scheveningen, Keres, 6... h6 7. h4 Nc6 8. Rg1 h5'),
			moves => {
			},
		},
		'rnbqkb1r/pp3pp1/3ppn1p/6P1/3NP3/2N5/PPP2P1P/R1BQKB1R b KQkq' => {
			eco => 'B81o',
			# TRANSLATORS: B81o: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g4 h6 7. g5
			variation => N__('Sicilian: Scheveningen, Keres, 6... h6 7. g5'),
			moves => {
			},
		},
		'rnbqkb1r/pp3pp1/3ppn1p/8/3NP1P1/2N5/PPP2P1P/R1BQKBR1 b Qkq' => {
			eco => 'B81p',
			# TRANSLATORS: B81p: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g4 h6 7. Rg1
			variation => N__('Sicilian: Scheveningen, Keres, 6... h6 7. Rg1'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2nppn2/8/3NP1P1/2N5/PPP2P1P/R1BQKB1R w KQkq' => {
			eco => 'B81q',
			# TRANSLATORS: B81q: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g4 Nc6
			variation => N__('Sicilian: Scheveningen, Keres, 6... Nc6'),
			moves => {
				'g4g5' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2nppn2/6P1/3NP3/2N5/PPP2P1P/R1BQKB1R b KQkq' => {
			eco => 'B81q',
			# TRANSLATORS: B81q: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g4 Nc6 7. g5
			variation => N__('Sicilian: Scheveningen, Keres, 6... Nc6'),
			moves => {
				'f6d7' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/2npp3/6P1/3NP3/2N5/PPP2P1P/R1BQKB1R w KQkq' => {
			eco => 'B81r',
			# TRANSLATORS: B81r: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g4 Nc6 7. g5 Nd7
			variation => N__('Sicilian: Scheveningen, Keres, 6... Nc6 7. g5 Nd7'),
			moves => {
				'c1e3' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/2npp3/6P1/3NP3/2N1B3/PPP2P1P/R2QKB1R b KQkq' => {
			eco => 'B81s',
			# TRANSLATORS: B81s: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g4 Nc6 7. g5 Nd7 8. Be3
			variation => N__('Sicilian: Scheveningen, Keres, 6... Nc6 7. g5 Nd7 8. Be3'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r1bqk2r/pp1nbppp/2npp3/6P1/3NP3/2N1B3/PPP2P1P/R2QKB1R w KQkq' => {
			eco => 'B81t',
			# TRANSLATORS: B81t: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. g4 Nc6 7. g5 Nd7 8. Be3 Be7
			variation => N__('Sicilian: Scheveningen, Keres, 6... Nc6 7. g5 Nd7 8. Be3 Be7'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/3ppn2/8/3NPP2/2N5/PPP3PP/R1BQKB1R b KQkq' => {
			eco => 'B82',
			# TRANSLATORS: B82: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. f4
			variation => N__('Sicilian: Scheveningen, 6. f4'),
			moves => {
				'a7a6' => 1,
				'b8c6' => 1,
				'd8b6' => 1,
				'f8e7' => 1,
			},
		},
		'rnbqkb1r/1p3ppp/p2ppn2/8/3NPP2/2N5/PPP3PP/R1BQKB1R w KQkq' => {
			eco => 'B82',
			# TRANSLATORS: B82: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. f4 a6
			variation => N__('Sicilian: Scheveningen, 6. f4 a6'),
			moves => {
				'c1e3' => 1,
			},
		},
		'rnbqkb1r/1p3ppp/p2ppn2/8/3NPP2/2N1B3/PPP3PP/R2QKB1R b KQkq' => {
			eco => 'B82',
			# TRANSLATORS: B82: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. f4 a6 7. Be3
			variation => N__('Sicilian: Scheveningen, 6. f4 a6 7. Be3'),
			moves => {
				'b7b5' => 1,
			},
		},
		'rnbqkb1r/5ppp/p2ppn2/1p6/3NPP2/2N1B3/PPP3PP/R2QKB1R w KQkq' => {
			eco => 'B82',
			# TRANSLATORS: B82: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. f4 a6 7. Be3 b5
			variation => N__('Sicilian: Scheveningen, 6. f4 a6 7. Be3 b5'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2nppn2/8/3NPP2/2N5/PPP3PP/R1BQKB1R w KQkq' => {
			eco => 'B82',
			# TRANSLATORS: B82: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. f4 Nc6
			variation => N__('Sicilian: Scheveningen, 6. f4 Nc6'),
			moves => {
				'c1e3' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2nppn2/8/3NPP2/2N1B3/PPP3PP/R2QKB1R b KQkq' => {
			eco => 'B82',
			# TRANSLATORS: B82: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. f4 Nc6 7. Be3
			variation => N__('Sicilian: Scheveningen, 6. f4 Nc6 7. Be3'),
			moves => {
				'd8c7' => 1,
				'f8e7' => 1,
			},
		},
		'r1b1kb1r/ppq2ppp/2nppn2/8/3NPP2/2N1B3/PPP3PP/R2QKB1R w KQkq' => {
			eco => 'B82',
			# TRANSLATORS: B82: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. f4 Nc6 7. Be3 Qc7
			variation => N__('Sicilian: Scheveningen, 6. f4 Nc6 7. Be3 Qc7'),
			moves => {
			},
		},
		'r1bqk2r/pp2bppp/2nppn2/8/3NPP2/2N1B3/PPP3PP/R2QKB1R w KQkq' => {
			eco => 'B82',
			# TRANSLATORS: B82: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. f4 Nc6 7. Be3 Be7
			variation => N__('Sicilian: Scheveningen, 6. f4 Nc6 7. Be3 Be7'),
			moves => {
				'd1f3' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2nppn2/8/3NPP2/2N1BQ2/PPP3PP/R3KB1R b KQkq' => {
			eco => 'B82',
			# TRANSLATORS: B82: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. f4 Nc6 7. Be3 Be7 8. Qf3
			variation => N__('Sicilian: Scheveningen, Tal Variation'),
			moves => {
				'd8c7' => 1,
				'e6e5' => 1,
			},
		},
		'r1b1k2r/ppq1bppp/2nppn2/8/3NPP2/2N1BQ2/PPP3PP/R3KB1R w KQkq' => {
			eco => 'B82',
			# TRANSLATORS: B82: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. f4 Nc6 7. Be3 Be7 8. Qf3 Qc7
			variation => N__('Sicilian: Scheveningen, Tal, 8... Qc7'),
			moves => {
			},
		},
		'r1bqk2r/pp2bppp/2np1n2/4p3/3NPP2/2N1BQ2/PPP3PP/R3KB1R w KQkq' => {
			eco => 'B82',
			# TRANSLATORS: B82: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. f4 Nc6 7. Be3 Be7 8. Qf3 e5
			variation => N__('Sicilian: Scheveningen, Tal, 8... e5'),
			moves => {
			},
		},
		'rnb1kb1r/pp3ppp/1q1ppn2/8/3NPP2/2N5/PPP3PP/R1BQKB1R w KQkq' => {
			eco => 'B82',
			# TRANSLATORS: B82: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. f4 Qb6
			variation => N__('Sicilian: Scheveningen, 6. f4 Qb6'),
			moves => {
			},
		},
		'rnbqk2r/pp2bppp/3ppn2/8/3NPP2/2N5/PPP3PP/R1BQKB1R w KQkq' => {
			eco => 'B82',
			# TRANSLATORS: B82: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. f4 Be7
			variation => N__('Sicilian: Scheveningen, 6. f4 Be7'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/3ppn2/8/3NP3/2N5/PPP1BPPP/R1BQK2R b KQkq' => {
			eco => 'B83',
			# TRANSLATORS: B83: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2
			variation => N__('Sicilian: Scheveningen, 6. Be2'),
			moves => {
				'a7a6' => 1,
				'b8c6' => 1,
				'f8e7' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2nppn2/8/3NP3/2N5/PPP1BPPP/R1BQK2R w KQkq' => {
			eco => 'B83',
			# TRANSLATORS: B83: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 Nc6
			variation => N__('Sicilian: Scheveningen, Modern'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2nppn2/8/3NP3/2N5/PPP1BPPP/R1BQ1RK1 b kq' => {
			eco => 'B83',
			# TRANSLATORS: B83: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 Nc6 7. O-O
			variation => N__('Sicilian: Scheveningen, Modern'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2nppn2/8/3NP3/2N5/PPP1BPPP/R1BQ1RK1 w kq' => {
			eco => 'B83',
			# TRANSLATORS: B83: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 Nc6 7. O-O Be7
			variation => N__('Sicilian: Scheveningen, Modern'),
			moves => {
				'c1e3' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2nppn2/8/3NP3/2N1B3/PPP1BPPP/R2Q1RK1 b kq' => {
			eco => 'B83',
			# TRANSLATORS: B83: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 Nc6 7. O-O Be7 8. Be3
			variation => N__('Sicilian: Scheveningen, Modern'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2nppn2/8/3NP3/2N1B3/PPP1BPPP/R2Q1RK1 w -' => {
			eco => 'B83',
			# TRANSLATORS: B83: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 Nc6 7. O-O Be7 8. Be3 O-O
			variation => N__('Sicilian: Scheveningen, Modern'),
			moves => {
				'f2f4' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2nppn2/8/3NPP2/2N1B3/PPP1B1PP/R2Q1RK1 b -' => {
			eco => 'B83',
			# TRANSLATORS: B83: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 Nc6 7. O-O Be7 8. Be3 O-O 9. f4
			variation => N__('Sicilian: Scheveningen, Modern, 9. f4'),
			moves => {
				'c8d7' => 1,
				'e6e5' => 1,
			},
		},
		'r2q1rk1/pp1bbppp/2nppn2/8/3NPP2/2N1B3/PPP1B1PP/R2Q1RK1 w -' => {
			eco => 'B83',
			# TRANSLATORS: B83: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 Nc6 7. O-O Be7 8. Be3 O-O 9. f4 Bd7
			variation => N__('Sicilian: Scheveningen, Modern, 9. f4 Bd7'),
			moves => {
				'd1e1' => 1,
				'd4b3' => 1,
				'g1h1' => 1,
			},
		},
		'r2q1rk1/pp1bbppp/2nppn2/8/3NPP2/2N1B3/PPP1B1PP/R3QRK1 b -' => {
			eco => 'B83',
			# TRANSLATORS: B83: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 Nc6 7. O-O Be7 8. Be3 O-O 9. f4 Bd7 10. Qe1
			variation => N__('Sicilian: Scheveningen, Modern, 9. f4 Bd7 10. Qe1'),
			moves => {
			},
		},
		'r2q1rk1/pp1bbppp/2nppn2/8/4PP2/1NN1B3/PPP1B1PP/R2Q1RK1 b -' => {
			eco => 'B83',
			# TRANSLATORS: B83: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 Nc6 7. O-O Be7 8. Be3 O-O 9. f4 Bd7 10. Nb3
			variation => N__('Sicilian: Scheveningen, Modern, 9. f4 Bd7 10. Nb3'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r2q1rk1/1p1bbppp/p1nppn2/8/4PP2/1NN1B3/PPP1B1PP/R2Q1RK1 w -' => {
			eco => 'B83',
			# TRANSLATORS: B83: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 Nc6 7. O-O Be7 8. Be3 O-O 9. f4 Bd7 10. Nb3 a6
			variation => N__('Sicilian: Scheveningen, Modern, 9. f4 Bd7 10. Nb3 a6'),
			moves => {
				'a2a4' => 1,
			},
		},
		'r2q1rk1/1p1bbppp/p1nppn2/8/P3PP2/1NN1B3/1PP1B1PP/R2Q1RK1 b -' => {
			eco => 'B83',
			# TRANSLATORS: B83: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 Nc6 7. O-O Be7 8. Be3 O-O 9. f4 Bd7 10. Nb3 a6 11. a4
			variation => N__('Sicilian: Scheveningen, Modern, 9. f4 Bd7 10. Nb3 a6 11. a4'),
			moves => {
			},
		},
		'r2q1rk1/pp1bbppp/2nppn2/8/3NPP2/2N1B3/PPP1B1PP/R2Q1R1K b -' => {
			eco => 'B83',
			# TRANSLATORS: B83: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 Nc6 7. O-O Be7 8. Be3 O-O 9. f4 Bd7 10. Kh1
			variation => N__('Sicilian: Scheveningen, Modern, 9. f4 Bd7 10. Kh1'),
			moves => {
			},
		},
		'r1bq1rk1/pp2bppp/2np1n2/4p3/3NPP2/2N1B3/PPP1B1PP/R2Q1RK1 w -' => {
			eco => 'B83',
			# TRANSLATORS: B83: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 Nc6 7. O-O Be7 8. Be3 O-O 9. f4 e5
			variation => N__('Sicilian: Scheveningen, Modern, 9. f4 e5'),
			moves => {
				'd4b3' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2np1n2/4p3/4PP2/1NN1B3/PPP1B1PP/R2Q1RK1 b -' => {
			eco => 'B83',
			# TRANSLATORS: B83: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 Nc6 7. O-O Be7 8. Be3 O-O 9. f4 e5 10. Nb3
			variation => N__('Sicilian: Scheveningen, Modern, 9. f4 e5 10. Nb3'),
			moves => {
				'e5f4' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2np1n2/8/4Pp2/1NN1B3/PPP1B1PP/R2Q1RK1 w -' => {
			eco => 'B83',
			# TRANSLATORS: B83: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 Nc6 7. O-O Be7 8. Be3 O-O 9. f4 e5 10. Nb3 exf4
			variation => N__('Sicilian: Scheveningen, Modern, 9. f4 e5 10. Nb3'),
			moves => {
				'e3f4' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2np1n2/8/4PB2/1NN5/PPP1B1PP/R2Q1RK1 b -' => {
			eco => 'B83',
			# TRANSLATORS: B83: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 Nc6 7. O-O Be7 8. Be3 O-O 9. f4 e5 10. Nb3 exf4 11. Bxf4
			variation => N__('Sicilian: Scheveningen, Modern, 9. f4 e5 10. Nb3 exf4 11.Bxf4'),
			moves => {
			},
		},
		'rnbqk2r/pp2bppp/3ppn2/8/3NP3/2N5/PPP1BPPP/R1BQK2R w KQkq' => {
			eco => 'B83',
			# TRANSLATORS: B83: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 Be7
			variation => N__('Sicilian: Scheveningen, 6. Be2'),
			moves => {
			},
		},
		'rnbqkb1r/1p3ppp/p2ppn2/8/3NP3/2N5/PPP1BPPP/R1BQK2R w KQkq' => {
			eco => 'B84',
			# TRANSLATORS: B84: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6
			variation => N__('Sicilian: Scheveningen, Classical'),
			moves => {
				'a2a4' => 1,
				'c1e3' => 1,
				'e1g1' => 1,
				'f2f4' => 1,
			},
		},
		'rnbqkb1r/1p3ppp/p2ppn2/8/P2NP3/2N5/1PP1BPPP/R1BQK2R b KQkq' => {
			eco => 'B84',
			# TRANSLATORS: B84: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. a4
			variation => N__('Sicilian: Scheveningen, Classical, 7. a4'),
			moves => {
			},
		},
		'rnbqkb1r/1p3ppp/p2ppn2/8/3NP3/2N1B3/PPP1BPPP/R2QK2R b KQkq' => {
			eco => 'B84',
			# TRANSLATORS: B84: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. Be3
			variation => N__('Sicilian: Scheveningen, Classical, 7. Be3'),
			moves => {
			},
		},
		'rnbqkb1r/1p3ppp/p2ppn2/8/3NP3/2N5/PPP1BPPP/R1BQ1RK1 b kq' => {
			eco => 'B84',
			# TRANSLATORS: B84: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. O-O
			variation => N__('Sicilian: Scheveningen, Classical, 7.O-O'),
			moves => {
				'b8c6' => 1,
				'b8d7' => 1,
				'd8c7' => 1,
				'f8e7' => 1,
			},
		},
		'r1bqkb1r/1p3ppp/p1nppn2/8/3NP3/2N5/PPP1BPPP/R1BQ1RK1 w kq' => {
			eco => 'B84',
			# TRANSLATORS: B84: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. O-O Nc6
			variation => N__('Sicilian: Scheveningen, Classical, 7.O-O Nc6'),
			moves => {
			},
		},
		'r1bqkb1r/1p1n1ppp/p2ppn2/8/3NP3/2N5/PPP1BPPP/R1BQ1RK1 w kq' => {
			eco => 'B84',
			# TRANSLATORS: B84: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. O-O Nbd7
			variation => N__('Sicilian: Scheveningen, Classical, 7.O-O Nbd7'),
			moves => {
				'a2a4' => 1,
				'f2f4' => 1,
			},
		},
		'r1bqkb1r/1p1n1ppp/p2ppn2/8/P2NP3/2N5/1PP1BPPP/R1BQ1RK1 b kq' => {
			eco => 'B84',
			# TRANSLATORS: B84: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. O-O Nbd7 8. a4
			variation => N__('Sicilian: Scheveningen, Classical, 7.O-O Nbd7 8. a4'),
			moves => {
			},
		},
		'r1bqkb1r/1p1n1ppp/p2ppn2/8/3NPP2/2N5/PPP1B1PP/R1BQ1RK1 b kq' => {
			eco => 'B84',
			# TRANSLATORS: B84: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. O-O Nbd7 8. f4
			variation => N__('Sicilian: Scheveningen, Classical, 7.O-O Nbd7 8. f4'),
			moves => {
			},
		},
		'rnb1kb1r/1pq2ppp/p2ppn2/8/3NP3/2N5/PPP1BPPP/R1BQ1RK1 w kq' => {
			eco => 'B84',
			# TRANSLATORS: B84: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. O-O Qc7
			variation => N__('Sicilian: Scheveningen, Classical, 7.O-O Qc7'),
			moves => {
				'a2a4' => 1,
				'c1e3' => 1,
				'e2f3' => 1,
				'f2f4' => 1,
				'g1h1' => 1,
			},
		},
		'rnb1kb1r/1pq2ppp/p2ppn2/8/P2NP3/2N5/1PP1BPPP/R1BQ1RK1 b kq' => {
			eco => 'B84',
			# TRANSLATORS: B84: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. O-O Qc7 8. a4
			variation => N__('Sicilian: Scheveningen, Classical, 7.O-O Qc7 8. a4'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1b1kb1r/1pq2ppp/p1nppn2/8/P2NP3/2N5/1PP1BPPP/R1BQ1RK1 w kq' => {
			eco => 'B84',
			# TRANSLATORS: B84: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. O-O Qc7 8. a4 Nc6
			variation => N__('Sicilian: Scheveningen, Classical, 7.O-O Qc7 8. a4 Nc6'),
			moves => {
			},
		},
		'rnb1kb1r/1pq2ppp/p2ppn2/8/3NP3/2N1B3/PPP1BPPP/R2Q1RK1 b kq' => {
			eco => 'B84',
			# TRANSLATORS: B84: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. O-O Qc7 8. Be3
			variation => N__('Sicilian: Scheveningen, Classical, 7.O-O Qc7 8. Be3'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1b1kb1r/1pq2ppp/p1nppn2/8/3NP3/2N1B3/PPP1BPPP/R2Q1RK1 w kq' => {
			eco => 'B84',
			# TRANSLATORS: B84: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. O-O Qc7 8. Be3 Nc6
			variation => N__('Sicilian: Scheveningen, Classical, 7.O-O Qc7 8. Be3 Nc6'),
			moves => {
			},
		},
		'rnb1kb1r/1pq2ppp/p2ppn2/8/3NP3/2N2B2/PPP2PPP/R1BQ1RK1 b kq' => {
			eco => 'B84',
			# TRANSLATORS: B84: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. O-O Qc7 8. Bf3
			variation => N__('Sicilian: Scheveningen, Classical, 7.O-O Qc7 8. Bf3'),
			moves => {
			},
		},
		'rnb1kb1r/1pq2ppp/p2ppn2/8/3NPP2/2N5/PPP1B1PP/R1BQ1RK1 b kq' => {
			eco => 'B84',
			# TRANSLATORS: B84: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. O-O Qc7 8. f4
			variation => N__('Sicilian: Scheveningen, Classical, 7.O-O Qc7 8. f4'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1b1kb1r/1pq2ppp/p1nppn2/8/3NPP2/2N5/PPP1B1PP/R1BQ1RK1 w kq' => {
			eco => 'B84',
			# TRANSLATORS: B84: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. O-O Qc7 8. f4 Nc6
			variation => N__('Sicilian: Scheveningen, Classical, 7.O-O Qc7 8. f4 Nc6'),
			moves => {
			},
		},
		'rnb1kb1r/1pq2ppp/p2ppn2/8/3NP3/2N5/PPP1BPPP/R1BQ1R1K b kq' => {
			eco => 'B84',
			# TRANSLATORS: B84: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. O-O Qc7 8. Kh1
			variation => N__('Sicilian: Scheveningen, Classical, 7.O-O Qc7 8. Kh1'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1b1kb1r/1pq2ppp/p1nppn2/8/3NP3/2N5/PPP1BPPP/R1BQ1R1K w kq' => {
			eco => 'B84',
			# TRANSLATORS: B84: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. O-O Qc7 8. Kh1 Nc6
			variation => N__('Sicilian: Scheveningen, Classical, 7.O-O Qc7 8. Kh1 Nc6'),
			moves => {
			},
		},
		'rnbqk2r/1p2bppp/p2ppn2/8/3NP3/2N5/PPP1BPPP/R1BQ1RK1 w kq' => {
			eco => 'B84',
			# TRANSLATORS: B84: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. O-O Be7
			variation => N__('Sicilian: Scheveningen, Classical, 7.O-O Be7'),
			moves => {
				'f2f4' => 1,
			},
		},
		'rnbqk2r/1p2bppp/p2ppn2/8/3NPP2/2N5/PPP1B1PP/R1BQ1RK1 b kq' => {
			eco => 'B84',
			# TRANSLATORS: B84: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. O-O Be7 8. f4
			variation => N__('Sicilian: Scheveningen, Classical, 7.O-O Be7 8. f4'),
			moves => {
				'd8c7' => 1,
				'e8g8' => 1,
			},
		},
		'rnb1k2r/1pq1bppp/p2ppn2/8/3NPP2/2N5/PPP1B1PP/R1BQ1RK1 w kq' => {
			eco => 'B84',
			# TRANSLATORS: B84: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. O-O Be7 8. f4 Qc7
			variation => N__('Sicilian: Scheveningen, Classical, 7.O-O Be7 8. f4 Qc7'),
			moves => {
				'c1e3' => 1,
				'g1h1' => 1,
			},
		},
		'rnb1k2r/1pq1bppp/p2ppn2/8/3NPP2/2N1B3/PPP1B1PP/R2Q1RK1 b kq' => {
			eco => 'B84',
			# TRANSLATORS: B84: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. O-O Be7 8. f4 Qc7 9. Be3
			variation => N__('Sicilian: Scheveningen, Classical, 7.O-O Be7 8. f4 Qc7 9. Be3'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1b1k2r/1pq1bppp/p1nppn2/8/3NPP2/2N1B3/PPP1B1PP/R2Q1RK1 w kq' => {
			eco => 'B84',
			# TRANSLATORS: B84: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. O-O Be7 8. f4 Qc7 9. Be3 Nc6
			variation => N__('Sicilian: Scheveningen, Classical, 7.O-O Be7 8. f4 Qc7 9. Be3 Nc6'),
			moves => {
			},
		},
		'rnb1k2r/1pq1bppp/p2ppn2/8/3NPP2/2N5/PPP1B1PP/R1BQ1R1K b kq' => {
			eco => 'B84',
			# TRANSLATORS: B84: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. O-O Be7 8. f4 Qc7 9. Kh1
			variation => N__('Sicilian: Scheveningen, Classical, 7.O-O Be7 8. f4 Qc7 9. Kh1'),
			moves => {
			},
		},
		'rnbq1rk1/1p2bppp/p2ppn2/8/3NPP2/2N5/PPP1B1PP/R1BQ1RK1 w -' => {
			eco => 'B84',
			# TRANSLATORS: B84: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. O-O Be7 8. f4 O-O
			variation => N__('Sicilian: Scheveningen, Classical, 7.O-O Be7 8. f4 O-O'),
			moves => {
				'c1e3' => 1,
			},
		},
		'rnbqkb1r/1p3ppp/p2ppn2/8/3NPP2/2N5/PPP1B1PP/R1BQK2R b KQkq' => {
			eco => 'B84',
			# TRANSLATORS: B84: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. f4
			variation => N__('Sicilian: Scheveningen, Classical, 7. f4'),
			moves => {
			},
		},
		'rnbq1rk1/1p2bppp/p2ppn2/8/3NPP2/2N1B3/PPP1B1PP/R2Q1RK1 b -' => {
			eco => 'B85',
			# TRANSLATORS: B85: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. O-O Be7 8. f4 O-O 9. Be3
			variation => N__('Sicilian: Scheveningen, Classical, Main Line'),
			moves => {
				'b8c6' => 1,
				'd8c7' => 1,
			},
		},
		'r1bq1rk1/1p2bppp/p1nppn2/8/3NPP2/2N1B3/PPP1B1PP/R2Q1RK1 w -' => {
			eco => 'B85',
			# TRANSLATORS: B85: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. O-O Be7 8. f4 O-O 9. Be3 Nc6
			variation => N__('Sicilian: Scheveningen, Classical, Main Line, 9... Nc6'),
			moves => {
				'a2a4' => 1,
				'd1e1' => 1,
				'g1h1' => 1,
			},
		},
		'r1bq1rk1/1p2bppp/p1nppn2/8/P2NPP2/2N1B3/1PP1B1PP/R2Q1RK1 b -' => {
			eco => 'B85',
			# TRANSLATORS: B85: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. O-O Be7 8. f4 O-O 9. Be3 Nc6 10. a4
			variation => N__('Sicilian: Scheveningen, Classical, Main Line, 9... Nc6 10. a4'),
			moves => {
				'c8d7' => 1,
				'd8c7' => 1,
			},
		},
		'r2q1rk1/1p1bbppp/p1nppn2/8/P2NPP2/2N1B3/1PP1B1PP/R2Q1RK1 w -' => {
			eco => 'B85',
			# TRANSLATORS: B85: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. O-O Be7 8. f4 O-O 9. Be3 Nc6 10. a4 Bd7
			variation => N__('Sicilian: Scheveningen, Classical, Main Line, 9... Nc6 10. a4 Bd7'),
			moves => {
			},
		},
		'r1b2rk1/1pq1bppp/p1nppn2/8/P2NPP2/2N1B3/1PP1B1PP/R2Q1RK1 w -' => {
			eco => 'B85',
			# TRANSLATORS: B85: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. O-O Be7 8. f4 O-O 9. Be3 Nc6 10. a4 Qc7
			variation => N__('Sicilian: Scheveningen, Classical, Main Line, 9... Nc6 10. a4 Qc7'),
			moves => {
				'g1h1' => 1,
			},
		},
		'r1b2rk1/1pq1bppp/p1nppn2/8/P2NPP2/2N1B3/1PP1B1PP/R2Q1R1K b -' => {
			eco => 'B85',
			# TRANSLATORS: B85: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. O-O Be7 8. f4 O-O 9. Be3 Nc6 10. a4 Qc7 11. Kh1
			variation => N__('Sicilian: Scheveningen, Classical, Main Line, 9... Nc6 10. a4 Qc7'),
			moves => {
			},
		},
		'r1bq1rk1/1p2bppp/p1nppn2/8/3NPP2/2N1B3/PPP1B1PP/R3QRK1 b -' => {
			eco => 'B85',
			# TRANSLATORS: B85: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. O-O Be7 8. f4 O-O 9. Be3 Nc6 10. Qe1
			variation => N__('Sicilian: Scheveningen, Classical, Main Line, 9... Nc6 10. Qe1'),
			moves => {
				'd8c7' => 1,
			},
		},
		'r1b2rk1/1pq1bppp/p1nppn2/8/3NPP2/2N1B3/PPP1B1PP/R3QRK1 w -' => {
			eco => 'B85',
			# TRANSLATORS: B85: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. O-O Be7 8. f4 O-O 9. Be3 Nc6 10. Qe1 Qc7
			variation => N__('Sicilian: Scheveningen, Classical, Main Line, 9... Nc6 10. Qe1 Qc7'),
			moves => {
				'e1g3' => 1,
			},
		},
		'r1b2rk1/1pq1bppp/p1nppn2/8/3NPP2/2N1B1Q1/PPP1B1PP/R4RK1 b -' => {
			eco => 'B85',
			# TRANSLATORS: B85: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. O-O Be7 8. f4 O-O 9. Be3 Nc6 10. Qe1 Qc7 11. Qg3
			variation => N__('Sicilian: Scheveningen, Classical, Main Line, 9... Nc6 10. Qe1 Qc7 11. Qg3'),
			moves => {
			},
		},
		'r1bq1rk1/1p2bppp/p1nppn2/8/3NPP2/2N1B3/PPP1B1PP/R2Q1R1K b -' => {
			eco => 'B85',
			# TRANSLATORS: B85: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. O-O Be7 8. f4 O-O 9. Be3 Nc6 10. Kh1
			variation => N__('Sicilian: Scheveningen, Classical, Main Line, 9... Nc6 10. Kh1'),
			moves => {
				'c8d7' => 1,
				'd8c7' => 1,
			},
		},
		'r2q1rk1/1p1bbppp/p1nppn2/8/3NPP2/2N1B3/PPP1B1PP/R2Q1R1K w -' => {
			eco => 'B85',
			# TRANSLATORS: B85: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. O-O Be7 8. f4 O-O 9. Be3 Nc6 10. Kh1 Bd7
			variation => N__('Sicilian: Scheveningen, Classical, Main Line, 9... Nc6 10. Kh1 Bd7'),
			moves => {
			},
		},
		'r1b2rk1/1pq1bppp/p1nppn2/8/3NPP2/2N1B3/PPP1B1PP/R2Q1R1K w -' => {
			eco => 'B85',
			# TRANSLATORS: B85: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. O-O Be7 8. f4 O-O 9. Be3 Nc6 10. Kh1 Qc7
			variation => N__('Sicilian: Scheveningen, Classical, Main Line, 9... Nc6 10. Kh1 Qc7'),
			moves => {
			},
		},
		'rnb2rk1/1pq1bppp/p2ppn2/8/3NPP2/2N1B3/PPP1B1PP/R2Q1RK1 w -' => {
			eco => 'B85',
			# TRANSLATORS: B85: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Be2 a6 7. O-O Be7 8. f4 O-O 9. Be3 Qc7
			variation => N__('Sicilian: Scheveningen, Classical, Main Line, 9... Qc7'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/3ppn2/8/2BNP3/2N5/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'B86',
			# TRANSLATORS: B86: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Bc4
			variation => N__('Sicilian: Sozin-Scheveningen'),
			moves => {
				'a7a6' => 1,
				'b8c6' => 1,
				'd8b6' => 1,
			},
		},
		'rnbqkb1r/1p3ppp/p2ppn2/8/2BNP3/2N5/PPP2PPP/R1BQK2R w KQkq' => {
			eco => 'B86',
			# TRANSLATORS: B86: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Bc4 a6
			variation => N__('Sicilian: Sozin-Najdorf'),
			moves => {
				'c4b3' => 1,
			},
		},
		'rnbqkb1r/1p3ppp/p2ppn2/8/3NP3/1BN5/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'B86',
			# TRANSLATORS: B86: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Bc4 a6 7. Bb3
			variation => N__('Sicilian: Sozin-Najdorf, 7. Bb3'),
			moves => {
				'b7b5' => 1,
				'f8e7' => 1,
			},
		},
		'rnbqk2r/1p2bppp/p2ppn2/8/3NP3/1BN5/PPP2PPP/R1BQK2R w KQkq' => {
			eco => 'B86',
			# TRANSLATORS: B86: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Bc4 a6 7. Bb3 Be7
			variation => N__('Sicilian: Sozin-Najdorf, 7. Bb3 Be7'),
			moves => {
			},
		},
		'rnb1kb1r/pp3ppp/1q1ppn2/8/2BNP3/2N5/PPP2PPP/R1BQK2R w KQkq' => {
			eco => 'B86',
			# TRANSLATORS: B86: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Bc4 Qb6
			variation => N__('Sicilian: Sozin-Scheveningen, 6... Qb6'),
			moves => {
			},
		},
		'rnbqkb1r/5ppp/p2ppn2/1p6/3NP3/1BN5/PPP2PPP/R1BQK2R w KQkq' => {
			eco => 'B87',
			# TRANSLATORS: B87: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Bc4 a6 7. Bb3 b5
			variation => N__('Sicilian: Sozin-Najdorf, 7. Bb3 b5'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbqkb1r/5ppp/p2ppn2/1p6/3NP3/1BN5/PPP2PPP/R1BQ1RK1 b kq' => {
			eco => 'B87',
			# TRANSLATORS: B87: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Bc4 a6 7. Bb3 b5 8. O-O
			variation => N__('Sicilian: Sozin-Najdorf, 7. Bb3 b5 8.O-O'),
			moves => {
				'f8e7' => 1,
			},
		},
		'rnbqk2r/4bppp/p2ppn2/1p6/3NP3/1BN5/PPP2PPP/R1BQ1RK1 w kq' => {
			eco => 'B87',
			# TRANSLATORS: B87: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Bc4 a6 7. Bb3 b5 8. O-O Be7
			variation => N__('Sicilian: Sozin-Najdorf, 7. Bb3 b5 8.O-O Be7'),
			moves => {
				'd1f3' => 1,
				'f2f4' => 1,
			},
		},
		'rnbqk2r/4bppp/p2ppn2/1p6/3NP3/1BN2Q2/PPP2PPP/R1B2RK1 b kq' => {
			eco => 'B87',
			# TRANSLATORS: B87: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Bc4 a6 7. Bb3 b5 8. O-O Be7 9. Qf3
			variation => N__('Sicilian: Sozin-Najdorf, 7. Bb3 b5 8.O-O Be7 9. Qf3'),
			moves => {
			},
		},
		'rnbqk2r/4bppp/p2ppn2/1p6/3NPP2/1BN5/PPP3PP/R1BQ1RK1 b kq' => {
			eco => 'B87',
			# TRANSLATORS: B87: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Bc4 a6 7. Bb3 b5 8. O-O Be7 9. f4
			variation => N__('Sicilian: Sozin-Najdorf, 7. Bb3 b5 8.O-O Be7 9. f4'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2nppn2/8/2BNP3/2N5/PPP2PPP/R1BQK2R w KQkq' => {
			eco => 'B88',
			# TRANSLATORS: B88: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Bc4 Nc6
			variation => N__('Sicilian: Sozin-Scheveningen'),
			moves => {
				'c1e3' => 1,
				'c4b3' => 1,
				'e1g1' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2nppn2/8/3NP3/1BN5/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'B88',
			# TRANSLATORS: B88: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Bc4 Nc6 7. Bb3
			variation => N__('Sicilian: Sozin-Scheveningen, 7. Bb3'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2nppn2/8/3NP3/1BN5/PPP2PPP/R1BQK2R w KQkq' => {
			eco => 'B88',
			# TRANSLATORS: B88: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Bc4 Nc6 7. Bb3 Be7
			variation => N__('Sicilian: Sozin-Scheveningen, 7. Bb3'),
			moves => {
				'c1e3' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2nppn2/8/3NP3/1BN1B3/PPP2PPP/R2QK2R b KQkq' => {
			eco => 'B88',
			# TRANSLATORS: B88: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Bc4 Nc6 7. Bb3 Be7 8. Be3
			variation => N__('Sicilian: Sozin-Scheveningen, 7. Bb3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2nppn2/8/3NP3/1BN1B3/PPP2PPP/R2QK2R w KQ' => {
			eco => 'B88',
			# TRANSLATORS: B88: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Bc4 Nc6 7. Bb3 Be7 8. Be3 O-O
			variation => N__('Sicilian: Sozin-Scheveningen, 7. Bb3'),
			moves => {
				'f2f4' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2nppn2/8/3NPP2/1BN1B3/PPP3PP/R2QK2R b KQ' => {
			eco => 'B88',
			# TRANSLATORS: B88: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Bc4 Nc6 7. Bb3 Be7 8. Be3 O-O 9. f4
			variation => N__('Sicilian: Sozin, Fischer Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2nppn2/8/2BNP3/2N5/PPP2PPP/R1BQ1RK1 b kq' => {
			eco => 'B88',
			# TRANSLATORS: B88: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Bc4 Nc6 7. O-O
			variation => N__('Sicilian: Sozin-Scheveningen, 7.O-O'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2nppn2/8/2BNP3/2N1B3/PPP2PPP/R2QK2R b KQkq' => {
			eco => 'B89',
			# TRANSLATORS: B89: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Bc4 Nc6 7. Be3
			variation => N__('Sicilian: Sozin, 7. Be3'),
			moves => {
				'a7a6' => 1,
				'f8e7' => 1,
			},
		},
		'r1bqkb1r/1p3ppp/p1nppn2/8/2BNP3/2N1B3/PPP2PPP/R2QK2R w KQkq' => {
			eco => 'B89',
			# TRANSLATORS: B89: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Bc4 Nc6 7. Be3 a6
			variation => N__('Sicilian: Sozin, 7. Be3 a6'),
			moves => {
				'd1e2' => 1,
			},
		},
		'r1bqkb1r/1p3ppp/p1nppn2/8/2BNP3/2N1B3/PPP1QPPP/R3K2R b KQkq' => {
			eco => 'B89',
			# TRANSLATORS: B89: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Bc4 Nc6 7. Be3 a6 8. Qe2
			variation => N__('Sicilian: Velimirovic vs. 7... a6'),
			moves => {
			},
		},
		'r1bqk2r/pp2bppp/2nppn2/8/2BNP3/2N1B3/PPP2PPP/R2QK2R w KQkq' => {
			eco => 'B89',
			# TRANSLATORS: B89: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Bc4 Nc6 7. Be3 Be7
			variation => N__('Sicilian: Sozin, 7. Be3 Be7'),
			moves => {
				'd1e2' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2nppn2/8/2BNP3/2N1B3/PPP1QPPP/R3K2R b KQkq' => {
			eco => 'B89',
			# TRANSLATORS: B89: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Bc4 Nc6 7. Be3 Be7 8. Qe2
			variation => N__('Sicilian: Velimirovic'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2nppn2/8/2BNP3/2N1B3/PPP1QPPP/R3K2R w KQ' => {
			eco => 'B89',
			# TRANSLATORS: B89: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Bc4 Nc6 7. Be3 Be7 8. Qe2 O-O
			variation => N__('Sicilian: Velimirovic'),
			moves => {
				'e1c1' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2nppn2/8/2BNP3/2N1B3/PPP1QPPP/2KR3R b -' => {
			eco => 'B89',
			# TRANSLATORS: B89: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Bc4 Nc6 7. Be3 Be7 8. Qe2 O-O 9. O-O-O
			variation => N__('Sicilian: Velimirovic, 9.O-O-O'),
			moves => {
				'd8c7' => 1,
			},
		},
		'r1b2rk1/ppq1bppp/2nppn2/8/2BNP3/2N1B3/PPP1QPPP/2KR3R w -' => {
			eco => 'B89',
			# TRANSLATORS: B89: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Bc4 Nc6 7. Be3 Be7 8. Qe2 O-O 9. O-O-O Qc7
			variation => N__('Sicilian: Velimirovic, 9.O-O-O Qc7'),
			moves => {
				'c4b3' => 1,
			},
		},
		'r1b2rk1/ppq1bppp/2nppn2/8/3NP3/1BN1B3/PPP1QPPP/2KR3R b -' => {
			eco => 'B89',
			# TRANSLATORS: B89: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Bc4 Nc6 7. Be3 Be7 8. Qe2 O-O 9. O-O-O Qc7 10. Bb3
			variation => N__('Sicilian: Velimirovic, 9.O-O-O Qc7'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r1b2rk1/1pq1bppp/p1nppn2/8/3NP3/1BN1B3/PPP1QPPP/2KR3R w -' => {
			eco => 'B89',
			# TRANSLATORS: B89: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 e6 6. Bc4 Nc6 7. Be3 Be7 8. Qe2 O-O 9. O-O-O Qc7 10. Bb3 a6
			variation => N__('Sicilian: Velimirovic, 9.O-O-O Qc7 10. Bb3 a6'),
			moves => {
			},
		},
		'rnbqkb1r/1p2pppp/p2p1n2/8/3NP3/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B90a',
			# TRANSLATORS: B90a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6
			variation => N__('Sicilian: Najdorf'),
			moves => {
				'a2a4' => 1,
				'c1e3' => 1,
				'c1g5' => 1,
				'f1c4' => 1,
				'f1e2' => 1,
				'f2f3' => 1,
				'f2f4' => 1,
				'g2g3' => 1,
				'h2h3' => 1,
			},
		},
		'rnbqkb1r/1p2pppp/p2p1n2/8/P2NP3/2N5/1PP2PPP/R1BQKB1R b KQkq' => {
			eco => 'B90b',
			# TRANSLATORS: B90b: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. a4
			variation => N__('Sicilian: Najdorf, 6. a4'),
			moves => {
				'e7e5' => 1,
			},
		},
		'rnbqkb1r/1p3ppp/p2p1n2/4p3/P2NP3/2N5/1PP2PPP/R1BQKB1R w KQkq' => {
			eco => 'B90c',
			# TRANSLATORS: B90c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. a4 e5
			variation => N__('Sicilian: Najdorf, 6. a4 e5'),
			moves => {
			},
		},
		'rnbqkb1r/1p2pppp/p2p1n2/8/3NP3/2N2P2/PPP3PP/R1BQKB1R b KQkq' => {
			eco => 'B90d',
			# TRANSLATORS: B90d: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. f3
			variation => N__('Sicilian: Najdorf, 6. f3'),
			moves => {
			},
		},
		'rnbqkb1r/1p2pppp/p2p1n2/8/3NP3/2N4P/PPP2PP1/R1BQKB1R b KQkq' => {
			eco => 'B90e',
			# TRANSLATORS: B90e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. h3
			variation => N__('Sicilian: Najdorf, Adams Attack'),
			moves => {
			},
		},
		'rnbqkb1r/1p2pppp/p2p1n2/8/2BNP3/2N5/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'B90f',
			# TRANSLATORS: B90f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bc4
			variation => N__('Sicilian: Najdorf, Fischer-Sozin Attack'),
			moves => {
			},
		},
		'rnbqkb1r/1p2pppp/p2p1n2/8/3NP3/2N1B3/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'B90g',
			# TRANSLATORS: B90g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be3
			variation => N__('Sicilian: Najdorf, 6. Be3'),
			moves => {
				'e7e5' => 1,
				'f6g4' => 1,
			},
		},
		'rnbqkb1r/1p2pppp/p2p4/8/3NP1n1/2N1B3/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B90h',
			# TRANSLATORS: B90h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be3 Ng4
			variation => N__('Sicilian: Najdorf, 6. Be3 Ng4'),
			moves => {
				'e3g5' => 1,
			},
		},
		'rnbqkb1r/1p2pppp/p2p4/6B1/3NP1n1/2N5/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'B90h',
			# TRANSLATORS: B90h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be3 Ng4 7. Bg5
			variation => N__('Sicilian: Najdorf, 6. Be3 Ng4 7. Bg5'),
			moves => {
				'h7h6' => 1,
			},
		},
		'rnbqkb1r/1p2ppp1/p2p3p/6B1/3NP1n1/2N5/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B90h',
			# TRANSLATORS: B90h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be3 Ng4 7. Bg5 h6
			variation => N__('Sicilian: Najdorf, 6. Be3 Ng4 7. Bg5'),
			moves => {
				'g5h4' => 1,
			},
		},
		'rnbqkb1r/1p2ppp1/p2p3p/8/3NP1nB/2N5/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'B90h',
			# TRANSLATORS: B90h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be3 Ng4 7. Bg5 h6 8. Bh4
			variation => N__('Sicilian: Najdorf, 6. Be3 Ng4 7. Bg5'),
			moves => {
				'g7g5' => 1,
			},
		},
		'rnbqkb1r/1p2pp2/p2p3p/6p1/3NP1nB/2N5/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B90h',
			# TRANSLATORS: B90h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be3 Ng4 7. Bg5 h6 8. Bh4 g5
			variation => N__('Sicilian: Najdorf, 6. Be3 Ng4 7. Bg5'),
			moves => {
				'h4g3' => 1,
			},
		},
		'rnbqkb1r/1p2pp2/p2p3p/6p1/3NP1n1/2N3B1/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'B90h',
			# TRANSLATORS: B90h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be3 Ng4 7. Bg5 h6 8. Bh4 g5 9. Bg3
			variation => N__('Sicilian: Najdorf, 6. Be3 Ng4 7. Bg5'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/1p2ppb1/p2p3p/6p1/3NP1n1/2N3B1/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B90i',
			# TRANSLATORS: B90i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be3 Ng4 7. Bg5 h6 8. Bh4 g5 9. Bg3 Bg7
			variation => N__('Sicilian: Najdorf, 6. Be3 Ng4 7. Bg5 h6 8. Bh4 g5 9. Bg3 Bg7'),
			moves => {
				'f1e2' => 1,
			},
		},
		'rnbqk2r/1p2ppb1/p2p3p/6p1/3NP1n1/2N3B1/PPP1BPPP/R2QK2R b KQkq' => {
			eco => 'B90j',
			# TRANSLATORS: B90j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be3 Ng4 7. Bg5 h6 8. Bh4 g5 9. Bg3 Bg7 10. Be2
			variation => N__('Sicilian: Najdorf, 6. Be3 Ng4 7. Bg5 h6 8. Bh4 g5 9. Bg3 Bg7 10. Be2'),
			moves => {
				'h6h5' => 1,
			},
		},
		'rnbqk2r/1p2ppb1/p2p4/6pp/3NP1n1/2N3B1/PPP1BPPP/R2QK2R w KQkq' => {
			eco => 'B90j',
			# TRANSLATORS: B90j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be3 Ng4 7. Bg5 h6 8. Bh4 g5 9. Bg3 Bg7 10. Be2 h5
			variation => N__('Sicilian: Najdorf, 6. Be3 Ng4 7. Bg5 h6 8. Bh4 g5 9. Bg3 Bg7 10. Be2 h5'),
			moves => {
			},
		},
		'rnbqkb1r/1p3ppp/p2p1n2/4p3/3NP3/2N1B3/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B90k',
			# TRANSLATORS: B90k: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be3 e5
			variation => N__('Sicilian: Najdorf, 6. Be3 e5'),
			moves => {
				'd4b3' => 1,
			},
		},
		'rnbqkb1r/1p3ppp/p2p1n2/4p3/4P3/1NN1B3/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'B90l',
			# TRANSLATORS: B90l: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be3 e5 7. Nb3
			variation => N__('Sicilian: Najdorf, 6. Be3 e5 7. Nb3'),
			moves => {
				'c8e6' => 1,
			},
		},
		'rn1qkb1r/1p3ppp/p2pbn2/4p3/4P3/1NN1B3/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B90l',
			# TRANSLATORS: B90l: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be3 e5 7. Nb3 Be6
			variation => N__('Sicilian: Najdorf, 6. Be3 e5 7. Nb3'),
			moves => {
				'd1d2' => 1,
				'f2f3' => 1,
			},
		},
		'rn1qkb1r/1p3ppp/p2pbn2/4p3/4P3/1NN1B3/PPPQ1PPP/R3KB1R b KQkq' => {
			eco => 'B90m',
			# TRANSLATORS: B90m: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be3 e5 7. Nb3 Be6 8. Qd2
			variation => N__('Sicilian: Najdorf, 6. Be3 e5 7. Nb3 Be6 8. Qd2'),
			moves => {
			},
		},
		'rn1qkb1r/1p3ppp/p2pbn2/4p3/4P3/1NN1BP2/PPP3PP/R2QKB1R b KQkq' => {
			eco => 'B90n',
			# TRANSLATORS: B90n: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be3 e5 7. Nb3 Be6 8. f3
			variation => N__('Sicilian: Najdorf, 6. Be3 e5 7. Nb3 Be6 8. f3'),
			moves => {
				'b8d7' => 1,
				'f8e7' => 1,
			},
		},
		'rn1qk2r/1p2bppp/p2pbn2/4p3/4P3/1NN1BP2/PPP3PP/R2QKB1R w KQkq' => {
			eco => 'B90o',
			# TRANSLATORS: B90o: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be3 e5 7. Nb3 Be6 8. f3 Be7
			variation => N__('Sicilian: Najdorf, 6. Be3 e5 7. Nb3 Be6 8. f3 Be7'),
			moves => {
				'd1d2' => 1,
			},
		},
		'rn1qk2r/1p2bppp/p2pbn2/4p3/4P3/1NN1BP2/PPPQ2PP/R3KB1R b KQkq' => {
			eco => 'B90o',
			# TRANSLATORS: B90o: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be3 e5 7. Nb3 Be6 8. f3 Be7 9. Qd2
			variation => N__('Sicilian: Najdorf, 6. Be3 e5 7. Nb3 Be6 8. f3 Be7 9. Qd2'),
			moves => {
				'b8d7' => 1,
				'e8g8' => 1,
			},
		},
		'r2qk2r/1p1nbppp/p2pbn2/4p3/4P3/1NN1BP2/PPPQ2PP/R3KB1R w KQkq' => {
			eco => 'B90p',
			# TRANSLATORS: B90p: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be3 e5 7. Nb3 Be6 8. f3 Be7 9. Qd2 Nbd7
			variation => N__('Sicilian: Najdorf, 6. Be3 e5 7. Nb3 Be6 8. f3 Be7 9. Qd2 Nbd7'),
			moves => {
			},
		},
		'rn1q1rk1/1p2bppp/p2pbn2/4p3/4P3/1NN1BP2/PPPQ2PP/R3KB1R w KQ' => {
			eco => 'B90q',
			# TRANSLATORS: B90q: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be3 e5 7. Nb3 Be6 8. f3 Be7 9. Qd2 O-O
			variation => N__('Sicilian: Najdorf, 6. Be3 e5 7. Nb3 Be6 8. f3 Be7 9. Qd2 O-O'),
			moves => {
				'e1c1' => 1,
			},
		},
		'rn1q1rk1/1p2bppp/p2pbn2/4p3/4P3/1NN1BP2/PPPQ2PP/2KR1B1R b -' => {
			eco => 'B90q',
			# TRANSLATORS: B90q: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be3 e5 7. Nb3 Be6 8. f3 Be7 9. Qd2 O-O 10. O-O-O
			variation => N__('Sicilian: Najdorf, 6. Be3 e5 7. Nb3 Be6 8. f3 Be7 9. Qd2 O-O 10.O-O-O'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r2q1rk1/1p1nbppp/p2pbn2/4p3/4P3/1NN1BP2/PPPQ2PP/2KR1B1R w -' => {
			eco => 'B90r',
			# TRANSLATORS: B90r: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be3 e5 7. Nb3 Be6 8. f3 Be7 9. Qd2 O-O 10. O-O-O Nbd7
			variation => N__('Sicilian: Najdorf, 6. Be3 e5 7. Nb3 Be6 8. f3 Be7 9. Qd2 O-O 10.O-O-O Nbd7'),
			moves => {
			},
		},
		'r2qkb1r/1p1n1ppp/p2pbn2/4p3/4P3/1NN1BP2/PPP3PP/R2QKB1R w KQkq' => {
			eco => 'B90s',
			# TRANSLATORS: B90s: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be3 e5 7. Nb3 Be6 8. f3 Nbd7
			variation => N__('Sicilian: Najdorf, 6. Be3 e5 7. Nb3 Be6 8. f3 Nbd7'),
			moves => {
				'd1d2' => 1,
			},
		},
		'r2qkb1r/1p1n1ppp/p2pbn2/4p3/4P3/1NN1BP2/PPPQ2PP/R3KB1R b KQkq' => {
			eco => 'B90t',
			# TRANSLATORS: B90t: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be3 e5 7. Nb3 Be6 8. f3 Nbd7 9. Qd2
			variation => N__('Sicilian: Najdorf, 6. Be3 e5 7. Nb3 Be6 8. f3 Be7 9. Qd2'),
			moves => {
				'b7b5' => 1,
			},
		},
		'r2qkb1r/3n1ppp/p2pbn2/1p2p3/4P3/1NN1BP2/PPPQ2PP/R3KB1R w KQkq' => {
			eco => 'B90u',
			# TRANSLATORS: B90u: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be3 e5 7. Nb3 Be6 8. f3 Nbd7 9. Qd2 b5
			variation => N__('Sicilian: Najdorf, 6. Be3 e5 7. Nb3 Be6 8. f3 Be7 9. Qd2 b5'),
			moves => {
			},
		},
		'rnbqkb1r/1p2pppp/p2p1n2/8/3NP3/2N3P1/PPP2P1P/R1BQKB1R b KQkq' => {
			eco => 'B91a',
			# TRANSLATORS: B91a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. g3
			variation => N__('Sicilian: Najdorf, 6. g3'),
			moves => {
				'b7b5' => 1,
				'b8c6' => 1,
				'c8g4' => 1,
				'e7e5' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/4pppp/p2p1n2/1p6/3NP3/2N3P1/PPP2P1P/R1BQKB1R w KQkq' => {
			eco => 'B91b',
			# TRANSLATORS: B91b: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. g3 b5
			variation => N__('Sicilian: Najdorf, 6. g3 b5'),
			moves => {
			},
		},
		'rnbqkb1r/1p2pp1p/p2p1np1/8/3NP3/2N3P1/PPP2P1P/R1BQKB1R w KQkq' => {
			eco => 'B91c',
			# TRANSLATORS: B91c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. g3 g6
			variation => N__('Sicilian: Najdorf, 6. g3 g6'),
			moves => {
			},
		},
		'r1bqkb1r/1p2pppp/p1np1n2/8/3NP3/2N3P1/PPP2P1P/R1BQKB1R w KQkq' => {
			eco => 'B91d',
			# TRANSLATORS: B91d: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. g3 Nc6
			variation => N__('Sicilian: Najdorf, 6. g3 Nc6'),
			moves => {
			},
		},
		'rn1qkb1r/1p2pppp/p2p1n2/8/3NP1b1/2N3P1/PPP2P1P/R1BQKB1R w KQkq' => {
			eco => 'B91e',
			# TRANSLATORS: B91e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. g3 Bg4
			variation => N__('Sicilian: Najdorf, 6. g3 Bg4'),
			moves => {
			},
		},
		'rnbqkb1r/1p3ppp/p2p1n2/4p3/3NP3/2N3P1/PPP2P1P/R1BQKB1R w KQkq' => {
			eco => 'B91f',
			# TRANSLATORS: B91f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. g3 e5
			variation => N__('Sicilian: Najdorf, 6. g3 e5'),
			moves => {
				'd4b3' => 1,
				'd4e2' => 1,
			},
		},
		'rnbqkb1r/1p3ppp/p2p1n2/4p3/4P3/1NN3P1/PPP2P1P/R1BQKB1R b KQkq' => {
			eco => 'B91g',
			# TRANSLATORS: B91g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. g3 e5 7. Nb3
			variation => N__('Sicilian: Najdorf, 6. g3 e5 7. Nb3'),
			moves => {
				'f8e7' => 1,
			},
		},
		'rnbqk2r/1p2bppp/p2p1n2/4p3/4P3/1NN3P1/PPP2P1P/R1BQKB1R w KQkq' => {
			eco => 'B91h',
			# TRANSLATORS: B91h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. g3 e5 7. Nb3 Be7
			variation => N__('Sicilian: Najdorf, 6. g3 e5 7. Nb3 Be7'),
			moves => {
			},
		},
		'rnbqkb1r/1p3ppp/p2p1n2/4p3/4P3/2N3P1/PPP1NP1P/R1BQKB1R b KQkq' => {
			eco => 'B91i',
			# TRANSLATORS: B91i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. g3 e5 7. Nde2
			variation => N__('Sicilian: Najdorf, 6. g3 e5 7.Nde2'),
			moves => {
				'b7b5' => 1,
				'b8d7' => 1,
				'f8e7' => 1,
			},
		},
		'rnbqkb1r/5ppp/p2p1n2/1p2p3/4P3/2N3P1/PPP1NP1P/R1BQKB1R w KQkq' => {
			eco => 'B91j',
			# TRANSLATORS: B91j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. g3 e5 7. Nde2 b5
			variation => N__('Sicilian: Najdorf, 6. g3 e5 7.Nde2 b5'),
			moves => {
			},
		},
		'r1bqkb1r/1p1n1ppp/p2p1n2/4p3/4P3/2N3P1/PPP1NP1P/R1BQKB1R w KQkq' => {
			eco => 'B91k',
			# TRANSLATORS: B91k: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. g3 e5 7. Nde2 Nbd7
			variation => N__('Sicilian: Najdorf, 6. g3 e5 7.Nde2 Nbd7'),
			moves => {
			},
		},
		'rnbqk2r/1p2bppp/p2p1n2/4p3/4P3/2N3P1/PPP1NP1P/R1BQKB1R w KQkq' => {
			eco => 'B91l',
			# TRANSLATORS: B91l: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. g3 e5 7. Nde2 Be7
			variation => N__('Sicilian: Najdorf, 6. g3 e5 7.Nde2 Be7'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqk2r/1p2bppp/p2p1n2/4p3/4P3/2N3P1/PPP1NPBP/R1BQK2R b KQkq' => {
			eco => 'B91l',
			# TRANSLATORS: B91l: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. g3 e5 7. Nde2 Be7 8. Bg2
			variation => N__('Sicilian: Najdorf, 6. g3 e5 7.Nde2 Be7'),
			moves => {
				'b8d7' => 1,
				'e8g8' => 1,
			},
		},
		'r1bqk2r/1p1nbppp/p2p1n2/4p3/4P3/2N3P1/PPP1NPBP/R1BQK2R w KQkq' => {
			eco => 'B91m',
			# TRANSLATORS: B91m: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. g3 e5 7. Nde2 Be7 8. Bg2 Nbd7
			variation => N__('Sicilian: Najdorf, 6. g3 e5 7.Nde2 Be7 8. Bg2 Nbd7'),
			moves => {
			},
		},
		'rnbq1rk1/1p2bppp/p2p1n2/4p3/4P3/2N3P1/PPP1NPBP/R1BQK2R w KQ' => {
			eco => 'B91n',
			# TRANSLATORS: B91n: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. g3 e5 7. Nde2 Be7 8. Bg2 O-O
			variation => N__('Sicilian: Najdorf, 6. g3 e5 7.Nde2 Be7 8. Bg2 O-O'),
			moves => {
			},
		},
		'rnbqkb1r/1p2pppp/p2p1n2/8/3NP3/2N5/PPP1BPPP/R1BQK2R b KQkq' => {
			eco => 'B92a',
			# TRANSLATORS: B92a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be2
			variation => N__('Sicilian: Najdorf, 6. Be2'),
			moves => {
				'b8d7' => 1,
				'e7e5' => 1,
			},
		},
		'r1bqkb1r/1p1npppp/p2p1n2/8/3NP3/2N5/PPP1BPPP/R1BQK2R w KQkq' => {
			eco => 'B92b',
			# TRANSLATORS: B92b: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be2 Nbd7
			variation => N__('Sicilian: Najdorf, 6. Be2 Nbd7'),
			moves => {
			},
		},
		'rnbqkb1r/1p3ppp/p2p1n2/4p3/3NP3/2N5/PPP1BPPP/R1BQK2R w KQkq' => {
			eco => 'B92c',
			# TRANSLATORS: B92c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be2 e5
			variation => N__('Sicilian: Najdorf, 6. Be2 e5'),
			moves => {
				'd4b3' => 1,
				'd4f3' => 1,
			},
		},
		'rnbqkb1r/1p3ppp/p2p1n2/4p3/4P3/2N2N2/PPP1BPPP/R1BQK2R b KQkq' => {
			eco => 'B92d',
			# TRANSLATORS: B92d: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be2 e5 7. Nf3
			variation => N__('Sicilian: Najdorf, 6. Be2 e5 7. Nf3'),
			moves => {
			},
		},
		'rnbqkb1r/1p3ppp/p2p1n2/4p3/4P3/1NN5/PPP1BPPP/R1BQK2R b KQkq' => {
			eco => 'B92e',
			# TRANSLATORS: B92e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be2 e5 7. Nb3
			variation => N__('Sicilian: Najdorf, 6. Be2 e5 7. Nb3'),
			moves => {
				'f8e7' => 1,
			},
		},
		'rnbqk2r/1p2bppp/p2p1n2/4p3/4P3/1NN5/PPP1BPPP/R1BQK2R w KQkq' => {
			eco => 'B92f',
			# TRANSLATORS: B92f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be2 e5 7. Nb3 Be7
			variation => N__('Sicilian: Najdorf, 6. Be2 e5 7. Nb3 Be7'),
			moves => {
				'c1e3' => 1,
				'e1g1' => 1,
			},
		},
		'rnbqk2r/1p2bppp/p2p1n2/4p3/4P3/1NN1B3/PPP1BPPP/R2QK2R b KQkq' => {
			eco => 'B92g',
			# TRANSLATORS: B92g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be2 e5 7. Nb3 Be7 8. Be3
			variation => N__('Sicilian: Najdorf, 6. Be2 e5 7. Nb3 Be7 8. Be3'),
			moves => {
				'c8e6' => 1,
			},
		},
		'rn1qk2r/1p2bppp/p2pbn2/4p3/4P3/1NN1B3/PPP1BPPP/R2QK2R w KQkq' => {
			eco => 'B92g',
			# TRANSLATORS: B92g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be2 e5 7. Nb3 Be7 8. Be3 Be6
			variation => N__('Sicilian: Najdorf, 6. Be2 e5 7. Nb3 Be7 8. Be3 Be6'),
			moves => {
			},
		},
		'rnbqk2r/1p2bppp/p2p1n2/4p3/4P3/1NN5/PPP1BPPP/R1BQ1RK1 b kq' => {
			eco => 'B92h',
			# TRANSLATORS: B92h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be2 e5 7. Nb3 Be7 8. O-O
			variation => N__('Sicilian: Najdorf, 6. Be2 e5 7. Nb3 Be7 8.O-O'),
			moves => {
				'c8e6' => 1,
				'e8g8' => 1,
			},
		},
		'rn1qk2r/1p2bppp/p2pbn2/4p3/4P3/1NN5/PPP1BPPP/R1BQ1RK1 w kq' => {
			eco => 'B92h',
			# TRANSLATORS: B92h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be2 e5 7. Nb3 Be7 8. O-O Be6
			variation => N__('Sicilian: Najdorf, 6. Be2 e5 7. Nb3 Be7 8.O-O Be6'),
			moves => {
				'f2f4' => 1,
			},
		},
		'rn1qk2r/1p2bppp/p2pbn2/4p3/4PP2/1NN5/PPP1B1PP/R1BQ1RK1 b kq' => {
			eco => 'B92i',
			# TRANSLATORS: B92i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be2 e5 7. Nb3 Be7 8. O-O Be6 9. f4
			variation => N__('Sicilian: Najdorf, 6. Be2 e5 7. Nb3 Be7 8.O-O Be6 9. f4'),
			moves => {
			},
		},
		'rnbq1rk1/1p2bppp/p2p1n2/4p3/4P3/1NN5/PPP1BPPP/R1BQ1RK1 w -' => {
			eco => 'B92j',
			# TRANSLATORS: B92j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be2 e5 7. Nb3 Be7 8. O-O O-O
			variation => N__('Sicilian: Najdorf, 6. Be2 e5 7. Nb3 Be7 8.O-O O-O'),
			moves => {
				'c1e3' => 1,
				'g1h1' => 1,
			},
		},
		'rnbq1rk1/1p2bppp/p2p1n2/4p3/4P3/1NN1B3/PPP1BPPP/R2Q1RK1 b -' => {
			eco => 'B92k',
			# TRANSLATORS: B92k: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be2 e5 7. Nb3 Be7 8. O-O O-O 9. Be3
			variation => N__('Sicilian: Najdorf, 6. Be2 e5 7. Nb3 Be7 8.O-O O-O 9. Be3'),
			moves => {
				'c8e6' => 1,
			},
		},
		'rn1q1rk1/1p2bppp/p2pbn2/4p3/4P3/1NN1B3/PPP1BPPP/R2Q1RK1 w -' => {
			eco => 'B92k',
			# TRANSLATORS: B92k: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be2 e5 7. Nb3 Be7 8. O-O O-O 9. Be3 Be6
			variation => N__('Sicilian: Najdorf, 6. Be2 e5 7. Nb3 Be7 8.O-O O-O 9. Be3 Be6'),
			moves => {
				'a2a4' => 1,
				'c3d5' => 1,
				'd1d2' => 1,
			},
		},
		'rn1q1rk1/1p2bppp/p2pbn2/4p3/P3P3/1NN1B3/1PP1BPPP/R2Q1RK1 b -' => {
			eco => 'B92l',
			# TRANSLATORS: B92l: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be2 e5 7. Nb3 Be7 8. O-O O-O 9. Be3 Be6 10. a4
			variation => N__('Sicilian: Najdorf, 6. Be2 e5 7. Nb3 Be7 8.O-O O-O 9. Be3 Be6 10. a4'),
			moves => {
			},
		},
		'rn1q1rk1/1p2bppp/p2pbn2/3Np3/4P3/1N2B3/PPP1BPPP/R2Q1RK1 b -' => {
			eco => 'B92m',
			# TRANSLATORS: B92m: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be2 e5 7. Nb3 Be7 8. O-O O-O 9. Be3 Be6 10. Nd5
			variation => N__('Sicilian: Najdorf, 6. Be2 e5 7. Nb3 Be7 8.O-O O-O 9. Be3 Be6 10. Nd5'),
			moves => {
			},
		},
		'rn1q1rk1/1p2bppp/p2pbn2/4p3/4P3/1NN1B3/PPPQBPPP/R4RK1 b -' => {
			eco => 'B92n',
			# TRANSLATORS: B92n: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be2 e5 7. Nb3 Be7 8. O-O O-O 9. Be3 Be6 10. Qd2
			variation => N__('Sicilian: Najdorf, 6. Be2 e5 7. Nb3 Be7 8.O-O O-O 9. Be3 Be6 10. Qd2'),
			moves => {
			},
		},
		'rnbq1rk1/1p2bppp/p2p1n2/4p3/4P3/1NN5/PPP1BPPP/R1BQ1R1K b -' => {
			eco => 'B92o',
			# TRANSLATORS: B92o: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be2 e5 7. Nb3 Be7 8. O-O O-O 9. Kh1
			variation => N__('Sicilian: Najdorf, 6. Be2 e5 7. Nb3 Be7 8.O-O O-O 9. Kh1'),
			moves => {
				'b8c6' => 1,
				'c8e6' => 1,
				'd8c7' => 1,
			},
		},
		'rn1q1rk1/1p2bppp/p2pbn2/4p3/4P3/1NN5/PPP1BPPP/R1BQ1R1K w -' => {
			eco => 'B92p',
			# TRANSLATORS: B92p: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be2 e5 7. Nb3 Be7 8. O-O O-O 9. Kh1 Be6
			variation => N__('Sicilian: Najdorf, 6. Be2 e5 7. Nb3 Be7 8.O-O O-O 9. Kh1 Be6'),
			moves => {
			},
		},
		'r1bq1rk1/1p2bppp/p1np1n2/4p3/4P3/1NN5/PPP1BPPP/R1BQ1R1K w -' => {
			eco => 'B92q',
			# TRANSLATORS: B92q: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be2 e5 7. Nb3 Be7 8. O-O O-O 9. Kh1 Nc6
			variation => N__('Sicilian: Najdorf, 6. Be2 e5 7. Nb3 Be7 8.O-O O-O 9. Kh1 Nc6'),
			moves => {
			},
		},
		'rnb2rk1/1pq1bppp/p2p1n2/4p3/4P3/1NN5/PPP1BPPP/R1BQ1R1K w -' => {
			eco => 'B92r',
			# TRANSLATORS: B92r: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Be2 e5 7. Nb3 Be7 8. O-O O-O 9. Kh1 Qc7
			variation => N__('Sicilian: Najdorf, 6. Be2 e5 7. Nb3 Be7 8.O-O O-O 9. Kh1 Qc7'),
			moves => {
			},
		},
		'rnbqkb1r/1p2pppp/p2p1n2/8/3NPP2/2N5/PPP3PP/R1BQKB1R b KQkq' => {
			eco => 'B93a',
			# TRANSLATORS: B93a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. f4
			variation => N__('Sicilian: Najdorf, 6. f4'),
			moves => {
				'b8c6' => 1,
				'b8d7' => 1,
				'd8c7' => 1,
				'e7e5' => 1,
			},
		},
		'r1bqkb1r/1p2pppp/p1np1n2/8/3NPP2/2N5/PPP3PP/R1BQKB1R w KQkq' => {
			eco => 'B93b',
			# TRANSLATORS: B93b: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. f4 Nc6
			variation => N__('Sicilian: Najdorf, 6. f4 Nc6'),
			moves => {
			},
		},
		'r1bqkb1r/1p1npppp/p2p1n2/8/3NPP2/2N5/PPP3PP/R1BQKB1R w KQkq' => {
			eco => 'B93c',
			# TRANSLATORS: B93c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. f4 Nbd7
			variation => N__('Sicilian: Najdorf, 6. f4 Nbd7'),
			moves => {
				'f1e2' => 1,
			},
		},
		'r1bqkb1r/1p1npppp/p2p1n2/8/3NPP2/2N5/PPP1B1PP/R1BQK2R b KQkq' => {
			eco => 'B93d',
			# TRANSLATORS: B93d: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. f4 Nbd7 7. Be2
			variation => N__('Sicilian: Najdorf, 6. f4 Nbd7 7. Be2'),
			moves => {
			},
		},
		'rnb1kb1r/1pq1pppp/p2p1n2/8/3NPP2/2N5/PPP3PP/R1BQKB1R w KQkq' => {
			eco => 'B93e',
			# TRANSLATORS: B93e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. f4 Qc7
			variation => N__('Sicilian: Najdorf, 6. f4 Qc7'),
			moves => {
				'd4f3' => 1,
				'f1d3' => 1,
			},
		},
		'rnb1kb1r/1pq1pppp/p2p1n2/8/3NPP2/2NB4/PPP3PP/R1BQK2R b KQkq' => {
			eco => 'B93f',
			# TRANSLATORS: B93f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. f4 Qc7 7. Bd3
			variation => N__('Sicilian: Najdorf, 6. f4 Qc7 7. Bd3'),
			moves => {
				'g7g6' => 1,
			},
		},
		'rnb1kb1r/1pq1pp1p/p2p1np1/8/3NPP2/2NB4/PPP3PP/R1BQK2R w KQkq' => {
			eco => 'B93g',
			# TRANSLATORS: B93g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. f4 Qc7 7. Bd3 g6
			variation => N__('Sicilian: Najdorf, 6. f4 Qc7 7. Bd3 g6'),
			moves => {
			},
		},
		'rnb1kb1r/1pq1pppp/p2p1n2/8/4PP2/2N2N2/PPP3PP/R1BQKB1R b KQkq' => {
			eco => 'B93h',
			# TRANSLATORS: B93h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. f4 Qc7 7. Nf3
			variation => N__('Sicilian: Najdorf, 6. f4 Qc7 7. Nf3'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r1b1kb1r/1pqnpppp/p2p1n2/8/4PP2/2N2N2/PPP3PP/R1BQKB1R w KQkq' => {
			eco => 'B93i',
			# TRANSLATORS: B93i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. f4 Qc7 7. Nf3 Nbd7
			variation => N__('Sicilian: Najdorf, 6. f4 Qc7 7. Nf3 Nbd7'),
			moves => {
				'f1d3' => 1,
			},
		},
		'r1b1kb1r/1pqnpppp/p2p1n2/8/4PP2/2NB1N2/PPP3PP/R1BQK2R b KQkq' => {
			eco => 'B93j',
			# TRANSLATORS: B93j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. f4 Qc7 7. Nf3 Nbd7 8. Bd3
			variation => N__('Sicilian: Najdorf, 6. f4 Qc7 7. Nf3 Nbd7 8. Bd3'),
			moves => {
			},
		},
		'rnbqkb1r/1p3ppp/p2p1n2/4p3/3NPP2/2N5/PPP3PP/R1BQKB1R w KQkq' => {
			eco => 'B93k',
			# TRANSLATORS: B93k: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. f4 e5
			variation => N__('Sicilian: Najdorf, 6. f4 e5'),
			moves => {
				'd4f3' => 1,
			},
		},
		'rnbqkb1r/1p3ppp/p2p1n2/4p3/4PP2/2N2N2/PPP3PP/R1BQKB1R b KQkq' => {
			eco => 'B93k',
			# TRANSLATORS: B93k: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. f4 e5 7. Nf3
			variation => N__('Sicilian: Najdorf, 6. f4 e5 7. Nf3'),
			moves => {
				'b8d7' => 1,
				'd8c7' => 1,
			},
		},
		'rnb1kb1r/1pq2ppp/p2p1n2/4p3/4PP2/2N2N2/PPP3PP/R1BQKB1R w KQkq' => {
			eco => 'B93l',
			# TRANSLATORS: B93l: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. f4 e5 7. Nf3 Qc7
			variation => N__('Sicilian: Najdorf, 6. f4 e5 7. Nf3 Qc7'),
			moves => {
				'a2a4' => 1,
			},
		},
		'rnb1kb1r/1pq2ppp/p2p1n2/4p3/P3PP2/2N2N2/1PP3PP/R1BQKB1R b KQkq' => {
			eco => 'B93m',
			# TRANSLATORS: B93m: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. f4 e5 7. Nf3 Qc7 8. a4
			variation => N__('Sicilian: Najdorf, 6. f4 e5 7. Nf3 Qc7 8. a4'),
			moves => {
			},
		},
		'r1bqkb1r/1p1n1ppp/p2p1n2/4p3/4PP2/2N2N2/PPP3PP/R1BQKB1R w KQkq' => {
			eco => 'B93n',
			# TRANSLATORS: B93n: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. f4 e5 7. Nf3 Nbd7
			variation => N__('Sicilian: Najdorf, 6. f4 e5 7. Nf3 Nbd7'),
			moves => {
				'a2a4' => 1,
				'f1d3' => 1,
			},
		},
		'r1bqkb1r/1p1n1ppp/p2p1n2/4p3/4PP2/2NB1N2/PPP3PP/R1BQK2R b KQkq' => {
			eco => 'B93o',
			# TRANSLATORS: B93o: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. f4 e5 7. Nf3 Nbd7 8. Bd3
			variation => N__('Sicilian: Najdorf, 6. f4 e5 7. Nf3 Nbd7 8. Bd3'),
			moves => {
			},
		},
		'r1bqkb1r/1p1n1ppp/p2p1n2/4p3/P3PP2/2N2N2/1PP3PP/R1BQKB1R b KQkq' => {
			eco => 'B93p',
			# TRANSLATORS: B93p: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. f4 e5 7. Nf3 Nbd7 8. a4
			variation => N__('Sicilian: Najdorf, 6. f4 e5 7. Nf3 Nbd7 8. a4'),
			moves => {
				'd8c7' => 1,
				'f8e7' => 1,
			},
		},
		'r1b1kb1r/1pqn1ppp/p2p1n2/4p3/P3PP2/2N2N2/1PP3PP/R1BQKB1R w KQkq' => {
			eco => 'B93q',
			# TRANSLATORS: B93q: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. f4 e5 7. Nf3 Nbd7 8. a4 Qc7
			variation => N__('Sicilian: Najdorf, 6. f4 e5 7. Nf3 Nbd7 8. a4 Qc7'),
			moves => {
			},
		},
		'r1bqk2r/1p1nbppp/p2p1n2/4p3/P3PP2/2N2N2/1PP3PP/R1BQKB1R w KQkq' => {
			eco => 'B93r',
			# TRANSLATORS: B93r: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. f4 e5 7. Nf3 Nbd7 8. a4 Be7
			variation => N__('Sicilian: Najdorf, 6. f4 e5 7. Nf3 Nbd7 8. a4 Be7'),
			moves => {
				'f1c4' => 1,
				'f1d3' => 1,
			},
		},
		'r1bqk2r/1p1nbppp/p2p1n2/4p3/P1B1PP2/2N2N2/1PP3PP/R1BQK2R b KQkq' => {
			eco => 'B93r',
			# TRANSLATORS: B93r: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. f4 e5 7. Nf3 Nbd7 8. a4 Be7 9. Bc4
			variation => N__('Sicilian: Najdorf, 6. f4 e5 7. Nf3 Nbd7 8. a4 Be7 9. Bc4'),
			moves => {
			},
		},
		'r1bqk2r/1p1nbppp/p2p1n2/4p3/P3PP2/2NB1N2/1PP3PP/R1BQK2R b KQkq' => {
			eco => 'B93s',
			# TRANSLATORS: B93s: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. f4 e5 7. Nf3 Nbd7 8. a4 Be7 9. Bd3
			variation => N__('Sicilian: Najdorf, 6. f4 e5 7. Nf3 Nbd7 8. a4 Be7 9. Bd3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/1p1nbppp/p2p1n2/4p3/P3PP2/2NB1N2/1PP3PP/R1BQK2R w KQ' => {
			eco => 'B93s',
			# TRANSLATORS: B93s: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. f4 e5 7. Nf3 Nbd7 8. a4 Be7 9. Bd3 O-O
			variation => N__('Sicilian: Najdorf, 6. f4 e5 7. Nf3 Nbd7 8. a4 Be7 9. Bd3'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bq1rk1/1p1nbppp/p2p1n2/4p3/P3PP2/2NB1N2/1PP3PP/R1BQ1RK1 b -' => {
			eco => 'B93s',
			# TRANSLATORS: B93s: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. f4 e5 7. Nf3 Nbd7 8. a4 Be7 9. Bd3 O-O 10. O-O
			variation => N__('Sicilian: Najdorf, 6. f4 e5 7. Nf3 Nbd7 8. a4 Be7 9. Bd3'),
			moves => {
				'd7c5' => 1,
				'e5f4' => 1,
			},
		},
		'r1bq1rk1/1p2bppp/p2p1n2/2n1p3/P3PP2/2NB1N2/1PP3PP/R1BQ1RK1 w -' => {
			eco => 'B93t',
			# TRANSLATORS: B93t: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. f4 e5 7. Nf3 Nbd7 8. a4 Be7 9. Bd3 O-O 10. O-O Nc5
			variation => N__('Sicilian: Najdorf, 6. f4 e5 7. Nf3 Nbd7 8. a4 Be7 9. Bd3 O-O 10.O-O Nc5'),
			moves => {
			},
		},
		'r1bq1rk1/1p1nbppp/p2p1n2/8/P3Pp2/2NB1N2/1PP3PP/R1BQ1RK1 w -' => {
			eco => 'B93u',
			# TRANSLATORS: B93u: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. f4 e5 7. Nf3 Nbd7 8. a4 Be7 9. Bd3 O-O 10. O-O exf4
			variation => N__('Sicilian: Najdorf, 6. f4 e5 7. Nf3 Nbd7 8. a4 Be7 9. Bd3 O-O 10.O-O exf4'),
			moves => {
			},
		},
		'rnbqkb1r/1p2pppp/p2p1n2/6B1/3NP3/2N5/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'B94a',
			# TRANSLATORS: B94a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5
			variation => N__('Sicilian: Najdorf, 6. Bg5'),
			moves => {
				'b7b5' => 1,
				'b8d7' => 1,
				'e7e5' => 1,
				'e7e6' => 1,
			},
		},
		'rnbqkb1r/4pppp/p2p1n2/1p4B1/3NP3/2N5/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B94b',
			# TRANSLATORS: B94b: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 b5
			variation => N__('Sicilian: Najdorf, 6. Bg5 b5'),
			moves => {
			},
		},
		'rnbqkb1r/1p3ppp/p2p1n2/4p1B1/3NP3/2N5/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B94c',
			# TRANSLATORS: B94c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e5
			variation => N__('Sicilian: Najdorf, 6. Bg5 e5'),
			moves => {
			},
		},
		'r1bqkb1r/1p1npppp/p2p1n2/6B1/3NP3/2N5/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B94d',
			# TRANSLATORS: B94d: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 Nbd7
			variation => N__('Sicilian: Najdorf, 6. Bg5 Nbd7'),
			moves => {
				'f1c4' => 1,
				'f2f4' => 1,
			},
		},
		'r1bqkb1r/1p1npppp/p2p1n2/6B1/3NPP2/2N5/PPP3PP/R2QKB1R b KQkq' => {
			eco => 'B94e',
			# TRANSLATORS: B94e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 Nbd7 7. f4
			variation => N__('Sicilian: Najdorf, 6. Bg5 Nbd7 7. f4'),
			moves => {
				'b7b5' => 1,
			},
		},
		'r1bqkb1r/3npppp/p2p1n2/1p4B1/3NPP2/2N5/PPP3PP/R2QKB1R w KQkq' => {
			eco => 'B94f',
			# TRANSLATORS: B94f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 Nbd7 7. f4 b5
			variation => N__('Sicilian: Najdorf, 6. Bg5 Nbd7 7. f4 b5'),
			moves => {
			},
		},
		'r1bqkb1r/1p1npppp/p2p1n2/6B1/2BNP3/2N5/PPP2PPP/R2QK2R b KQkq' => {
			eco => 'B94g',
			# TRANSLATORS: B94g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 Nbd7 7. Bc4
			variation => N__('Sicilian: Najdorf, 6. Bg5 Nbd7 7. Bc4'),
			moves => {
				'd8a5' => 1,
				'e7e6' => 1,
			},
		},
		'r1bqkb1r/1p1n1ppp/p2ppn2/6B1/2BNP3/2N5/PPP2PPP/R2QK2R w KQkq' => {
			eco => 'B94h',
			# TRANSLATORS: B94h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 Nbd7 7. Bc4 e6
			variation => N__('Sicilian: Najdorf, 6. Bg5 Nbd7 7. Bc4 e6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqkb1r/1p1n1ppp/p2ppn2/6B1/2BNP3/2N5/PPP2PPP/R2Q1RK1 b kq' => {
			eco => 'B94i',
			# TRANSLATORS: B94i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 Nbd7 7. Bc4 e6 8. O-O
			variation => N__('Sicilian: Najdorf, 6. Bg5 Nbd7 7. Bc4 e6 8.O-O'),
			moves => {
			},
		},
		'r1b1kb1r/1p1npppp/p2p1n2/q5B1/2BNP3/2N5/PPP2PPP/R2QK2R w KQkq' => {
			eco => 'B94j',
			# TRANSLATORS: B94j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 Nbd7 7. Bc4 Qa5
			variation => N__('Sicilian: Najdorf, 6. Bg5 Nbd7 7. Bc4 Qa5'),
			moves => {
				'd1d2' => 1,
			},
		},
		'r1b1kb1r/1p1npppp/p2p1n2/q5B1/2BNP3/2N5/PPPQ1PPP/R3K2R b KQkq' => {
			eco => 'B94j',
			# TRANSLATORS: B94j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 Nbd7 7. Bc4 Qa5 8. Qd2
			variation => N__('Sicilian: Najdorf, 6. Bg5 Nbd7 7. Bc4 Qa5'),
			moves => {
				'e7e6' => 1,
			},
		},
		'r1b1kb1r/1p1n1ppp/p2ppn2/q5B1/2BNP3/2N5/PPPQ1PPP/R3K2R w KQkq' => {
			eco => 'B94j',
			# TRANSLATORS: B94j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 Nbd7 7. Bc4 Qa5 8. Qd2 e6
			variation => N__('Sicilian: Najdorf, 6. Bg5 Nbd7 7. Bc4 Qa5'),
			moves => {
				'e1c1' => 1,
			},
		},
		'r1b1kb1r/1p1n1ppp/p2ppn2/q5B1/2BNP3/2N5/PPPQ1PPP/2KR3R b kq' => {
			eco => 'B94k',
			# TRANSLATORS: B94k: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 Nbd7 7. Bc4 Qa5 8. Qd2 e6 9. O-O-O
			variation => N__('Sicilian: Najdorf, 6. Bg5 Nbd7 7. Bc4 Qa5 8. Qd2 e6 9.O-O-O'),
			moves => {
			},
		},
		'rnbqkb1r/1p3ppp/p2ppn2/6B1/3NP3/2N5/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'B95a',
			# TRANSLATORS: B95a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6
			variation => N__('Sicilian: Najdorf, 6... e6'),
			moves => {
				'd1d2' => 1,
				'd1d3' => 1,
				'd1e2' => 1,
				'd1f3' => 1,
				'f1d3' => 1,
				'f1e2' => 1,
				'f2f4' => 1,
			},
		},
		'rnbqkb1r/1p3ppp/p2ppn2/6B1/3NP3/2NB4/PPP2PPP/R2QK2R b KQkq' => {
			eco => 'B95b',
			# TRANSLATORS: B95b: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. Bd3
			variation => N__('Sicilian: Najdorf, 6... e6 7. Bd3'),
			moves => {
			},
		},
		'rnbqkb1r/1p3ppp/p2ppn2/6B1/3NP3/2N5/PPP1BPPP/R2QK2R b KQkq' => {
			eco => 'B95c',
			# TRANSLATORS: B95c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. Be2
			variation => N__('Sicilian: Najdorf, 6... e6 7. Be2'),
			moves => {
			},
		},
		'rnbqkb1r/1p3ppp/p2ppn2/6B1/3NP3/2N5/PPP1QPPP/R3KB1R b KQkq' => {
			eco => 'B95d',
			# TRANSLATORS: B95d: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. Qe2
			variation => N__('Sicilian: Najdorf, 6... e6 7. Qe2'),
			moves => {
			},
		},
		'rnbqkb1r/1p3ppp/p2ppn2/6B1/3NP3/2N5/PPPQ1PPP/R3KB1R b KQkq' => {
			eco => 'B95e',
			# TRANSLATORS: B95e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. Qd2
			variation => N__('Sicilian: Najdorf, 6... e6 7. Qd2'),
			moves => {
				'f8e7' => 1,
			},
		},
		'rnbqk2r/1p2bppp/p2ppn2/6B1/3NP3/2N5/PPPQ1PPP/R3KB1R w KQkq' => {
			eco => 'B95f',
			# TRANSLATORS: B95f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. Qd2 Be7
			variation => N__('Sicilian: Najdorf, 6... e6 7. Qd2 Be7'),
			moves => {
				'e1c1' => 1,
			},
		},
		'rnbqk2r/1p2bppp/p2ppn2/6B1/3NP3/2N5/PPPQ1PPP/2KR1B1R b kq' => {
			eco => 'B95g',
			# TRANSLATORS: B95g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. Qd2 Be7 8. O-O-O
			variation => N__('Sicilian: Najdorf, 6... e6 7. Qd2 Be7 8.O-O-O'),
			moves => {
			},
		},
		'rnbqkb1r/1p3ppp/p2ppn2/6B1/3NP3/2NQ4/PPP2PPP/R3KB1R b KQkq' => {
			eco => 'B95h',
			# TRANSLATORS: B95h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. Qd3
			variation => N__('Sicilian: Najdorf, 6... e6 7. Qd3'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkb1r/1p3ppp/p1nppn2/6B1/3NP3/2NQ4/PPP2PPP/R3KB1R w KQkq' => {
			eco => 'B95i',
			# TRANSLATORS: B95i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. Qd3 Nc6
			variation => N__('Sicilian: Najdorf, 6... e6 7. Qd3 Nc6'),
			moves => {
			},
		},
		'rnbqkb1r/1p3ppp/p2ppn2/6B1/3NP3/2N2Q2/PPP2PPP/R3KB1R b KQkq' => {
			eco => 'B95j',
			# TRANSLATORS: B95j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. Qf3
			variation => N__('Sicilian: Najdorf, 6... e6 7. Qf3'),
			moves => {
				'b8d7' => 1,
				'f8e7' => 1,
				'h7h6' => 1,
			},
		},
		'r1bqkb1r/1p1n1ppp/p2ppn2/6B1/3NP3/2N2Q2/PPP2PPP/R3KB1R w KQkq' => {
			eco => 'B95k',
			# TRANSLATORS: B95k: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. Qf3 Nbd7
			variation => N__('Sicilian: Najdorf, 6... e6 7. Qf3 Nbd7'),
			moves => {
			},
		},
		'rnbqk2r/1p2bppp/p2ppn2/6B1/3NP3/2N2Q2/PPP2PPP/R3KB1R w KQkq' => {
			eco => 'B95l',
			# TRANSLATORS: B95l: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. Qf3 Be7
			variation => N__('Sicilian: Najdorf, 6... e6 7. Qf3 Be7'),
			moves => {
				'e1c1' => 1,
			},
		},
		'rnbqk2r/1p2bppp/p2ppn2/6B1/3NP3/2N2Q2/PPP2PPP/2KR1B1R b kq' => {
			eco => 'B95l',
			# TRANSLATORS: B95l: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. Qf3 Be7 8. O-O-O
			variation => N__('Sicilian: Najdorf, 6... e6 7. Qf3 Be7'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r1bqk2r/1p1nbppp/p2ppn2/6B1/3NP3/2N2Q2/PPP2PPP/2KR1B1R w kq' => {
			eco => 'B95m',
			# TRANSLATORS: B95m: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. Qf3 Be7 8. O-O-O Nbd7
			variation => N__('Sicilian: Najdorf, 6... e6 7. Qf3 Be7 8.O-O-O Nbd7'),
			moves => {
			},
		},
		'rnbqkb1r/1p3pp1/p2ppn1p/6B1/3NP3/2N2Q2/PPP2PPP/R3KB1R w KQkq' => {
			eco => 'B95n',
			# TRANSLATORS: B95n: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. Qf3 h6
			variation => N__('Sicilian: Najdorf, 6... e6 7. Qf3 h6'),
			moves => {
			},
		},
		'rnbqkb1r/1p3ppp/p2ppn2/6B1/3NPP2/2N5/PPP3PP/R2QKB1R b KQkq' => {
			eco => 'B96a',
			# TRANSLATORS: B96a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4
			variation => N__('Sicilian: Najdorf, 7. f4'),
			moves => {
				'b7b5' => 1,
				'b8c6' => 1,
				'b8d7' => 1,
				'c8d7' => 1,
				'd8b6' => 1,
				'd8c7' => 1,
				'f8e7' => 1,
				'h7h6' => 1,
			},
		},
		'rnbqkb1r/1p3pp1/p2ppn1p/6B1/3NPP2/2N5/PPP3PP/R2QKB1R w KQkq' => {
			eco => 'B96b',
			# TRANSLATORS: B96b: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 h6
			variation => N__('Sicilian: Najdorf, 7. f4 h6'),
			moves => {
				'g5h4' => 1,
			},
		},
		'rnbqkb1r/1p3pp1/p2ppn1p/8/3NPP1B/2N5/PPP3PP/R2QKB1R b KQkq' => {
			eco => 'B96b',
			# TRANSLATORS: B96b: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 h6 8. Bh4
			variation => N__('Sicilian: Najdorf, 7. f4 h6'),
			moves => {
				'd8b6' => 1,
			},
		},
		'rnb1kb1r/1p3pp1/pq1ppn1p/8/3NPP1B/2N5/PPP3PP/R2QKB1R w KQkq' => {
			eco => 'B96b',
			# TRANSLATORS: B96b: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 h6 8. Bh4 Qb6
			variation => N__('Sicilian: Najdorf, Delayed Poisoned Pawn'),
			moves => {
			},
		},
		'r1bqkb1r/1p3ppp/p1nppn2/6B1/3NPP2/2N5/PPP3PP/R2QKB1R w KQkq' => {
			eco => 'B96c',
			# TRANSLATORS: B96c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Nc6
			variation => N__('Sicilian: Najdorf, 7. f4 Nc6'),
			moves => {
				'd4c6' => 1,
				'e4e5' => 1,
			},
		},
		'r1bqkb1r/1p3ppp/p1nppn2/4P1B1/3N1P2/2N5/PPP3PP/R2QKB1R b KQkq' => {
			eco => 'B96c',
			# TRANSLATORS: B96c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Nc6 8. e5
			variation => N__('Sicilian: Najdorf, 7. f4 Nc6 8. e5'),
			moves => {
			},
		},
		'r1bqkb1r/1p3ppp/p1Nppn2/6B1/4PP2/2N5/PPP3PP/R2QKB1R b KQkq' => {
			eco => 'B96d',
			# TRANSLATORS: B96d: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Nc6 8. Nxc6
			variation => N__('Sicilian: Najdorf, 7. f4 Nc6 8.Nxc6'),
			moves => {
			},
		},
		'rn1qkb1r/1p1b1ppp/p2ppn2/6B1/3NPP2/2N5/PPP3PP/R2QKB1R w KQkq' => {
			eco => 'B96e',
			# TRANSLATORS: B96e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Bd7
			variation => N__('Sicilian: Najdorf, 7. f4 Bd7'),
			moves => {
			},
		},
		'rnb1kb1r/1pq2ppp/p2ppn2/6B1/3NPP2/2N5/PPP3PP/R2QKB1R w KQkq' => {
			eco => 'B96f',
			# TRANSLATORS: B96f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qc7
			variation => N__('Sicilian: Najdorf, 7. f4 Qc7'),
			moves => {
				'd1f3' => 1,
				'g5f6' => 1,
			},
		},
		'rnb1kb1r/1pq2ppp/p2ppB2/8/3NPP2/2N5/PPP3PP/R2QKB1R b KQkq' => {
			eco => 'B96f',
			# TRANSLATORS: B96f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qc7 8. Bxf6
			variation => N__('Sicilian: Najdorf, 7. f4 Qc7 8.Bxf6'),
			moves => {
			},
		},
		'rnb1kb1r/1pq2ppp/p2ppn2/6B1/3NPP2/2N2Q2/PPP3PP/R3KB1R b KQkq' => {
			eco => 'B96g',
			# TRANSLATORS: B96g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qc7 8. Qf3
			variation => N__('Sicilian: Najdorf, 7. f4 Qc7 8. Qf3'),
			moves => {
				'b7b5' => 1,
			},
		},
		'rnb1kb1r/2q2ppp/p2ppn2/1p4B1/3NPP2/2N2Q2/PPP3PP/R3KB1R w KQkq' => {
			eco => 'B96h',
			# TRANSLATORS: B96h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qc7 8. Qf3 b5
			variation => N__('Sicilian: Najdorf, 7. f4 Qc7 8. Qf3 b5'),
			moves => {
				'e1c1' => 1,
				'f4f5' => 1,
				'g5f6' => 1,
			},
		},
		'rnb1kb1r/2q2ppp/p2ppn2/1p4B1/3NPP2/2N2Q2/PPP3PP/2KR1B1R b kq' => {
			eco => 'B96h',
			# TRANSLATORS: B96h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qc7 8. Qf3 b5 9. O-O-O
			variation => N__('Sicilian: Najdorf, 7. f4 Qc7 8. Qf3 b5 9.O-O-O'),
			moves => {
			},
		},
		'rnb1kb1r/2q2ppp/p2ppn2/1p3PB1/3NP3/2N2Q2/PPP3PP/R3KB1R b KQkq' => {
			eco => 'B96h',
			# TRANSLATORS: B96h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qc7 8. Qf3 b5 9. f5
			variation => N__('Sicilian: Najdorf, 7. f4 Qc7 8. Qf3 b5 9. f5'),
			moves => {
			},
		},
		'rnb1kb1r/2q2ppp/p2ppB2/1p6/3NPP2/2N2Q2/PPP3PP/R3KB1R b KQkq' => {
			eco => 'B96h',
			# TRANSLATORS: B96h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qc7 8. Qf3 b5 9. Bxf6
			variation => N__('Sicilian: Najdorf, 7. f4 Qc7 8. Qf3 b5 9.Bxf6'),
			moves => {
			},
		},
		'r1bqkb1r/1p1n1ppp/p2ppn2/6B1/3NPP2/2N5/PPP3PP/R2QKB1R w KQkq' => {
			eco => 'B96i',
			# TRANSLATORS: B96i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Nbd7
			variation => N__('Sicilian: Najdorf, 7. f4 Nbd7'),
			moves => {
				'd1e2' => 1,
				'd1f3' => 1,
				'f1c4' => 1,
			},
		},
		'r1bqkb1r/1p1n1ppp/p2ppn2/6B1/3NPP2/2N5/PPP1Q1PP/R3KB1R b KQkq' => {
			eco => 'B96i',
			# TRANSLATORS: B96i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Nbd7 8. Qe2
			variation => N__('Sicilian: Najdorf, 7. f4 Nbd7 8. Qe2'),
			moves => {
				'd8c7' => 1,
			},
		},
		'r1b1kb1r/1pqn1ppp/p2ppn2/6B1/3NPP2/2N5/PPP1Q1PP/R3KB1R w KQkq' => {
			eco => 'B96i',
			# TRANSLATORS: B96i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Nbd7 8. Qe2 Qc7
			variation => N__('Sicilian: Najdorf, 7. f4 Nbd7 8. Qe2 Qc7'),
			moves => {
			},
		},
		'r1bqkb1r/1p1n1ppp/p2ppn2/6B1/2BNPP2/2N5/PPP3PP/R2QK2R b KQkq' => {
			eco => 'B96i',
			# TRANSLATORS: B96i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Nbd7 8. Bc4
			variation => N__('Sicilian: Najdorf, 7. f4 Nbd7 8. Bc4'),
			moves => {
			},
		},
		'r1bqkb1r/1p1n1ppp/p2ppn2/6B1/3NPP2/2N2Q2/PPP3PP/R3KB1R b KQkq' => {
			eco => 'B96j',
			# TRANSLATORS: B96j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Nbd7 8. Qf3
			variation => N__('Sicilian: Najdorf, 7. f4 Nbd7 8. Qf3'),
			moves => {
				'd8c7' => 1,
			},
		},
		'r1b1kb1r/1pqn1ppp/p2ppn2/6B1/3NPP2/2N2Q2/PPP3PP/R3KB1R w KQkq' => {
			eco => 'B96j',
			# TRANSLATORS: B96j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Nbd7 8. Qf3 Qc7
			variation => N__('Sicilian: Najdorf, 7. f4 Nbd7 8. Qf3 Qc7'),
			moves => {
				'e1c1' => 1,
			},
		},
		'r1b1kb1r/1pqn1ppp/p2ppn2/6B1/3NPP2/2N2Q2/PPP3PP/2KR1B1R b kq' => {
			eco => 'B96j',
			# TRANSLATORS: B96j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Nbd7 8. Qf3 Qc7 9. O-O-O
			variation => N__('Sicilian: Najdorf, 7. f4 Nbd7 8. Qf3 Qc7'),
			moves => {
				'b7b5' => 1,
			},
		},
		'r1b1kb1r/2qn1ppp/p2ppn2/1p4B1/3NPP2/2N2Q2/PPP3PP/2KR1B1R w kq' => {
			eco => 'B96k',
			# TRANSLATORS: B96k: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Nbd7 8. Qf3 Qc7 9. O-O-O b5
			variation => N__('Sicilian: Najdorf, 7. f4 Nbd7 8. Qf3 Qc7 9.O-O-O b5'),
			moves => {
				'e4e5' => 1,
				'f1d3' => 1,
			},
		},
		'r1b1kb1r/2qn1ppp/p2ppn2/1p4B1/3NPP2/2NB1Q2/PPP3PP/2KR3R b kq' => {
			eco => 'B96l',
			# TRANSLATORS: B96l: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Nbd7 8. Qf3 Qc7 9. O-O-O b5 10. Bd3
			variation => N__('Sicilian: Najdorf, 7. f4 Nbd7 8. Qf3 Qc7 9.O-O-O b5 10. Bd3'),
			moves => {
			},
		},
		'r1b1kb1r/2qn1ppp/p2ppn2/1p2P1B1/3N1P2/2N2Q2/PPP3PP/2KR1B1R b kq' => {
			eco => 'B96m',
			# TRANSLATORS: B96m: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Nbd7 8. Qf3 Qc7 9. O-O-O b5 10. e5
			variation => N__('Sicilian: Najdorf, 7. f4 Nbd7 8. Qf3 Qc7 9.O-O-O b5 10. e5'),
			moves => {
			},
		},
		'rnbqkb1r/5ppp/p2ppn2/1p4B1/3NPP2/2N5/PPP3PP/R2QKB1R w KQkq' => {
			eco => 'B96n',
			# TRANSLATORS: B96n: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 b5
			variation => N__('Sicilian: Najdorf, Polugaevsky Variation'),
			moves => {
				'e4e5' => 1,
			},
		},
		'rnbqkb1r/5ppp/p2ppn2/1p2P1B1/3N1P2/2N5/PPP3PP/R2QKB1R b KQkq' => {
			eco => 'B96n',
			# TRANSLATORS: B96n: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 b5 8. e5
			variation => N__('Sicilian: Najdorf, Polugaevsky, 8. e5'),
			moves => {
				'd6e5' => 1,
			},
		},
		'rnbqkb1r/5ppp/p3pn2/1p2p1B1/3N1P2/2N5/PPP3PP/R2QKB1R w KQkq' => {
			eco => 'B96n',
			# TRANSLATORS: B96n: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 b5 8. e5 dxe5
			variation => N__('Sicilian: Najdorf, Polugaevsky, 8. e5'),
			moves => {
				'f4e5' => 1,
			},
		},
		'rnbqkb1r/5ppp/p3pn2/1p2P1B1/3N4/2N5/PPP3PP/R2QKB1R b KQkq' => {
			eco => 'B96n',
			# TRANSLATORS: B96n: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 b5 8. e5 dxe5 9. fxe5
			variation => N__('Sicilian: Najdorf, Polugaevsky, 8. e5'),
			moves => {
				'd8c7' => 1,
			},
		},
		'rnb1kb1r/2q2ppp/p3pn2/1p2P1B1/3N4/2N5/PPP3PP/R2QKB1R w KQkq' => {
			eco => 'B96n',
			# TRANSLATORS: B96n: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 b5 8. e5 dxe5 9. fxe5 Qc7
			variation => N__('Sicilian: Najdorf, Polugaevsky, 9.fxe5 Qc7'),
			moves => {
				'd1e2' => 1,
				'd4f3' => 1,
				'e5f6' => 1,
				'f1b5' => 1,
			},
		},
		'rnb1kb1r/2q2ppp/p3pn2/1p2P1B1/8/2N2N2/PPP3PP/R2QKB1R b KQkq' => {
			eco => 'B96o',
			# TRANSLATORS: B96o: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 b5 8. e5 dxe5 9. fxe5 Qc7 10. Nf3
			variation => N__('Sicilian: Najdorf, Polugaevsky, 10. Nf3'),
			moves => {
			},
		},
		'rnb1kb1r/2q2ppp/p3pn2/1B2P1B1/3N4/2N5/PPP3PP/R2QK2R b KQkq' => {
			eco => 'B96p',
			# TRANSLATORS: B96p: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 b5 8. e5 dxe5 9. fxe5 Qc7 10. Bxb5+
			variation => N__('Sicilian: Najdorf, Polugaevsky, 10.Bxb5+'),
			moves => {
			},
		},
		'rnb1kb1r/2q2ppp/p3pP2/1p4B1/3N4/2N5/PPP3PP/R2QKB1R b KQkq' => {
			eco => 'B96q',
			# TRANSLATORS: B96q: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 b5 8. e5 dxe5 9. fxe5 Qc7 10. exf6
			variation => N__('Sicilian: Najdorf, Polugaevsky, 10.exf6'),
			moves => {
				'c7e5' => 1,
			},
		},
		'rnb1kb1r/5ppp/p3pP2/1p2q1B1/3N4/2N5/PPP3PP/R2QKB1R w KQkq' => {
			eco => 'B96q',
			# TRANSLATORS: B96q: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 b5 8. e5 dxe5 9. fxe5 Qc7 10. exf6 Qe5+
			variation => N__('Sicilian: Najdorf, Polugaevsky, 10.exf6'),
			moves => {
				'f1e2' => 1,
			},
		},
		'rnb1kb1r/5ppp/p3pP2/1p2q1B1/3N4/2N5/PPP1B1PP/R2QK2R b KQkq' => {
			eco => 'B96r',
			# TRANSLATORS: B96r: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 b5 8. e5 dxe5 9. fxe5 Qc7 10. exf6 Qe5+ 11. Be2
			variation => N__('Sicilian: Najdorf, Polugaevsky, 10.exf6 Qe5+ 11. Be2'),
			moves => {
				'e5g5' => 1,
			},
		},
		'rnb1kb1r/5ppp/p3pP2/1p4q1/3N4/2N5/PPP1B1PP/R2QK2R w KQkq' => {
			eco => 'B96r',
			# TRANSLATORS: B96r: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 b5 8. e5 dxe5 9. fxe5 Qc7 10. exf6 Qe5+ 11. Be2 Qxg5
			variation => N__('Sicilian: Najdorf, Polugaevsky, 10.exf6 Qe5+ 11. Be2'),
			moves => {
				'd1d3' => 1,
			},
		},
		'rnb1kb1r/5ppp/p3pP2/1p4q1/3N4/2NQ4/PPP1B1PP/R3K2R b KQkq' => {
			eco => 'B96s',
			# TRANSLATORS: B96s: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 b5 8. e5 dxe5 9. fxe5 Qc7 10. exf6 Qe5+ 11. Be2 Qxg5 12. Qd3
			variation => N__('Sicilian: Najdorf, Polugaevsky, 10.exf6 Qe5+ 11. Be2 Qxg5 12. Qd3'),
			moves => {
			},
		},
		'rnb1kb1r/2q2ppp/p3pn2/1p2P1B1/3N4/2N5/PPP1Q1PP/R3KB1R b KQkq' => {
			eco => 'B96t',
			# TRANSLATORS: B96t: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 b5 8. e5 dxe5 9. fxe5 Qc7 10. Qe2
			variation => N__('Sicilian: Najdorf, Polugaevsky, 10. Qe2'),
			moves => {
				'f6d7' => 1,
			},
		},
		'rnb1kb1r/2qn1ppp/p3p3/1p2P1B1/3N4/2N5/PPP1Q1PP/R3KB1R w KQkq' => {
			eco => 'B96t',
			# TRANSLATORS: B96t: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 b5 8. e5 dxe5 9. fxe5 Qc7 10. Qe2 Nfd7
			variation => N__('Sicilian: Najdorf, Polugaevsky, 10. Qe2'),
			moves => {
				'e1c1' => 1,
			},
		},
		'rnb1kb1r/2qn1ppp/p3p3/1p2P1B1/3N4/2N5/PPP1Q1PP/2KR1B1R b kq' => {
			eco => 'B96t',
			# TRANSLATORS: B96t: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 b5 8. e5 dxe5 9. fxe5 Qc7 10. Qe2 Nfd7 11. O-O-O
			variation => N__('Sicilian: Najdorf, Polugaevsky, 10. Qe2'),
			moves => {
				'b8c6' => 1,
				'c8b7' => 1,
			},
		},
		'r1b1kb1r/2qn1ppp/p1n1p3/1p2P1B1/3N4/2N5/PPP1Q1PP/2KR1B1R w kq' => {
			eco => 'B96u',
			# TRANSLATORS: B96u: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 b5 8. e5 dxe5 9. fxe5 Qc7 10. Qe2 Nfd7 11. O-O-O Nc6
			variation => N__('Sicilian: Najdorf, Polugaevsky, 10. Qe2 Nfd7 11.O-O-O Nc6'),
			moves => {
			},
		},
		'rn2kb1r/1bqn1ppp/p3p3/1p2P1B1/3N4/2N5/PPP1Q1PP/2KR1B1R w kq' => {
			eco => 'B96v',
			# TRANSLATORS: B96v: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 b5 8. e5 dxe5 9. fxe5 Qc7 10. Qe2 Nfd7 11. O-O-O Bb7
			variation => N__('Sicilian: Najdorf, Polugaevsky, 10. Qe2 Nfd7 11.O-O-O Bb7'),
			moves => {
				'e2g4' => 1,
			},
		},
		'rn2kb1r/1bqn1ppp/p3p3/1p2P1B1/3N2Q1/2N5/PPP3PP/2KR1B1R b kq' => {
			eco => 'B96w',
			# TRANSLATORS: B96w: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 b5 8. e5 dxe5 9. fxe5 Qc7 10. Qe2 Nfd7 11. O-O-O Bb7 12. Qg4
			variation => N__('Sicilian: Najdorf, Polugaevsky, 10. Qe2 Nfd7 11.O-O-O Bb7 12. Qg4'),
			moves => {
				'c7e5' => 1,
			},
		},
		'rn2kb1r/1b1n1ppp/p3p3/1p2q1B1/3N2Q1/2N5/PPP3PP/2KR1B1R w kq' => {
			eco => 'B96w',
			# TRANSLATORS: B96w: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 b5 8. e5 dxe5 9. fxe5 Qc7 10. Qe2 Nfd7 11. O-O-O Bb7 12. Qg4 Qxe5
			variation => N__('Sicilian: Najdorf, Polugaevsky, 10. Qe2 Nfd7 11.O-O-O Bb7 12. Qg4 Qxe5'),
			moves => {
			},
		},
		'rnb1kb1r/1p3ppp/pq1ppn2/6B1/3NPP2/2N5/PPP3PP/R2QKB1R w KQkq' => {
			eco => 'B97a',
			# TRANSLATORS: B97a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6
			variation => N__('Sicilian: Najdorf, Poisoned Pawn'),
			moves => {
				'a2a3' => 1,
				'd1d2' => 1,
				'd1d3' => 1,
				'd4b3' => 1,
				'g5f6' => 1,
			},
		},
		'rnb1kb1r/1p3ppp/pq1ppB2/8/3NPP2/2N5/PPP3PP/R2QKB1R b KQkq' => {
			eco => 'B97b',
			# TRANSLATORS: B97b: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Bxf6
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, 8.Bxf6'),
			moves => {
			},
		},
		'rnb1kb1r/1p3ppp/pq1ppn2/6B1/3NPP2/P1N5/1PP3PP/R2QKB1R b KQkq' => {
			eco => 'B97c',
			# TRANSLATORS: B97c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. a3
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, 8. a3'),
			moves => {
			},
		},
		'rnb1kb1r/1p3ppp/pq1ppn2/6B1/3NPP2/2NQ4/PPP3PP/R3KB1R b KQkq' => {
			eco => 'B97d',
			# TRANSLATORS: B97d: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd3
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, 8. Qd3'),
			moves => {
			},
		},
		'rnb1kb1r/1p3ppp/pq1ppn2/6B1/4PP2/1NN5/PPP3PP/R2QKB1R b KQkq' => {
			eco => 'B97e',
			# TRANSLATORS: B97e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Nb3
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, 8. Nb3'),
			moves => {
				'b8d7' => 1,
				'f8e7' => 1,
			},
		},
		'r1b1kb1r/1p1n1ppp/pq1ppn2/6B1/4PP2/1NN5/PPP3PP/R2QKB1R w KQkq' => {
			eco => 'B97e',
			# TRANSLATORS: B97e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Nb3 Nbd7
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, 8. Nb3'),
			moves => {
				'd1f3' => 1,
			},
		},
		'rnb1k2r/1p2bppp/pq1ppn2/6B1/4PP2/1NN5/PPP3PP/R2QKB1R w KQkq' => {
			eco => 'B97f',
			# TRANSLATORS: B97f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Nb3 Be7
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, 8. Nb3 Be7'),
			moves => {
			},
		},
		'r1b1kb1r/1p1n1ppp/pq1ppn2/6B1/4PP2/1NN2Q2/PPP3PP/R3KB1R b KQkq' => {
			eco => 'B97g',
			# TRANSLATORS: B97g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Nb3 Nbd7 9. Qf3
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, 8. Nb3 Nbd7 9. Qf3'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r1b1k2r/1p1nbppp/pq1ppn2/6B1/4PP2/1NN2Q2/PPP3PP/R3KB1R w KQkq' => {
			eco => 'B97h',
			# TRANSLATORS: B97h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Nb3 Nbd7 9. Qf3 Be7
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, 8. Nb3 Nbd7 9. Qf3 Be7'),
			moves => {
			},
		},
		'rnb1kb1r/1p3ppp/pq1ppn2/6B1/3NPP2/2N5/PPPQ2PP/R3KB1R b KQkq' => {
			eco => 'B97i',
			# TRANSLATORS: B97i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, 8. Qd2'),
			moves => {
				'b6b2' => 1,
			},
		},
		'rnb1kb1r/1p3ppp/p2ppn2/6B1/3NPP2/2N5/PqPQ2PP/R3KB1R w KQkq' => {
			eco => 'B97i',
			# TRANSLATORS: B97i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2
			variation => N__('Sicilian: Najdorf, Poisoned Pawn Accepted'),
			moves => {
				'a1b1' => 1,
				'd4b3' => 1,
			},
		},
		'rnb1kb1r/1p3ppp/p2ppn2/6B1/4PP2/1NN5/PqPQ2PP/R3KB1R b KQkq' => {
			eco => 'B97j',
			# TRANSLATORS: B97j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Nb3
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, 9. Nb3'),
			moves => {
				'b2a3' => 1,
				'b8c6' => 1,
			},
		},
		'r1b1kb1r/1p3ppp/p1nppn2/6B1/4PP2/1NN5/PqPQ2PP/R3KB1R w KQkq' => {
			eco => 'B97j',
			# TRANSLATORS: B97j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Nb3 Nc6
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, 9. Nb3 Nc6'),
			moves => {
			},
		},
		'rnb1kb1r/1p3ppp/p2ppn2/6B1/4PP2/qNN5/P1PQ2PP/R3KB1R w KQkq' => {
			eco => 'B97k',
			# TRANSLATORS: B97k: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Nb3 Qa3
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, 9. Nb3 Qa3'),
			moves => {
				'g5f6' => 1,
			},
		},
		'rnb1kb1r/1p3ppp/p2ppB2/8/4PP2/qNN5/P1PQ2PP/R3KB1R b KQkq' => {
			eco => 'B97l',
			# TRANSLATORS: B97l: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Nb3 Qa3 10. Bxf6
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, 9. Nb3 Qa3 10.Bxf6'),
			moves => {
			},
		},
		'rnb1kb1r/1p3ppp/p2ppn2/6B1/3NPP2/2N5/PqPQ2PP/1R2KB1R b Kkq' => {
			eco => 'B97m',
			# TRANSLATORS: B97m: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, 9. Rb1'),
			moves => {
				'b2a3' => 1,
			},
		},
		'rnb1kb1r/1p3ppp/p2ppn2/6B1/3NPP2/q1N5/P1PQ2PP/1R2KB1R w Kkq' => {
			eco => 'B97m',
			# TRANSLATORS: B97m: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, 9. Rb1 Qa3'),
			moves => {
				'e4e5' => 1,
				'f1e2' => 1,
				'f4f5' => 1,
				'g5f6' => 1,
			},
		},
		'rnb1kb1r/1p3ppp/p2ppn2/6B1/3NPP2/q1N5/P1PQB1PP/1R2K2R b Kkq' => {
			eco => 'B97n',
			# TRANSLATORS: B97n: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. Be2
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, 10. Be2'),
			moves => {
				'f8e7' => 1,
			},
		},
		'rnb1k2r/1p2bppp/p2ppn2/6B1/3NPP2/q1N5/P1PQB1PP/1R2K2R w Kkq' => {
			eco => 'B97n',
			# TRANSLATORS: B97n: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. Be2 Be7
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, 10. Be2'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnb1k2r/1p2bppp/p2ppn2/6B1/3NPP2/q1N5/P1PQB1PP/1R3RK1 b kq' => {
			eco => 'B97n',
			# TRANSLATORS: B97n: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. Be2 Be7 11. O-O
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, 10. Be2 Be7 11.O-O'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r1b1k2r/1p1nbppp/p2ppn2/6B1/3NPP2/q1N5/P1PQB1PP/1R3RK1 w kq' => {
			eco => 'B97n',
			# TRANSLATORS: B97n: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. Be2 Be7 11. O-O Nbd7
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, 10. Be2 Be7 11.O-O Nbd7'),
			moves => {
			},
		},
		'rnb1kb1r/1p3ppp/p2ppB2/8/3NPP2/q1N5/P1PQ2PP/1R2KB1R b Kkq' => {
			eco => 'B97o',
			# TRANSLATORS: B97o: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. Bxf6
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, 10.Bxf6'),
			moves => {
				'g7f6' => 1,
			},
		},
		'rnb1kb1r/1p3p1p/p2ppp2/8/3NPP2/q1N5/P1PQ2PP/1R2KB1R w Kkq' => {
			eco => 'B97o',
			# TRANSLATORS: B97o: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. Bxf6 gxf6
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, 10.Bxf6'),
			moves => {
				'f1e2' => 1,
			},
		},
		'rnb1kb1r/1p3p1p/p2ppp2/8/3NPP2/q1N5/P1PQB1PP/1R2K2R b Kkq' => {
			eco => 'B97o',
			# TRANSLATORS: B97o: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. Bxf6 gxf6 11. Be2
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, 10.Bxf6'),
			moves => {
				'b8c6' => 1,
				'f8g7' => 1,
			},
		},
		'r1b1kb1r/1p3p1p/p1nppp2/8/3NPP2/q1N5/P1PQB1PP/1R2K2R w Kkq' => {
			eco => 'B97o',
			# TRANSLATORS: B97o: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. Bxf6 gxf6 11. Be2 Nc6
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, 10.Bxf6 gxf6 11. Be2 Nc6'),
			moves => {
			},
		},
		'rnb1k2r/1p3pbp/p2ppp2/8/3NPP2/q1N5/P1PQB1PP/1R2K2R w Kkq' => {
			eco => 'B97o',
			# TRANSLATORS: B97o: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. Bxf6 gxf6 11. Be2 Bg7
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, 10.Bxf6 gxf6 11. Be2 Bg7'),
			moves => {
			},
		},
		'rnb1kb1r/1p3ppp/p2ppn2/4P1B1/3N1P2/q1N5/P1PQ2PP/1R2KB1R b Kkq' => {
			eco => 'B97p',
			# TRANSLATORS: B97p: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. e5
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, 10. e5'),
			moves => {
				'd6e5' => 1,
			},
		},
		'rnb1kb1r/1p3ppp/p3pn2/4p1B1/3N1P2/q1N5/P1PQ2PP/1R2KB1R w Kkq' => {
			eco => 'B97p',
			# TRANSLATORS: B97p: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. e5 dxe5
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, 10. e5 dxe5'),
			moves => {
				'f4e5' => 1,
			},
		},
		'rnb1kb1r/1p3ppp/p3pn2/4P1B1/3N4/q1N5/P1PQ2PP/1R2KB1R b Kkq' => {
			eco => 'B97p',
			# TRANSLATORS: B97p: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. e5 dxe5 11. fxe5
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, 10. e5 dxe5'),
			moves => {
				'f6d7' => 1,
			},
		},
		'rnb1kb1r/1p1n1ppp/p3p3/4P1B1/3N4/q1N5/P1PQ2PP/1R2KB1R w Kkq' => {
			eco => 'B97p',
			# TRANSLATORS: B97p: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. e5 dxe5 11. fxe5 Nfd7
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, 10. e5 dxe5'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnb1kb1r/1p1n1ppp/p3p3/4P1B1/2BN4/q1N5/P1PQ2PP/1R2K2R b Kkq' => {
			eco => 'B97p',
			# TRANSLATORS: B97p: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. e5 dxe5 11. fxe5 Nfd7 12. Bc4
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, 10. e5 dxe5 11.fxe5 Nfd7 12. Bc4'),
			moves => {
				'f8b4' => 1,
			},
		},
		'rnb1k2r/1p1n1ppp/p3p3/4P1B1/1bBN4/q1N5/P1PQ2PP/1R2K2R w Kkq' => {
			eco => 'B97p',
			# TRANSLATORS: B97p: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. e5 dxe5 11. fxe5 Nfd7 12. Bc4 Bb4
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, 10. e5 dxe5 11.fxe5 Nfd7 12. Bc4 Bb4'),
			moves => {
			},
		},
		'rnb1kb1r/1p3ppp/p2ppn2/5PB1/3NP3/q1N5/P1PQ2PP/1R2KB1R b Kkq' => {
			eco => 'B97q',
			# TRANSLATORS: B97q: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. f5
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, 10. f5'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1b1kb1r/1p3ppp/p1nppn2/5PB1/3NP3/q1N5/P1PQ2PP/1R2KB1R w Kkq' => {
			eco => 'B97q',
			# TRANSLATORS: B97q: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. f5 Nc6
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, 10. f5 Nc6'),
			moves => {
				'f5e6' => 1,
			},
		},
		'r1b1kb1r/1p3ppp/p1npPn2/6B1/3NP3/q1N5/P1PQ2PP/1R2KB1R b Kkq' => {
			eco => 'B97q',
			# TRANSLATORS: B97q: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. f5 Nc6 11. fxe6
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, 10. f5 Nc6'),
			moves => {
				'f7e6' => 1,
			},
		},
		'r1b1kb1r/1p4pp/p1nppn2/6B1/3NP3/q1N5/P1PQ2PP/1R2KB1R w Kkq' => {
			eco => 'B97q',
			# TRANSLATORS: B97q: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. f5 Nc6 11. fxe6 fxe6
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, 10. f5 Nc6'),
			moves => {
				'd4c6' => 1,
			},
		},
		'r1b1kb1r/1p4pp/p1Nppn2/6B1/4P3/q1N5/P1PQ2PP/1R2KB1R b Kkq' => {
			eco => 'B97q',
			# TRANSLATORS: B97q: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. f5 Nc6 11. fxe6 fxe6 12. Nxc6
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, 10. f5 Nc6'),
			moves => {
				'b7c6' => 1,
			},
		},
		'r1b1kb1r/6pp/p1pppn2/6B1/4P3/q1N5/P1PQ2PP/1R2KB1R w Kkq' => {
			eco => 'B97r',
			# TRANSLATORS: B97r: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. f5 Nc6 11. fxe6 fxe6 12. Nxc6 bxc6
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, Main Line'),
			moves => {
				'e4e5' => 1,
				'f1e2' => 1,
			},
		},
		'r1b1kb1r/6pp/p1pppn2/6B1/4P3/q1N5/P1PQB1PP/1R2K2R b Kkq' => {
			eco => 'B97s',
			# TRANSLATORS: B97s: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. f5 Nc6 11. fxe6 fxe6 12. Nxc6 bxc6 13. Be2
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, Main Line, Timman\'s 13. Be2'),
			moves => {
			},
		},
		'r1b1kb1r/6pp/p1pppn2/4P1B1/8/q1N5/P1PQ2PP/1R2KB1R b Kkq' => {
			eco => 'B97t',
			# TRANSLATORS: B97t: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. f5 Nc6 11. fxe6 fxe6 12. Nxc6 bxc6 13. e5
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, Main Line, 13. e5'),
			moves => {
				'd6e5' => 1,
				'f6d5' => 1,
			},
		},
		'r1b1kb1r/6pp/p1ppp3/3nP1B1/8/q1N5/P1PQ2PP/1R2KB1R w Kkq' => {
			eco => 'B97t',
			# TRANSLATORS: B97t: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. f5 Nc6 11. fxe6 fxe6 12. Nxc6 bxc6 13. e5 Nd5
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, Main Line, 13. e5 Nd5'),
			moves => {
			},
		},
		'r1b1kb1r/6pp/p1p1pn2/4p1B1/8/q1N5/P1PQ2PP/1R2KB1R w Kkq' => {
			eco => 'B97u',
			# TRANSLATORS: B97u: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. f5 Nc6 11. fxe6 fxe6 12. Nxc6 bxc6 13. e5 dxe5
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, Main Line, 13. e5 dxe5'),
			moves => {
				'g5f6' => 1,
			},
		},
		'r1b1kb1r/6pp/p1p1pB2/4p3/8/q1N5/P1PQ2PP/1R2KB1R b Kkq' => {
			eco => 'B97u',
			# TRANSLATORS: B97u: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. f5 Nc6 11. fxe6 fxe6 12. Nxc6 bxc6 13. e5 dxe5 14. Bxf6
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, Main Line, 13. e5 dxe5'),
			moves => {
				'g7f6' => 1,
			},
		},
		'r1b1kb1r/7p/p1p1pp2/4p3/8/q1N5/P1PQ2PP/1R2KB1R w Kkq' => {
			eco => 'B97u',
			# TRANSLATORS: B97u: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. f5 Nc6 11. fxe6 fxe6 12. Nxc6 bxc6 13. e5 dxe5 14. Bxf6 gxf6
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, Main Line, 13. e5 dxe5'),
			moves => {
				'c3e4' => 1,
			},
		},
		'r1b1kb1r/7p/p1p1pp2/4p3/4N3/q7/P1PQ2PP/1R2KB1R b Kkq' => {
			eco => 'B97u',
			# TRANSLATORS: B97u: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. f5 Nc6 11. fxe6 fxe6 12. Nxc6 bxc6 13. e5 dxe5 14. Bxf6 gxf6 15. Ne4
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, Main Line, 13. e5 dxe5: 15. Ne4'),
			moves => {
				'a3a2' => 1,
				'f8e7' => 1,
			},
		},
		'r1b1kb1r/7p/p1p1pp2/4p3/4N3/8/q1PQ2PP/1R2KB1R w Kkq' => {
			eco => 'B97v',
			# TRANSLATORS: B97v: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. f5 Nc6 11. fxe6 fxe6 12. Nxc6 bxc6 13. e5 dxe5 14. Bxf6 gxf6 15. Ne4 Qxa2
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, Main Line, 13. e5 dxe5: 15. Ne4 Qxa2'),
			moves => {
			},
		},
		'r1b1k2r/4b2p/p1p1pp2/4p3/4N3/q7/P1PQ2PP/1R2KB1R w Kkq' => {
			eco => 'B97w',
			# TRANSLATORS: B97w: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. f5 Nc6 11. fxe6 fxe6 12. Nxc6 bxc6 13. e5 dxe5 14. Bxf6 gxf6 15. Ne4 Be7
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, Main Line, 13. e5 dxe5: 15. Ne4 Be7'),
			moves => {
				'f1e2' => 1,
			},
		},
		'r1b1k2r/4b2p/p1p1pp2/4p3/4N3/q7/P1PQB1PP/1R2K2R b Kkq' => {
			eco => 'B97w',
			# TRANSLATORS: B97w: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. f5 Nc6 11. fxe6 fxe6 12. Nxc6 bxc6 13. e5 dxe5 14. Bxf6 gxf6 15. Ne4 Be7 16. Be2
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, Main Line, 13. e5 dxe5: 15. Ne4 Be7'),
			moves => {
				'h7h5' => 1,
			},
		},
		'r1b1k2r/4b3/p1p1pp2/4p2p/4N3/q7/P1PQB1PP/1R2K2R w Kkq' => {
			eco => 'B97w',
			# TRANSLATORS: B97w: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. f5 Nc6 11. fxe6 fxe6 12. Nxc6 bxc6 13. e5 dxe5 14. Bxf6 gxf6 15. Ne4 Be7 16. Be2 h5
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, Main Line, 13. e5 dxe5: 15. Ne4 Be7'),
			moves => {
				'b1b3' => 1,
			},
		},
		'r1b1k2r/4b3/p1p1pp2/4p2p/4N3/qR6/P1PQB1PP/4K2R b Kkq' => {
			eco => 'B97w',
			# TRANSLATORS: B97w: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. f5 Nc6 11. fxe6 fxe6 12. Nxc6 bxc6 13. e5 dxe5 14. Bxf6 gxf6 15. Ne4 Be7 16. Be2 h5 17. Rb3
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, Main Line, 13. e5 dxe5: 15. Ne4 Be7'),
			moves => {
				'a3a4' => 1,
			},
		},
		'r1b1k2r/4b3/p1p1pp2/4p2p/q3N3/1R6/P1PQB1PP/4K2R w Kkq' => {
			eco => 'B97w',
			# TRANSLATORS: B97w: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. f5 Nc6 11. fxe6 fxe6 12. Nxc6 bxc6 13. e5 dxe5 14. Bxf6 gxf6 15. Ne4 Be7 16. Be2 h5 17. Rb3 Qa4
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, Main Line, 13. e5 dxe5: 15. Ne4 Be7'),
			moves => {
				'c2c4' => 1,
				'e4f6' => 1,
			},
		},
		'r1b1k2r/4b3/p1p1pp2/4p2p/q1P1N3/1R6/P2QB1PP/4K2R b Kkq' => {
			eco => 'B97x',
			# TRANSLATORS: B97x: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. f5 Nc6 11. fxe6 fxe6 12. Nxc6 bxc6 13. e5 dxe5 14. Bxf6 gxf6 15. Ne4 Be7 16. Be2 h5 17. Rb3 Qa4 18. c4
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, Main Line, 13. e5 dxe5 with 18. c4'),
			moves => {
			},
		},
		'r1b1k2r/4b3/p1p1pN2/4p2p/q7/1R6/P1PQB1PP/4K2R b Kkq' => {
			eco => 'B97y',
			# TRANSLATORS: B97y: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Qb6 8. Qd2 Qxb2 9. Rb1 Qa3 10. f5 Nc6 11. fxe6 fxe6 12. Nxc6 bxc6 13. e5 dxe5 14. Bxf6 gxf6 15. Ne4 Be7 16. Be2 h5 17. Rb3 Qa4 18. Nxf6+
			variation => N__('Sicilian: Najdorf, Poisoned Pawn, Main Line, 13. e5 dxe5 with 18.Nxf6+'),
			moves => {
			},
		},
		'rnbqk2r/1p2bppp/p2ppn2/6B1/3NPP2/2N5/PPP3PP/R2QKB1R w KQkq' => {
			eco => 'B98a',
			# TRANSLATORS: B98a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7
			variation => N__('Sicilian: Najdorf, 7... Be7'),
			moves => {
				'd1f3' => 1,
			},
		},
		'rnbqk2r/1p2bppp/p2ppn2/6B1/3NPP2/2N2Q2/PPP3PP/R3KB1R b KQkq' => {
			eco => 'B98b',
			# TRANSLATORS: B98b: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3
			variation => N__('Sicilian: Najdorf, 7... Be7 8. Qf3'),
			moves => {
				'd8a5' => 1,
				'd8c7' => 1,
				'h7h6' => 1,
			},
		},
		'rnb1k2r/1p2bppp/p2ppn2/q5B1/3NPP2/2N2Q2/PPP3PP/R3KB1R w KQkq' => {
			eco => 'B98c',
			# TRANSLATORS: B98c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qa5
			variation => N__('Sicilian: Najdorf, Danner Variation'),
			moves => {
				'e1c1' => 1,
			},
		},
		'rnb1k2r/1p2bppp/p2ppn2/q5B1/3NPP2/2N2Q2/PPP3PP/2KR1B1R b kq' => {
			eco => 'B98c',
			# TRANSLATORS: B98c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qa5 9. O-O-O
			variation => N__('Sicilian: Najdorf, Danner Variation'),
			moves => {
				'c8d7' => 1,
			},
		},
		'rn2k2r/1p1bbppp/p2ppn2/q5B1/3NPP2/2N2Q2/PPP3PP/2KR1B1R w kq' => {
			eco => 'B98d',
			# TRANSLATORS: B98d: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qa5 9. O-O-O Bd7
			variation => N__('Sicilian: Najdorf, Danner, 9.O-O-O Bd7'),
			moves => {
				'e4e5' => 1,
			},
		},
		'rn2k2r/1p1bbppp/p2ppn2/q3P1B1/3N1P2/2N2Q2/PPP3PP/2KR1B1R b kq' => {
			eco => 'B98e',
			# TRANSLATORS: B98e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qa5 9. O-O-O Bd7 10. e5
			variation => N__('Sicilian: Najdorf, Danner, 9.O-O-O Bd7 10. e5'),
			moves => {
			},
		},
		'rnbqk2r/1p2bpp1/p2ppn1p/6B1/3NPP2/2N2Q2/PPP3PP/R3KB1R w KQkq' => {
			eco => 'B98f',
			# TRANSLATORS: B98f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 h6
			variation => N__('Sicilian: Najdorf, 7... Be7 8. Qf3 h6'),
			moves => {
				'g5h4' => 1,
			},
		},
		'rnbqk2r/1p2bpp1/p2ppn1p/8/3NPP1B/2N2Q2/PPP3PP/R3KB1R b KQkq' => {
			eco => 'B98f',
			# TRANSLATORS: B98f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 h6 9. Bh4
			variation => N__('Sicilian: Najdorf, 7... Be7 8. Qf3 h6'),
			moves => {
				'd8c7' => 1,
				'g7g5' => 1,
			},
		},
		'rnb1k2r/1pq1bpp1/p2ppn1p/8/3NPP1B/2N2Q2/PPP3PP/R3KB1R w KQkq' => {
			eco => 'B98g',
			# TRANSLATORS: B98g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 h6 9. Bh4 Qc7
			variation => N__('Sicilian: Najdorf, Browne Variation'),
			moves => {
				'e1c1' => 1,
			},
		},
		'rnb1k2r/1pq1bpp1/p2ppn1p/8/3NPP1B/2N2Q2/PPP3PP/2KR1B1R b kq' => {
			eco => 'B98g',
			# TRANSLATORS: B98g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 h6 9. Bh4 Qc7 10. O-O-O
			variation => N__('Sicilian: Najdorf, Browne Variation'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r1b1k2r/1pqnbpp1/p2ppn1p/8/3NPP1B/2N2Q2/PPP3PP/2KR1B1R w kq' => {
			eco => 'B98h',
			# TRANSLATORS: B98h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 h6 9. Bh4 Qc7 10. O-O-O Nbd7
			variation => N__('Sicilian: Najdorf, Browne, 10.O-O-O Nbd7'),
			moves => {
				'f1e2' => 1,
				'f3g3' => 1,
			},
		},
		'r1b1k2r/1pqnbpp1/p2ppn1p/8/3NPP1B/2N3Q1/PPP3PP/2KR1B1R b kq' => {
			eco => 'B98i',
			# TRANSLATORS: B98i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 h6 9. Bh4 Qc7 10. O-O-O Nbd7 11. Qg3
			variation => N__('Sicilian: Najdorf, Browne, 10.O-O-O Nbd7 11. Qg3'),
			moves => {
			},
		},
		'r1b1k2r/1pqnbpp1/p2ppn1p/8/3NPP1B/2N2Q2/PPP1B1PP/2KR3R b kq' => {
			eco => 'B98j',
			# TRANSLATORS: B98j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 h6 9. Bh4 Qc7 10. O-O-O Nbd7 11. Be2
			variation => N__('Sicilian: Najdorf, Browne, 10.O-O-O Nbd7 11. Be2'),
			moves => {
			},
		},
		'rnbqk2r/1p2bp2/p2ppn1p/6p1/3NPP1B/2N2Q2/PPP3PP/R3KB1R w KQkq' => {
			eco => 'B98k',
			# TRANSLATORS: B98k: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 h6 9. Bh4 g5
			variation => N__('Sicilian: Najdorf, Gothenburg (Argentine) Variation'),
			moves => {
				'f4g5' => 1,
			},
		},
		'rnbqk2r/1p2bp2/p2ppn1p/6P1/3NP2B/2N2Q2/PPP3PP/R3KB1R b KQkq' => {
			eco => 'B98k',
			# TRANSLATORS: B98k: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 h6 9. Bh4 g5 10. fxg5
			variation => N__('Sicilian: Najdorf, Gothenburg (Argentine) Variation'),
			moves => {
				'f6d7' => 1,
			},
		},
		'rnbqk2r/1p1nbp2/p2pp2p/6P1/3NP2B/2N2Q2/PPP3PP/R3KB1R w KQkq' => {
			eco => 'B98k',
			# TRANSLATORS: B98k: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 h6 9. Bh4 g5 10. fxg5 Nfd7
			variation => N__('Sicilian: Najdorf, Gothenburg (Argentine) Variation'),
			moves => {
				'd4e6' => 1,
				'f3h5' => 1,
			},
		},
		'rnbqk2r/1p1nbp2/p2pN2p/6P1/4P2B/2N2Q2/PPP3PP/R3KB1R b KQkq' => {
			eco => 'B98l',
			# TRANSLATORS: B98l: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 h6 9. Bh4 g5 10. fxg5 Nfd7 11. Nxe6
			variation => N__('Sicilian: Najdorf, Gothenburg, 11.Nxe6'),
			moves => {
			},
		},
		'rnbqk2r/1p1nbp2/p2pp2p/6PQ/3NP2B/2N5/PPP3PP/R3KB1R b KQkq' => {
			eco => 'B98m',
			# TRANSLATORS: B98m: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 h6 9. Bh4 g5 10. fxg5 Nfd7 11. Qh5
			variation => N__('Sicilian: Najdorf, Gothenburg, 11. Qh5'),
			moves => {
			},
		},
		'rnb1k2r/1pq1bppp/p2ppn2/6B1/3NPP2/2N2Q2/PPP3PP/R3KB1R w KQkq' => {
			eco => 'B98n',
			# TRANSLATORS: B98n: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7
			variation => N__('Sicilian: Najdorf, 8... Qc7'),
			moves => {
				'e1c1' => 1,
			},
		},
		'rnb1k2r/1pq1bppp/p2ppn2/6B1/3NPP2/2N2Q2/PPP3PP/2KR1B1R b kq' => {
			eco => 'B98n',
			# TRANSLATORS: B98n: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O
			variation => N__('Sicilian: Najdorf, 8... Qc7 9.O-O-O'),
			moves => {
				'b7b5' => 1,
				'b8c6' => 1,
				'b8d7' => 1,
			},
		},
		'rnb1k2r/2q1bppp/p2ppn2/1p4B1/3NPP2/2N2Q2/PPP3PP/2KR1B1R w kq' => {
			eco => 'B98o',
			# TRANSLATORS: B98o: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O b5
			variation => N__('Sicilian: Najdorf, 8... Qc7 9.O-O-O b5'),
			moves => {
			},
		},
		'r1b1k2r/1pq1bppp/p1nppn2/6B1/3NPP2/2N2Q2/PPP3PP/2KR1B1R w kq' => {
			eco => 'B98p',
			# TRANSLATORS: B98p: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nc6
			variation => N__('Sicilian: Najdorf, 8... Qc7 9.O-O-O Nc6'),
			moves => {
				'd4c6' => 1,
			},
		},
		'r1b1k2r/1pq1bppp/p1Nppn2/6B1/4PP2/2N2Q2/PPP3PP/2KR1B1R b kq' => {
			eco => 'B98q',
			# TRANSLATORS: B98q: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nc6 10. Nxc6
			variation => N__('Sicilian: Najdorf, 8... Qc7 9.O-O-O Nc6 10.Nxc6'),
			moves => {
			},
		},
		'r1b1k2r/1pqnbppp/p2ppn2/6B1/3NPP2/2N2Q2/PPP3PP/2KR1B1R w kq' => {
			eco => 'B99a',
			# TRANSLATORS: B99a: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7
			variation => N__('Sicilian: Najdorf, Main Line'),
			moves => {
				'f1d3' => 1,
				'f1e2' => 1,
				'f3g3' => 1,
				'g2g4' => 1,
			},
		},
		'r1b1k2r/1pqnbppp/p2ppn2/6B1/3NPP2/2N3Q1/PPP3PP/2KR1B1R b kq' => {
			eco => 'B99b',
			# TRANSLATORS: B99b: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. Qg3
			variation => N__('Sicilian: Najdorf, Main Line, 10. Qg3'),
			moves => {
			},
		},
		'r1b1k2r/1pqnbppp/p2ppn2/6B1/3NPP2/2N2Q2/PPP1B1PP/2KR3R b kq' => {
			eco => 'B99c',
			# TRANSLATORS: B99c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. Be2
			variation => N__('Sicilian: Najdorf, Main Line, Keres Variation'),
			moves => {
				'b7b5' => 1,
			},
		},
		'r1b1k2r/2qnbppp/p2ppn2/1p4B1/3NPP2/2N2Q2/PPP1B1PP/2KR3R w kq' => {
			eco => 'B99c',
			# TRANSLATORS: B99c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. Be2 b5
			variation => N__('Sicilian: Najdorf, Main Line, Keres Variation'),
			moves => {
				'g5f6' => 1,
			},
		},
		'r1b1k2r/2qnbppp/p2ppB2/1p6/3NPP2/2N2Q2/PPP1B1PP/2KR3R b kq' => {
			eco => 'B99c',
			# TRANSLATORS: B99c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. Be2 b5 11. Bxf6
			variation => N__('Sicilian: Najdorf, Main Line, Keres Variation'),
			moves => {
				'd7f6' => 1,
			},
		},
		'r1b1k2r/2q1bppp/p2ppn2/1p6/3NPP2/2N2Q2/PPP1B1PP/2KR3R w kq' => {
			eco => 'B99c',
			# TRANSLATORS: B99c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. Be2 b5 11. Bxf6 Nxf6
			variation => N__('Sicilian: Najdorf, Main Line, Keres Variation'),
			moves => {
				'e4e5' => 1,
			},
		},
		'r1b1k2r/2q1bppp/p2ppn2/1p2P3/3N1P2/2N2Q2/PPP1B1PP/2KR3R b kq' => {
			eco => 'B99c',
			# TRANSLATORS: B99c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. Be2 b5 11. Bxf6 Nxf6 12. e5
			variation => N__('Sicilian: Najdorf, Main Line, Keres Variation'),
			moves => {
				'c8b7' => 1,
			},
		},
		'r3k2r/1bq1bppp/p2ppn2/1p2P3/3N1P2/2N2Q2/PPP1B1PP/2KR3R w kq' => {
			eco => 'B99c',
			# TRANSLATORS: B99c: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. Be2 b5 11. Bxf6 Nxf6 12. e5 Bb7
			variation => N__('Sicilian: Najdorf, Main Line, Keres 10... b5 11.Bxf6 Nxf6 12. e5 Bb7'),
			moves => {
				'e5f6' => 1,
				'f3g3' => 1,
			},
		},
		'r3k2r/1bq1bppp/p2ppP2/1p6/3N1P2/2N2Q2/PPP1B1PP/2KR3R b kq' => {
			eco => 'B99d',
			# TRANSLATORS: B99d: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. Be2 b5 11. Bxf6 Nxf6 12. e5 Bb7 13. exf6
			variation => N__('Sicilian: Najdorf, Main Line, Keres, Queen Sacrifice Line'),
			moves => {
			},
		},
		'r3k2r/1bq1bppp/p2ppn2/1p2P3/3N1P2/2N3Q1/PPP1B1PP/2KR3R b kq' => {
			eco => 'B99e',
			# TRANSLATORS: B99e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. Be2 b5 11. Bxf6 Nxf6 12. e5 Bb7 13. Qg3
			variation => N__('Sicilian: Najdorf, Main Line, Keres, 13. Qg3'),
			moves => {
				'd6e5' => 1,
			},
		},
		'r3k2r/1bq1bppp/p3pn2/1p2p3/3N1P2/2N3Q1/PPP1B1PP/2KR3R w kq' => {
			eco => 'B99e',
			# TRANSLATORS: B99e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. Be2 b5 11. Bxf6 Nxf6 12. e5 Bb7 13. Qg3 dxe5
			variation => N__('Sicilian: Najdorf, Main Line, Keres, 13. Qg3'),
			moves => {
				'f4e5' => 1,
			},
		},
		'r3k2r/1bq1bppp/p3pn2/1p2P3/3N4/2N3Q1/PPP1B1PP/2KR3R b kq' => {
			eco => 'B99e',
			# TRANSLATORS: B99e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. Be2 b5 11. Bxf6 Nxf6 12. e5 Bb7 13. Qg3 dxe5 14. fxe5
			variation => N__('Sicilian: Najdorf, Main Line, Keres, 13. Qg3'),
			moves => {
				'f6d7' => 1,
			},
		},
		'r3k2r/1bqnbppp/p3p3/1p2P3/3N4/2N3Q1/PPP1B1PP/2KR3R w kq' => {
			eco => 'B99e',
			# TRANSLATORS: B99e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. Be2 b5 11. Bxf6 Nxf6 12. e5 Bb7 13. Qg3 dxe5 14. fxe5 Nd7
			variation => N__('Sicilian: Najdorf, Main Line, Keres, 13. Qg3'),
			moves => {
				'e2b5' => 1,
			},
		},
		'r3k2r/1bqnbppp/p3p3/1B2P3/3N4/2N3Q1/PPP3PP/2KR3R b kq' => {
			eco => 'B99e',
			# TRANSLATORS: B99e: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. Be2 b5 11. Bxf6 Nxf6 12. e5 Bb7 13. Qg3 dxe5 14. fxe5 Nd7 15. Bxb5
			variation => N__('Sicilian: Najdorf, Main Line, Keres, 13. Qg3 dxe5 14.fxe5 Nd7 15.Bxb5'),
			moves => {
			},
		},
		'r1b1k2r/1pqnbppp/p2ppn2/6B1/3NPP2/2NB1Q2/PPP3PP/2KR3R b kq' => {
			eco => 'B99f',
			# TRANSLATORS: B99f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. Bd3
			variation => N__('Sicilian: Najdorf, Main Line, 10. Bd3'),
			moves => {
				'b7b5' => 1,
				'h7h6' => 1,
			},
		},
		'r1b1k2r/1pqnbpp1/p2ppn1p/6B1/3NPP2/2NB1Q2/PPP3PP/2KR3R w kq' => {
			eco => 'B99f',
			# TRANSLATORS: B99f: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. Bd3 h6
			variation => N__('Sicilian: Najdorf, Main Line, 10. Bd3 h6'),
			moves => {
				'f3h3' => 1,
				'g5h4' => 1,
			},
		},
		'r1b1k2r/1pqnbpp1/p2ppn1p/6B1/3NPP2/2NB3Q/PPP3PP/2KR3R b kq' => {
			eco => 'B99g',
			# TRANSLATORS: B99g: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. Bd3 h6 11. Qh3
			variation => N__('Sicilian: Najdorf, Main Line, 10. Bd3 h6 11. Qh3'),
			moves => {
			},
		},
		'r1b1k2r/1pqnbpp1/p2ppn1p/8/3NPP1B/2NB1Q2/PPP3PP/2KR3R b kq' => {
			eco => 'B99h',
			# TRANSLATORS: B99h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. Bd3 h6 11. Bh4
			variation => N__('Sicilian: Najdorf, Main Line, 10. Bd3 h6 11. Bh4'),
			moves => {
				'g7g5' => 1,
			},
		},
		'r1b1k2r/1pqnbp2/p2ppn1p/6p1/3NPP1B/2NB1Q2/PPP3PP/2KR3R w kq' => {
			eco => 'B99h',
			# TRANSLATORS: B99h: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. Bd3 h6 11. Bh4 g5
			variation => N__('Sicilian: Najdorf, Main Line, 10. Bd3 h6 11. Bh4 g5'),
			moves => {
				'f4g5' => 1,
			},
		},
		'r1b1k2r/1pqnbp2/p2ppn1p/6P1/3NP2B/2NB1Q2/PPP3PP/2KR3R b kq' => {
			eco => 'B99i',
			# TRANSLATORS: B99i: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. Bd3 h6 11. Bh4 g5 12. fxg5
			variation => N__('Sicilian: Najdorf, Main Line, 10. Bd3 h6 11. Bh4 g5 12.fxg5'),
			moves => {
			},
		},
		'r1b1k2r/2qnbppp/p2ppn2/1p4B1/3NPP2/2NB1Q2/PPP3PP/2KR3R w kq' => {
			eco => 'B99j',
			# TRANSLATORS: B99j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. Bd3 b5
			variation => N__('Sicilian: Najdorf, Main Line, 10. Bd3 b5'),
			moves => {
				'h1e1' => 1,
			},
		},
		'r1b1k2r/2qnbppp/p2ppn2/1p4B1/3NPP2/2NB1Q2/PPP3PP/2KRR3 b kq' => {
			eco => 'B99j',
			# TRANSLATORS: B99j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. Bd3 b5 11. Rhe1
			variation => N__('Sicilian: Najdorf, Main Line, 10. Bd3 b5'),
			moves => {
				'c8b7' => 1,
			},
		},
		'r3k2r/1bqnbppp/p2ppn2/1p4B1/3NPP2/2NB1Q2/PPP3PP/2KRR3 w kq' => {
			eco => 'B99j',
			# TRANSLATORS: B99j: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. Bd3 b5 11. Rhe1 Bb7
			variation => N__('Sicilian: Najdorf, Main Line, 10. Bd3 b5 11.Rhe1 Bb7'),
			moves => {
				'c3d5' => 1,
				'f3g3' => 1,
			},
		},
		'r3k2r/1bqnbppp/p2ppn2/1p1N2B1/3NPP2/3B1Q2/PPP3PP/2KRR3 b kq' => {
			eco => 'B99k',
			# TRANSLATORS: B99k: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. Bd3 b5 11. Rhe1 Bb7 12. Nd5
			variation => N__('Sicilian: Najdorf, Main Line, 10. Bd3 b5 11.Rhe1 Bb7 12. Nd5'),
			moves => {
			},
		},
		'r3k2r/1bqnbppp/p2ppn2/1p4B1/3NPP2/2NB2Q1/PPP3PP/2KRR3 b kq' => {
			eco => 'B99l',
			# TRANSLATORS: B99l: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. Bd3 b5 11. Rhe1 Bb7 12. Qg3
			variation => N__('Sicilian: Najdorf, Main Line, 10. Bd3 b5 11.Rhe1 Bb7 12. Qg3'),
			moves => {
			},
		},
		'r1b1k2r/1pqnbppp/p2ppn2/6B1/3NPPP1/2N2Q2/PPP4P/2KR1B1R b kq' => {
			eco => 'B99m',
			# TRANSLATORS: B99m: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. g4
			variation => N__('Sicilian: Najdorf, Main Line, 10. g4'),
			moves => {
				'b7b5' => 1,
				'h7h6' => 1,
			},
		},
		'r1b1k2r/1pqnbpp1/p2ppn1p/6B1/3NPPP1/2N2Q2/PPP4P/2KR1B1R w kq' => {
			eco => 'B99m',
			# TRANSLATORS: B99m: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. g4 h6
			variation => N__('Sicilian: Najdorf, Main Line, 10. g4 h6'),
			moves => {
			},
		},
		'r1b1k2r/2qnbppp/p2ppn2/1p4B1/3NPPP1/2N2Q2/PPP4P/2KR1B1R w kq' => {
			eco => 'B99n',
			# TRANSLATORS: B99n: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. g4 b5
			variation => N__('Sicilian: Najdorf, Main Line, 10. g4 b5'),
			moves => {
				'a2a3' => 1,
				'f1d3' => 1,
				'g5f6' => 1,
			},
		},
		'r1b1k2r/2qnbppp/p2ppn2/1p4B1/3NPPP1/2NB1Q2/PPP4P/2KR3R b kq' => {
			eco => 'B99n',
			# TRANSLATORS: B99n: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. g4 b5 11. Bd3
			variation => N__('Sicilian: Najdorf, Main Line, 10. g4 b5 11. Bd3'),
			moves => {
				'c8b7' => 1,
			},
		},
		'r3k2r/1bqnbppp/p2ppn2/1p4B1/3NPPP1/2NB1Q2/PPP4P/2KR3R w kq' => {
			eco => 'B99n',
			# TRANSLATORS: B99n: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. g4 b5 11. Bd3 Bb7
			variation => N__('Sicilian: Najdorf, Main Line, 10. g4 b5 11. Bd3 Bb7'),
			moves => {
			},
		},
		'r1b1k2r/2qnbppp/p2ppn2/1p4B1/3NPPP1/P1N2Q2/1PP4P/2KR1B1R b kq' => {
			eco => 'B99o',
			# TRANSLATORS: B99o: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. g4 b5 11. a3
			variation => N__('Sicilian: Najdorf, Main Line, 10. g4 b5 11. a3'),
			moves => {
			},
		},
		'r1b1k2r/2qnbppp/p2ppB2/1p6/3NPPP1/2N2Q2/PPP4P/2KR1B1R b kq' => {
			eco => 'B99p',
			# TRANSLATORS: B99p: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. g4 b5 11. Bxf6
			variation => N__('Sicilian: Najdorf, Main Line, 10. g4 b5 11.Bxf6'),
			moves => {
				'd7f6' => 1,
				'g7f6' => 1,
			},
		},
		'r1b1k2r/2qnbp1p/p2ppp2/1p6/3NPPP1/2N2Q2/PPP4P/2KR1B1R w kq' => {
			eco => 'B99q',
			# TRANSLATORS: B99q: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. g4 b5 11. Bxf6 gxf6
			variation => N__('Sicilian: Najdorf, Main Line, 10. g4 b5 11.Bxf6 gxf6'),
			moves => {
			},
		},
		'r1b1k2r/2q1bppp/p2ppn2/1p6/3NPPP1/2N2Q2/PPP4P/2KR1B1R w kq' => {
			eco => 'B99r',
			# TRANSLATORS: B99r: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. g4 b5 11. Bxf6 Nxf6
			variation => N__('Sicilian: Najdorf, Main Line, 10. g4 b5 11.Bxf6 Nxf6'),
			moves => {
				'g4g5' => 1,
			},
		},
		'r1b1k2r/2q1bppp/p2ppn2/1p4P1/3NPP2/2N2Q2/PPP4P/2KR1B1R b kq' => {
			eco => 'B99r',
			# TRANSLATORS: B99r: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. g4 b5 11. Bxf6 Nxf6 12. g5
			variation => N__('Sicilian: Najdorf, Main Line, 10. g4 b5 11.Bxf6 Nxf6 12. g5'),
			moves => {
				'f6d7' => 1,
			},
		},
		'r1b1k2r/2qnbppp/p2pp3/1p4P1/3NPP2/2N2Q2/PPP4P/2KR1B1R w kq' => {
			eco => 'B99r',
			# TRANSLATORS: B99r: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. g4 b5 11. Bxf6 Nxf6 12. g5 Nd7
			variation => N__('Sicilian: Najdorf, Main Line, 10. g4 b5 11.Bxf6 Nxf6 12. g5'),
			moves => {
				'a2a3' => 1,
				'f4f5' => 1,
			},
		},
		'r1b1k2r/2qnbppp/p2pp3/1p4P1/3NPP2/P1N2Q2/1PP4P/2KR1B1R b kq' => {
			eco => 'B99r',
			# TRANSLATORS: B99r: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. g4 b5 11. Bxf6 Nxf6 12. g5 Nd7 13. a3
			variation => N__('Sicilian: Najdorf, Main Line, 10. g4 b5 11.Bxf6 Nxf6 12. g5 Nd7 13. a3'),
			moves => {
			},
		},
		'r1b1k2r/2qnbppp/p2pp3/1p3PP1/3NP3/2N2Q2/PPP4P/2KR1B1R b kq' => {
			eco => 'B99s',
			# TRANSLATORS: B99s: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. g4 b5 11. Bxf6 Nxf6 12. g5 Nd7 13. f5
			variation => N__('Sicilian: Najdorf, Modern Main Line 13. f5'),
			moves => {
				'd7c5' => 1,
				'e7g5' => 1,
			},
		},
		'r1b1k2r/2qn1ppp/p2pp3/1p3Pb1/3NP3/2N2Q2/PPP4P/2KR1B1R w kq' => {
			eco => 'B99t',
			# TRANSLATORS: B99t: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. g4 b5 11. Bxf6 Nxf6 12. g5 Nd7 13. f5 Bxg5+
			variation => N__('Sicilian: Najdorf, Modern Main Line 13. f5 Bxg5+'),
			moves => {
				'c1b1' => 1,
			},
		},
		'r1b1k2r/2qn1ppp/p2pp3/1p3Pb1/3NP3/2N2Q2/PPP4P/1K1R1B1R b kq' => {
			eco => 'B99t',
			# TRANSLATORS: B99t: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. g4 b5 11. Bxf6 Nxf6 12. g5 Nd7 13. f5 Bxg5+ 14. Kb1
			variation => N__('Sicilian: Najdorf, Modern Main Line 13. f5 Bxg5+'),
			moves => {
				'd7e5' => 1,
			},
		},
		'r1b1k2r/2q2ppp/p2pp3/1p2nPb1/3NP3/2N2Q2/PPP4P/1K1R1B1R w kq' => {
			eco => 'B99u',
			# TRANSLATORS: B99u: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. g4 b5 11. Bxf6 Nxf6 12. g5 Nd7 13. f5 Bxg5+ 14. Kb1 Ne5
			variation => N__('Sicilian: Najdorf, Modern Main Line 13. f5 Bxg5+ 14. Kb1 Ne5'),
			moves => {
			},
		},
		'r1b1k2r/2q1bppp/p2pp3/1pn2PP1/3NP3/2N2Q2/PPP4P/2KR1B1R w kq' => {
			eco => 'B99v',
			# TRANSLATORS: B99v: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. g4 b5 11. Bxf6 Nxf6 12. g5 Nd7 13. f5 Nc5
			variation => N__('Sicilian: Najdorf, Modern Main Line 13. f5 Nc5'),
			moves => {
				'f5f6' => 1,
				'h2h4' => 1,
			},
		},
		'r1b1k2r/2q1bppp/p2pp3/1pn2PP1/3NP2P/2N2Q2/PPP5/2KR1B1R b kq' => {
			eco => 'B99w',
			# TRANSLATORS: B99w: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. g4 b5 11. Bxf6 Nxf6 12. g5 Nd7 13. f5 Nc5 14. h4
			variation => N__('Sicilian: Najdorf, Modern Main Line 13. f5 Nc5 14. h4'),
			moves => {
			},
		},
		'r1b1k2r/2q1bppp/p2ppP2/1pn3P1/3NP3/2N2Q2/PPP4P/2KR1B1R b kq' => {
			eco => 'B99x',
			# TRANSLATORS: B99x: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. g4 b5 11. Bxf6 Nxf6 12. g5 Nd7 13. f5 Nc5 14. f6
			variation => N__('Sicilian: Najdorf, Modern Main Line 13. f5 Nc5 14. f6'),
			moves => {
				'g7f6' => 1,
			},
		},
		'r1b1k2r/2q1bp1p/p2ppp2/1pn3P1/3NP3/2N2Q2/PPP4P/2KR1B1R w kq' => {
			eco => 'B99x',
			# TRANSLATORS: B99x: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. g4 b5 11. Bxf6 Nxf6 12. g5 Nd7 13. f5 Nc5 14. f6 gxf6
			variation => N__('Sicilian: Najdorf, Modern Main Line 13. f5 Nc5 14. f6'),
			moves => {
				'g5f6' => 1,
			},
		},
		'r1b1k2r/2q1bp1p/p2ppP2/1pn5/3NP3/2N2Q2/PPP4P/2KR1B1R b kq' => {
			eco => 'B99x',
			# TRANSLATORS: B99x: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. g4 b5 11. Bxf6 Nxf6 12. g5 Nd7 13. f5 Nc5 14. f6 gxf6 15. gxf6
			variation => N__('Sicilian: Najdorf, Modern Main Line 13. f5 Nc5 14. f6'),
			moves => {
				'e7f8' => 1,
			},
		},
		'r1b1kb1r/2q2p1p/p2ppP2/1pn5/3NP3/2N2Q2/PPP4P/2KR1B1R w kq' => {
			eco => 'B99x',
			# TRANSLATORS: B99x: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. g4 b5 11. Bxf6 Nxf6 12. g5 Nd7 13. f5 Nc5 14. f6 gxf6 15. gxf6 Bf8
			variation => N__('Sicilian: Najdorf, Modern Main Line 13. f5 Nc5 14. f6'),
			moves => {
				'h1g1' => 1,
			},
		},
		'r1b1kb1r/2q2p1p/p2ppP2/1pn5/3NP3/2N2Q2/PPP4P/2KR1BR1 b kq' => {
			eco => 'B99y',
			# TRANSLATORS: B99y: 1. e4 c5 2. Nf3 d6 3. d4 cxd4 4. Nxd4 Nf6 5. Nc3 a6 6. Bg5 e6 7. f4 Be7 8. Qf3 Qc7 9. O-O-O Nbd7 10. g4 b5 11. Bxf6 Nxf6 12. g5 Nd7 13. f5 Nc5 14. f6 gxf6 15. gxf6 Bf8 16. Rg1
			variation => N__('Sicilian: Najdorf, Modern Main Line 13. f5 Nc5 14. f6: Perenyi\'s 16. Rg1'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/4p3/8/4P3/8/PPPP1PPP/RNBQKBNR w KQkq' => {
			eco => 'C00a',
			# TRANSLATORS: C00a: 1. e4 e6
			variation => N__('French'),
			moves => {
				'b1c3' => 1,
				'b2b3' => 1,
				'c2c4' => 1,
				'd1e2' => 1,
				'd2d3' => 1,
				'd2d4' => 1,
				'e4e5' => 1,
				'f1b5' => 1,
				'f2f4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pppp1ppp/4p3/1B6/4P3/8/PPPP1PPP/RNBQK1NR b KQkq' => {
			eco => 'C00a',
			# TRANSLATORS: C00a: 1. e4 e6 2. Bb5
			variation => N__('French: Bird Variation'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/4p3/8/4P3/1P6/P1PP1PPP/RNBQKBNR b KQkq' => {
			eco => 'C00b',
			# TRANSLATORS: C00b: 1. e4 e6 2. b3
			variation => N__('French: Reti (Spielmann) Variation'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/4p3/8/4PP2/8/PPPP2PP/RNBQKBNR b KQkq' => {
			eco => 'C00c',
			# TRANSLATORS: C00c: 1. e4 e6 2. f4
			variation => N__('French: La Bourdonnais Variation'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/4p3/4P3/8/8/PPPP1PPP/RNBQKBNR b KQkq' => {
			eco => 'C00d',
			# TRANSLATORS: C00d: 1. e4 e6 2. e5
			variation => N__('French: Steinitz Attack'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/4p3/8/2P1P3/8/PP1P1PPP/RNBQKBNR b KQkq' => {
			eco => 'C00e',
			# TRANSLATORS: C00e: 1. e4 e6 2. c4
			variation => N__('French: Steiner (Anglo-French) Variation'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/3p4/2P1P3/8/PP1P1PPP/RNBQKBNR w KQkq' => {
			eco => 'C00e',
			# TRANSLATORS: C00e: 1. e4 e6 2. c4 d5
			variation => N__('French: Steiner (Anglo-French) Variation'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/3P4/4P3/8/PP1P1PPP/RNBQKBNR b KQkq' => {
			eco => 'C00e',
			# TRANSLATORS: C00e: 1. e4 e6 2. c4 d5 3. cxd5
			variation => N__('French: Steiner (Anglo-French) Variation'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/8/3p4/4P3/8/PP1P1PPP/RNBQKBNR w KQkq' => {
			eco => 'C00e',
			# TRANSLATORS: C00e: 1. e4 e6 2. c4 d5 3. cxd5 exd5
			variation => N__('French: Steiner (Anglo-French) Variation'),
			moves => {
				'd1b3' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/8/3p4/4P3/1Q6/PP1P1PPP/RNB1KBNR b KQkq' => {
			eco => 'C00e',
			# TRANSLATORS: C00e: 1. e4 e6 2. c4 d5 3. cxd5 exd5 4. Qb3
			variation => N__('French: Orthoschnapp Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/4p3/8/4P3/2N5/PPPP1PPP/R1BQKBNR b KQkq' => {
			eco => 'C00f',
			# TRANSLATORS: C00f: 1. e4 e6 2. Nc3
			variation => N__('French: 2. Nc3'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/3p4/4P3/2N5/PPPP1PPP/R1BQKBNR w KQkq' => {
			eco => 'C00f',
			# TRANSLATORS: C00f: 1. e4 e6 2. Nc3 d5
			variation => N__('French: 2. Nc3 d5'),
			moves => {
				'f2f4' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/3p4/4PP2/2N5/PPPP2PP/R1BQKBNR b KQkq' => {
			eco => 'C00f',
			# TRANSLATORS: C00f: 1. e4 e6 2. Nc3 d5 3. f4
			variation => N__('French: Pelikan Variation'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/4p3/8/4P3/8/PPPPQPPP/RNB1KBNR b KQkq' => {
			eco => 'C00g',
			# TRANSLATORS: C00g: 1. e4 e6 2. Qe2
			variation => N__('French: Chigorin Variation'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqkbnr/pp1p1ppp/4p3/2p5/4P3/8/PPPPQPPP/RNB1KBNR w KQkq' => {
			eco => 'C00h',
			# TRANSLATORS: C00h: 1. e4 e6 2. Qe2 c5
			variation => N__('French: Chigorin, 2... c5'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pp1p1ppp/4p3/2p5/4P3/5N2/PPPPQPPP/RNB1KB1R b KQkq' => {
			eco => 'C00i',
			# TRANSLATORS: C00i: 1. e4 e6 2. Qe2 c5 3. Nf3
			variation => N__('French: Chigorin, 2... c5 3. Nf3'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/4p3/8/4P3/5N2/PPPP1PPP/RNBQKB1R b KQkq' => {
			eco => 'C00j',
			# TRANSLATORS: C00j: 1. e4 e6 2. Nf3
			variation => N__('French: 2. Nf3'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/3p4/4P3/5N2/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'C00j',
			# TRANSLATORS: C00j: 1. e4 e6 2. Nf3 d5
			variation => N__('French: 2. Nf3 d5'),
			moves => {
				'b1c3' => 1,
				'e4e5' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/3pP3/8/5N2/PPPP1PPP/RNBQKB1R b KQkq' => {
			eco => 'C00j',
			# TRANSLATORS: C00j: 1. e4 e6 2. Nf3 d5 3. e5
			variation => N__('French: 2. Nf3 d5 3. e5'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/4p3/2ppP3/8/5N2/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'C00j',
			# TRANSLATORS: C00j: 1. e4 e6 2. Nf3 d5 3. e5 c5
			variation => N__('French: 2. Nf3 d5 3. e5 c5'),
			moves => {
				'b2b4' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/4p3/2ppP3/1P6/5N2/P1PP1PPP/RNBQKB1R b KQkq' => {
			eco => 'C00k',
			# TRANSLATORS: C00k: 1. e4 e6 2. Nf3 d5 3. e5 c5 4. b4
			variation => N__('French: Wing Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/3p4/4P3/2N2N2/PPPP1PPP/R1BQKB1R b KQkq' => {
			eco => 'C00l',
			# TRANSLATORS: C00l: 1. e4 e6 2. Nf3 d5 3. Nc3
			variation => N__('French: Two Knights Variation'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/4p3/8/4P3/3P4/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'C00m',
			# TRANSLATORS: C00m: 1. e4 e6 2. d3
			variation => N__('French: KIA 2. d3'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/3p4/4P3/3P4/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'C00m',
			# TRANSLATORS: C00m: 1. e4 e6 2. d3 d5
			variation => N__('French: KIA 2. d3 d5'),
			moves => {
				'b1d2' => 1,
				'd1e2' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/3p4/4P3/3P4/PPP1QPPP/RNB1KBNR b KQkq' => {
			eco => 'C00n',
			# TRANSLATORS: C00n: 1. e4 e6 2. d3 d5 3. Qe2
			variation => N__('French: KIA 2. d3 d5 3. Qe2'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p4/4P3/3P4/PPP1QPPP/RNB1KBNR w KQkq' => {
			eco => 'C00o',
			# TRANSLATORS: C00o: 1. e4 e6 2. d3 d5 3. Qe2 Nf6
			variation => N__('French: KIA 2. d3 d5 3. Qe2 Nf6'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/3p4/4P3/3P4/PPPN1PPP/R1BQKBNR b KQkq' => {
			eco => 'C00p',
			# TRANSLATORS: C00p: 1. e4 e6 2. d3 d5 3. Nd2
			variation => N__('French: KIA 2. d3 d5 3. Nd2'),
			moves => {
				'c7c5' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/4p3/2pp4/4P3/3P4/PPPN1PPP/R1BQKBNR w KQkq' => {
			eco => 'C00q',
			# TRANSLATORS: C00q: 1. e4 e6 2. d3 d5 3. Nd2 c5
			variation => N__('French: KIA 2. d3 d5 3. Nd2 c5'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p4/4P3/3P4/PPPN1PPP/R1BQKBNR w KQkq' => {
			eco => 'C00r',
			# TRANSLATORS: C00r: 1. e4 e6 2. d3 d5 3. Nd2 Nf6
			variation => N__('French: KIA 2. d3 d5 3. Nd2 Nf6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p4/4P3/3P1N2/PPPN1PPP/R1BQKB1R b KQkq' => {
			eco => 'C00s',
			# TRANSLATORS: C00s: 1. e4 e6 2. d3 d5 3. Nd2 Nf6 4. Ngf3
			variation => N__('French: KIA, Reversed Philidor'),
			moves => {
				'b7b6' => 1,
				'b8c6' => 1,
			},
		},
		'rnbqkb1r/p1p2ppp/1p2pn2/3p4/4P3/3P1N2/PPPN1PPP/R1BQKB1R w KQkq' => {
			eco => 'C00t',
			# TRANSLATORS: C00t: 1. e4 e6 2. d3 d5 3. Nd2 Nf6 4. Ngf3 b6
			variation => N__('French: KIA, Reversed Philidor, 4... b6'),
			moves => {
			},
		},
		'r1bqkb1r/ppp2ppp/2n1pn2/3p4/4P3/3P1N2/PPPN1PPP/R1BQKB1R w KQkq' => {
			eco => 'C00u',
			# TRANSLATORS: C00u: 1. e4 e6 2. d3 d5 3. Nd2 Nf6 4. Ngf3 Nc6
			variation => N__('French: KIA, Reversed Philidor, 4... Nc6'),
			moves => {
				'c2c3' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2n1pn2/3p4/4P3/2PP1N2/PP1N1PPP/R1BQKB1R b KQkq' => {
			eco => 'C00v',
			# TRANSLATORS: C00v: 1. e4 e6 2. d3 d5 3. Nd2 Nf6 4. Ngf3 Nc6 5. c3
			variation => N__('French: KIA, Reversed Philidor, 4... Nc6 5. c3'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/4p3/8/3PP3/8/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'C00w',
			# TRANSLATORS: C00w: 1. e4 e6 2. d4
			variation => N__('French: 2. d4'),
			moves => {
				'a7a6' => 1,
				'c7c5' => 1,
				'd7d5' => 1,
			},
		},
		'rnbqkbnr/1ppp1ppp/p3p3/8/3PP3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'C00w',
			# TRANSLATORS: C00w: 1. e4 e6 2. d4 a6
			variation => N__('French: St. George'),
			moves => {
			},
		},
		'rnbqkbnr/pp1p1ppp/4p3/2p5/3PP3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'C00w',
			# TRANSLATORS: C00w: 1. e4 e6 2. d4 c5
			variation => N__('French: Franco-Benoni'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/3p4/3PP3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'C00x',
			# TRANSLATORS: C00x: 1. e4 e6 2. d4 d5
			variation => N__('French: 2. d4 d5'),
			moves => {
				'b1c3' => 1,
				'b1d2' => 1,
				'c1e3' => 1,
				'c2c4' => 1,
				'e4d5' => 1,
				'e4e5' => 1,
				'f1d3' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/3p4/3PP3/4B3/PPP2PPP/RN1QKBNR b KQkq' => {
			eco => 'C00x',
			# TRANSLATORS: C00x: 1. e4 e6 2. d4 d5 3. Be3
			variation => N__('French: Alapin-Diemer Gambit (ADG)'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/3p4/3PP3/3B4/PPP2PPP/RNBQK1NR b KQkq' => {
			eco => 'C00y',
			# TRANSLATORS: C00y: 1. e4 e6 2. d4 d5 3. Bd3
			variation => N__('French: Schlechter'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/3P4/3P4/8/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'C01a',
			# TRANSLATORS: C01a: 1. e4 e6 2. d4 d5 3. exd5
			variation => N__('French: Exchange'),
			moves => {
				'd8d5' => 1,
				'e6d5' => 1,
			},
		},
		'rnb1kbnr/ppp2ppp/4p3/3q4/3P4/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'C01a',
			# TRANSLATORS: C01a: 1. e4 e6 2. d4 d5 3. exd5 Qxd5
			variation => N__('French: Exchange, 3...Qxd5'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/8/3p4/3P4/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'C01b',
			# TRANSLATORS: C01b: 1. e4 e6 2. d4 d5 3. exd5 exd5
			variation => N__('French: Exchange'),
			moves => {
				'b1c3' => 1,
				'c1f4' => 1,
				'c2c4' => 1,
				'f1d3' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/8/3p4/2PP4/8/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'C01c',
			# TRANSLATORS: C01c: 1. e4 e6 2. d4 d5 3. exd5 exd5 4. c4
			variation => N__('French: Exchange, 4. c4'),
			moves => {
				'c7c6' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/2p5/3p4/2PP4/8/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'C01c',
			# TRANSLATORS: C01c: 1. e4 e6 2. d4 d5 3. exd5 exd5 4. c4 c6
			variation => N__('French: Exchange, 4. c4 c6'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3p4/2PP4/8/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'C01d',
			# TRANSLATORS: C01d: 1. e4 e6 2. d4 d5 3. exd5 exd5 4. c4 Nf6
			variation => N__('French: Exchange, 4. c4 Nf6'),
			moves => {
				'b1c3' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3p4/2PP4/5N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'C01d',
			# TRANSLATORS: C01d: 1. e4 e6 2. d4 d5 3. exd5 exd5 4. c4 Nf6 5. Nf3
			variation => N__('French: Exchange, 4. c4 Nf6'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3p4/2PP4/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'C01e',
			# TRANSLATORS: C01e: 1. e4 e6 2. d4 d5 3. exd5 exd5 4. c4 Nf6 5. Nc3
			variation => N__('French: Exchange, 4. c4 Nf6 5. Nc3'),
			moves => {
				'c7c6' => 1,
				'f8b4' => 1,
				'f8e7' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/2p2n2/3p4/2PP4/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'C01e',
			# TRANSLATORS: C01e: 1. e4 e6 2. d4 d5 3. exd5 exd5 4. c4 Nf6 5. Nc3 c6
			variation => N__('French: Exchange, 4. c4 Nf6 5. Nc3 c6'),
			moves => {
			},
		},
		'rnbqk2r/ppp2ppp/5n2/3p4/1bPP4/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'C01e',
			# TRANSLATORS: C01e: 1. e4 e6 2. d4 d5 3. exd5 exd5 4. c4 Nf6 5. Nc3 Bb4
			variation => N__('French: Exchange, 4. c4 Nf6 5. Nc3 Bb4'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/5n2/3p4/1bPP4/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'C01e',
			# TRANSLATORS: C01e: 1. e4 e6 2. d4 d5 3. exd5 exd5 4. c4 Nf6 5. Nc3 Bb4 6. Nf3
			variation => N__('French: Exchange, 4. c4 Nf6 5. Nc3 Bb4'),
			moves => {
			},
		},
		'rnbqk2r/ppp1bppp/5n2/3p4/2PP4/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'C01f',
			# TRANSLATORS: C01f: 1. e4 e6 2. d4 d5 3. exd5 exd5 4. c4 Nf6 5. Nc3 Be7
			variation => N__('French: Exchange, 4. c4 Nf6 5. Nc3 Be7'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqk2r/ppp1bppp/5n2/3p4/2PP4/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'C01f',
			# TRANSLATORS: C01f: 1. e4 e6 2. d4 d5 3. exd5 exd5 4. c4 Nf6 5. Nc3 Be7 6. Nf3
			variation => N__('French: Exchange, 4. c4 Nf6 5. Nc3 Be7'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/8/3p4/3P1B2/8/PPP2PPP/RN1QKBNR b KQkq' => {
			eco => 'C01g',
			# TRANSLATORS: C01g: 1. e4 e6 2. d4 d5 3. exd5 exd5 4. Bf4
			variation => N__('French: Exchange, 4. Bf4'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/8/3p4/3P4/3B4/PPP2PPP/RNBQK1NR b KQkq' => {
			eco => 'C01h',
			# TRANSLATORS: C01h: 1. e4 e6 2. d4 d5 3. exd5 exd5 4. Bd3
			variation => N__('French: Exchange, 4. Bd3'),
			moves => {
				'b8c6' => 1,
				'f8d6' => 1,
			},
		},
		'r1bqkbnr/ppp2ppp/2n5/3p4/3P4/3B4/PPP2PPP/RNBQK1NR w KQkq' => {
			eco => 'C01i',
			# TRANSLATORS: C01i: 1. e4 e6 2. d4 d5 3. exd5 exd5 4. Bd3 Nc6
			variation => N__('French: Exchange, 4. Bd3 Nc6'),
			moves => {
			},
		},
		'rnbqk1nr/ppp2ppp/3b4/3p4/3P4/3B4/PPP2PPP/RNBQK1NR w KQkq' => {
			eco => 'C01j',
			# TRANSLATORS: C01j: 1. e4 e6 2. d4 d5 3. exd5 exd5 4. Bd3 Bd6
			variation => N__('French: Exchange, 4. Bd3 Bd6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/8/3p4/3P4/5N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'C01k',
			# TRANSLATORS: C01k: 1. e4 e6 2. d4 d5 3. exd5 exd5 4. Nf3
			variation => N__('French: Exchange, 4. Nf3'),
			moves => {
				'f8d6' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3p4/3P4/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C01l',
			# TRANSLATORS: C01l: 1. e4 e6 2. d4 d5 3. exd5 exd5 4. Nf3 Nf6
			variation => N__('French: Exchange, 4. Nf3 Nf6'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3p4/3P4/3B1N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C01m',
			# TRANSLATORS: C01m: 1. e4 e6 2. d4 d5 3. exd5 exd5 4. Nf3 Nf6 5. Bd3
			variation => N__('French: Exchange, 4. Nf3 Nf6 5. Bd3'),
			moves => {
			},
		},
		'rnbqk1nr/ppp2ppp/3b4/3p4/3P4/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C01n',
			# TRANSLATORS: C01n: 1. e4 e6 2. d4 d5 3. exd5 exd5 4. Nf3 Bd6
			variation => N__('French: Exchange, 4. Nf3 Bd6'),
			moves => {
				'c2c4' => 1,
			},
		},
		'rnbqk1nr/ppp2ppp/3b4/3p4/3P4/3B1N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C01o',
			# TRANSLATORS: C01o: 1. e4 e6 2. d4 d5 3. exd5 exd5 4. Bd3 Bd6 5. Nf3
			variation => N__('French: Exchange, 4. Nf3 Bd6 5. Bd3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/3b1n2/3p4/3P4/3B1N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C01p',
			# TRANSLATORS: C01p: 1. e4 e6 2. d4 d5 3. exd5 exd5 4. Bd3 Bd6 5. Nf3 Nf6
			variation => N__('French: Exchange, 4. Nf3 Bd6 5. Bd3 Nf6'),
			moves => {
			},
		},
		'rnbqk1nr/ppp2ppp/3b4/3p4/2PP4/5N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'C01q',
			# TRANSLATORS: C01q: 1. e4 e6 2. d4 d5 3. exd5 exd5 4. Nf3 Bd6 5. c4
			variation => N__('French: Exchange, 4. Nf3 Bd6 5. c4'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/8/3p4/3P4/2N5/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'C01r',
			# TRANSLATORS: C01r: 1. e4 e6 2. d4 d5 3. exd5 exd5 4. Nc3
			variation => N__('French: Exchange, 4. Nc3'),
			moves => {
				'f8b4' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3p4/3P4/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'C01s',
			# TRANSLATORS: C01s: 1. e4 e6 2. d4 d5 3. exd5 exd5 4. Nc3 Nf6
			variation => N__('French: Exchange, 4. Nc3 Nf6'),
			moves => {
				'c1g5' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3p4/3P4/2N2N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'C01s',
			# TRANSLATORS: C01s: 1. e4 e6 2. d4 d5 3. exd5 exd5 4. Nc3 Nf6 5. Nf3
			variation => N__('French: Exchange, 4. Nc3 Nf6 5. Nf3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3p2B1/3P4/2N5/PPP2PPP/R2QKBNR b KQkq' => {
			eco => 'C01t',
			# TRANSLATORS: C01t: 1. e4 e6 2. d4 d5 3. exd5 exd5 4. Nc3 Nf6 5. Bg5
			variation => N__('French: Exchange, Svenonius Variation'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2n2n2/3p2B1/3P4/2N5/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'C01t',
			# TRANSLATORS: C01t: 1. e4 e6 2. d4 d5 3. exd5 exd5 4. Nc3 Nf6 5. Bg5 Nc6
			variation => N__('French: Exchange, Bogoljubow Variation'),
			moves => {
			},
		},
		'rnbqk1nr/ppp2ppp/8/3p4/1b1P4/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'C01u',
			# TRANSLATORS: C01u: 1. e4 e6 2. d4 d5 3. exd5 exd5 4. Nc3 Bb4
			variation => N__('French: Exchange Winawer'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rnbqk1nr/ppp2ppp/8/3p4/1b1P4/2NB4/PPP2PPP/R1BQK1NR b KQkq' => {
			eco => 'C01v',
			# TRANSLATORS: C01v: 1. e4 e6 2. d4 d5 3. exd5 exd5 4. Nc3 Bb4 5. Bd3
			variation => N__('French: Exchange Winawer, 5. Bd3'),
			moves => {
				'b8c6' => 1,
				'g8e7' => 1,
			},
		},
		'rnbqk2r/ppp1nppp/8/3p4/1b1P4/2NB4/PPP2PPP/R1BQK1NR w KQkq' => {
			eco => 'C01v',
			# TRANSLATORS: C01v: 1. e4 e6 2. d4 d5 3. exd5 exd5 4. Nc3 Bb4 5. Bd3 Ne7
			variation => N__('French: Exchange Winawer, 5. Bd3'),
			moves => {
				'd1h5' => 1,
			},
		},
		'rnbqk2r/ppp1nppp/8/3p3Q/1b1P4/2NB4/PPP2PPP/R1B1K1NR b KQkq' => {
			eco => 'C01v',
			# TRANSLATORS: C01v: 1. e4 e6 2. d4 d5 3. exd5 exd5 4. Nc3 Bb4 5. Bd3 Ne7 6. Qh5
			variation => N__('French: Exchange, Canal Attack'),
			moves => {
			},
		},
		'r1bqk1nr/ppp2ppp/2n5/3p4/1b1P4/2NB4/PPP2PPP/R1BQK1NR w KQkq' => {
			eco => 'C01w',
			# TRANSLATORS: C01w: 1. e4 e6 2. d4 d5 3. exd5 exd5 4. Nc3 Bb4 5. Bd3 Nc6
			variation => N__('French: Exchange Winawer, 5. Bd3 Nc6'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/3pP3/3P4/8/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'C02a',
			# TRANSLATORS: C02a: 1. e4 e6 2. d4 d5 3. e5
			variation => N__('French: Advance'),
			moves => {
				'b7b6' => 1,
				'c7c5' => 1,
				'g8e7' => 1,
			},
		},
		'rnbqkb1r/ppp1nppp/4p3/3pP3/3P4/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'C02a',
			# TRANSLATORS: C02a: 1. e4 e6 2. d4 d5 3. e5 Ne7
			variation => N__('French: Advance, 3... Ne7'),
			moves => {
			},
		},
		'rnbqkbnr/p1p2ppp/1p2p3/3pP3/3P4/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'C02b',
			# TRANSLATORS: C02b: 1. e4 e6 2. d4 d5 3. e5 b6
			variation => N__('French: Advance, 3... b6'),
			moves => {
				'c2c3' => 1,
			},
		},
		'rnbqkbnr/p1p2ppp/1p2p3/3pP3/3P4/2P5/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'C02b',
			# TRANSLATORS: C02b: 1. e4 e6 2. d4 d5 3. e5 b6 4. c3
			variation => N__('French: Advance, 3... b6'),
			moves => {
				'd8d7' => 1,
			},
		},
		'rnb1kbnr/p1pq1ppp/1p2p3/3pP3/3P4/2P5/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'C02b',
			# TRANSLATORS: C02b: 1. e4 e6 2. d4 d5 3. e5 b6 4. c3 Qd7
			variation => N__('French: Advance, 3... b6'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/4p3/2ppP3/3P4/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'C02c',
			# TRANSLATORS: C02c: 1. e4 e6 2. d4 d5 3. e5 c5
			variation => N__('French: Advance, 3... c5'),
			moves => {
				'b2b4' => 1,
				'c2c3' => 1,
				'd1g4' => 1,
				'd4c5' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/4p3/2ppP3/1P1P4/8/P1P2PPP/RNBQKBNR b KQkq' => {
			eco => 'C02c',
			# TRANSLATORS: C02c: 1. e4 e6 2. d4 d5 3. e5 c5 4. b4
			variation => N__('French: Advance, Wing Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/4p3/2PpP3/8/8/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'C02d',
			# TRANSLATORS: C02d: 1. e4 e6 2. d4 d5 3. e5 c5 4. dxc5
			variation => N__('French: Advance, Steinitz'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/4p3/2ppP3/3P2Q1/8/PPP2PPP/RNB1KBNR b KQkq' => {
			eco => 'C02e',
			# TRANSLATORS: C02e: 1. e4 e6 2. d4 d5 3. e5 c5 4. Qg4
			variation => N__('French: Advance, Nimzowitsch Attack'),
			moves => {
				'c5d4' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/4p3/3pP3/3p2Q1/8/PPP2PPP/RNB1KBNR w KQkq' => {
			eco => 'C02e',
			# TRANSLATORS: C02e: 1. e4 e6 2. d4 d5 3. e5 c5 4. Qg4 cxd4
			variation => N__('French: Advance, Nimzowitsch Attack'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/4p3/3pP3/3p2Q1/5N2/PPP2PPP/RNB1KB1R b KQkq' => {
			eco => 'C02e',
			# TRANSLATORS: C02e: 1. e4 e6 2. d4 d5 3. e5 c5 4. Qg4 cxd4 5. Nf3
			variation => N__('French: Advance, Nimzowitsch Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/4p3/2ppP3/3P4/5N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'C02f',
			# TRANSLATORS: C02f: 1. e4 e6 2. d4 d5 3. e5 c5 4. Nf3
			variation => N__('French: Advance, 4. Nf3'),
			moves => {
				'c5d4' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/4p3/3pP3/3p4/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C02f',
			# TRANSLATORS: C02f: 1. e4 e6 2. d4 d5 3. e5 c5 4. Nf3 cxd4
			variation => N__('French: Advance, 4. Nf3'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/4p3/3pP3/3p4/3B1N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C02f',
			# TRANSLATORS: C02f: 1. e4 e6 2. d4 d5 3. e5 c5 4. Nf3 cxd4 5. Bd3
			variation => N__('French: Advance, Ruisdonk Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/4p3/2ppP3/3P4/2P5/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'C02g',
			# TRANSLATORS: C02g: 1. e4 e6 2. d4 d5 3. e5 c5 4. c3
			variation => N__('French: Advance, 4. c3'),
			moves => {
				'b8c6' => 1,
				'd8b6' => 1,
			},
		},
		'rnb1kbnr/pp3ppp/1q2p3/2ppP3/3P4/2P5/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'C02h',
			# TRANSLATORS: C02h: 1. e4 e6 2. d4 d5 3. e5 c5 4. c3 Qb6
			variation => N__('French: Advance, 4. c3 Qb6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnb1kbnr/pp3ppp/1q2p3/2ppP3/3P4/2P2N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'C02h',
			# TRANSLATORS: C02h: 1. e4 e6 2. d4 d5 3. e5 c5 4. c3 Qb6 5. Nf3
			variation => N__('French: Advance, 4. c3 Qb6'),
			moves => {
				'c8d7' => 1,
			},
		},
		'rn2kbnr/pp1b1ppp/1q2p3/2ppP3/3P4/2P2N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'C02i',
			# TRANSLATORS: C02i: 1. e4 e6 2. d4 d5 3. e5 c5 4. c3 Qb6 5. Nf3 Bd7
			variation => N__('French: Advance, Wade'),
			moves => {
				'f1e2' => 1,
			},
		},
		'rn2kbnr/pp1b1ppp/1q2p3/2ppP3/3P4/2P2N2/PP2BPPP/RNBQK2R b KQkq' => {
			eco => 'C02j',
			# TRANSLATORS: C02j: 1. e4 e6 2. d4 d5 3. e5 c5 4. c3 Qb6 5. Nf3 Bd7 6. Be2
			variation => N__('French: Advance, Wade, 6. Be2'),
			moves => {
			},
		},
		'r1bqkbnr/pp3ppp/2n1p3/2ppP3/3P4/2P5/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'C02k',
			# TRANSLATORS: C02k: 1. e4 e6 2. d4 d5 3. e5 c5 4. c3 Nc6
			variation => N__('French: Advance, 4... Nc6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'r1bqkbnr/pp3ppp/2n1p3/2ppP3/3P4/2P2N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'C02l',
			# TRANSLATORS: C02l: 1. e4 e6 2. d4 d5 3. e5 c5 4. c3 Nc6 5. Nf3
			variation => N__('French: Advance, Paulsen'),
			moves => {
				'c8d7' => 1,
				'd8b6' => 1,
				'g8e7' => 1,
			},
		},
		'r1bqkb1r/pp2nppp/2n1p3/2ppP3/3P4/2P2N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'C02m',
			# TRANSLATORS: C02m: 1. e4 e6 2. d4 d5 3. e5 c5 4. c3 Nc6 5. Nf3 Nge7
			variation => N__('French: Advance, 5. Nf3 Nge7'),
			moves => {
			},
		},
		'r2qkbnr/pp1b1ppp/2n1p3/2ppP3/3P4/2P2N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'C02n',
			# TRANSLATORS: C02n: 1. e4 e6 2. d4 d5 3. e5 c5 4. c3 Nc6 5. Nf3 Bd7
			variation => N__('French: Advance, Euwe'),
			moves => {
				'a2a3' => 1,
				'f1e2' => 1,
			},
		},
		'r2qkbnr/pp1b1ppp/2n1p3/2ppP3/3P4/P1P2N2/1P3PPP/RNBQKB1R b KQkq' => {
			eco => 'C02o',
			# TRANSLATORS: C02o: 1. e4 e6 2. d4 d5 3. e5 c5 4. c3 Nc6 5. Nf3 Bd7 6. a3
			variation => N__('French: Advance, Euwe, 6. a3'),
			moves => {
			},
		},
		'r2qkbnr/pp1b1ppp/2n1p3/2ppP3/3P4/2P2N2/PP2BPPP/RNBQK2R b KQkq' => {
			eco => 'C02p',
			# TRANSLATORS: C02p: 1. e4 e6 2. d4 d5 3. e5 c5 4. c3 Nc6 5. Nf3 Bd7 6. Be2
			variation => N__('French: Advance, Euwe, 6. Be2'),
			moves => {
				'g8e7' => 1,
			},
		},
		'r2qkb1r/pp1bnppp/2n1p3/2ppP3/3P4/2P2N2/PP2BPPP/RNBQK2R w KQkq' => {
			eco => 'C02q',
			# TRANSLATORS: C02q: 1. e4 e6 2. d4 d5 3. e5 c5 4. c3 Nc6 5. Nf3 Bd7 6. Be2 Nge7
			variation => N__('French: Advance, Euwe, 6. Be2 Nge7'),
			moves => {
			},
		},
		'r1b1kbnr/pp3ppp/1qn1p3/2ppP3/3P4/2P2N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'C02r',
			# TRANSLATORS: C02r: 1. e4 e6 2. d4 d5 3. e5 c5 4. c3 Nc6 5. Nf3 Qb6
			variation => N__('French: Advance, 5. Nf3 Qb6'),
			moves => {
				'a2a3' => 1,
				'f1d3' => 1,
				'f1e2' => 1,
			},
		},
		'r1b1kbnr/pp3ppp/1qn1p3/2ppP3/3P4/2PB1N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'C02s',
			# TRANSLATORS: C02s: 1. e4 e6 2. d4 d5 3. e5 c5 4. c3 Nc6 5. Nf3 Qb6 6. Bd3
			variation => N__('French: Advance, Milner-Barry Gambit'),
			moves => {
			},
		},
		'r1b1kbnr/pp3ppp/1qn1p3/2ppP3/3P4/2P2N2/PP2BPPP/RNBQK2R b KQkq' => {
			eco => 'C02t',
			# TRANSLATORS: C02t: 1. e4 e6 2. d4 d5 3. e5 c5 4. c3 Nc6 5. Nf3 Qb6 6. Be2
			variation => N__('French: Advance, 5. Nf3 Qb6 6. Be2'),
			moves => {
				'c5d4' => 1,
			},
		},
		'r1b1kbnr/pp3ppp/1qn1p3/3pP3/3p4/2P2N2/PP2BPPP/RNBQK2R w KQkq' => {
			eco => 'C02t',
			# TRANSLATORS: C02t: 1. e4 e6 2. d4 d5 3. e5 c5 4. c3 Nc6 5. Nf3 Qb6 6. Be2 cxd4
			variation => N__('French: Advance, 5. Nf3 Qb6 6. Be2'),
			moves => {
				'c3d4' => 1,
			},
		},
		'r1b1kbnr/pp3ppp/1qn1p3/3pP3/3P4/5N2/PP2BPPP/RNBQK2R b KQkq' => {
			eco => 'C02u',
			# TRANSLATORS: C02u: 1. e4 e6 2. d4 d5 3. e5 c5 4. c3 Nc6 5. Nf3 Qb6 6. Be2 cxd4 7. cxd4
			variation => N__('French: Advance, 5. Nf3 Qb6 6. Be2 cxd4 7.cxd4'),
			moves => {
			},
		},
		'r1b1kbnr/pp3ppp/1qn1p3/2ppP3/3P4/P1P2N2/1P3PPP/RNBQKB1R b KQkq' => {
			eco => 'C02v',
			# TRANSLATORS: C02v: 1. e4 e6 2. d4 d5 3. e5 c5 4. c3 Nc6 5. Nf3 Qb6 6. a3
			variation => N__('French: Advance, 5. Nf3 Qb6 6. a3'),
			moves => {
				'c5c4' => 1,
				'c8d7' => 1,
				'g8h6' => 1,
			},
		},
		'r3kbnr/pp1b1ppp/1qn1p3/2ppP3/3P4/P1P2N2/1P3PPP/RNBQKB1R w KQkq' => {
			eco => 'C02w',
			# TRANSLATORS: C02w: 1. e4 e6 2. d4 d5 3. e5 c5 4. c3 Nc6 5. Nf3 Qb6 6. a3 Bd7
			variation => N__('French: Advance, 5. Nf3 Qb6 6. a3 Bd7'),
			moves => {
			},
		},
		'r1b1kb1r/pp3ppp/1qn1p2n/2ppP3/3P4/P1P2N2/1P3PPP/RNBQKB1R w KQkq' => {
			eco => 'C02x',
			# TRANSLATORS: C02x: 1. e4 e6 2. d4 d5 3. e5 c5 4. c3 Nc6 5. Nf3 Qb6 6. a3 Nh6
			variation => N__('French: Advance, 5. Nf3 Qb6 6. a3 Nh6'),
			moves => {
			},
		},
		'r1b1kbnr/pp3ppp/1qn1p3/3pP3/2pP4/P1P2N2/1P3PPP/RNBQKB1R w KQkq' => {
			eco => 'C02y',
			# TRANSLATORS: C02y: 1. e4 e6 2. d4 d5 3. e5 c5 4. c3 Nc6 5. Nf3 Qb6 6. a3 c4
			variation => N__('French: Advance, 5. Nf3 Qb6 6. a3 c4'),
			moves => {
				'b1d2' => 1,
			},
		},
		'r1b1kbnr/pp3ppp/1qn1p3/3pP3/2pP4/P1P2N2/1P1N1PPP/R1BQKB1R b KQkq' => {
			eco => 'C02z',
			# TRANSLATORS: C02z: 1. e4 e6 2. d4 d5 3. e5 c5 4. c3 Nc6 5. Nf3 Qb6 6. a3 c4 7. Nbd2
			variation => N__('French: Advance, 5. Nf3 Qb6 6. a3 c4 7.Nbd2'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/3p4/3PP3/8/PPPN1PPP/R1BQKBNR b KQkq' => {
			eco => 'C03a',
			# TRANSLATORS: C03a: 1. e4 e6 2. d4 d5 3. Nd2
			variation => N__('French: Tarrasch'),
			moves => {
				'a7a6' => 1,
				'b7b6' => 1,
				'b8c6' => 1,
				'c7c5' => 1,
				'd5e4' => 1,
				'f7f5' => 1,
				'f8e7' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/8/3Pp3/8/PPPN1PPP/R1BQKBNR w KQkq' => {
			eco => 'C03a',
			# TRANSLATORS: C03a: 1. e4 e6 2. d4 d5 3. Nd2 dxe4
			variation => N__('French: Tarrasch, 3...dxe4'),
			moves => {
			},
		},
		'rnbqkbnr/ppp3pp/4p3/3p1p2/3PP3/8/PPPN1PPP/R1BQKBNR w KQkq' => {
			eco => 'C03b',
			# TRANSLATORS: C03b: 1. e4 e6 2. d4 d5 3. Nd2 f5
			variation => N__('French: Tarrasch, Haberditz Variation'),
			moves => {
			},
		},
		'rnbqkbnr/p1p2ppp/1p2p3/3p4/3PP3/8/PPPN1PPP/R1BQKBNR w KQkq' => {
			eco => 'C03c',
			# TRANSLATORS: C03c: 1. e4 e6 2. d4 d5 3. Nd2 b6
			variation => N__('French: Tarrasch, 3... b6'),
			moves => {
			},
		},
		'rnbqkbnr/1pp2ppp/p3p3/3p4/3PP3/8/PPPN1PPP/R1BQKBNR w KQkq' => {
			eco => 'C03d',
			# TRANSLATORS: C03d: 1. e4 e6 2. d4 d5 3. Nd2 a6
			variation => N__('French: Tarrasch, 3... a6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/1pp2ppp/p3p3/3p4/3PP3/5N2/PPPN1PPP/R1BQKB1R b KQkq' => {
			eco => 'C03e',
			# TRANSLATORS: C03e: 1. e4 e6 2. d4 d5 3. Nd2 a6 4. Ngf3
			variation => N__('French: Tarrasch, 3... a6 4.Ngf3'),
			moves => {
			},
		},
		'rnbqk1nr/ppp1bppp/4p3/3p4/3PP3/8/PPPN1PPP/R1BQKBNR w KQkq' => {
			eco => 'C03f',
			# TRANSLATORS: C03f: 1. e4 e6 2. d4 d5 3. Nd2 Be7
			variation => N__('French: Tarrasch, 3... Be7'),
			moves => {
				'f1d3' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqk1nr/ppp1bppp/4p3/3p4/3PP3/3B4/PPPN1PPP/R1BQK1NR b KQkq' => {
			eco => 'C03g',
			# TRANSLATORS: C03g: 1. e4 e6 2. d4 d5 3. Nd2 Be7 4. Bd3
			variation => N__('French: Tarrasch, 3... Be7 4. Bd3'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqk1nr/pp2bppp/4p3/2pp4/3PP3/3B4/PPPN1PPP/R1BQK1NR w KQkq' => {
			eco => 'C03h',
			# TRANSLATORS: C03h: 1. e4 e6 2. d4 d5 3. Nd2 Be7 4. Bd3 c5
			variation => N__('French: Tarrasch, 3... Be7 4. Bd3 c5'),
			moves => {
				'd4c5' => 1,
			},
		},
		'rnbqk1nr/pp2bppp/4p3/2Pp4/4P3/3B4/PPPN1PPP/R1BQK1NR b KQkq' => {
			eco => 'C03h',
			# TRANSLATORS: C03h: 1. e4 e6 2. d4 d5 3. Nd2 Be7 4. Bd3 c5 5. dxc5
			variation => N__('French: Tarrasch, 3... Be7 4. Bd3 c5'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqk2r/pp2bppp/4pn2/2Pp4/4P3/3B4/PPPN1PPP/R1BQK1NR w KQkq' => {
			eco => 'C03i',
			# TRANSLATORS: C03i: 1. e4 e6 2. d4 d5 3. Nd2 Be7 4. Bd3 c5 5. dxc5 Nf6
			variation => N__('French: Tarrasch, 3... Be7 4. Bd3 c5 5.dxc5 Nf6'),
			moves => {
			},
		},
		'rnbqk1nr/ppp1bppp/4p3/3p4/3PP3/5N2/PPPN1PPP/R1BQKB1R b KQkq' => {
			eco => 'C03j',
			# TRANSLATORS: C03j: 1. e4 e6 2. d4 d5 3. Nd2 Be7 4. Ngf3
			variation => N__('French: Tarrasch, 3... Be7 4.Ngf3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqk2r/ppp1bppp/4pn2/3p4/3PP3/5N2/PPPN1PPP/R1BQKB1R w KQkq' => {
			eco => 'C03j',
			# TRANSLATORS: C03j: 1. e4 e6 2. d4 d5 3. Nd2 Be7 4. Ngf3 Nf6
			variation => N__('French: Tarrasch, 3... Be7 4.Ngf3 Nf6'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rnbqk2r/ppp1bppp/4pn2/3p4/3PP3/3B1N2/PPPN1PPP/R1BQK2R b KQkq' => {
			eco => 'C03k',
			# TRANSLATORS: C03k: 1. e4 e6 2. d4 d5 3. Nd2 Be7 4. Ngf3 Nf6 5. Bd3
			variation => N__('French: Tarrasch, 3... Be7 4.Ngf3 Nf6 5. Bd3'),
			moves => {
			},
		},
		'r1bqkbnr/ppp2ppp/2n1p3/3p4/3PP3/8/PPPN1PPP/R1BQKBNR w KQkq' => {
			eco => 'C03l',
			# TRANSLATORS: C03l: 1. e4 e6 2. d4 d5 3. Nd2 Nc6
			variation => N__('French: Tarrasch, Guimard Variation'),
			moves => {
				'c2c3' => 1,
				'g1f3' => 1,
			},
		},
		'r1bqkbnr/ppp2ppp/2n1p3/3p4/3PP3/2P5/PP1N1PPP/R1BQKBNR b KQkq' => {
			eco => 'C03m',
			# TRANSLATORS: C03m: 1. e4 e6 2. d4 d5 3. Nd2 Nc6 4. c3
			variation => N__('French: Tarrasch, Guimard, 4. c3'),
			moves => {
				'e6e5' => 1,
			},
		},
		'r1bqkbnr/ppp2ppp/2n5/3pp3/3PP3/2P5/PP1N1PPP/R1BQKBNR w KQkq' => {
			eco => 'C03n',
			# TRANSLATORS: C03n: 1. e4 e6 2. d4 d5 3. Nd2 Nc6 4. c3 e5
			variation => N__('French: Tarrasch, Guimard, 4. c3 e5'),
			moves => {
			},
		},
		'r1bqkbnr/ppp2ppp/2n1p3/3p4/3PP3/5N2/PPPN1PPP/R1BQKB1R b KQkq' => {
			eco => 'C03o',
			# TRANSLATORS: C03o: 1. e4 e6 2. d4 d5 3. Nd2 Nc6 4. Ngf3
			variation => N__('French: Tarrasch, Guimard, 4.Ngf3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2n1pn2/3p4/3PP3/5N2/PPPN1PPP/R1BQKB1R w KQkq' => {
			eco => 'C04a',
			# TRANSLATORS: C04a: 1. e4 e6 2. d4 d5 3. Nd2 Nc6 4. Ngf3 Nf6
			variation => N__('French: Tarrasch, Guimard, 4.Ngf3 Nf6'),
			moves => {
				'e4e5' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2n1pn2/3pP3/3P4/5N2/PPPN1PPP/R1BQKB1R b KQkq' => {
			eco => 'C04b',
			# TRANSLATORS: C04b: 1. e4 e6 2. d4 d5 3. Nd2 Nc6 4. Ngf3 Nf6 5. e5
			variation => N__('French: Tarrasch, Guimard, 4.Ngf3 Nf6 5. e5'),
			moves => {
				'f6d7' => 1,
			},
		},
		'r1bqkb1r/pppn1ppp/2n1p3/3pP3/3P4/5N2/PPPN1PPP/R1BQKB1R w KQkq' => {
			eco => 'C04c',
			# TRANSLATORS: C04c: 1. e4 e6 2. d4 d5 3. Nd2 Nc6 4. Ngf3 Nf6 5. e5 Nd7
			variation => N__('French: Tarrasch, Guimard, Main Line'),
			moves => {
				'c2c3' => 1,
				'd2b3' => 1,
				'f1b5' => 1,
				'f1e2' => 1,
			},
		},
		'r1bqkb1r/pppn1ppp/2n1p3/3pP3/3P4/2P2N2/PP1N1PPP/R1BQKB1R b KQkq' => {
			eco => 'C04d',
			# TRANSLATORS: C04d: 1. e4 e6 2. d4 d5 3. Nd2 Nc6 4. Ngf3 Nf6 5. e5 Nd7 6. c3
			variation => N__('French: Tarrasch, Guimard, Main Line, 6. c3'),
			moves => {
			},
		},
		'r1bqkb1r/pppn1ppp/2n1p3/1B1pP3/3P4/5N2/PPPN1PPP/R1BQK2R b KQkq' => {
			eco => 'C04e',
			# TRANSLATORS: C04e: 1. e4 e6 2. d4 d5 3. Nd2 Nc6 4. Ngf3 Nf6 5. e5 Nd7 6. Bb5
			variation => N__('French: Tarrasch, Guimard, Main Line, 6. Bb5'),
			moves => {
			},
		},
		'r1bqkb1r/pppn1ppp/2n1p3/3pP3/3P4/5N2/PPPNBPPP/R1BQK2R b KQkq' => {
			eco => 'C04f',
			# TRANSLATORS: C04f: 1. e4 e6 2. d4 d5 3. Nd2 Nc6 4. Ngf3 Nf6 5. e5 Nd7 6. Be2
			variation => N__('French: Tarrasch, Guimard, Main Line, 6. Be2'),
			moves => {
				'f7f6' => 1,
			},
		},
		'r1bqkb1r/pppn2pp/2n1pp2/3pP3/3P4/5N2/PPPNBPPP/R1BQK2R w KQkq' => {
			eco => 'C04g',
			# TRANSLATORS: C04g: 1. e4 e6 2. d4 d5 3. Nd2 Nc6 4. Ngf3 Nf6 5. e5 Nd7 6. Be2 f6
			variation => N__('French: Tarrasch, Guimard, Main Line, 6. Be2 f6'),
			moves => {
			},
		},
		'r1bqkb1r/pppn1ppp/2n1p3/3pP3/3P4/1N3N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'C04h',
			# TRANSLATORS: C04h: 1. e4 e6 2. d4 d5 3. Nd2 Nc6 4. Ngf3 Nf6 5. e5 Nd7 6. Nb3
			variation => N__('French: Tarrasch, Guimard, Main Line, 6. Nb3'),
			moves => {
				'a7a5' => 1,
				'f8e7' => 1,
			},
		},
		'r1bqkb1r/1ppn1ppp/2n1p3/p2pP3/3P4/1N3N2/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'C04i',
			# TRANSLATORS: C04i: 1. e4 e6 2. d4 d5 3. Nd2 Nc6 4. Ngf3 Nf6 5. e5 Nd7 6. Nb3 a5
			variation => N__('French: Tarrasch, Guimard, Main Line, 6. Nb3 a5'),
			moves => {
			},
		},
		'r1bqk2r/pppnbppp/2n1p3/3pP3/3P4/1N3N2/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'C04j',
			# TRANSLATORS: C04j: 1. e4 e6 2. d4 d5 3. Nd2 Nc6 4. Ngf3 Nf6 5. e5 Nd7 6. Nb3 Be7
			variation => N__('French: Tarrasch, Guimard, Main Line, 6. Nb3 Be7'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p4/3PP3/8/PPPN1PPP/R1BQKBNR w KQkq' => {
			eco => 'C05a',
			# TRANSLATORS: C05a: 1. e4 e6 2. d4 d5 3. Nd2 Nf6
			variation => N__('French: Tarrasch, Closed'),
			moves => {
				'e4e5' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3pP3/3P4/8/PPPN1PPP/R1BQKBNR b KQkq' => {
			eco => 'C05b',
			# TRANSLATORS: C05b: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5
			variation => N__('French: Tarrasch, Closed, 4. e5'),
			moves => {
				'f6d7' => 1,
				'f6e4' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4p3/3pP3/3Pn3/8/PPPN1PPP/R1BQKBNR w KQkq' => {
			eco => 'C05c',
			# TRANSLATORS: C05c: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Ne4
			variation => N__('French: Tarrasch, Closed, 4... Ne4'),
			moves => {
				'd2e4' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4p3/3pP3/3PN3/8/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'C05c',
			# TRANSLATORS: C05c: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Ne4 5. Nxe4
			variation => N__('French: Tarrasch, Closed, 4... Ne4 5.Nxe4'),
			moves => {
			},
		},
		'rnbqkb1r/pppn1ppp/4p3/3pP3/3P4/8/PPPN1PPP/R1BQKBNR w KQkq' => {
			eco => 'C05d',
			# TRANSLATORS: C05d: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7
			variation => N__('French: Tarrasch, Closed, 4...Nfd7'),
			moves => {
				'c2c3' => 1,
				'f1d3' => 1,
				'f2f4' => 1,
			},
		},
		'rnbqkb1r/pppn1ppp/4p3/3pP3/3P1P2/8/PPPN2PP/R1BQKBNR b KQkq' => {
			eco => 'C05e',
			# TRANSLATORS: C05e: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. f4
			variation => N__('French: Tarrasch, Closed, 5. f4'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqkb1r/pp1n1ppp/4p3/2ppP3/3P1P2/8/PPPN2PP/R1BQKBNR w KQkq' => {
			eco => 'C05e',
			# TRANSLATORS: C05e: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. f4 c5
			variation => N__('French: Tarrasch, Closed, 5. f4'),
			moves => {
				'c2c3' => 1,
			},
		},
		'rnbqkb1r/pp1n1ppp/4p3/2ppP3/3P1P2/2P5/PP1N2PP/R1BQKBNR b KQkq' => {
			eco => 'C05e',
			# TRANSLATORS: C05e: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. f4 c5 6. c3
			variation => N__('French: Tarrasch, Closed, 5. f4'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/2n1p3/2ppP3/3P1P2/2P5/PP1N2PP/R1BQKBNR w KQkq' => {
			eco => 'C05f',
			# TRANSLATORS: C05f: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. f4 c5 6. c3 Nc6
			variation => N__('French: Tarrasch, Closed, 5. f4 c5 6. c3 Nc6'),
			moves => {
				'd2f3' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/2n1p3/2ppP3/3P1P2/2P2N2/PP4PP/R1BQKBNR b KQkq' => {
			eco => 'C05g',
			# TRANSLATORS: C05g: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. f4 c5 6. c3 Nc6 7. Ndf3
			variation => N__('French: Tarrasch, Closed, 5. f4 c5 6. c3 Nc6 7.Ndf3'),
			moves => {
				'c5d4' => 1,
				'd8b6' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/2n1p3/3pP3/3p1P2/2P2N2/PP4PP/R1BQKBNR w KQkq' => {
			eco => 'C05h',
			# TRANSLATORS: C05h: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. f4 c5 6. c3 Nc6 7. Ndf3 cxd4
			variation => N__('French: Tarrasch, Closed, 5. f4 c5 6. c3 Nc6 7.Ndf3 cxd4'),
			moves => {
			},
		},
		'r1b1kb1r/pp1n1ppp/1qn1p3/2ppP3/3P1P2/2P2N2/PP4PP/R1BQKBNR w KQkq' => {
			eco => 'C05i',
			# TRANSLATORS: C05i: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. f4 c5 6. c3 Nc6 7. Ndf3 Qb6
			variation => N__('French: Tarrasch, Closed, 5. f4 c5 6. c3 Nc6 7.Ndf3 Qb6'),
			moves => {
				'g1e2' => 1,
				'g2g3' => 1,
				'h2h4' => 1,
			},
		},
		'r1b1kb1r/pp1n1ppp/1qn1p3/2ppP3/3P1P1P/2P2N2/PP4P1/R1BQKBNR b KQkq' => {
			eco => 'C05j',
			# TRANSLATORS: C05j: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. f4 c5 6. c3 Nc6 7. Ndf3 Qb6 8. h4
			variation => N__('French: Tarrasch, Closed, 5. f4 c5 6. c3 Nc6 7.Ndf3 Qb6 8. h4'),
			moves => {
				'c5d4' => 1,
			},
		},
		'r1b1kb1r/pp1n1ppp/1qn1p3/3pP3/3p1P1P/2P2N2/PP4P1/R1BQKBNR w KQkq' => {
			eco => 'C05j',
			# TRANSLATORS: C05j: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. f4 c5 6. c3 Nc6 7. Ndf3 Qb6 8. h4 cxd4
			variation => N__('French: Tarrasch, Closed, 5. f4 c5 6. c3 Nc6 7.Ndf3 Qb6 8. h4'),
			moves => {
				'c3d4' => 1,
			},
		},
		'r1b1kb1r/pp1n1ppp/1qn1p3/3pP3/3P1P1P/5N2/PP4P1/R1BQKBNR b KQkq' => {
			eco => 'C05j',
			# TRANSLATORS: C05j: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. f4 c5 6. c3 Nc6 7. Ndf3 Qb6 8. h4 cxd4 9. cxd4
			variation => N__('French: Tarrasch, Closed, 5. f4 c5 6. c3 Nc6 7.Ndf3 Qb6 8. h4'),
			moves => {
			},
		},
		'r1b1kb1r/pp1n1ppp/1qn1p3/2ppP3/3P1P2/2P2N2/PP2N1PP/R1BQKB1R b KQkq' => {
			eco => 'C05k',
			# TRANSLATORS: C05k: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. f4 c5 6. c3 Nc6 7. Ndf3 Qb6 8. Ne2
			variation => N__('French: Tarrasch, Closed, 5. f4 c5 6. c3 Nc6 7.Ndf3 Qb6 8. Ne2'),
			moves => {
				'c5d4' => 1,
			},
		},
		'r1b1kb1r/pp1n1ppp/1qn1p3/3pP3/3p1P2/2P2N2/PP2N1PP/R1BQKB1R w KQkq' => {
			eco => 'C05k',
			# TRANSLATORS: C05k: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. f4 c5 6. c3 Nc6 7. Ndf3 Qb6 8. Ne2 cxd4
			variation => N__('French: Tarrasch, Closed, 5. f4 c5 6. c3 Nc6 7.Ndf3 Qb6 8. Ne2'),
			moves => {
				'c3d4' => 1,
			},
		},
		'r1b1kb1r/pp1n1ppp/1qn1p3/3pP3/3P1P2/5N2/PP2N1PP/R1BQKB1R b KQkq' => {
			eco => 'C05k',
			# TRANSLATORS: C05k: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. f4 c5 6. c3 Nc6 7. Ndf3 Qb6 8. Ne2 cxd4 9. cxd4
			variation => N__('French: Tarrasch, Closed, 5. f4 c5 6. c3 Nc6 7.Ndf3 Qb6 8. Ne2'),
			moves => {
			},
		},
		'r1b1kb1r/pp1n1ppp/1qn1p3/2ppP3/3P1P2/2P2NP1/PP5P/R1BQKBNR b KQkq' => {
			eco => 'C05l',
			# TRANSLATORS: C05l: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. f4 c5 6. c3 Nc6 7. Ndf3 Qb6 8. g3
			variation => N__('French: Tarrasch, Closed, 5. f4 c5 6. c3 Nc6 7.Ndf3 Qb6 8. g3'),
			moves => {
				'c5d4' => 1,
			},
		},
		'r1b1kb1r/pp1n1ppp/1qn1p3/3pP3/3p1P2/2P2NP1/PP5P/R1BQKBNR w KQkq' => {
			eco => 'C05l',
			# TRANSLATORS: C05l: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. f4 c5 6. c3 Nc6 7. Ndf3 Qb6 8. g3 cxd4
			variation => N__('French: Tarrasch, Closed, 5. f4 c5 6. c3 Nc6 7.Ndf3 Qb6 8. g3'),
			moves => {
				'c3d4' => 1,
			},
		},
		'r1b1kb1r/pp1n1ppp/1qn1p3/3pP3/3P1P2/5NP1/PP5P/R1BQKBNR b KQkq' => {
			eco => 'C05l',
			# TRANSLATORS: C05l: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. f4 c5 6. c3 Nc6 7. Ndf3 Qb6 8. g3 cxd4 9. cxd4
			variation => N__('French: Tarrasch, Closed, 5. f4 c5 6. c3 Nc6 7.Ndf3 Qb6 8. g3'),
			moves => {
			},
		},
		'rnbqkb1r/pppn1ppp/4p3/3pP3/3P4/2P5/PP1N1PPP/R1BQKBNR b KQkq' => {
			eco => 'C05m',
			# TRANSLATORS: C05m: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. c3
			variation => N__('French: Tarrasch, Closed, 5. c3'),
			moves => {
			},
		},
		'rnbqkb1r/pppn1ppp/4p3/3pP3/3P4/3B4/PPPN1PPP/R1BQK1NR b KQkq' => {
			eco => 'C05n',
			# TRANSLATORS: C05n: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3
			variation => N__('French: Tarrasch, 5. Bd3'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqkb1r/pp1n1ppp/4p3/2ppP3/3P4/3B4/PPPN1PPP/R1BQK1NR w KQkq' => {
			eco => 'C05n',
			# TRANSLATORS: C05n: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5
			variation => N__('French: Tarrasch, 5. Bd3'),
			moves => {
				'c2c3' => 1,
			},
		},
		'rnbqkb1r/pp1n1ppp/4p3/2ppP3/3P4/2PB4/PP1N1PPP/R1BQK1NR b KQkq' => {
			eco => 'C05n',
			# TRANSLATORS: C05n: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3
			variation => N__('French: Tarrasch, 5. Bd3'),
			moves => {
				'b7b6' => 1,
				'b8c6' => 1,
			},
		},
		'rnbqkb1r/p2n1ppp/1p2p3/2ppP3/3P4/2PB4/PP1N1PPP/R1BQK1NR w KQkq' => {
			eco => 'C05o',
			# TRANSLATORS: C05o: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 b6
			variation => N__('French: Tarrasch, Botvinnik'),
			moves => {
			},
		},
		'r1bqkb1r/pp1n1ppp/2n1p3/2ppP3/3P4/2PB4/PP1N1PPP/R1BQK1NR w KQkq' => {
			eco => 'C05p',
			# TRANSLATORS: C05p: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 Nc6
			variation => N__('French: Tarrasch, Closed, 6... Nc6'),
			moves => {
				'd2f3' => 1,
				'g1e2' => 1,
				'g1f3' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/2n1p3/2ppP3/3P4/2PB1N2/PP3PPP/R1BQK1NR b KQkq' => {
			eco => 'C05p',
			# TRANSLATORS: C05p: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 Nc6 7. Ndf3
			variation => N__('French: Tarrasch, Closed, 7.Ndf3'),
			moves => {
				'd8a5' => 1,
			},
		},
		'r1b1kb1r/pp1n1ppp/2n1p3/q1ppP3/3P4/2PB1N2/PP3PPP/R1BQK1NR w KQkq' => {
			eco => 'C05q',
			# TRANSLATORS: C05q: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 Nc6 7. Ndf3 Qa5
			variation => N__('French: Tarrasch, Closed, 7.Ndf3 Qa5'),
			moves => {
			},
		},
		'r1bqkb1r/pp1n1ppp/2n1p3/2ppP3/3P4/2PB1N2/PP1N1PPP/R1BQK2R b KQkq' => {
			eco => 'C05r',
			# TRANSLATORS: C05r: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 Nc6 7. Ngf3
			variation => N__('French: Tarrasch, Closed, 7.Ngf3'),
			moves => {
				'd8b6' => 1,
				'f8e7' => 1,
			},
		},
		'r1b1kb1r/pp1n1ppp/1qn1p3/2ppP3/3P4/2PB1N2/PP1N1PPP/R1BQK2R w KQkq' => {
			eco => 'C05r',
			# TRANSLATORS: C05r: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 Nc6 7. Ngf3 Qb6
			variation => N__('French: Tarrasch, Closed, 7.Ngf3'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqk2r/pp1nbppp/2n1p3/2ppP3/3P4/2PB1N2/PP1N1PPP/R1BQK2R w KQkq' => {
			eco => 'C05s',
			# TRANSLATORS: C05s: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 Nc6 7. Ngf3 Be7
			variation => N__('French: Tarrasch, Closed, 7.Ngf3 Be7'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqk2r/pp1nbppp/2n1p3/2ppP3/3P4/2PB1N2/PP1N1PPP/R1BQ1RK1 b kq' => {
			eco => 'C05s',
			# TRANSLATORS: C05s: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 Nc6 7. Ngf3 Be7 8. O-O
			variation => N__('French: Tarrasch, Closed, 7.Ngf3 Be7'),
			moves => {
				'g7g5' => 1,
			},
		},
		'r1bqk2r/pp1nbp1p/2n1p3/2ppP1p1/3P4/2PB1N2/PP1N1PPP/R1BQ1RK1 w kq' => {
			eco => 'C05t',
			# TRANSLATORS: C05t: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 Nc6 7. Ngf3 Be7 8. O-O g5
			variation => N__('French: Tarrasch, Closed, 7.Ngf3 Be7 8.O-O g5'),
			moves => {
			},
		},
		'r1b1kb1r/pp1n1ppp/1qn1p3/2ppP3/3P4/2PB1N2/PP1N1PPP/R1BQ1RK1 b kq' => {
			eco => 'C05u',
			# TRANSLATORS: C05u: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 Nc6 7. Ngf3 Qb6 8. O-O
			variation => N__('French: Tarrasch, Closed, Nunn-Korchnoi Gambit'),
			moves => {
			},
		},
		'r1bqkb1r/pp1n1ppp/2n1p3/2ppP3/3P4/2PB4/PP1NNPPP/R1BQK2R b KQkq' => {
			eco => 'C05v',
			# TRANSLATORS: C05v: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 Nc6 7. Ne2
			variation => N__('French: Tarrasch, Closed, 7. Ne2'),
			moves => {
				'a7a5' => 1,
				'c5d4' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/2n1p3/3pP3/3p4/2PB4/PP1NNPPP/R1BQK2R w KQkq' => {
			eco => 'C05v',
			# TRANSLATORS: C05v: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 Nc6 7. Ne2 cxd4
			variation => N__('French: Tarrasch, Closed, 7. Ne2'),
			moves => {
				'c3d4' => 1,
			},
		},
		'r1bqkb1r/1p1n1ppp/2n1p3/p1ppP3/3P4/2PB4/PP1NNPPP/R1BQK2R w KQkq' => {
			eco => 'C05w',
			# TRANSLATORS: C05w: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 Nc6 7. Ne2 a5
			variation => N__('French: Tarrasch, Closed, 7. Ne2 a5'),
			moves => {
			},
		},
		'r1bqkb1r/pp1n1ppp/2n1p3/3pP3/3P4/3B4/PP1NNPPP/R1BQK2R b KQkq' => {
			eco => 'C06a',
			# TRANSLATORS: C06a: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 Nc6 7. Ne2 cxd4 8. cxd4
			variation => N__('French: Tarrasch, Closed, Main Line'),
			moves => {
				'd7b6' => 1,
				'd8b6' => 1,
				'f7f6' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/1nn1p3/3pP3/3P4/3B4/PP1NNPPP/R1BQK2R w KQkq' => {
			eco => 'C06b',
			# TRANSLATORS: C06b: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 Nc6 7. Ne2 cxd4 8. cxd4 Nb6
			variation => N__('French: Tarrasch, Closed, Leningrad'),
			moves => {
				'd2f3' => 1,
				'e1g1' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/1nn1p3/3pP3/3P4/3B1N2/PP2NPPP/R1BQK2R b KQkq' => {
			eco => 'C06c',
			# TRANSLATORS: C06c: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 Nc6 7. Ne2 cxd4 8. cxd4 Nb6 9. Nf3
			variation => N__('French: Tarrasch, Closed, Leningrad, 9. Nf3'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/1nn1p3/3pP3/3P4/3B4/PP1NNPPP/R1BQ1RK1 b kq' => {
			eco => 'C06d',
			# TRANSLATORS: C06d: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 Nc6 7. Ne2 cxd4 8. cxd4 Nb6 9. O-O
			variation => N__('French: Tarrasch, Closed, Leningrad, 9.O-O'),
			moves => {
				'a7a5' => 1,
				'c8d7' => 1,
			},
		},
		'r1bqkb1r/1p3ppp/1nn1p3/p2pP3/3P4/3B4/PP1NNPPP/R1BQ1RK1 w kq' => {
			eco => 'C06e',
			# TRANSLATORS: C06e: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 Nc6 7. Ne2 cxd4 8. cxd4 Nb6 9. O-O a5
			variation => N__('French: Tarrasch, Closed, Leningrad, 9.O-O a5'),
			moves => {
			},
		},
		'r2qkb1r/pp1b1ppp/1nn1p3/3pP3/3P4/3B4/PP1NNPPP/R1BQ1RK1 w kq' => {
			eco => 'C06f',
			# TRANSLATORS: C06f: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 Nc6 7. Ne2 cxd4 8. cxd4 Nb6 9. O-O Bd7
			variation => N__('French: Tarrasch, Closed, Leningrad, 9.O-O Bd7'),
			moves => {
			},
		},
		'r1b1kb1r/pp1n1ppp/1qn1p3/3pP3/3P4/3B4/PP1NNPPP/R1BQK2R w KQkq' => {
			eco => 'C06g',
			# TRANSLATORS: C06g: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 Nc6 7. Ne2 cxd4 8. cxd4 Qb6
			variation => N__('French: Tarrasch, Closed, 8... Qb6'),
			moves => {
				'd2f3' => 1,
				'e1g1' => 1,
			},
		},
		'r1b1kb1r/pp1n1ppp/1qn1p3/3pP3/3P4/3B4/PP1NNPPP/R1BQ1RK1 b kq' => {
			eco => 'C06h',
			# TRANSLATORS: C06h: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 Nc6 7. Ne2 cxd4 8. cxd4 Qb6 9. O-O
			variation => N__('French: Tarrasch, Closed, 8... Qb6 9.O-O'),
			moves => {
			},
		},
		'r1b1kb1r/pp1n1ppp/1qn1p3/3pP3/3P4/3B1N2/PP2NPPP/R1BQK2R b KQkq' => {
			eco => 'C06i',
			# TRANSLATORS: C06i: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 Nc6 7. Ne2 cxd4 8. cxd4 Qb6 9. Nf3
			variation => N__('French: Tarrasch, Closed, 8... Qb6 9. Nf3'),
			moves => {
				'f7f6' => 1,
			},
		},
		'r1b1kb1r/pp1n2pp/1qn1pp2/3pP3/3P4/3B1N2/PP2NPPP/R1BQK2R w KQkq' => {
			eco => 'C06j',
			# TRANSLATORS: C06j: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 Nc6 7. Ne2 cxd4 8. cxd4 Qb6 9. Nf3 f6
			variation => N__('French: Tarrasch, Closed, 8... Qb6 9. Nf3 f6'),
			moves => {
			},
		},
		'r1bqkb1r/pp1n2pp/2n1pp2/3pP3/3P4/3B4/PP1NNPPP/R1BQK2R w KQkq' => {
			eco => 'C06k',
			# TRANSLATORS: C06k: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 Nc6 7. Ne2 cxd4 8. cxd4 f6
			variation => N__('French: Tarrasch, Closed, 8... f6'),
			moves => {
				'e2f4' => 1,
				'e5f6' => 1,
			},
		},
		'r1bqkb1r/pp1n2pp/2n1pp2/3pP3/3P1N2/3B4/PP1N1PPP/R1BQK2R b KQkq' => {
			eco => 'C06l',
			# TRANSLATORS: C06l: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 Nc6 7. Ne2 cxd4 8. cxd4 f6 9. Nf4
			variation => N__('French: Tarrasch, Closed, 8... f6 9. Nf4'),
			moves => {
			},
		},
		'r1bqkb1r/pp1n2pp/2n1pP2/3p4/3P4/3B4/PP1NNPPP/R1BQK2R b KQkq' => {
			eco => 'C06m',
			# TRANSLATORS: C06m: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 Nc6 7. Ne2 cxd4 8. cxd4 f6 9. exf6
			variation => N__('French: Tarrasch, Closed, 8... f6 9.exf6'),
			moves => {
				'd7f6' => 1,
			},
		},
		'r1bqkb1r/pp4pp/2n1pn2/3p4/3P4/3B4/PP1NNPPP/R1BQK2R w KQkq' => {
			eco => 'C06n',
			# TRANSLATORS: C06n: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 Nc6 7. Ne2 cxd4 8. cxd4 f6 9. exf6 Nxf6
			variation => N__('French: Tarrasch, Closed, 8... f6 9.exf6 Nxf6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqkb1r/pp4pp/2n1pn2/3p4/3P4/3B4/PP1NNPPP/R1BQ1RK1 b kq' => {
			eco => 'C06n',
			# TRANSLATORS: C06n: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 Nc6 7. Ne2 cxd4 8. cxd4 f6 9. exf6 Nxf6 10. O-O
			variation => N__('French: Tarrasch, Closed, 8... f6 9.exf6 Nxf6'),
			moves => {
				'f8d6' => 1,
			},
		},
		'r1bqk2r/pp4pp/2nbpn2/3p4/3P4/3B4/PP1NNPPP/R1BQ1RK1 w kq' => {
			eco => 'C06n',
			# TRANSLATORS: C06n: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 Nc6 7. Ne2 cxd4 8. cxd4 f6 9. exf6 Nxf6 10. O-O Bd6
			variation => N__('French: Tarrasch, Closed, 8... f6 9.exf6 Nxf6'),
			moves => {
				'd2f3' => 1,
			},
		},
		'r1bqk2r/pp4pp/2nbpn2/3p4/3P4/3B1N2/PP2NPPP/R1BQ1RK1 b kq' => {
			eco => 'C06o',
			# TRANSLATORS: C06o: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 Nc6 7. Ne2 cxd4 8. cxd4 f6 9. exf6 Nxf6 10. O-O Bd6 11. Nf3
			variation => N__('French: Tarrasch, Closed, 8... f6 9.exf6 Nxf6 10.O-O Bd6 11. Nf3'),
			moves => {
				'd8b6' => 1,
				'd8c7' => 1,
				'e8g8' => 1,
			},
		},
		'r1b1k2r/pp4pp/1qnbpn2/3p4/3P4/3B1N2/PP2NPPP/R1BQ1RK1 w kq' => {
			eco => 'C06o',
			# TRANSLATORS: C06o: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 Nc6 7. Ne2 cxd4 8. cxd4 f6 9. exf6 Nxf6 10. O-O Bd6 11. Nf3 Qb6
			variation => N__('French: Tarrasch, Closed, 8... f6 9.exf6, 11... Qb6'),
			moves => {
				'e2c3' => 1,
			},
		},
		'r1b1k2r/pp4pp/1qnbpn2/3p4/3P4/2NB1N2/PP3PPP/R1BQ1RK1 b kq' => {
			eco => 'C06p',
			# TRANSLATORS: C06p: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 Nc6 7. Ne2 cxd4 8. cxd4 f6 9. exf6 Nxf6 10. O-O Bd6 11. Nf3 Qb6 12. Nc3
			variation => N__('French: Tarrasch, Closed, 8... f6 9.exf6, 11... Qb6 12. Nc3'),
			moves => {
			},
		},
		'r1b1k2r/ppq3pp/2nbpn2/3p4/3P4/3B1N2/PP2NPPP/R1BQ1RK1 w kq' => {
			eco => 'C06q',
			# TRANSLATORS: C06q: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 Nc6 7. Ne2 cxd4 8. cxd4 f6 9. exf6 Nxf6 10. O-O Bd6 11. Nf3 Qc7
			variation => N__('French: Tarrasch, Closed, 8... f6 9.exf6, 11... Qc7'),
			moves => {
				'c1g5' => 1,
			},
		},
		'r1b1k2r/ppq3pp/2nbpn2/3p2B1/3P4/3B1N2/PP2NPPP/R2Q1RK1 b kq' => {
			eco => 'C06r',
			# TRANSLATORS: C06r: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 Nc6 7. Ne2 cxd4 8. cxd4 f6 9. exf6 Nxf6 10. O-O Bd6 11. Nf3 Qc7 12. Bg5
			variation => N__('French: Tarrasch, Closed, 8... f6 9.exf6, 11... Qc7 12. Bg5'),
			moves => {
			},
		},
		'r1bq1rk1/pp4pp/2nbpn2/3p4/3P4/3B1N2/PP2NPPP/R1BQ1RK1 w -' => {
			eco => 'C06s',
			# TRANSLATORS: C06s: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 Nc6 7. Ne2 cxd4 8. cxd4 f6 9. exf6 Nxf6 10. O-O Bd6 11. Nf3 O-O
			variation => N__('French: Tarrasch, Closed, 8... f6 9.exf6, 11...O-O'),
			moves => {
				'c1f4' => 1,
			},
		},
		'r1bq1rk1/pp4pp/2nbpn2/3p4/3P1B2/3B1N2/PP2NPPP/R2Q1RK1 b -' => {
			eco => 'C06t',
			# TRANSLATORS: C06t: 1. e4 e6 2. d4 d5 3. Nd2 Nf6 4. e5 Nfd7 5. Bd3 c5 6. c3 Nc6 7. Ne2 cxd4 8. cxd4 f6 9. exf6 Nxf6 10. O-O Bd6 11. Nf3 O-O 12. Bf4
			variation => N__('French: Tarrasch, Closed, 8... f6 9.exf6, 11...O-O 12. Bf4'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/4p3/2pp4/3PP3/8/PPPN1PPP/R1BQKBNR w KQkq' => {
			eco => 'C07a',
			# TRANSLATORS: C07a: 1. e4 e6 2. d4 d5 3. Nd2 c5
			variation => N__('French: Tarrasch, Open'),
			moves => {
				'c2c3' => 1,
				'd4c5' => 1,
				'e4d5' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/4p3/2pp4/3PP3/2P5/PP1N1PPP/R1BQKBNR b KQkq' => {
			eco => 'C07b',
			# TRANSLATORS: C07b: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. c3
			variation => N__('French: Tarrasch, Open, 4. c3'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/4p3/2Pp4/4P3/8/PPPN1PPP/R1BQKBNR b KQkq' => {
			eco => 'C07c',
			# TRANSLATORS: C07c: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. dxc5
			variation => N__('French: Tarrasch, Open, 4.dxc5'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/4p3/2pp4/3PP3/5N2/PPPN1PPP/R1BQKB1R b KQkq' => {
			eco => 'C07d',
			# TRANSLATORS: C07d: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. Ngf3
			variation => N__('French: Tarrasch, Open, 4.Ngf3'),
			moves => {
				'a7a6' => 1,
				'b8c6' => 1,
				'c5d4' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/1p3ppp/p3p3/2pp4/3PP3/5N2/PPPN1PPP/R1BQKB1R w KQkq' => {
			eco => 'C07e',
			# TRANSLATORS: C07e: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. Ngf3 a6
			variation => N__('French: Tarrasch, Open, 4.Ngf3 a6'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2pp4/3PP3/5N2/PPPN1PPP/R1BQKB1R w KQkq' => {
			eco => 'C07f',
			# TRANSLATORS: C07f: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. Ngf3 Nf6
			variation => N__('French: Tarrasch, Open, 4.Ngf3 Nf6'),
			moves => {
			},
		},
		'r1bqkbnr/pp3ppp/2n1p3/2pp4/3PP3/5N2/PPPN1PPP/R1BQKB1R w KQkq' => {
			eco => 'C07g',
			# TRANSLATORS: C07g: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. Ngf3 Nc6
			variation => N__('French: Tarrasch, Open, 4.Ngf3 Nc6'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/4p3/3p4/3pP3/5N2/PPPN1PPP/R1BQKB1R w KQkq' => {
			eco => 'C07h',
			# TRANSLATORS: C07h: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. Ngf3 cxd4
			variation => N__('French: Tarrasch, Open, 4.Ngf3 cxd4'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/4p3/2pP4/3P4/8/PPPN1PPP/R1BQKBNR b KQkq' => {
			eco => 'C07i',
			# TRANSLATORS: C07i: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5
			variation => N__('French: Tarrasch, Open, 4.exd5'),
			moves => {
				'd8d5' => 1,
				'e6d5' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2pP4/3P4/8/PPPN1PPP/R1BQKBNR w KQkq' => {
			eco => 'C07i',
			# TRANSLATORS: C07i: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 Nf6
			variation => N__('French: Tarrasch, Shaposhnikov Gambit'),
			moves => {
			},
		},
		'rnb1kbnr/pp3ppp/4p3/2pq4/3P4/8/PPPN1PPP/R1BQKBNR w KQkq' => {
			eco => 'C07j',
			# TRANSLATORS: C07j: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 Qxd5
			variation => N__('French: Tarrasch, Open, 4.exd5 Qxd5'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnb1kbnr/pp3ppp/4p3/2pq4/3P4/5N2/PPPN1PPP/R1BQKB1R b KQkq' => {
			eco => 'C07k',
			# TRANSLATORS: C07k: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 Qxd5 5. Ngf3
			variation => N__('French: Tarrasch, Open, 4.exd5 Qxd5 5.Ngf3'),
			moves => {
				'c5d4' => 1,
			},
		},
		'rnb1kbnr/pp3ppp/4p3/3q4/3p4/5N2/PPPN1PPP/R1BQKB1R w KQkq' => {
			eco => 'C07l',
			# TRANSLATORS: C07l: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 Qxd5 5. Ngf3 cxd4
			variation => N__('French: Tarrasch, Open, 4.exd5 Qxd5 5.Ngf3 cxd4'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnb1kbnr/pp3ppp/4p3/3q4/2Bp4/5N2/PPPN1PPP/R1BQK2R b KQkq' => {
			eco => 'C07m',
			# TRANSLATORS: C07m: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 Qxd5 5. Ngf3 cxd4 6. Bc4
			variation => N__('French: Tarrasch, Open, 4.exd5 Qxd5 5.Ngf3 cxd4 6. Bc4'),
			moves => {
				'd5d6' => 1,
				'd5d8' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/4p3/8/2Bp4/5N2/PPPN1PPP/R1BQK2R w KQkq' => {
			eco => 'C07n',
			# TRANSLATORS: C07n: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 Qxd5 5. Ngf3 cxd4 6. Bc4 Qd8
			variation => N__('French: Tarrasch, Open, Eliskases Variation'),
			moves => {
			},
		},
		'rnb1kbnr/pp3ppp/3qp3/8/2Bp4/5N2/PPPN1PPP/R1BQK2R w KQkq' => {
			eco => 'C07o',
			# TRANSLATORS: C07o: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 Qxd5 5. Ngf3 cxd4 6. Bc4 Qd6
			variation => N__('French: Tarrasch, Open, 4.exd5 Qxd5 5.Ngf3 cxd4 6. Bc4 Qd6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnb1kbnr/pp3ppp/3qp3/8/2Bp4/5N2/PPPN1PPP/R1BQ1RK1 b kq' => {
			eco => 'C07o',
			# TRANSLATORS: C07o: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 Qxd5 5. Ngf3 cxd4 6. Bc4 Qd6 7. O-O
			variation => N__('French: Tarrasch, Open, 4.exd5 Qxd5 5.Ngf3 cxd4 6. Bc4 Qd6'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnb1kb1r/pp3ppp/3qpn2/8/2Bp4/5N2/PPPN1PPP/R1BQ1RK1 w kq' => {
			eco => 'C07o',
			# TRANSLATORS: C07o: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 Qxd5 5. Ngf3 cxd4 6. Bc4 Qd6 7. O-O Nf6
			variation => N__('French: Tarrasch, Open, 4.exd5 Qxd5 5.Ngf3 cxd4 6. Bc4 Qd6'),
			moves => {
				'd2b3' => 1,
			},
		},
		'rnb1kb1r/pp3ppp/3qpn2/8/2Bp4/1N3N2/PPP2PPP/R1BQ1RK1 b kq' => {
			eco => 'C07o',
			# TRANSLATORS: C07o: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 Qxd5 5. Ngf3 cxd4 6. Bc4 Qd6 7. O-O Nf6 8. Nb3
			variation => N__('French: Tarrasch, Open, 4.exd5 Qxd5 5.Ngf3 cxd4 6. Bc4 Qd6'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1b1kb1r/pp3ppp/2nqpn2/8/2Bp4/1N3N2/PPP2PPP/R1BQ1RK1 w kq' => {
			eco => 'C07o',
			# TRANSLATORS: C07o: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 Qxd5 5. Ngf3 cxd4 6. Bc4 Qd6 7. O-O Nf6 8. Nb3 Nc6
			variation => N__('French: Tarrasch, Open, 4.exd5 Qxd5 5.Ngf3 cxd4 6. Bc4 Qd6'),
			moves => {
				'b3d4' => 1,
			},
		},
		'r1b1kb1r/pp3ppp/2nqpn2/8/2BN4/5N2/PPP2PPP/R1BQ1RK1 b kq' => {
			eco => 'C07o',
			# TRANSLATORS: C07o: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 Qxd5 5. Ngf3 cxd4 6. Bc4 Qd6 7. O-O Nf6 8. Nb3 Nc6 9. Nbxd4
			variation => N__('French: Tarrasch, Open, 4.exd5 Qxd5 5.Ngf3 cxd4 6. Bc4 Qd6'),
			moves => {
				'c6d4' => 1,
			},
		},
		'r1b1kb1r/pp3ppp/3qpn2/8/2Bn4/5N2/PPP2PPP/R1BQ1RK1 w kq' => {
			eco => 'C07o',
			# TRANSLATORS: C07o: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 Qxd5 5. Ngf3 cxd4 6. Bc4 Qd6 7. O-O Nf6 8. Nb3 Nc6 9. Nbxd4 Nxd4
			variation => N__('French: Tarrasch, Open, 4.exd5 Qxd5 5.Ngf3 cxd4 6. Bc4 Qd6'),
			moves => {
				'd1d4' => 1,
				'f3d4' => 1,
			},
		},
		'r1b1kb1r/pp3ppp/3qpn2/8/2BQ4/5N2/PPP2PPP/R1B2RK1 b kq' => {
			eco => 'C07p',
			# TRANSLATORS: C07p: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 Qxd5 5. Ngf3 cxd4 6. Bc4 Qd6 7. O-O Nf6 8. Nb3 Nc6 9. Nbxd4 Nxd4 10. Qxd4
			variation => N__('French: Tarrasch, Open, 4.exd5 Qxd5, Main Line, 10.Qxd4'),
			moves => {
				'd6d4' => 1,
			},
		},
		'r1b1kb1r/pp3ppp/4pn2/8/2Bq4/5N2/PPP2PPP/R1B2RK1 w kq' => {
			eco => 'C07p',
			# TRANSLATORS: C07p: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 Qxd5 5. Ngf3 cxd4 6. Bc4 Qd6 7. O-O Nf6 8. Nb3 Nc6 9. Nbxd4 Nxd4 10. Qxd4 Qxd4
			variation => N__('French: Tarrasch, Open, 4.exd5 Qxd5, Main Line, 10.Qxd4 Qxd4'),
			moves => {
			},
		},
		'r1b1kb1r/pp3ppp/3qpn2/8/2BN4/8/PPP2PPP/R1BQ1RK1 b kq' => {
			eco => 'C07q',
			# TRANSLATORS: C07q: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 Qxd5 5. Ngf3 cxd4 6. Bc4 Qd6 7. O-O Nf6 8. Nb3 Nc6 9. Nbxd4 Nxd4 10. Nxd4
			variation => N__('French: Tarrasch, Open, 4.exd5 Qxd5, Main Line, 10.Nxd4'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r1b1kb1r/1p3ppp/p2qpn2/8/2BN4/8/PPP2PPP/R1BQ1RK1 w kq' => {
			eco => 'C07r',
			# TRANSLATORS: C07r: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 Qxd5 5. Ngf3 cxd4 6. Bc4 Qd6 7. O-O Nf6 8. Nb3 Nc6 9. Nbxd4 Nxd4 10. Nxd4 a6
			variation => N__('French: Tarrasch, Open, 4.exd5 Qxd5, Main Line, 10.Nxd4 a6'),
			moves => {
				'c2c3' => 1,
				'f1e1' => 1,
			},
		},
		'r1b1kb1r/1p3ppp/p2qpn2/8/2BN4/2P5/PP3PPP/R1BQ1RK1 b kq' => {
			eco => 'C07s',
			# TRANSLATORS: C07s: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 Qxd5 5. Ngf3 cxd4 6. Bc4 Qd6 7. O-O Nf6 8. Nb3 Nc6 9. Nbxd4 Nxd4 10. Nxd4 a6 11. c3
			variation => N__('French: Tarrasch, Open, 4.exd5 Qxd5, Main Line, 10.Nxd4 a6 11. c3'),
			moves => {
			},
		},
		'r1b1kb1r/1p3ppp/p2qpn2/8/2BN4/8/PPP2PPP/R1BQR1K1 b kq' => {
			eco => 'C07t',
			# TRANSLATORS: C07t: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 Qxd5 5. Ngf3 cxd4 6. Bc4 Qd6 7. O-O Nf6 8. Nb3 Nc6 9. Nbxd4 Nxd4 10. Nxd4 a6 11. Re1
			variation => N__('French: Tarrasch, Open, 4.exd5 Qxd5, Main Line, 10.Nxd4 a6 11. Re1'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/8/2pp4/3P4/8/PPPN1PPP/R1BQKBNR w KQkq' => {
			eco => 'C08a',
			# TRANSLATORS: C08a: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5
			variation => N__('French: Tarrasch, Open, 4.exd5 exd5'),
			moves => {
				'f1b5' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/8/1Bpp4/3P4/8/PPPN1PPP/R1BQK1NR b KQkq' => {
			eco => 'C08a',
			# TRANSLATORS: C08a: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Bb5+
			variation => N__('French: Tarrasch, Open, 4.exd5 exd5'),
			moves => {
				'b8c6' => 1,
				'c8d7' => 1,
			},
		},
		'r1bqkbnr/pp3ppp/2n5/1Bpp4/3P4/8/PPPN1PPP/R1BQK1NR w KQkq' => {
			eco => 'C08b',
			# TRANSLATORS: C08b: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Bb5+ Nc6
			variation => N__('French: Tarrasch, Open, 4.exd5 exd5 5. Bb5+ Nc6'),
			moves => {
				'd1e2' => 1,
			},
		},
		'r1bqkbnr/pp3ppp/2n5/1Bpp4/3P4/8/PPPNQPPP/R1B1K1NR b KQkq' => {
			eco => 'C08c',
			# TRANSLATORS: C08c: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Bb5+ Nc6 6. Qe2+
			variation => N__('French: Tarrasch, Open, 4.exd5 exd5 5. Bb5+ Nc6 6. Qe2+'),
			moves => {
			},
		},
		'rn1qkbnr/pp1b1ppp/8/1Bpp4/3P4/8/PPPN1PPP/R1BQK1NR w KQkq' => {
			eco => 'C08d',
			# TRANSLATORS: C08d: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Bb5+ Bd7
			variation => N__('French: Tarrasch, Open, 4.exd5 exd5 5. Bb5+ Bd7'),
			moves => {
				'd1e2' => 1,
			},
		},
		'rn1qkbnr/pp1b1ppp/8/1Bpp4/3P4/8/PPPNQPPP/R1B1K1NR b KQkq' => {
			eco => 'C08e',
			# TRANSLATORS: C08e: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Bb5+ Bd7 6. Qe2+
			variation => N__('French: Tarrasch, Open, 4.exd5 exd5 5. Bb5+ Bd7 6. Qe2+'),
			moves => {
				'f8e7' => 1,
			},
		},
		'rn1qk1nr/pp1bbppp/8/1Bpp4/3P4/8/PPPNQPPP/R1B1K1NR w KQkq' => {
			eco => 'C08f',
			# TRANSLATORS: C08f: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Bb5+ Bd7 6. Qe2+ Be7
			variation => N__('French: Tarrasch, Open, 4.exd5 exd5 5. Bb5+ Bd7 6. Qe2+ Be7'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/8/2pp4/3P4/5N2/PPPN1PPP/R1BQKB1R b KQkq' => {
			eco => 'C08g',
			# TRANSLATORS: C08g: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3
			variation => N__('French: Tarrasch, Open, 4.exd5 exd5 5.Ngf3'),
			moves => {
				'a7a6' => 1,
				'b8c6' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/1p3ppp/p7/2pp4/3P4/5N2/PPPN1PPP/R1BQKB1R w KQkq' => {
			eco => 'C08h',
			# TRANSLATORS: C08h: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 a6
			variation => N__('French: Tarrasch, Open, 4.exd5 exd5 5.Ngf3 a6'),
			moves => {
				'f1e2' => 1,
			},
		},
		'rnbqkbnr/1p3ppp/p7/2pp4/3P4/5N2/PPPNBPPP/R1BQK2R b KQkq' => {
			eco => 'C08i',
			# TRANSLATORS: C08i: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 a6 6. Be2
			variation => N__('French: Tarrasch, Open, 4.exd5 exd5 5.Ngf3 a6 6. Be2'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/5n2/2pp4/3P4/5N2/PPPN1PPP/R1BQKB1R w KQkq' => {
			eco => 'C08j',
			# TRANSLATORS: C08j: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nf6
			variation => N__('French: Tarrasch, Open, 4.exd5 exd5 5.Ngf3 Nf6'),
			moves => {
				'f1b5' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/5n2/1Bpp4/3P4/5N2/PPPN1PPP/R1BQK2R b KQkq' => {
			eco => 'C08j',
			# TRANSLATORS: C08j: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nf6 6. Bb5+
			variation => N__('French: Tarrasch, Open, 4.exd5 exd5 5.Ngf3 Nf6'),
			moves => {
				'c8d7' => 1,
			},
		},
		'rn1qkb1r/pp1b1ppp/5n2/1Bpp4/3P4/5N2/PPPN1PPP/R1BQK2R w KQkq' => {
			eco => 'C08j',
			# TRANSLATORS: C08j: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nf6 6. Bb5+ Bd7
			variation => N__('French: Tarrasch, Open, 4.exd5 exd5 5.Ngf3 Nf6'),
			moves => {
				'b5d7' => 1,
			},
		},
		'rn1qkb1r/pp1B1ppp/5n2/2pp4/3P4/5N2/PPPN1PPP/R1BQK2R b KQkq' => {
			eco => 'C08k',
			# TRANSLATORS: C08k: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nf6 6. Bb5+ Bd7 7. Bxd7+
			variation => N__('French: Tarrasch, Open, 4.exd5 exd5 5.Ngf3 Nf6, 7.Bxd7'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r2qkb1r/pp1n1ppp/5n2/2pp4/3P4/5N2/PPPN1PPP/R1BQK2R w KQkq' => {
			eco => 'C08k',
			# TRANSLATORS: C08k: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nf6 6. Bb5+ Bd7 7. Bxd7+ Nbxd7
			variation => N__('French: Tarrasch, Open, 4.exd5 exd5 5.Ngf3 Nf6, 7.Bxd7'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r2qkb1r/pp1n1ppp/5n2/2pp4/3P4/5N2/PPPN1PPP/R1BQ1RK1 b kq' => {
			eco => 'C08k',
			# TRANSLATORS: C08k: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nf6 6. Bb5+ Bd7 7. Bxd7+ Nbxd7 8. O-O
			variation => N__('French: Tarrasch, Open, 4.exd5 exd5 5.Ngf3 Nf6, 7.Bxd7'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r2qk2r/pp1nbppp/5n2/2pp4/3P4/5N2/PPPN1PPP/R1BQ1RK1 w kq' => {
			eco => 'C08k',
			# TRANSLATORS: C08k: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nf6 6. Bb5+ Bd7 7. Bxd7+ Nbxd7 8. O-O Be7
			variation => N__('French: Tarrasch, Open, 4.exd5 exd5 5.Ngf3 Nf6, 7.Bxd7'),
			moves => {
				'd4c5' => 1,
			},
		},
		'r2qk2r/pp1nbppp/5n2/2Pp4/8/5N2/PPPN1PPP/R1BQ1RK1 b kq' => {
			eco => 'C08l',
			# TRANSLATORS: C08l: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nf6 6. Bb5+ Bd7 7. Bxd7+ Nbxd7 8. O-O Be7 9. dxc5
			variation => N__('French: Tarrasch, Open, 4.exd5 exd5 5.Ngf3 Nf6, Main Line'),
			moves => {
				'd7c5' => 1,
			},
		},
		'r2qk2r/pp2bppp/5n2/2np4/8/5N2/PPPN1PPP/R1BQ1RK1 w kq' => {
			eco => 'C08l',
			# TRANSLATORS: C08l: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nf6 6. Bb5+ Bd7 7. Bxd7+ Nbxd7 8. O-O Be7 9. dxc5 Nxc5
			variation => N__('French: Tarrasch, Open, 4.exd5 exd5 5.Ngf3 Nf6, Main Line'),
			moves => {
				'd2b3' => 1,
			},
		},
		'r2qk2r/pp2bppp/5n2/2np4/8/1N3N2/PPP2PPP/R1BQ1RK1 b kq' => {
			eco => 'C08m',
			# TRANSLATORS: C08m: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nf6 6. Bb5+ Bd7 7. Bxd7+ Nbxd7 8. O-O Be7 9. dxc5 Nxc5 10. Nb3
			variation => N__('French: Tarrasch, Open, 4.exd5 exd5 5.Ngf3 Nf6, Main Line, 10. Nb3'),
			moves => {
			},
		},
		'r1bqkbnr/pp3ppp/2n5/2pp4/3P4/5N2/PPPN1PPP/R1BQKB1R w KQkq' => {
			eco => 'C09a',
			# TRANSLATORS: C09a: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nc6
			variation => N__('French: Tarrasch, Open, 5.Ngf3 Nc6'),
			moves => {
				'f1b5' => 1,
			},
		},
		'r1bqkbnr/pp3ppp/2n5/1Bpp4/3P4/5N2/PPPN1PPP/R1BQK2R b KQkq' => {
			eco => 'C09b',
			# TRANSLATORS: C09b: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nc6 6. Bb5
			variation => N__('French: Tarrasch, Open, 5.Ngf3 Nc6 6. Bb5'),
			moves => {
				'c5d4' => 1,
				'f8d6' => 1,
			},
		},
		'r1bqkbnr/pp3ppp/2n5/1B1p4/3p4/5N2/PPPN1PPP/R1BQK2R w KQkq' => {
			eco => 'C09c',
			# TRANSLATORS: C09c: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nc6 6. Bb5 cxd4
			variation => N__('French: Tarrasch, Open, 5.Ngf3 Nc6 6. Bb5 cxd4'),
			moves => {
			},
		},
		'r1bqk1nr/pp3ppp/2nb4/1Bpp4/3P4/5N2/PPPN1PPP/R1BQK2R w KQkq' => {
			eco => 'C09d',
			# TRANSLATORS: C09d: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nc6 6. Bb5 Bd6
			variation => N__('French: Tarrasch, Open, 5.Ngf3 Nc6 6. Bb5 Bd6'),
			moves => {
				'd4c5' => 1,
				'e1g1' => 1,
			},
		},
		'r1bqk1nr/pp3ppp/2nb4/1Bpp4/3P4/5N2/PPPN1PPP/R1BQ1RK1 b kq' => {
			eco => 'C09d',
			# TRANSLATORS: C09d: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nc6 6. Bb5 Bd6 7. O-O
			variation => N__('French: Tarrasch, Open, 7.O-O'),
			moves => {
				'g8e7' => 1,
			},
		},
		'r1bqk2r/pp2nppp/2nb4/1Bpp4/3P4/5N2/PPPN1PPP/R1BQ1RK1 w kq' => {
			eco => 'C09d',
			# TRANSLATORS: C09d: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nc6 6. Bb5 Bd6 7. O-O Ne7
			variation => N__('French: Tarrasch, Open, 7.O-O'),
			moves => {
				'd4c5' => 1,
			},
		},
		'r1bqk2r/pp2nppp/2nb4/1BPp4/8/5N2/PPPN1PPP/R1BQ1RK1 b kq' => {
			eco => 'C09d',
			# TRANSLATORS: C09d: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nc6 6. Bb5 Bd6 7. O-O Ne7 8. dxc5
			variation => N__('French: Tarrasch, Open, 7.O-O'),
			moves => {
				'd6c5' => 1,
			},
		},
		'r1bqk1nr/pp3ppp/2nb4/1BPp4/8/5N2/PPPN1PPP/R1BQK2R b KQkq' => {
			eco => 'C09e',
			# TRANSLATORS: C09e: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nc6 6. Bb5 Bd6 7. dxc5
			variation => N__('French: Tarrasch, Open, 7.dxc5'),
			moves => {
				'd6c5' => 1,
			},
		},
		'r1bqk1nr/pp3ppp/2n5/1Bbp4/8/5N2/PPPN1PPP/R1BQK2R w KQkq' => {
			eco => 'C09e',
			# TRANSLATORS: C09e: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nc6 6. Bb5 Bd6 7. dxc5 Bxc5
			variation => N__('French: Tarrasch, Open, 7.dxc5'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqk1nr/pp3ppp/2n5/1Bbp4/8/5N2/PPPN1PPP/R1BQ1RK1 b kq' => {
			eco => 'C09e',
			# TRANSLATORS: C09e: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nc6 6. Bb5 Bd6 7. dxc5 Bxc5 8. O-O
			variation => N__('French: Tarrasch, Open, 7.dxc5'),
			moves => {
				'g8e7' => 1,
			},
		},
		'r1bqk2r/pp2nppp/2n5/1Bbp4/8/5N2/PPPN1PPP/R1BQ1RK1 w kq' => {
			eco => 'C09f',
			# TRANSLATORS: C09f: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nc6 6. Bb5 Bd6 7. O-O Ne7 8. dxc5 Bxc5
			variation => N__('French: Tarrasch, Open, Main Line'),
			moves => {
				'c2c3' => 1,
				'd2b3' => 1,
			},
		},
		'r1bqk2r/pp2nppp/2n5/1Bbp4/8/2P2N2/PP1N1PPP/R1BQ1RK1 b kq' => {
			eco => 'C09g',
			# TRANSLATORS: C09g: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nc6 6. Bb5 Bd6 7. O-O Ne7 8. dxc5 Bxc5 9. c3
			variation => N__('French: Tarrasch, Open, Main Line, 9. c3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp2nppp/2n5/1Bbp4/8/2P2N2/PP1N1PPP/R1BQ1RK1 w -' => {
			eco => 'C09g',
			# TRANSLATORS: C09g: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nc6 6. Bb5 Bd6 7. O-O Ne7 8. dxc5 Bxc5 9. c3 O-O
			variation => N__('French: Tarrasch, Open, Main Line, 9. c3'),
			moves => {
				'd2b3' => 1,
			},
		},
		'r1bq1rk1/pp2nppp/2n5/1Bbp4/8/1NP2N2/PP3PPP/R1BQ1RK1 b -' => {
			eco => 'C09g',
			# TRANSLATORS: C09g: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nc6 6. Bb5 Bd6 7. O-O Ne7 8. dxc5 Bxc5 9. c3 O-O 10. Nb3
			variation => N__('French: Tarrasch, Open, Main Line, 9. c3'),
			moves => {
				'c5b6' => 1,
				'c5d6' => 1,
			},
		},
		'r1bq1rk1/pp2nppp/2nb4/1B1p4/8/1NP2N2/PP3PPP/R1BQ1RK1 w -' => {
			eco => 'C09h',
			# TRANSLATORS: C09h: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nc6 6. Bb5 Bd6 7. O-O Ne7 8. dxc5 Bxc5 9. c3 O-O 10. Nb3 Bd6
			variation => N__('French: Tarrasch, Open, Main Line, 9. c3 O-O 10. Nb3 Bd6'),
			moves => {
			},
		},
		'r1bq1rk1/pp2nppp/1bn5/1B1p4/8/1NP2N2/PP3PPP/R1BQ1RK1 w -' => {
			eco => 'C09i',
			# TRANSLATORS: C09i: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nc6 6. Bb5 Bd6 7. O-O Ne7 8. dxc5 Bxc5 9. c3 O-O 10. Nb3 Bb6
			variation => N__('French: Tarrasch, Open, Main Line, 9. c3 O-O 10. Nb3 Bb6'),
			moves => {
				'f1e1' => 1,
			},
		},
		'r1bq1rk1/pp2nppp/1bn5/1B1p4/8/1NP2N2/PP3PPP/R1BQR1K1 b -' => {
			eco => 'C09j',
			# TRANSLATORS: C09j: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nc6 6. Bb5 Bd6 7. O-O Ne7 8. dxc5 Bxc5 9. c3 O-O 10. Nb3 Bb6 11. Re1
			variation => N__('French: Tarrasch, Open, Main Line, 9. c3 O-O 10. Nb3 Bb6 11. Re1'),
			moves => {
			},
		},
		'r1bqk2r/pp2nppp/2n5/1Bbp4/8/1N3N2/PPP2PPP/R1BQ1RK1 b kq' => {
			eco => 'C09k',
			# TRANSLATORS: C09k: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nc6 6. Bb5 Bd6 7. O-O Ne7 8. dxc5 Bxc5 9. Nb3
			variation => N__('French: Tarrasch, Open, Main Line, 9. Nb3'),
			moves => {
				'c5b6' => 1,
				'c5d6' => 1,
			},
		},
		'r1bqk2r/pp2nppp/1bn5/1B1p4/8/1N3N2/PPP2PPP/R1BQ1RK1 w kq' => {
			eco => 'C09k',
			# TRANSLATORS: C09k: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nc6 6. Bb5 Bd6 7. O-O Ne7 8. dxc5 Bxc5 9. Nb3 Bb6
			variation => N__('French: Tarrasch, Open, Main Line, 9. Nb3 Bb6'),
			moves => {
			},
		},
		'r1bqk2r/pp2nppp/2nb4/1B1p4/8/1N3N2/PPP2PPP/R1BQ1RK1 w kq' => {
			eco => 'C09l',
			# TRANSLATORS: C09l: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nc6 6. Bb5 Bd6 7. O-O Ne7 8. dxc5 Bxc5 9. Nb3 Bd6
			variation => N__('French: Tarrasch, Open, Main Line, 9. Nb3 Bd6'),
			moves => {
				'b3d4' => 1,
				'c1g5' => 1,
				'f1e1' => 1,
			},
		},
		'r1bqk2r/pp2nppp/2nb4/1B1p4/3N4/5N2/PPP2PPP/R1BQ1RK1 b kq' => {
			eco => 'C09m',
			# TRANSLATORS: C09m: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nc6 6. Bb5 Bd6 7. O-O Ne7 8. dxc5 Bxc5 9. Nb3 Bd6 10. Nbd4
			variation => N__('French: Tarrasch, Open, Main Line, 9. Nb3 Bd6 10.Nbd4'),
			moves => {
			},
		},
		'r1bqk2r/pp2nppp/2nb4/1B1p2B1/8/1N3N2/PPP2PPP/R2Q1RK1 b kq' => {
			eco => 'C09n',
			# TRANSLATORS: C09n: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nc6 6. Bb5 Bd6 7. O-O Ne7 8. dxc5 Bxc5 9. Nb3 Bd6 10. Bg5
			variation => N__('French: Tarrasch, Open, Main Line, 9. Nb3 Bd6 10. Bg5'),
			moves => {
			},
		},
		'r1bqk2r/pp2nppp/2nb4/1B1p4/8/1N3N2/PPP2PPP/R1BQR1K1 b kq' => {
			eco => 'C09o',
			# TRANSLATORS: C09o: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nc6 6. Bb5 Bd6 7. O-O Ne7 8. dxc5 Bxc5 9. Nb3 Bd6 10. Re1
			variation => N__('French: Tarrasch, Open, Main Line, 9. Nb3 Bd6 10. Re1'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp2nppp/2nb4/1B1p4/8/1N3N2/PPP2PPP/R1BQR1K1 w -' => {
			eco => 'C09o',
			# TRANSLATORS: C09o: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nc6 6. Bb5 Bd6 7. O-O Ne7 8. dxc5 Bxc5 9. Nb3 Bd6 10. Re1 O-O
			variation => N__('French: Tarrasch, Open, Main Line, 9. Nb3 Bd6 10. Re1'),
			moves => {
				'c1g5' => 1,
			},
		},
		'r1bq1rk1/pp2nppp/2nb4/1B1p2B1/8/1N3N2/PPP2PPP/R2QR1K1 b -' => {
			eco => 'C09p',
			# TRANSLATORS: C09p: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nc6 6. Bb5 Bd6 7. O-O Ne7 8. dxc5 Bxc5 9. Nb3 Bd6 10. Re1 O-O 11. Bg5
			variation => N__('French: Tarrasch, Open, Main Line, 9. Nb3 Bd6 10. Re1 O-O 11. Bg5'),
			moves => {
				'c8g4' => 1,
			},
		},
		'r2q1rk1/pp2nppp/2nb4/1B1p2B1/6b1/1N3N2/PPP2PPP/R2QR1K1 w -' => {
			eco => 'C09q',
			# TRANSLATORS: C09q: 1. e4 e6 2. d4 d5 3. Nd2 c5 4. exd5 exd5 5. Ngf3 Nc6 6. Bb5 Bd6 7. O-O Ne7 8. dxc5 Bxc5 9. Nb3 Bd6 10. Re1 O-O 11. Bg5 Bg4
			variation => N__('French: Tarrasch, Open, Main Line, 9. Nb3 Bd6 10. Re1 O-O 11. Bg5 Bg4'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/3p4/3PP3/2N5/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'C10a',
			# TRANSLATORS: C10a: 1. e4 e6 2. d4 d5 3. Nc3
			variation => N__('French: 3. Nc3'),
			moves => {
				'b8c6' => 1,
				'c7c5' => 1,
				'd5e4' => 1,
				'f8b4' => 1,
				'f8e7' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/4p3/2pp4/3PP3/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'C10b',
			# TRANSLATORS: C10b: 1. e4 e6 2. d4 d5 3. Nc3 c5
			variation => N__('French: Marshall Variation'),
			moves => {
			},
		},
		'r1bqkbnr/ppp2ppp/2n1p3/3p4/3PP3/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'C10c',
			# TRANSLATORS: C10c: 1. e4 e6 2. d4 d5 3. Nc3 Nc6
			variation => N__('French: 3. Nc3 Nc6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'r1bqkbnr/ppp2ppp/2n1p3/3p4/3PP3/2N2N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'C10c',
			# TRANSLATORS: C10c: 1. e4 e6 2. d4 d5 3. Nc3 Nc6 4. Nf3
			variation => N__('French: 3. Nc3 Nc6'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2n1pn2/3p4/3PP3/2N2N2/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'C10d',
			# TRANSLATORS: C10d: 1. e4 e6 2. d4 d5 3. Nc3 Nc6 4. Nf3 Nf6
			variation => N__('French: 3. Nc3 Nc6 4. Nf3 Nf6'),
			moves => {
			},
		},
		'rnbqk1nr/ppp1bppp/4p3/3p4/3PP3/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'C10e',
			# TRANSLATORS: C10e: 1. e4 e6 2. d4 d5 3. Nc3 Be7
			variation => N__('French: 3. Nc3 Be7'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/8/3Pp3/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'C10f',
			# TRANSLATORS: C10f: 1. e4 e6 2. d4 d5 3. Nc3 dxe4
			variation => N__('French: Rubinstein'),
			moves => {
				'c3e4' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/8/3PN3/8/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'C10f',
			# TRANSLATORS: C10f: 1. e4 e6 2. d4 d5 3. Nc3 dxe4 4. Nxe4
			variation => N__('French: Rubinstein'),
			moves => {
				'b8d7' => 1,
				'c8d7' => 1,
				'd8d5' => 1,
				'e6e5' => 1,
				'g8f6' => 1,
			},
		},
		'rnb1kbnr/ppp2ppp/4p3/3q4/3PN3/8/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'C10f',
			# TRANSLATORS: C10f: 1. e4 e6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Qd5
			variation => N__('French: Rubinstein, Frere (Becker) Variation'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/8/4p3/3PN3/8/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'C10f',
			# TRANSLATORS: C10f: 1. e4 e6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 e5
			variation => N__('French: Rubinstein, Ellis Gambit'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/8/3PN3/8/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'C10g',
			# TRANSLATORS: C10g: 1. e4 e6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nf6
			variation => N__('French: Rubinstein, 4... Nf6'),
			moves => {
			},
		},
		'r1bqkbnr/pppn1ppp/4p3/8/3PN3/8/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'C10h',
			# TRANSLATORS: C10h: 1. e4 e6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7
			variation => N__('French: Rubinstein, 4... Nd7'),
			moves => {
				'g1f3' => 1,
			},
		},
		'r1bqkbnr/pppn1ppp/4p3/8/3PN3/5N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'C10h',
			# TRANSLATORS: C10h: 1. e4 e6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Nf3
			variation => N__('French: Rubinstein, 4... Nd7'),
			moves => {
				'f8e7' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqk1nr/pppnbppp/4p3/8/3PN3/5N2/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'C10i',
			# TRANSLATORS: C10i: 1. e4 e6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Nf3 Be7
			variation => N__('French: Rubinstein, 5. Nf3 Be7'),
			moves => {
			},
		},
		'r1bqkb1r/pppn1ppp/4pn2/8/3PN3/5N2/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'C10j',
			# TRANSLATORS: C10j: 1. e4 e6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Nf3 Ngf6
			variation => N__('French: Rubinstein, 5. Nf3 Ngf6'),
			moves => {
				'e4f6' => 1,
				'f1d3' => 1,
			},
		},
		'r1bqkb1r/pppn1ppp/4pn2/8/3PN3/3B1N2/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'C10k',
			# TRANSLATORS: C10k: 1. e4 e6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Nf3 Ngf6 6. Bd3
			variation => N__('French: Rubinstein, 5. Nf3 Ngf6 6. Bd3'),
			moves => {
			},
		},
		'r1bqkb1r/pppn1ppp/4pN2/8/3P4/5N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'C10l',
			# TRANSLATORS: C10l: 1. e4 e6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Nf3 Ngf6 6. Nxf6+
			variation => N__('French: Rubinstein, 5. Nf3 Ngf6 6.Nxf6+'),
			moves => {
				'd7f6' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/4pn2/8/3P4/5N2/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'C10l',
			# TRANSLATORS: C10l: 1. e4 e6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Nf3 Ngf6 6. Nxf6+ Nxf6
			variation => N__('French: Rubinstein, 5. Nf3 Ngf6 6.Nxf6+'),
			moves => {
				'c1g5' => 1,
				'f1d3' => 1,
				'f3e5' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/4pn2/4N3/3P4/8/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'C10m',
			# TRANSLATORS: C10m: 1. e4 e6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Nf3 Ngf6 6. Nxf6+ Nxf6 7. Ne5
			variation => N__('French: Rubinstein, Capablanca'),
			moves => {
			},
		},
		'r1bqkb1r/ppp2ppp/4pn2/8/3P4/3B1N2/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'C10n',
			# TRANSLATORS: C10n: 1. e4 e6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Nf3 Ngf6 6. Nxf6+ Nxf6 7. Bd3
			variation => N__('French: Rubinstein, 7. Bd3'),
			moves => {
				'c7c5' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/4pn2/2p5/3P4/3B1N2/PPP2PPP/R1BQK2R w KQkq' => {
			eco => 'C10o',
			# TRANSLATORS: C10o: 1. e4 e6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Nf3 Ngf6 6. Nxf6+ Nxf6 7. Bd3 c5
			variation => N__('French: Rubinstein, 7. Bd3 c5'),
			moves => {
				'd4c5' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/4pn2/2P5/8/3B1N2/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'C10p',
			# TRANSLATORS: C10p: 1. e4 e6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Nf3 Ngf6 6. Nxf6+ Nxf6 7. Bd3 c5 8. dxc5
			variation => N__('French: Rubinstein, 7. Bd3 c5 8.dxc5'),
			moves => {
			},
		},
		'r1bqkb1r/ppp2ppp/4pn2/6B1/3P4/5N2/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'C10q',
			# TRANSLATORS: C10q: 1. e4 e6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Nd7 5. Nf3 Ngf6 6. Nxf6+ Nxf6 7. Bg5
			variation => N__('French: Rubinstein, 7. Bg5'),
			moves => {
			},
		},
		'rn1qkbnr/pppb1ppp/4p3/8/3PN3/8/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'C10r',
			# TRANSLATORS: C10r: 1. e4 e6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bd7
			variation => N__('French: Rubinstein, 4... Bd7'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rn1qkbnr/pppb1ppp/4p3/8/3PN3/5N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'C10s',
			# TRANSLATORS: C10s: 1. e4 e6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bd7 5. Nf3
			variation => N__('French: Rubinstein, 4... Bd7 5. Nf3'),
			moves => {
				'd7c6' => 1,
			},
		},
		'rn1qkbnr/ppp2ppp/2b1p3/8/3PN3/5N2/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'C10s',
			# TRANSLATORS: C10s: 1. e4 e6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bd7 5. Nf3 Bc6
			variation => N__('French: Rubinstein, 4... Bd7 5. Nf3'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rn1qkbnr/ppp2ppp/2b1p3/8/3PN3/3B1N2/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'C10t',
			# TRANSLATORS: C10t: 1. e4 e6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bd7 5. Nf3 Bc6 6. Bd3
			variation => N__('French: Rubinstein, 4... Bd7 5. Nf3 Bc6 6. Bd3'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r2qkbnr/pppn1ppp/2b1p3/8/3PN3/3B1N2/PPP2PPP/R1BQK2R w KQkq' => {
			eco => 'C10u',
			# TRANSLATORS: C10u: 1. e4 e6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bd7 5. Nf3 Bc6 6. Bd3 Nd7
			variation => N__('French: Rubinstein, 4... Bd7 5. Nf3 Bc6 6. Bd3 Nd7'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r2qkbnr/pppn1ppp/2b1p3/8/3PN3/3B1N2/PPP2PPP/R1BQ1RK1 b kq' => {
			eco => 'C10v',
			# TRANSLATORS: C10v: 1. e4 e6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bd7 5. Nf3 Bc6 6. Bd3 Nd7 7. O-O
			variation => N__('French: Rubinstein, 4... Bd7 5. Nf3 Bc6 6. Bd3 Nd7 7.O-O'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r2qkb1r/pppn1ppp/2b1pn2/8/3PN3/3B1N2/PPP2PPP/R1BQ1RK1 w kq' => {
			eco => 'C10w',
			# TRANSLATORS: C10w: 1. e4 e6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bd7 5. Nf3 Bc6 6. Bd3 Nd7 7. O-O Ngf6
			variation => N__('French: Rubinstein, 4... Bd7 5. Nf3 Bc6 6. Bd3 Nd7 7.O-O Ngf6'),
			moves => {
				'e4g3' => 1,
			},
		},
		'r2qkb1r/pppn1ppp/2b1pn2/8/3P4/3B1NN1/PPP2PPP/R1BQ1RK1 b kq' => {
			eco => 'C10x',
			# TRANSLATORS: C10x: 1. e4 e6 2. d4 d5 3. Nc3 dxe4 4. Nxe4 Bd7 5. Nf3 Bc6 6. Bd3 Nd7 7. O-O Ngf6 8. Ng3
			variation => N__('French: Rubinstein, 4... Bd7 5. Nf3 Bc6 6. Bd3 Nd7 7.O-O Ngf6 8. Ng3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p4/3PP3/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'C11a',
			# TRANSLATORS: C11a: 1. e4 e6 2. d4 d5 3. Nc3 Nf6
			variation => N__('French: 3. Nc3 Nf6'),
			moves => {
				'c1e3' => 1,
				'c1g5' => 1,
				'e4d5' => 1,
				'e4e5' => 1,
				'f1d3' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p4/3PP3/2N1B3/PPP2PPP/R2QKBNR b KQkq' => {
			eco => 'C11a',
			# TRANSLATORS: C11a: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Be3
			variation => N__('French: Henneberger Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3P4/3P4/2N5/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'C11a',
			# TRANSLATORS: C11a: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. exd5
			variation => N__('French: 3. Nc3 Nf6 4.exd5'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p4/3PP3/2NB4/PPP2PPP/R1BQK1NR b KQkq' => {
			eco => 'C11b',
			# TRANSLATORS: C11b: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bd3
			variation => N__('French: Swiss Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3pP3/3P4/2N5/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'C11c',
			# TRANSLATORS: C11c: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. e5
			variation => N__('French: Steinitz'),
			moves => {
				'f6d7' => 1,
			},
		},
		'rnbqkb1r/pppn1ppp/4p3/3pP3/3P4/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'C11c',
			# TRANSLATORS: C11c: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. e5 Nfd7
			variation => N__('French: Steinitz'),
			moves => {
				'd1g4' => 1,
				'f2f4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/pppn1ppp/4p3/3pP3/3P2Q1/2N5/PPP2PPP/R1B1KBNR b KQkq' => {
			eco => 'C11c',
			# TRANSLATORS: C11c: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. e5 Nfd7 5. Qg4
			variation => N__('French: Steinitz, Gledhill Attack'),
			moves => {
			},
		},
		'rnbqkb1r/pppn1ppp/4p3/3pP3/3P4/2N2N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'C11d',
			# TRANSLATORS: C11d: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. e5 Nfd7 5. Nf3
			variation => N__('French: Steinitz, 5. Nf3'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqkb1r/pp1n1ppp/4p3/2ppP3/3P4/2N2N2/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'C11d',
			# TRANSLATORS: C11d: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. e5 Nfd7 5. Nf3 c5
			variation => N__('French: Steinitz, 5. Nf3 c5'),
			moves => {
				'd4c5' => 1,
			},
		},
		'rnbqkb1r/pp1n1ppp/4p3/2PpP3/8/2N2N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'C11e',
			# TRANSLATORS: C11e: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. e5 Nfd7 5. Nf3 c5 6. dxc5
			variation => N__('French: Steinitz, 5. Nf3 c5 6.dxc5'),
			moves => {
			},
		},
		'rnbqkb1r/pppn1ppp/4p3/3pP3/3P1P2/2N5/PPP3PP/R1BQKBNR b KQkq' => {
			eco => 'C11f',
			# TRANSLATORS: C11f: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. e5 Nfd7 5. f4
			variation => N__('French: Steinitz, 5. f4'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqkb1r/pp1n1ppp/4p3/2ppP3/3P1P2/2N5/PPP3PP/R1BQKBNR w KQkq' => {
			eco => 'C11f',
			# TRANSLATORS: C11f: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. e5 Nfd7 5. f4 c5
			variation => N__('French: Steinitz, 5. f4 c5'),
			moves => {
				'd4c5' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/pp1n1ppp/4p3/2PpP3/5P2/2N5/PPP3PP/R1BQKBNR b KQkq' => {
			eco => 'C11g',
			# TRANSLATORS: C11g: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. e5 Nfd7 5. f4 c5 6. dxc5
			variation => N__('French: Steinitz, 6.dxc5'),
			moves => {
				'b8c6' => 1,
				'f8c5' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/2n1p3/2PpP3/5P2/2N5/PPP3PP/R1BQKBNR w KQkq' => {
			eco => 'C11g',
			# TRANSLATORS: C11g: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. e5 Nfd7 5. f4 c5 6. dxc5 Nc6
			variation => N__('French: Steinitz, 6.dxc5 Nc6'),
			moves => {
				'a2a3' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/2n1p3/2PpP3/5P2/P1N5/1PP3PP/R1BQKBNR b KQkq' => {
			eco => 'C11g',
			# TRANSLATORS: C11g: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. e5 Nfd7 5. f4 c5 6. dxc5 Nc6 7. a3
			variation => N__('French: Steinitz, 6.dxc5 Nc6'),
			moves => {
				'f8c5' => 1,
			},
		},
		'r1bqk2r/pp1n1ppp/2n1p3/2bpP3/5P2/P1N5/1PP3PP/R1BQKBNR w KQkq' => {
			eco => 'C11g',
			# TRANSLATORS: C11g: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. e5 Nfd7 5. f4 c5 6. dxc5 Nc6 7. a3 Bxc5
			variation => N__('French: Steinitz, 6.dxc5 Nc6'),
			moves => {
				'd1g4' => 1,
			},
		},
		'r1bqk2r/pp1n1ppp/2n1p3/2bpP3/5PQ1/P1N5/1PP3PP/R1B1KBNR b KQkq' => {
			eco => 'C11g',
			# TRANSLATORS: C11g: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. e5 Nfd7 5. f4 c5 6. dxc5 Nc6 7. a3 Bxc5 8. Qg4
			variation => N__('French: Steinitz, 6.dxc5 Nc6'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp1n1ppp/2n1p3/2bpP3/5PQ1/P1N5/1PP3PP/R1B1KBNR w KQ' => {
			eco => 'C11g',
			# TRANSLATORS: C11g: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. e5 Nfd7 5. f4 c5 6. dxc5 Nc6 7. a3 Bxc5 8. Qg4 O-O
			variation => N__('French: Steinitz, 6.dxc5 Nc6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'r1bq1rk1/pp1n1ppp/2n1p3/2bpP3/5PQ1/P1N2N2/1PP3PP/R1B1KB1R b KQ' => {
			eco => 'C11g',
			# TRANSLATORS: C11g: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. e5 Nfd7 5. f4 c5 6. dxc5 Nc6 7. a3 Bxc5 8. Qg4 O-O 9. Nf3
			variation => N__('French: Steinitz, 6.dxc5 Nc6'),
			moves => {
				'f7f6' => 1,
			},
		},
		'r1bq1rk1/pp1n2pp/2n1pp2/2bpP3/5PQ1/P1N2N2/1PP3PP/R1B1KB1R w KQ' => {
			eco => 'C11g',
			# TRANSLATORS: C11g: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. e5 Nfd7 5. f4 c5 6. dxc5 Nc6 7. a3 Bxc5 8. Qg4 O-O 9. Nf3 f6
			variation => N__('French: Steinitz, Brodsky-Jones Variation'),
			moves => {
			},
		},
		'rnbqk2r/pp1n1ppp/4p3/2bpP3/5P2/2N5/PPP3PP/R1BQKBNR w KQkq' => {
			eco => 'C11g',
			# TRANSLATORS: C11g: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. e5 Nfd7 5. f4 c5 6. dxc5 Bxc5
			variation => N__('French: Steinitz, 6.dxc5'),
			moves => {
				'd1g4' => 1,
			},
		},
		'rnbqk2r/pp1n1ppp/4p3/2bpP3/5PQ1/2N5/PPP3PP/R1B1KBNR b KQkq' => {
			eco => 'C11g',
			# TRANSLATORS: C11g: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. e5 Nfd7 5. f4 c5 6. dxc5 Bxc5 7. Qg4
			variation => N__('French: Steinitz, Bradford Attack'),
			moves => {
			},
		},
		'rnbqkb1r/pp1n1ppp/4p3/2ppP3/3P1P2/2N2N2/PPP3PP/R1BQKB1R b KQkq' => {
			eco => 'C11h',
			# TRANSLATORS: C11h: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. e5 Nfd7 5. f4 c5 6. Nf3
			variation => N__('French: Steinitz, 6. Nf3'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/2n1p3/2ppP3/3P1P2/2N2N2/PPP3PP/R1BQKB1R w KQkq' => {
			eco => 'C11h',
			# TRANSLATORS: C11h: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. e5 Nfd7 5. f4 c5 6. Nf3 Nc6
			variation => N__('French: Steinitz, 6. Nf3'),
			moves => {
				'c1e3' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/2n1p3/2ppP3/3P1P2/2N1BN2/PPP3PP/R2QKB1R b KQkq' => {
			eco => 'C11i',
			# TRANSLATORS: C11i: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. e5 Nfd7 5. f4 c5 6. Nf3 Nc6 7. Be3
			variation => N__('French: Steinitz, Boleslavsky Variation'),
			moves => {
				'a7a6' => 1,
				'c5d4' => 1,
			},
		},
		'r1bqkb1r/1p1n1ppp/p1n1p3/2ppP3/3P1P2/2N1BN2/PPP3PP/R2QKB1R w KQkq' => {
			eco => 'C11j',
			# TRANSLATORS: C11j: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. e5 Nfd7 5. f4 c5 6. Nf3 Nc6 7. Be3 a6
			variation => N__('French: Steinitz, Boleslavsky, 7... a6'),
			moves => {
				'd1d2' => 1,
			},
		},
		'r1bqkb1r/1p1n1ppp/p1n1p3/2ppP3/3P1P2/2N1BN2/PPPQ2PP/R3KB1R b KQkq' => {
			eco => 'C11j',
			# TRANSLATORS: C11j: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. e5 Nfd7 5. f4 c5 6. Nf3 Nc6 7. Be3 a6 8. Qd2
			variation => N__('French: Steinitz, Boleslavsky, 7... a6'),
			moves => {
				'b7b5' => 1,
			},
		},
		'r1bqkb1r/3n1ppp/p1n1p3/1pppP3/3P1P2/2N1BN2/PPPQ2PP/R3KB1R w KQkq' => {
			eco => 'C11k',
			# TRANSLATORS: C11k: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. e5 Nfd7 5. f4 c5 6. Nf3 Nc6 7. Be3 a6 8. Qd2 b5
			variation => N__('French: Steinitz, Boleslavsky, 7... a6 8. Qd2 b5'),
			moves => {
			},
		},
		'r1bqkb1r/pp1n1ppp/2n1p3/3pP3/3p1P2/2N1BN2/PPP3PP/R2QKB1R w KQkq' => {
			eco => 'C11l',
			# TRANSLATORS: C11l: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. e5 Nfd7 5. f4 c5 6. Nf3 Nc6 7. Be3 cxd4
			variation => N__('French: Steinitz, Boleslavsky, 7...cxd4'),
			moves => {
				'f3d4' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/2n1p3/3pP3/3N1P2/2N1B3/PPP3PP/R2QKB1R b KQkq' => {
			eco => 'C11l',
			# TRANSLATORS: C11l: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. e5 Nfd7 5. f4 c5 6. Nf3 Nc6 7. Be3 cxd4 8. Nxd4
			variation => N__('French: Steinitz, Boleslavsky, 7...cxd4'),
			moves => {
				'd8b6' => 1,
				'f8c5' => 1,
			},
		},
		'r1b1kb1r/pp1n1ppp/1qn1p3/3pP3/3N1P2/2N1B3/PPP3PP/R2QKB1R w KQkq' => {
			eco => 'C11m',
			# TRANSLATORS: C11m: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. e5 Nfd7 5. f4 c5 6. Nf3 Nc6 7. Be3 cxd4 8. Nxd4 Qb6
			variation => N__('French: Steinitz, Boleslavsky, 7...cxd4 8.Nxd4 Qb6'),
			moves => {
			},
		},
		'r1bqk2r/pp1n1ppp/2n1p3/2bpP3/3N1P2/2N1B3/PPP3PP/R2QKB1R w KQkq' => {
			eco => 'C11n',
			# TRANSLATORS: C11n: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. e5 Nfd7 5. f4 c5 6. Nf3 Nc6 7. Be3 cxd4 8. Nxd4 Bc5
			variation => N__('French: Steinitz, Boleslavsky, 7...cxd4 8.Nxd4 Bc5'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p2B1/3PP3/2N5/PPP2PPP/R2QKBNR b KQkq' => {
			eco => 'C11o',
			# TRANSLATORS: C11o: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5
			variation => N__('French: 3. Nc3 Nf6 4. Bg5'),
			moves => {
				'd5e4' => 1,
				'f8b4' => 1,
				'f8e7' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/6B1/3Pp3/2N5/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'C11o',
			# TRANSLATORS: C11o: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 dxe4
			variation => N__('French: Burn Variation'),
			moves => {
				'c3e4' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/6B1/3PN3/8/PPP2PPP/R2QKBNR b KQkq' => {
			eco => 'C11p',
			# TRANSLATORS: C11p: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 dxe4 5. Nxe4
			variation => N__('French: Burn, 5.Nxe4'),
			moves => {
				'b8d7' => 1,
				'f8e7' => 1,
			},
		},
		'r1bqkb1r/pppn1ppp/4pn2/6B1/3PN3/8/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'C11p',
			# TRANSLATORS: C11p: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 dxe4 5. Nxe4 Nbd7
			variation => N__('French: Burn, 5.Nxe4 Nbd7'),
			moves => {
				'g1f3' => 1,
			},
		},
		'r1bqkb1r/pppn1ppp/4pn2/6B1/3PN3/5N2/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'C11q',
			# TRANSLATORS: C11q: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 dxe4 5. Nxe4 Nbd7 6. Nf3
			variation => N__('French: Burn, 5.Nxe4 Nbd7 6. Nf3'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r1bqk2r/pppnbppp/4pn2/6B1/3PN3/5N2/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'C11r',
			# TRANSLATORS: C11r: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 dxe4 5. Nxe4 Nbd7 6. Nf3 Be7
			variation => N__('French: Burn, 5.Nxe4 Nbd7 6. Nf3 Be7'),
			moves => {
				'e4f6' => 1,
			},
		},
		'r1bqk2r/pppnbppp/4pN2/6B1/3P4/5N2/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'C11r',
			# TRANSLATORS: C11r: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 dxe4 5. Nxe4 Nbd7 6. Nf3 Be7 7. Nxf6+
			variation => N__('French: Burn, 5.Nxe4 Nbd7 6. Nf3 Be7'),
			moves => {
				'd7f6' => 1,
			},
		},
		'r1bqk2r/ppp1bppp/4pn2/6B1/3P4/5N2/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'C11r',
			# TRANSLATORS: C11r: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 dxe4 5. Nxe4 Nbd7 6. Nf3 Be7 7. Nxf6+ Nxf6
			variation => N__('French: Burn, 5.Nxe4 Nbd7 6. Nf3 Be7'),
			moves => {
			},
		},
		'rnbqk2r/ppp1bppp/4pn2/6B1/3PN3/8/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'C11s',
			# TRANSLATORS: C11s: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 dxe4 5. Nxe4 Be7
			variation => N__('French: Burn, 5.Nxe4 Be7'),
			moves => {
				'g5f6' => 1,
			},
		},
		'rnbqk2r/ppp1bppp/4pB2/8/3PN3/8/PPP2PPP/R2QKBNR b KQkq' => {
			eco => 'C11s',
			# TRANSLATORS: C11s: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 dxe4 5. Nxe4 Be7 6. Bxf6
			variation => N__('French: Burn, 5.Nxe4 Be7'),
			moves => {
				'e7f6' => 1,
				'g7f6' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/4pb2/8/3PN3/8/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'C11t',
			# TRANSLATORS: C11t: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 dxe4 5. Nxe4 Be7 6. Bxf6 Bxf6
			variation => N__('French: Burn, 6.Bxf6 Bxf6'),
			moves => {
			},
		},
		'rnbqk2r/ppp1bp1p/4pp2/8/3PN3/8/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'C11u',
			# TRANSLATORS: C11u: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 dxe4 5. Nxe4 Be7 6. Bxf6 gxf6
			variation => N__('French: Burn, 6.Bxf6 gxf6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqk2r/ppp1bp1p/4pp2/8/3PN3/5N2/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'C11v',
			# TRANSLATORS: C11v: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 dxe4 5. Nxe4 Be7 6. Bxf6 gxf6 7. Nf3
			variation => N__('French: Burn, 6.Bxf6 gxf6 7. Nf3'),
			moves => {
				'b7b6' => 1,
				'f6f5' => 1,
			},
		},
		'rnbqk2r/p1p1bp1p/1p2pp2/8/3PN3/5N2/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'C11w',
			# TRANSLATORS: C11w: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 dxe4 5. Nxe4 Be7 6. Bxf6 gxf6 7. Nf3 b6
			variation => N__('French: Burn, 6.Bxf6 gxf6 7. Nf3 b6'),
			moves => {
				'f1c4' => 1,
				'f1d3' => 1,
			},
		},
		'rnbqk2r/p1p1bp1p/1p2pp2/8/2BPN3/5N2/PPP2PPP/R2QK2R b KQkq' => {
			eco => 'C11w',
			# TRANSLATORS: C11w: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 dxe4 5. Nxe4 Be7 6. Bxf6 gxf6 7. Nf3 b6 8. Bc4
			variation => N__('French: Burn, 6.Bxf6 gxf6 7. Nf3 b6 8. Bc4'),
			moves => {
			},
		},
		'rnbqk2r/p1p1bp1p/1p2pp2/8/3PN3/3B1N2/PPP2PPP/R2QK2R b KQkq' => {
			eco => 'C11w',
			# TRANSLATORS: C11w: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 dxe4 5. Nxe4 Be7 6. Bxf6 gxf6 7. Nf3 b6 8. Bd3
			variation => N__('French: Burn, 6.Bxf6 gxf6 7. Nf3 b6 8. Bd3'),
			moves => {
			},
		},
		'rnbqk2r/ppp1bp1p/4p3/5p2/3PN3/5N2/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'C11x',
			# TRANSLATORS: C11x: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 dxe4 5. Nxe4 Be7 6. Bxf6 gxf6 7. Nf3 f5
			variation => N__('French: Burn, 6.Bxf6 gxf6 7. Nf3 f5'),
			moves => {
			},
		},
		'rnbqk2r/ppp2ppp/4pn2/3p2B1/1b1PP3/2N5/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'C12a',
			# TRANSLATORS: C12a: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Bb4
			variation => N__('French: MacCutcheon'),
			moves => {
				'e4d5' => 1,
				'e4e5' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/4pn2/3P2B1/1b1P4/2N5/PPP2PPP/R2QKBNR b KQkq' => {
			eco => 'C12b',
			# TRANSLATORS: C12b: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Bb4 5. exd5
			variation => N__('French: MacCutcheon, 5.exd5'),
			moves => {
				'd8d5' => 1,
			},
		},
		'rnb1k2r/ppp2ppp/4pn2/3q2B1/1b1P4/2N5/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'C12c',
			# TRANSLATORS: C12c: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Bb4 5. exd5 Qxd5
			variation => N__('French: MacCutcheon, 5.exd5 Qxd5'),
			moves => {
				'g5f6' => 1,
			},
		},
		'rnb1k2r/ppp2ppp/4pB2/3q4/1b1P4/2N5/PPP2PPP/R2QKBNR b KQkq' => {
			eco => 'C12c',
			# TRANSLATORS: C12c: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Bb4 5. exd5 Qxd5 6. Bxf6
			variation => N__('French: MacCutcheon, 5.exd5 Qxd5'),
			moves => {
				'g7f6' => 1,
			},
		},
		'rnb1k2r/ppp2p1p/4pp2/3q4/1b1P4/2N5/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'C12c',
			# TRANSLATORS: C12c: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Bb4 5. exd5 Qxd5 6. Bxf6 gxf6
			variation => N__('French: MacCutcheon, 5.exd5 Qxd5'),
			moves => {
				'd1d2' => 1,
			},
		},
		'rnb1k2r/ppp2p1p/4pp2/3q4/1b1P4/2N5/PPPQ1PPP/R3KBNR b KQkq' => {
			eco => 'C12c',
			# TRANSLATORS: C12c: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Bb4 5. exd5 Qxd5 6. Bxf6 gxf6 7. Qd2
			variation => N__('French: MacCutcheon, 5.exd5 Qxd5'),
			moves => {
				'd5a5' => 1,
			},
		},
		'rnb1k2r/ppp2p1p/4pp2/q7/1b1P4/2N5/PPPQ1PPP/R3KBNR w KQkq' => {
			eco => 'C12c',
			# TRANSLATORS: C12c: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Bb4 5. exd5 Qxd5 6. Bxf6 gxf6 7. Qd2 Qa5
			variation => N__('French: MacCutcheon, Bogoljubow Variation'),
			moves => {
			},
		},
		'rnbqk2r/ppp2ppp/4pn2/3pP1B1/1b1P4/2N5/PPP2PPP/R2QKBNR b KQkq' => {
			eco => 'C12d',
			# TRANSLATORS: C12d: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Bb4 5. e5
			variation => N__('French: MacCutcheon, Advance Variation'),
			moves => {
				'h7h6' => 1,
			},
		},
		'rnbqk2r/ppp2pp1/4pn1p/3pP1B1/1b1P4/2N5/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'C12d',
			# TRANSLATORS: C12d: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Bb4 5. e5 h6
			variation => N__('French: MacCutcheon, Advance Variation'),
			moves => {
				'e5f6' => 1,
				'g5c1' => 1,
				'g5d2' => 1,
				'g5e3' => 1,
				'g5h4' => 1,
			},
		},
		'rnbqk2r/ppp2pp1/4pP1p/3p2B1/1b1P4/2N5/PPP2PPP/R2QKBNR b KQkq' => {
			eco => 'C12e',
			# TRANSLATORS: C12e: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Bb4 5. e5 h6 6. exf6
			variation => N__('French: MacCutcheon, Chigorin Variation'),
			moves => {
				'h6g5' => 1,
			},
		},
		'rnbqk2r/ppp2pp1/4pP2/3p2p1/1b1P4/2N5/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'C12e',
			# TRANSLATORS: C12e: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Bb4 5. e5 h6 6. exf6 hxg5
			variation => N__('French: MacCutcheon, Chigorin Variation'),
			moves => {
				'f6g7' => 1,
			},
		},
		'rnbqk2r/ppp2pP1/4p3/3p2p1/1b1P4/2N5/PPP2PPP/R2QKBNR b KQkq' => {
			eco => 'C12e',
			# TRANSLATORS: C12e: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Bb4 5. e5 h6 6. exf6 hxg5 7. fxg7
			variation => N__('French: MacCutcheon, Chigorin Variation'),
			moves => {
				'h8g8' => 1,
			},
		},
		'rnbqk1r1/ppp2pP1/4p3/3p2p1/1b1P4/2N5/PPP2PPP/R2QKBNR w KQq' => {
			eco => 'C12e',
			# TRANSLATORS: C12e: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Bb4 5. e5 h6 6. exf6 hxg5 7. fxg7 Rg8
			variation => N__('French: MacCutcheon, Chigorin Variation'),
			moves => {
				'h2h4' => 1,
			},
		},
		'rnbqk1r1/ppp2pP1/4p3/3p2p1/1b1P3P/2N5/PPP2PP1/R2QKBNR b KQq' => {
			eco => 'C12e',
			# TRANSLATORS: C12e: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Bb4 5. e5 h6 6. exf6 hxg5 7. fxg7 Rg8 8. h4
			variation => N__('French: MacCutcheon, Chigorin Variation'),
			moves => {
				'g5h4' => 1,
			},
		},
		'rnbqk1r1/ppp2pP1/4p3/3p4/1b1P3p/2N5/PPP2PP1/R2QKBNR w KQq' => {
			eco => 'C12e',
			# TRANSLATORS: C12e: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Bb4 5. e5 h6 6. exf6 hxg5 7. fxg7 Rg8 8. h4 gxh4
			variation => N__('French: MacCutcheon, Chigorin Variation'),
			moves => {
				'd1g4' => 1,
			},
		},
		'rnbqk1r1/ppp2pP1/4p3/3p4/1b1P2Qp/2N5/PPP2PP1/R3KBNR b KQq' => {
			eco => 'C12e',
			# TRANSLATORS: C12e: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Bb4 5. e5 h6 6. exf6 hxg5 7. fxg7 Rg8 8. h4 gxh4 9. Qg4
			variation => N__('French: MacCutcheon, Grigoriev Variation'),
			moves => {
			},
		},
		'rnbqk2r/ppp2pp1/4pn1p/3pP3/1b1P4/2N5/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'C12f',
			# TRANSLATORS: C12f: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Bb4 5. e5 h6 6. Bc1
			variation => N__('French: MacCutcheon, Olland (Dutch) Variation'),
			moves => {
			},
		},
		'rnbqk2r/ppp2pp1/4pn1p/3pP3/1b1P3B/2N5/PPP2PPP/R2QKBNR b KQkq' => {
			eco => 'C12g',
			# TRANSLATORS: C12g: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Bb4 5. e5 h6 6. Bh4
			variation => N__('French: MacCutcheon, Bernstein Variation'),
			moves => {
			},
		},
		'rnbqk2r/ppp2pp1/4pn1p/3pP3/1b1P4/2N1B3/PPP2PPP/R2QKBNR b KQkq' => {
			eco => 'C12h',
			# TRANSLATORS: C12h: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Bb4 5. e5 h6 6. Be3
			variation => N__('French: MacCutcheon, Janowski Variation'),
			moves => {
			},
		},
		'rnbqk2r/ppp2pp1/4pn1p/3pP3/1b1P4/2N5/PPPB1PPP/R2QKBNR b KQkq' => {
			eco => 'C12i',
			# TRANSLATORS: C12i: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Bb4 5. e5 h6 6. Bd2
			variation => N__('French: MacCutcheon, 6. Bd2'),
			moves => {
				'b4c3' => 1,
				'f6d7' => 1,
			},
		},
		'rnbqk2r/pppn1pp1/4p2p/3pP3/1b1P4/2N5/PPPB1PPP/R2QKBNR w KQkq' => {
			eco => 'C12i',
			# TRANSLATORS: C12i: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Bb4 5. e5 h6 6. Bd2 Nfd7
			variation => N__('French: MacCutcheon, Tartakower Variation'),
			moves => {
			},
		},
		'rnbqk2r/ppp2pp1/4pn1p/3pP3/3P4/2b5/PPPB1PPP/R2QKBNR w KQkq' => {
			eco => 'C12j',
			# TRANSLATORS: C12j: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Bb4 5. e5 h6 6. Bd2 Bxc3
			variation => N__('French: MacCutcheon, Lasker Variation'),
			moves => {
				'b2c3' => 1,
			},
		},
		'rnbqk2r/ppp2pp1/4pn1p/3pP3/3P4/2P5/P1PB1PPP/R2QKBNR b KQkq' => {
			eco => 'C12k',
			# TRANSLATORS: C12k: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Bb4 5. e5 h6 6. Bd2 Bxc3 7. bxc3
			variation => N__('French: MacCutcheon, Lasker, 7.bxc3'),
			moves => {
				'f6e4' => 1,
			},
		},
		'rnbqk2r/ppp2pp1/4p2p/3pP3/3Pn3/2P5/P1PB1PPP/R2QKBNR w KQkq' => {
			eco => 'C12k',
			# TRANSLATORS: C12k: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Bb4 5. e5 h6 6. Bd2 Bxc3 7. bxc3 Ne4
			variation => N__('French: MacCutcheon, Lasker, 7.bxc3'),
			moves => {
				'd1g4' => 1,
			},
		},
		'rnbqk2r/ppp2pp1/4p2p/3pP3/3Pn1Q1/2P5/P1PB1PPP/R3KBNR b KQkq' => {
			eco => 'C12l',
			# TRANSLATORS: C12l: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Bb4 5. e5 h6 6. Bd2 Bxc3 7. bxc3 Ne4 8. Qg4
			variation => N__('French: MacCutcheon, 8. Qg4'),
			moves => {
				'e8f8' => 1,
				'g7g6' => 1,
			},
		},
		'rnbq1k1r/ppp2pp1/4p2p/3pP3/3Pn1Q1/2P5/P1PB1PPP/R3KBNR w KQ' => {
			eco => 'C12l',
			# TRANSLATORS: C12l: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Bb4 5. e5 h6 6. Bd2 Bxc3 7. bxc3 Ne4 8. Qg4 Kf8
			variation => N__('French: MacCutcheon, 8. Qg4 Kf8'),
			moves => {
				'd2c1' => 1,
				'f1d3' => 1,
			},
		},
		'rnbq1k1r/ppp2pp1/4p2p/3pP3/3Pn1Q1/2P5/P1P2PPP/R1B1KBNR b KQ' => {
			eco => 'C12l',
			# TRANSLATORS: C12l: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Bb4 5. e5 h6 6. Bd2 Bxc3 7. bxc3 Ne4 8. Qg4 Kf8 9. Bc1
			variation => N__('French: MacCutcheon, Duras Variation'),
			moves => {
			},
		},
		'rnbq1k1r/ppp2pp1/4p2p/3pP3/3Pn1Q1/2PB4/P1PB1PPP/R3K1NR b KQ' => {
			eco => 'C12m',
			# TRANSLATORS: C12m: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Bb4 5. e5 h6 6. Bd2 Bxc3 7. bxc3 Ne4 8. Qg4 Kf8 9. Bd3
			variation => N__('French: MacCutcheon, 8. Qg4 Kf8 9. Bd3'),
			moves => {
			},
		},
		'rnbqk2r/ppp2p2/4p1pp/3pP3/3Pn1Q1/2P5/P1PB1PPP/R3KBNR w KQkq' => {
			eco => 'C12n',
			# TRANSLATORS: C12n: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Bb4 5. e5 h6 6. Bd2 Bxc3 7. bxc3 Ne4 8. Qg4 g6
			variation => N__('French: MacCutcheon, 8. Qg4 g6'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rnbqk2r/ppp2p2/4p1pp/3pP3/3Pn1Q1/2PB4/P1PB1PPP/R3K1NR b KQkq' => {
			eco => 'C12o',
			# TRANSLATORS: C12o: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Bb4 5. e5 h6 6. Bd2 Bxc3 7. bxc3 Ne4 8. Qg4 g6 9. Bd3
			variation => N__('French: MacCutcheon, 8. Qg4 g6 9. Bd3'),
			moves => {
				'e4d2' => 1,
			},
		},
		'rnbqk2r/ppp2p2/4p1pp/3pP3/3P2Q1/2PB4/P1Pn1PPP/R3K1NR w KQkq' => {
			eco => 'C12o',
			# TRANSLATORS: C12o: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Bb4 5. e5 h6 6. Bd2 Bxc3 7. bxc3 Ne4 8. Qg4 g6 9. Bd3 Nxd2
			variation => N__('French: MacCutcheon, 8. Qg4 g6 9. Bd3'),
			moves => {
				'e1d2' => 1,
			},
		},
		'rnbqk2r/ppp2p2/4p1pp/3pP3/3P2Q1/2PB4/P1PK1PPP/R5NR b kq' => {
			eco => 'C12o',
			# TRANSLATORS: C12o: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Bb4 5. e5 h6 6. Bd2 Bxc3 7. bxc3 Ne4 8. Qg4 g6 9. Bd3 Nxd2 10. Kxd2
			variation => N__('French: MacCutcheon, 8. Qg4 g6 9. Bd3'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqk2r/pp3p2/4p1pp/2ppP3/3P2Q1/2PB4/P1PK1PPP/R5NR w kq' => {
			eco => 'C12p',
			# TRANSLATORS: C12p: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Bb4 5. e5 h6 6. Bd2 Bxc3 7. bxc3 Ne4 8. Qg4 g6 9. Bd3 Nxd2 10. Kxd2 c5
			variation => N__('French: MacCutcheon, Main Line'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqk2r/pp3p2/4p1pp/2ppP3/3P2Q1/2PB1N2/P1PK1PPP/R6R b kq' => {
			eco => 'C12q',
			# TRANSLATORS: C12q: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Bb4 5. e5 h6 6. Bd2 Bxc3 7. bxc3 Ne4 8. Qg4 g6 9. Bd3 Nxd2 10. Kxd2 c5 11. Nf3
			variation => N__('French: MacCutcheon, Main Line, 11. Nf3'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqk2r/pp3p2/2n1p1pp/2ppP3/3P2Q1/2PB1N2/P1PK1PPP/R6R w kq' => {
			eco => 'C12r',
			# TRANSLATORS: C12r: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Bb4 5. e5 h6 6. Bd2 Bxc3 7. bxc3 Ne4 8. Qg4 g6 9. Bd3 Nxd2 10. Kxd2 c5 11. Nf3 Nc6
			variation => N__('French: MacCutcheon, Main Line, 11. Nf3 Nc6'),
			moves => {
			},
		},
		'rnbqk2r/ppp1bppp/4pn2/3p2B1/3PP3/2N5/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'C13a',
			# TRANSLATORS: C13a: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7
			variation => N__('French: Classical'),
			moves => {
				'e4e5' => 1,
				'g5f6' => 1,
			},
		},
		'rnbqk2r/ppp1bppp/4pB2/3p4/3PP3/2N5/PPP2PPP/R2QKBNR b KQkq' => {
			eco => 'C13b',
			# TRANSLATORS: C13b: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. Bxf6
			variation => N__('French: Classical, Anderssen Variation'),
			moves => {
				'e7f6' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/4pb2/3p4/3PP3/2N5/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'C13b',
			# TRANSLATORS: C13b: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. Bxf6 Bxf6
			variation => N__('French: Classical, Anderssen Variation'),
			moves => {
				'e4e5' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/4pb2/3pP3/3P4/2N5/PPP2PPP/R2QKBNR b KQkq' => {
			eco => 'C13b',
			# TRANSLATORS: C13b: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. Bxf6 Bxf6 6. e5
			variation => N__('French: Classical, Anderssen Variation'),
			moves => {
				'f6e7' => 1,
			},
		},
		'rnbqk2r/ppp1bppp/4p3/3pP3/3P4/2N5/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'C13b',
			# TRANSLATORS: C13b: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. Bxf6 Bxf6 6. e5 Be7
			variation => N__('French: Classical, Anderssen Variation'),
			moves => {
				'd1g4' => 1,
			},
		},
		'rnbqk2r/ppp1bppp/4p3/3pP3/3P2Q1/2N5/PPP2PPP/R3KBNR b KQkq' => {
			eco => 'C13c',
			# TRANSLATORS: C13c: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. Bxf6 Bxf6 6. e5 Be7 7. Qg4
			variation => N__('French: Classical, Anderssen-Richter Variation'),
			moves => {
			},
		},
		'rnbqk2r/ppp1bppp/4pn2/3pP1B1/3P4/2N5/PPP2PPP/R2QKBNR b KQkq' => {
			eco => 'C13d',
			# TRANSLATORS: C13d: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5
			variation => N__('French: Classical, 5. e5'),
			moves => {
				'f6d7' => 1,
				'f6e4' => 1,
				'f6g8' => 1,
			},
		},
		'rnbqk1nr/ppp1bppp/4p3/3pP1B1/3P4/2N5/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'C13d',
			# TRANSLATORS: C13d: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Ng8
			variation => N__('French: Classical, Nimzowitsch Variation'),
			moves => {
				'g5e3' => 1,
			},
		},
		'rnbqk1nr/ppp1bppp/4p3/3pP3/3P4/2N1B3/PPP2PPP/R2QKBNR b KQkq' => {
			eco => 'C13d',
			# TRANSLATORS: C13d: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Ng8 6. Be3
			variation => N__('French: Classical, Nimzowitsch Variation'),
			moves => {
				'b7b6' => 1,
			},
		},
		'rnbqk1nr/p1p1bppp/1p2p3/3pP3/3P4/2N1B3/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'C13e',
			# TRANSLATORS: C13e: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Ng8 6. Be3 b6
			variation => N__('French: Classical, Frankfurt Variation'),
			moves => {
			},
		},
		'rnbqk2r/ppp1bppp/4p3/3pP1B1/3Pn3/2N5/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'C13f',
			# TRANSLATORS: C13f: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Ne4
			variation => N__('French: Classical, Tartakower Variation'),
			moves => {
				'g5e7' => 1,
			},
		},
		'rnbqk2r/ppp1Bppp/4p3/3pP3/3Pn3/2N5/PPP2PPP/R2QKBNR b KQkq' => {
			eco => 'C13g',
			# TRANSLATORS: C13g: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Ne4 6. Bxe7
			variation => N__('French: Classical, Tartakower, 6.Bxe7'),
			moves => {
			},
		},
		'rnbqk2r/pppnbppp/4p3/3pP1B1/3P4/2N5/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'C13h',
			# TRANSLATORS: C13h: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7
			variation => N__('French: Classical, 5. e5 Nfd7'),
			moves => {
				'g5e7' => 1,
				'h2h4' => 1,
			},
		},
		'rnbqk2r/pppnBppp/4p3/3pP3/3P4/2N5/PPP2PPP/R2QKBNR b KQkq' => {
			eco => 'C13h',
			# TRANSLATORS: C13h: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. Bxe7
			variation => N__('French: Classical, 5. e5 Nfd7'),
			moves => {
				'd8e7' => 1,
			},
		},
		'rnbqk2r/pppnbppp/4p3/3pP1B1/3P3P/2N5/PPP2PP1/R2QKBNR b KQkq' => {
			eco => 'C13i',
			# TRANSLATORS: C13i: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. h4
			variation => N__('French: Chatard-Alekhine Attack'),
			moves => {
				'a7a6' => 1,
				'c7c5' => 1,
				'e7g5' => 1,
				'e8g8' => 1,
				'f7f6' => 1,
			},
		},
		'rnbqk2r/pppnb1pp/4pp2/3pP1B1/3P3P/2N5/PPP2PP1/R2QKBNR w KQkq' => {
			eco => 'C13j',
			# TRANSLATORS: C13j: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. h4 f6
			variation => N__('French: Chatard-Alekhine, Teichmann Variation'),
			moves => {
			},
		},
		'rnbq1rk1/pppnbppp/4p3/3pP1B1/3P3P/2N5/PPP2PP1/R2QKBNR w KQ' => {
			eco => 'C13k',
			# TRANSLATORS: C13k: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. h4 O-O
			variation => N__('French: Chatard-Alekhine, Spielmann Variation'),
			moves => {
			},
		},
		'rnbqk2r/pppn1ppp/4p3/3pP1b1/3P3P/2N5/PPP2PP1/R2QKBNR w KQkq' => {
			eco => 'C13l',
			# TRANSLATORS: C13l: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. h4 Bxg5
			variation => N__('French: Chatard-Alekhine, 6...Bxg5'),
			moves => {
				'h4g5' => 1,
			},
		},
		'rnbqk2r/pppn1ppp/4p3/3pP1P1/3P4/2N5/PPP2PP1/R2QKBNR b KQkq' => {
			eco => 'C13l',
			# TRANSLATORS: C13l: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. h4 Bxg5 7. hxg5
			variation => N__('French: Chatard-Alekhine, 6...Bxg5'),
			moves => {
				'd8g5' => 1,
			},
		},
		'rnb1k2r/pppn1ppp/4p3/3pP1q1/3P4/2N5/PPP2PP1/R2QKBNR w KQkq' => {
			eco => 'C13l',
			# TRANSLATORS: C13l: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. h4 Bxg5 7. hxg5 Qxg5
			variation => N__('French: Chatard-Alekhine, 6...Bxg5 7.hxg5 Qxg5'),
			moves => {
				'g1h3' => 1,
			},
		},
		'rnb1k2r/pppn1ppp/4p3/3pP1q1/3P4/2N4N/PPP2PP1/R2QKB1R b KQkq' => {
			eco => 'C13l',
			# TRANSLATORS: C13l: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. h4 Bxg5 7. hxg5 Qxg5 8. Nh3
			variation => N__('French: Chatard-Alekhine, 6...Bxg5 7.hxg5 Qxg5'),
			moves => {
				'g5e7' => 1,
			},
		},
		'rnb1k2r/pppnqppp/4p3/3pP3/3P4/2N4N/PPP2PP1/R2QKB1R w KQkq' => {
			eco => 'C13l',
			# TRANSLATORS: C13l: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. h4 Bxg5 7. hxg5 Qxg5 8. Nh3 Qe7
			variation => N__('French: Chatard-Alekhine, 6...Bxg5 7.hxg5 Qxg5'),
			moves => {
				'h3f4' => 1,
			},
		},
		'rnb1k2r/pppnqppp/4p3/3pP3/3P1N2/2N5/PPP2PP1/R2QKB1R b KQkq' => {
			eco => 'C13m',
			# TRANSLATORS: C13m: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. h4 Bxg5 7. hxg5 Qxg5 8. Nh3 Qe7 9. Nf4
			variation => N__('French: Chatard-Alekhine, 6...Bxg5 7.hxg5 Qxg5 8. Nh3 Qe7 9. Nf4'),
			moves => {
			},
		},
		'rnbqk2r/1ppnbppp/p3p3/3pP1B1/3P3P/2N5/PPP2PP1/R2QKBNR w KQkq' => {
			eco => 'C13n',
			# TRANSLATORS: C13n: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. h4 a6
			variation => N__('French: Chatard-Alekhine, Maroczy Variation'),
			moves => {
				'd1g4' => 1,
			},
		},
		'rnbqk2r/1ppnbppp/p3p3/3pP1B1/3P2QP/2N5/PPP2PP1/R3KBNR b KQkq' => {
			eco => 'C13n',
			# TRANSLATORS: C13n: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. h4 a6 7. Qg4
			variation => N__('French: Chatard-Alekhine, Maroczy Variation'),
			moves => {
				'e7g5' => 1,
			},
		},
		'rnbqk2r/1ppn1ppp/p3p3/3pP1b1/3P2QP/2N5/PPP2PP1/R3KBNR w KQkq' => {
			eco => 'C13o',
			# TRANSLATORS: C13o: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. h4 a6 7. Qg4 Bxg5
			variation => N__('French: Chatard-Alekhine, Maroczy, 7. Qg4 Bxg5'),
			moves => {
			},
		},
		'rnbqk2r/pp1nbppp/4p3/2ppP1B1/3P3P/2N5/PPP2PP1/R2QKBNR w KQkq' => {
			eco => 'C13p',
			# TRANSLATORS: C13p: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. h4 c5
			variation => N__('French: Chatard-Alekhine, Breyer Variation'),
			moves => {
				'g5e7' => 1,
			},
		},
		'rnbqk2r/pp1nBppp/4p3/2ppP3/3P3P/2N5/PPP2PP1/R2QKBNR b KQkq' => {
			eco => 'C13q',
			# TRANSLATORS: C13q: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. h4 c5 7. Bxe7
			variation => N__('French: Chatard-Alekhine, Breyer, 7.Bxe7'),
			moves => {
				'e8e7' => 1,
			},
		},
		'rnbq3r/pp1nkppp/4p3/2ppP3/3P3P/2N5/PPP2PP1/R2QKBNR w KQ' => {
			eco => 'C13r',
			# TRANSLATORS: C13r: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. h4 c5 7. Bxe7 Kxe7
			variation => N__('French: Chatard-Alekhine, Breyer, 7.Bxe7 Kxe7'),
			moves => {
			},
		},
		'rnb1k2r/pppnqppp/4p3/3pP3/3P4/2N5/PPP2PPP/R2QKBNR w KQkq' => {
			eco => 'C14a',
			# TRANSLATORS: C14a: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. Bxe7 Qxe7
			variation => N__('French: Classical, 6.Bxe7 Qxe7'),
			moves => {
				'c3b5' => 1,
				'd1d2' => 1,
				'd1g4' => 1,
				'f1d3' => 1,
				'f2f4' => 1,
			},
		},
		'rnb1k2r/pppnqppp/4p3/3pP3/3P2Q1/2N5/PPP2PPP/R3KBNR b KQkq' => {
			eco => 'C14b',
			# TRANSLATORS: C14b: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. Bxe7 Qxe7 7. Qg4
			variation => N__('French: Classical, Pollock Variation'),
			moves => {
			},
		},
		'rnb1k2r/pppnqppp/4p3/3pP3/3P4/2NB4/PPP2PPP/R2QK1NR b KQkq' => {
			eco => 'C14c',
			# TRANSLATORS: C14c: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. Bxe7 Qxe7 7. Bd3
			variation => N__('French: Classical, Tarrasch Variation'),
			moves => {
			},
		},
		'rnb1k2r/pppnqppp/4p3/1N1pP3/3P4/8/PPP2PPP/R2QKBNR b KQkq' => {
			eco => 'C14d',
			# TRANSLATORS: C14d: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. Bxe7 Qxe7 7. Nb5
			variation => N__('French: Classical, Alapin Variation'),
			moves => {
			},
		},
		'rnb1k2r/pppnqppp/4p3/3pP3/3P4/2N5/PPPQ1PPP/R3KBNR b KQkq' => {
			eco => 'C14e',
			# TRANSLATORS: C14e: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. Bxe7 Qxe7 7. Qd2
			variation => N__('French: Classical, Rubinstein Variation'),
			moves => {
			},
		},
		'rnb1k2r/pppnqppp/4p3/3pP3/3P1P2/2N5/PPP3PP/R2QKBNR b KQkq' => {
			eco => 'C14f',
			# TRANSLATORS: C14f: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. Bxe7 Qxe7 7. f4
			variation => N__('French: Classical, Steinitz Variation'),
			moves => {
				'a7a6' => 1,
				'e8g8' => 1,
			},
		},
		'rnb1k2r/1ppnqppp/p3p3/3pP3/3P1P2/2N5/PPP3PP/R2QKBNR w KQkq' => {
			eco => 'C14g',
			# TRANSLATORS: C14g: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. Bxe7 Qxe7 7. f4 a6
			variation => N__('French: Classical, Steinitz, 7... a6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnb1k2r/1ppnqppp/p3p3/3pP3/3P1P2/2N2N2/PPP3PP/R2QKB1R b KQkq' => {
			eco => 'C14g',
			# TRANSLATORS: C14g: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. Bxe7 Qxe7 7. f4 a6 8. Nf3
			variation => N__('French: Classical, Steinitz, 7... a6'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnb1k2r/1p1nqppp/p3p3/2ppP3/3P1P2/2N2N2/PPP3PP/R2QKB1R w KQkq' => {
			eco => 'C14h',
			# TRANSLATORS: C14h: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. Bxe7 Qxe7 7. f4 a6 8. Nf3 c5
			variation => N__('French: Classical, Steinitz, 7... a6 8. Nf3 c5'),
			moves => {
				'd4c5' => 1,
			},
		},
		'rnb1k2r/1p1nqppp/p3p3/2PpP3/5P2/2N2N2/PPP3PP/R2QKB1R b KQkq' => {
			eco => 'C14i',
			# TRANSLATORS: C14i: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. Bxe7 Qxe7 7. f4 a6 8. Nf3 c5 9. dxc5
			variation => N__('French: Classical, Steinitz, 7... a6 8. Nf3 c5'),
			moves => {
			},
		},
		'rnb2rk1/pppnqppp/4p3/3pP3/3P1P2/2N5/PPP3PP/R2QKBNR w KQ' => {
			eco => 'C14j',
			# TRANSLATORS: C14j: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. Bxe7 Qxe7 7. f4 O-O
			variation => N__('French: Classical, Steinitz, 7...O-O'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnb2rk1/pppnqppp/4p3/3pP3/3P1P2/2N2N2/PPP3PP/R2QKB1R b KQ' => {
			eco => 'C14j',
			# TRANSLATORS: C14j: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. Bxe7 Qxe7 7. f4 O-O 8. Nf3
			variation => N__('French: Classical, Steinitz, 7...O-O'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnb2rk1/pp1nqppp/4p3/2ppP3/3P1P2/2N2N2/PPP3PP/R2QKB1R w KQ' => {
			eco => 'C14k',
			# TRANSLATORS: C14k: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. Bxe7 Qxe7 7. f4 O-O 8. Nf3 c5
			variation => N__('French: Classical, Steinitz, 7...O-O 8. Nf3 c5'),
			moves => {
				'd1d2' => 1,
				'd4c5' => 1,
			},
		},
		'rnb2rk1/pp1nqppp/4p3/2PpP3/5P2/2N2N2/PPP3PP/R2QKB1R b KQ' => {
			eco => 'C14l',
			# TRANSLATORS: C14l: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. Bxe7 Qxe7 7. f4 O-O 8. Nf3 c5 9. dxc5
			variation => N__('French: Classical, Steinitz, 8. Nf3 c5 9.dxc5'),
			moves => {
			},
		},
		'rnb2rk1/pp1nqppp/4p3/2ppP3/3P1P2/2N2N2/PPPQ2PP/R3KB1R b KQ' => {
			eco => 'C14m',
			# TRANSLATORS: C14m: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. Bxe7 Qxe7 7. f4 O-O 8. Nf3 c5 9. Qd2
			variation => N__('French: Classical, Steinitz, 9. Qd2'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1b2rk1/pp1nqppp/2n1p3/2ppP3/3P1P2/2N2N2/PPPQ2PP/R3KB1R w KQ' => {
			eco => 'C14m',
			# TRANSLATORS: C14m: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. Bxe7 Qxe7 7. f4 O-O 8. Nf3 c5 9. Qd2 Nc6
			variation => N__('French: Classical, Steinitz, 9. Qd2'),
			moves => {
				'd4c5' => 1,
				'e1c1' => 1,
			},
		},
		'r1b2rk1/pp1nqppp/2n1p3/2ppP3/3P1P2/2N2N2/PPPQ2PP/2KR1B1R b -' => {
			eco => 'C14m',
			# TRANSLATORS: C14m: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. Bxe7 Qxe7 7. f4 O-O 8. Nf3 c5 9. Qd2 Nc6 10. O-O-O
			variation => N__('French: Classical, Steinitz, 9. Qd2'),
			moves => {
				'c5c4' => 1,
			},
		},
		'r1b2rk1/pp1nqppp/2n1p3/3pP3/2pP1P2/2N2N2/PPPQ2PP/2KR1B1R w -' => {
			eco => 'C14m',
			# TRANSLATORS: C14m: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. Bxe7 Qxe7 7. f4 O-O 8. Nf3 c5 9. Qd2 Nc6 10. O-O-O c4
			variation => N__('French: Classical, Stahlberg Variation'),
			moves => {
			},
		},
		'r1b2rk1/pp1nqppp/2n1p3/2PpP3/5P2/2N2N2/PPPQ2PP/R3KB1R b KQ' => {
			eco => 'C14n',
			# TRANSLATORS: C14n: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. Bxe7 Qxe7 7. f4 O-O 8. Nf3 c5 9. Qd2 Nc6 10. dxc5
			variation => N__('French: Classical, Steinitz, 9. Qd2 Nc6 10.dxc5'),
			moves => {
				'e7c5' => 1,
			},
		},
		'r1b2rk1/pp1n1ppp/2n1p3/2qpP3/5P2/2N2N2/PPPQ2PP/R3KB1R w KQ' => {
			eco => 'C14o',
			# TRANSLATORS: C14o: 1. e4 e6 2. d4 d5 3. Nc3 Nf6 4. Bg5 Be7 5. e5 Nfd7 6. Bxe7 Qxe7 7. f4 O-O 8. Nf3 c5 9. Qd2 Nc6 10. dxc5 Qxc5
			variation => N__('French: Classical, Steinitz, 9. Qd2 Nc6 10.dxc5 Qxc5'),
			moves => {
			},
		},
		'rnbqk1nr/ppp2ppp/4p3/3p4/1b1PP3/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'C15a',
			# TRANSLATORS: C15a: 1. e4 e6 2. d4 d5 3. Nc3 Bb4
			variation => N__('French: Winawer'),
			moves => {
				'a2a3' => 1,
				'c1d2' => 1,
				'd1d3' => 1,
				'd1g4' => 1,
				'e4d5' => 1,
				'e4e5' => 1,
				'f1d3' => 1,
				'g1e2' => 1,
			},
		},
		'rnbqk1nr/ppp2ppp/4p3/3P4/1b1P4/2N5/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'C15b',
			# TRANSLATORS: C15b: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. exd5
			variation => N__('French: Winawer, 4.exd5'),
			moves => {
				'd8d5' => 1,
			},
		},
		'rnb1k1nr/ppp2ppp/4p3/3q4/1b1P4/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'C15b',
			# TRANSLATORS: C15b: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. exd5 Qxd5
			variation => N__('French: Winawer, 4.exd5 Qxd5'),
			moves => {
			},
		},
		'rnbqk1nr/ppp2ppp/4p3/3p4/1b1PP1Q1/2N5/PPP2PPP/R1B1KBNR b KQkq' => {
			eco => 'C15c',
			# TRANSLATORS: C15c: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. Qg4
			variation => N__('French: Winawer, 4. Qg4'),
			moves => {
			},
		},
		'rnbqk1nr/ppp2ppp/4p3/3p4/1b1PP3/2NQ4/PPP2PPP/R1B1KBNR b KQkq' => {
			eco => 'C15d',
			# TRANSLATORS: C15d: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. Qd3
			variation => N__('French: Winawer, 4. Qd3'),
			moves => {
				'd5e4' => 1,
			},
		},
		'rnbqk1nr/ppp2ppp/4p3/8/1b1Pp3/2NQ4/PPP2PPP/R1B1KBNR w KQkq' => {
			eco => 'C15d',
			# TRANSLATORS: C15d: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. Qd3 dxe4
			variation => N__('French: Winawer, 4. Qd3 dxe4'),
			moves => {
			},
		},
		'rnbqk1nr/ppp2ppp/4p3/3p4/1b1PP3/2NB4/PPP2PPP/R1BQK1NR b KQkq' => {
			eco => 'C15e',
			# TRANSLATORS: C15e: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. Bd3
			variation => N__('French: Winawer, 4. Bd3'),
			moves => {
				'c7c5' => 1,
				'd5e4' => 1,
			},
		},
		'rnbqk1nr/pp3ppp/4p3/2pp4/1b1PP3/2NB4/PPP2PPP/R1BQK1NR w KQkq' => {
			eco => 'C15f',
			# TRANSLATORS: C15f: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. Bd3 c5
			variation => N__('French: Winawer, 4. Bd3 c5'),
			moves => {
				'e4d5' => 1,
			},
		},
		'rnbqk1nr/pp3ppp/4p3/2pP4/1b1P4/2NB4/PPP2PPP/R1BQK1NR b KQkq' => {
			eco => 'C15f',
			# TRANSLATORS: C15f: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. Bd3 c5 5. exd5
			variation => N__('French: Winawer, 4. Bd3 c5'),
			moves => {
				'd8d5' => 1,
			},
		},
		'rnb1k1nr/pp3ppp/4p3/2pq4/1b1P4/2NB4/PPP2PPP/R1BQK1NR w KQkq' => {
			eco => 'C15f',
			# TRANSLATORS: C15f: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. Bd3 c5 5. exd5 Qxd5
			variation => N__('French: Winawer, 4. Bd3 c5'),
			moves => {
				'c1d2' => 1,
			},
		},
		'rnb1k1nr/pp3ppp/4p3/2pq4/1b1P4/2NB4/PPPB1PPP/R2QK1NR b KQkq' => {
			eco => 'C15f',
			# TRANSLATORS: C15f: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. Bd3 c5 5. exd5 Qxd5 6. Bd2
			variation => N__('French: Winawer, Kondratiyev Variation'),
			moves => {
			},
		},
		'rnbqk1nr/ppp2ppp/4p3/8/1b1Pp3/2NB4/PPP2PPP/R1BQK1NR w KQkq' => {
			eco => 'C15g',
			# TRANSLATORS: C15g: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. Bd3 dxe4
			variation => N__('French: Winawer, 4. Bd3 dxe4'),
			moves => {
				'd3e4' => 1,
			},
		},
		'rnbqk1nr/ppp2ppp/4p3/8/1b1PB3/2N5/PPP2PPP/R1BQK1NR b KQkq' => {
			eco => 'C15g',
			# TRANSLATORS: C15g: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. Bd3 dxe4 5. Bxe4
			variation => N__('French: Winawer, 4. Bd3 dxe4 5.Bxe4'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/4pn2/8/1b1PB3/2N5/PPP2PPP/R1BQK1NR w KQkq' => {
			eco => 'C15g',
			# TRANSLATORS: C15g: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. Bd3 dxe4 5. Bxe4 Nf6
			variation => N__('French: Winawer, 4. Bd3 dxe4 5.Bxe4 Nf6'),
			moves => {
			},
		},
		'rnbqk1nr/ppp2ppp/4p3/3p4/1b1PP3/2N5/PPPB1PPP/R2QKBNR b KQkq' => {
			eco => 'C15h',
			# TRANSLATORS: C15h: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. Bd2
			variation => N__('French: Winawer, Müller-Zhuravlev Gambit'),
			moves => {
				'd5e4' => 1,
			},
		},
		'rnbqk1nr/ppp2ppp/4p3/8/1b1Pp3/2N5/PPPB1PPP/R2QKBNR w KQkq' => {
			eco => 'C15h',
			# TRANSLATORS: C15h: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. Bd2 dxe4
			variation => N__('French: Winawer, Müller-Zhuravlev Gambit'),
			moves => {
				'd1g4' => 1,
			},
		},
		'rnbqk1nr/ppp2ppp/4p3/8/1b1Pp1Q1/2N5/PPPB1PPP/R3KBNR b KQkq' => {
			eco => 'C15i',
			# TRANSLATORS: C15i: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. Bd2 dxe4 5. Qg4
			variation => N__('French: Winawer, Müller-Zhuravlev Gambit, 5. Qg4'),
			moves => {
				'd8d4' => 1,
				'g8f6' => 1,
			},
		},
		'rnb1k1nr/ppp2ppp/4p3/8/1b1qp1Q1/2N5/PPPB1PPP/R3KBNR w KQkq' => {
			eco => 'C15i',
			# TRANSLATORS: C15i: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. Bd2 dxe4 5. Qg4 Qxd4
			variation => N__('French: Winawer, Müller-Zhuravlev Gambit, Kunin Variation'),
			moves => {
			},
		},
		'rnbqk2r/ppp2ppp/4pn2/8/1b1Pp1Q1/2N5/PPPB1PPP/R3KBNR w KQkq' => {
			eco => 'C15j',
			# TRANSLATORS: C15j: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. Bd2 dxe4 5. Qg4 Nf6
			variation => N__('French: Winawer, Müller-Zhuravlev Gambit, 5. Qg4 Nf6'),
			moves => {
			},
		},
		'rnbqk1nr/ppp2ppp/4p3/3p4/1b1PP3/P1N5/1PP2PPP/R1BQKBNR b KQkq' => {
			eco => 'C15k',
			# TRANSLATORS: C15k: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. a3
			variation => N__('French: Winawer, 4. a3'),
			moves => {
				'b4c3' => 1,
			},
		},
		'rnbqk1nr/ppp2ppp/4p3/3p4/3PP3/P1b5/1PP2PPP/R1BQKBNR w KQkq' => {
			eco => 'C15k',
			# TRANSLATORS: C15k: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. a3 Bxc3+
			variation => N__('French: Winawer, 4. a3 Bxc3+'),
			moves => {
				'b2c3' => 1,
			},
		},
		'rnbqk1nr/ppp2ppp/4p3/3p4/3PP3/P1P5/2P2PPP/R1BQKBNR b KQkq' => {
			eco => 'C15k',
			# TRANSLATORS: C15k: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3
			variation => N__('French: Winawer, 4. a3 Bxc3+'),
			moves => {
				'd5e4' => 1,
			},
		},
		'rnbqk1nr/ppp2ppp/4p3/8/3Pp3/P1P5/2P2PPP/R1BQKBNR w KQkq' => {
			eco => 'C15k',
			# TRANSLATORS: C15k: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 dxe4
			variation => N__('French: Winawer, 4. a3 Bxc3+ 5.bxc3 dxe4'),
			moves => {
				'd1g4' => 1,
				'f2f3' => 1,
			},
		},
		'rnbqk1nr/ppp2ppp/4p3/8/3Pp3/P1P2P2/2P3PP/R1BQKBNR b KQkq' => {
			eco => 'C15l',
			# TRANSLATORS: C15l: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 dxe4 6. f3
			variation => N__('French: Winawer, Winkelmann-Reimer Gambit (WRG)'),
			moves => {
				'c7c5' => 1,
				'e4f3' => 1,
				'e6e5' => 1,
			},
		},
		'rnbqk1nr/pp3ppp/4p3/2p5/3Pp3/P1P2P2/2P3PP/R1BQKBNR w KQkq' => {
			eco => 'C15l',
			# TRANSLATORS: C15l: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 dxe4 6. f3 c5
			variation => N__('French: Winawer, Winkelmann-Reimer, 6... c5'),
			moves => {
			},
		},
		'rnbqk1nr/ppp2ppp/4p3/8/3P4/P1P2p2/2P3PP/R1BQKBNR w KQkq' => {
			eco => 'C15l',
			# TRANSLATORS: C15l: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 dxe4 6. f3 exf3
			variation => N__('French: Winawer, Winkelmann-Reimer Gambit Accepted'),
			moves => {
			},
		},
		'rnbqk1nr/ppp2ppp/8/4p3/3Pp3/P1P2P2/2P3PP/R1BQKBNR w KQkq' => {
			eco => 'C15l',
			# TRANSLATORS: C15l: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 dxe4 6. f3 e5
			variation => N__('French: Winawer, Winkelmann-Reimer, Hübner Defence'),
			moves => {
			},
		},
		'rnbqk1nr/ppp2ppp/4p3/8/3Pp1Q1/P1P5/2P2PPP/R1B1KBNR b KQkq' => {
			eco => 'C15m',
			# TRANSLATORS: C15m: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 dxe4 6. Qg4
			variation => N__('French: Winawer, 4. a3 Bxc3+ 5.bxc3 dxe4 6. Qg4'),
			moves => {
			},
		},
		'rnbqk1nr/ppp2ppp/4p3/3p4/1b1PP3/2N5/PPP1NPPP/R1BQKB1R b KQkq' => {
			eco => 'C15n',
			# TRANSLATORS: C15n: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. Ne2
			variation => N__('French: Winawer, Alekhine Gambit'),
			moves => {
				'b8c6' => 1,
				'd5e4' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/4pn2/3p4/1b1PP3/2N5/PPP1NPPP/R1BQKB1R w KQkq' => {
			eco => 'C15o',
			# TRANSLATORS: C15o: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. Ne2 Nf6
			variation => N__('French: Winawer, Alekhine Gambit, 4... Nf6'),
			moves => {
			},
		},
		'r1bqk1nr/ppp2ppp/2n1p3/3p4/1b1PP3/2N5/PPP1NPPP/R1BQKB1R w KQkq' => {
			eco => 'C15p',
			# TRANSLATORS: C15p: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. Ne2 Nc6
			variation => N__('French: Winawer, Alekhine Gambit, 4... Nc6'),
			moves => {
			},
		},
		'rnbqk1nr/ppp2ppp/4p3/8/1b1Pp3/2N5/PPP1NPPP/R1BQKB1R w KQkq' => {
			eco => 'C15q',
			# TRANSLATORS: C15q: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. Ne2 dxe4
			variation => N__('French: Winawer, Alekhine Gambit Accepted'),
			moves => {
				'a2a3' => 1,
			},
		},
		'rnbqk1nr/ppp2ppp/4p3/8/1b1Pp3/P1N5/1PP1NPPP/R1BQKB1R b KQkq' => {
			eco => 'C15q',
			# TRANSLATORS: C15q: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. Ne2 dxe4 5. a3
			variation => N__('French: Winawer, Alekhine Gambit Accepted'),
			moves => {
				'b4c3' => 1,
				'b4e7' => 1,
			},
		},
		'rnbqk1nr/ppp2ppp/4p3/8/3Pp3/P1b5/1PP1NPPP/R1BQKB1R w KQkq' => {
			eco => 'C15q',
			# TRANSLATORS: C15q: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. Ne2 dxe4 5. a3 Bxc3+
			variation => N__('French: Winawer, Alekhine Gambit, 5. a3 Bxc3+'),
			moves => {
				'e2c3' => 1,
			},
		},
		'rnbqk1nr/ppp2ppp/4p3/8/3Pp3/P1N5/1PP2PPP/R1BQKB1R b KQkq' => {
			eco => 'C15q',
			# TRANSLATORS: C15q: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. Ne2 dxe4 5. a3 Bxc3+ 6. Nxc3
			variation => N__('French: Winawer, Alekhine Gambit, 5. a3 Bxc3+'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqk1nr/ppp2ppp/2n1p3/8/3Pp3/P1N5/1PP2PPP/R1BQKB1R w KQkq' => {
			eco => 'C15r',
			# TRANSLATORS: C15r: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. Ne2 dxe4 5. a3 Bxc3+ 6. Nxc3 Nc6
			variation => N__('French: Winawer, Alekhine Gambit, Kan Variation'),
			moves => {
				'f1b5' => 1,
			},
		},
		'r1bqk1nr/ppp2ppp/2n1p3/1B6/3Pp3/P1N5/1PP2PPP/R1BQK2R b KQkq' => {
			eco => 'C15s',
			# TRANSLATORS: C15s: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. Ne2 dxe4 5. a3 Bxc3+ 6. Nxc3 Nc6 7. Bb5
			variation => N__('French: Winawer, Alekhine Gambit, Kan, 7. Bb5'),
			moves => {
			},
		},
		'rnbqk1nr/ppp1bppp/4p3/8/3Pp3/P1N5/1PP1NPPP/R1BQKB1R w KQkq' => {
			eco => 'C15t',
			# TRANSLATORS: C15t: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. Ne2 dxe4 5. a3 Be7
			variation => N__('French: Winawer, Alekhine Gambit, 5. a3 Be7'),
			moves => {
				'c3e4' => 1,
			},
		},
		'rnbqk1nr/ppp1bppp/4p3/8/3PN3/P7/1PP1NPPP/R1BQKB1R b KQkq' => {
			eco => 'C15t',
			# TRANSLATORS: C15t: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. Ne2 dxe4 5. a3 Be7 6. Nxe4
			variation => N__('French: Winawer, Alekhine Gambit, 5. a3 Be7'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqk2r/ppp1bppp/4pn2/8/3PN3/P7/1PP1NPPP/R1BQKB1R w KQkq' => {
			eco => 'C15u',
			# TRANSLATORS: C15u: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. Ne2 dxe4 5. a3 Be7 6. Nxe4 Nf6
			variation => N__('French: Winawer, Alekhine Gambit, 5. a3 Be7 6.Nxe4 Nf6'),
			moves => {
				'd1d3' => 1,
				'e2g3' => 1,
			},
		},
		'rnbqk2r/ppp1bppp/4pn2/8/3PN3/P5N1/1PP2PPP/R1BQKB1R b KQkq' => {
			eco => 'C15u',
			# TRANSLATORS: C15u: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. Ne2 dxe4 5. a3 Be7 6. Nxe4 Nf6 7. N2g3
			variation => N__('French: Winawer, Alekhine Gambit, 5. a3 Be7 6.Nxe4 Nf6'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppp1bppp/4pn2/8/3PN3/P5N1/1PP2PPP/R1BQKB1R w KQ' => {
			eco => 'C15u',
			# TRANSLATORS: C15u: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. Ne2 dxe4 5. a3 Be7 6. Nxe4 Nf6 7. N2g3 O-O
			variation => N__('French: Winawer, Alekhine Gambit, 5. a3 Be7 6.Nxe4 Nf6'),
			moves => {
				'f1e2' => 1,
			},
		},
		'rnbq1rk1/ppp1bppp/4pn2/8/3PN3/P5N1/1PP1BPPP/R1BQK2R b KQ' => {
			eco => 'C15u',
			# TRANSLATORS: C15u: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. Ne2 dxe4 5. a3 Be7 6. Nxe4 Nf6 7. N2g3 O-O 8. Be2
			variation => N__('French: Winawer, Alekhine Gambit, 5. a3 Be7 6.Nxe4 Nf6'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bq1rk1/ppp1bppp/2n1pn2/8/3PN3/P5N1/1PP1BPPP/R1BQK2R w KQ' => {
			eco => 'C15u',
			# TRANSLATORS: C15u: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. Ne2 dxe4 5. a3 Be7 6. Nxe4 Nf6 7. N2g3 O-O 8. Be2 Nc6
			variation => N__('French: Winawer, Alekhine Gambit, Alatortsev Variation'),
			moves => {
			},
		},
		'rnbqk2r/ppp1bppp/4pn2/8/3PN3/P2Q4/1PP1NPPP/R1B1KB1R b KQkq' => {
			eco => 'C15v',
			# TRANSLATORS: C15v: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. Ne2 dxe4 5. a3 Be7 6. Nxe4 Nf6 7. Qd3
			variation => N__('French: Winawer, Alekhine Gambit, 5. a3 Be7 6.Nxe4 Nf6 7. Qd3'),
			moves => {
			},
		},
		'rnbqk1nr/ppp2ppp/4p3/3pP3/1b1P4/2N5/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'C16a',
			# TRANSLATORS: C16a: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5
			variation => N__('French: Winawer, Advance Variation'),
			moves => {
				'b7b6' => 1,
				'c7c5' => 1,
				'd8d7' => 1,
				'g8e7' => 1,
			},
		},
		'rnbqk1nr/p1p2ppp/1p2p3/3pP3/1b1P4/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'C16b',
			# TRANSLATORS: C16b: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 b6
			variation => N__('French: Winawer, 4. e5 b6'),
			moves => {
				'a2a3' => 1,
				'd1g4' => 1,
			},
		},
		'rnbqk1nr/p1p2ppp/1p2p3/3pP3/1b1P2Q1/2N5/PPP2PPP/R1B1KBNR b KQkq' => {
			eco => 'C16c',
			# TRANSLATORS: C16c: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 b6 5. Qg4
			variation => N__('French: Winawer, 4. e5 b6 5. Qg4'),
			moves => {
				'b4f8' => 1,
			},
		},
		'rnbqkbnr/p1p2ppp/1p2p3/3pP3/3P2Q1/2N5/PPP2PPP/R1B1KBNR w KQkq' => {
			eco => 'C16c',
			# TRANSLATORS: C16c: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 b6 5. Qg4 Bf8
			variation => N__('French: Winawer, 4. e5 b6 5. Qg4'),
			moves => {
				'c1g5' => 1,
			},
		},
		'rnbqkbnr/p1p2ppp/1p2p3/3pP1B1/3P2Q1/2N5/PPP2PPP/R3KBNR b KQkq' => {
			eco => 'C16d',
			# TRANSLATORS: C16d: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 b6 5. Qg4 Bf8 6. Bg5
			variation => N__('French: Winawer, 4. e5 b6 5. Qg4 Bf8 6. Bg5'),
			moves => {
			},
		},
		'rnbqk1nr/p1p2ppp/1p2p3/3pP3/1b1P4/P1N5/1PP2PPP/R1BQKBNR b KQkq' => {
			eco => 'C16e',
			# TRANSLATORS: C16e: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 b6 5. a3
			variation => N__('French: Winawer, 4. e5 b6 5. a3'),
			moves => {
				'b4f8' => 1,
			},
		},
		'rnbqkbnr/p1p2ppp/1p2p3/3pP3/3P4/P1N5/1PP2PPP/R1BQKBNR w KQkq' => {
			eco => 'C16e',
			# TRANSLATORS: C16e: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 b6 5. a3 Bf8
			variation => N__('French: Winawer, 4. e5 b6 5. a3 Bf8'),
			moves => {
			},
		},
		'rnb1k1nr/pppq1ppp/4p3/3pP3/1b1P4/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'C16f',
			# TRANSLATORS: C16f: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 Qd7
			variation => N__('French: Winawer, Petrosian Variation'),
			moves => {
				'a2a3' => 1,
				'c1d2' => 1,
			},
		},
		'rnb1k1nr/pppq1ppp/4p3/3pP3/1b1P4/2N5/PPPB1PPP/R2QKBNR b KQkq' => {
			eco => 'C16g',
			# TRANSLATORS: C16g: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 Qd7 5. Bd2
			variation => N__('French: Winawer, Petrosian, 5. Bd2'),
			moves => {
			},
		},
		'rnb1k1nr/pppq1ppp/4p3/3pP3/1b1P4/P1N5/1PP2PPP/R1BQKBNR b KQkq' => {
			eco => 'C16h',
			# TRANSLATORS: C16h: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 Qd7 5. a3
			variation => N__('French: Winawer, Petrosian, 5. a3'),
			moves => {
				'b4c3' => 1,
			},
		},
		'rnb1k1nr/pppq1ppp/4p3/3pP3/3P4/P1b5/1PP2PPP/R1BQKBNR w KQkq' => {
			eco => 'C16h',
			# TRANSLATORS: C16h: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 Qd7 5. a3 Bxc3+
			variation => N__('French: Winawer, Petrosian, 5. a3'),
			moves => {
				'b2c3' => 1,
			},
		},
		'rnb1k1nr/pppq1ppp/4p3/3pP3/3P4/P1P5/2P2PPP/R1BQKBNR b KQkq' => {
			eco => 'C16h',
			# TRANSLATORS: C16h: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 Qd7 5. a3 Bxc3+ 6. bxc3
			variation => N__('French: Winawer, Petrosian, 5. a3'),
			moves => {
				'b7b6' => 1,
			},
		},
		'rnb1k1nr/p1pq1ppp/1p2p3/3pP3/3P4/P1P5/2P2PPP/R1BQKBNR w KQkq' => {
			eco => 'C16i',
			# TRANSLATORS: C16i: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 Qd7 5. a3 Bxc3+ 6. bxc3 b6
			variation => N__('French: Winawer, Petrosian, 5. a3 Bxc3+ 6.bxc3 b6'),
			moves => {
				'd1g4' => 1,
			},
		},
		'rnb1k1nr/p1pq1ppp/1p2p3/3pP3/3P2Q1/P1P5/2P2PPP/R1B1KBNR b KQkq' => {
			eco => 'C16i',
			# TRANSLATORS: C16i: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 Qd7 5. a3 Bxc3+ 6. bxc3 b6 7. Qg4
			variation => N__('French: Winawer, Petrosian, 5. a3 Bxc3+ 6.bxc3 b6 7. Qg4'),
			moves => {
			},
		},
		'rnbqk2r/ppp1nppp/4p3/3pP3/1b1P4/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'C16j',
			# TRANSLATORS: C16j: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 Ne7
			variation => N__('French: Winawer, Advance, 4... Ne7'),
			moves => {
				'a2a3' => 1,
				'c1d2' => 1,
			},
		},
		'rnbqk2r/ppp1nppp/4p3/3pP3/1b1P4/2N5/PPPB1PPP/R2QKBNR b KQkq' => {
			eco => 'C16k',
			# TRANSLATORS: C16k: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 Ne7 5. Bd2
			variation => N__('French: Winawer, Advance, 4... Ne7 5. Bd2'),
			moves => {
				'b7b6' => 1,
			},
		},
		'rnbqk2r/p1p1nppp/1p2p3/3pP3/1b1P4/2N5/PPPB1PPP/R2QKBNR w KQkq' => {
			eco => 'C16l',
			# TRANSLATORS: C16l: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 Ne7 5. Bd2 b6
			variation => N__('French: Winawer, Advance, 4... Ne7 5. Bd2 b6'),
			moves => {
			},
		},
		'rnbqk2r/ppp1nppp/4p3/3pP3/1b1P4/P1N5/1PP2PPP/R1BQKBNR b KQkq' => {
			eco => 'C16m',
			# TRANSLATORS: C16m: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 Ne7 5. a3
			variation => N__('French: Winawer, Advance, 4... Ne7 5. a3'),
			moves => {
				'b4c3' => 1,
			},
		},
		'rnbqk2r/ppp1nppp/4p3/3pP3/3P4/P1b5/1PP2PPP/R1BQKBNR w KQkq' => {
			eco => 'C16m',
			# TRANSLATORS: C16m: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 Ne7 5. a3 Bxc3+
			variation => N__('French: Winawer, Advance, 4... Ne7 5. a3'),
			moves => {
				'b2c3' => 1,
			},
		},
		'rnbqk2r/ppp1nppp/4p3/3pP3/3P4/P1P5/2P2PPP/R1BQKBNR b KQkq' => {
			eco => 'C16m',
			# TRANSLATORS: C16m: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 Ne7 5. a3 Bxc3+ 6. bxc3
			variation => N__('French: Winawer, Advance, 4... Ne7 5. a3'),
			moves => {
				'b7b6' => 1,
			},
		},
		'rnbqk2r/p1p1nppp/1p2p3/3pP3/3P4/P1P5/2P2PPP/R1BQKBNR w KQkq' => {
			eco => 'C16n',
			# TRANSLATORS: C16n: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 Ne7 5. a3 Bxc3+ 6. bxc3 b6
			variation => N__('French: Winawer, Advance, 4... Ne7 5. a3 Bxc3+ 6.bxc3 b6'),
			moves => {
				'd1g4' => 1,
			},
		},
		'rnbqk2r/p1p1nppp/1p2p3/3pP3/3P2Q1/P1P5/2P2PPP/R1B1KBNR b KQkq' => {
			eco => 'C16o',
			# TRANSLATORS: C16o: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 Ne7 5. a3 Bxc3+ 6. bxc3 b6 7. Qg4
			variation => N__('French: Winawer, Advance, 4... Ne7 5. a3 Bxc3+ 6.bxc3 b6 7. Qg4'),
			moves => {
			},
		},
		'rnbqk1nr/pp3ppp/4p3/2ppP3/1b1P4/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'C17a',
			# TRANSLATORS: C17a: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5
			variation => N__('French: Winawer, Advance, 4... c5'),
			moves => {
				'a2a3' => 1,
				'c1d2' => 1,
				'd1g4' => 1,
				'd4c5' => 1,
			},
		},
		'rnbqk1nr/pp3ppp/4p3/2PpP3/1b6/2N5/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'C17b',
			# TRANSLATORS: C17b: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. dxc5
			variation => N__('French: Winawer, Advance, 5.dxc5'),
			moves => {
			},
		},
		'rnbqk1nr/pp3ppp/4p3/2ppP3/1b1P2Q1/2N5/PPP2PPP/R1B1KBNR b KQkq' => {
			eco => 'C17c',
			# TRANSLATORS: C17c: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. Qg4
			variation => N__('French: Winawer, Russian Variation'),
			moves => {
				'g8e7' => 1,
			},
		},
		'rnbqk2r/pp2nppp/4p3/2ppP3/1b1P2Q1/2N5/PPP2PPP/R1B1KBNR w KQkq' => {
			eco => 'C17c',
			# TRANSLATORS: C17c: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. Qg4 Ne7
			variation => N__('French: Winawer, Russian Variation'),
			moves => {
				'd4c5' => 1,
			},
		},
		'rnbqk2r/pp2nppp/4p3/2PpP3/1b4Q1/2N5/PPP2PPP/R1B1KBNR b KQkq' => {
			eco => 'C17d',
			# TRANSLATORS: C17d: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. Qg4 Ne7 6. dxc5
			variation => N__('French: Winawer, Russian, 6.dxc5'),
			moves => {
			},
		},
		'rnbqk1nr/pp3ppp/4p3/2ppP3/1b1P4/2N5/PPPB1PPP/R2QKBNR b KQkq' => {
			eco => 'C17e',
			# TRANSLATORS: C17e: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. Bd2
			variation => N__('French: Winawer, Bogoljubow Variation'),
			moves => {
				'c5d4' => 1,
				'g8e7' => 1,
			},
		},
		'rnbqk1nr/pp3ppp/4p3/3pP3/1b1p4/2N5/PPPB1PPP/R2QKBNR w KQkq' => {
			eco => 'C17f',
			# TRANSLATORS: C17f: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. Bd2 cxd4
			variation => N__('French: Winawer, Bogoljubow, 5...cxd4'),
			moves => {
			},
		},
		'rnbqk2r/pp2nppp/4p3/2ppP3/1b1P4/2N5/PPPB1PPP/R2QKBNR w KQkq' => {
			eco => 'C17g',
			# TRANSLATORS: C17g: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. Bd2 Ne7
			variation => N__('French: Winawer, Bogoljubow, 5... Ne7'),
			moves => {
				'a2a3' => 1,
				'c3b5' => 1,
				'd4c5' => 1,
			},
		},
		'rnbqk2r/pp2nppp/4p3/2ppP3/1b1P4/P1N5/1PPB1PPP/R2QKBNR b KQkq' => {
			eco => 'C17h',
			# TRANSLATORS: C17h: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. Bd2 Ne7 6. a3
			variation => N__('French: Winawer, Bogoljubow, 5... Ne7 6. a3'),
			moves => {
			},
		},
		'rnbqk2r/pp2nppp/4p3/2PpP3/1b6/2N5/PPPB1PPP/R2QKBNR b KQkq' => {
			eco => 'C17i',
			# TRANSLATORS: C17i: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. Bd2 Ne7 6. dxc5
			variation => N__('French: Winawer, Bogoljubow, 5... Ne7 6.dxc5'),
			moves => {
			},
		},
		'rnbqk2r/pp2nppp/4p3/1NppP3/1b1P4/8/PPPB1PPP/R2QKBNR b KQkq' => {
			eco => 'C17j',
			# TRANSLATORS: C17j: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. Bd2 Ne7 6. Nb5
			variation => N__('French: Winawer, Bogoljubow, 5... Ne7 6. Nb5'),
			moves => {
			},
		},
		'rnbqk1nr/pp3ppp/4p3/2ppP3/1b1P4/P1N5/1PP2PPP/R1BQKBNR b KQkq' => {
			eco => 'C17k',
			# TRANSLATORS: C17k: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3
			variation => N__('French: Winawer, 5. a3'),
			moves => {
				'b4a5' => 1,
				'b4c3' => 1,
				'c5d4' => 1,
			},
		},
		'rnbqk1nr/pp3ppp/4p3/3pP3/1b1p4/P1N5/1PP2PPP/R1BQKBNR w KQkq' => {
			eco => 'C17l',
			# TRANSLATORS: C17l: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 cxd4
			variation => N__('French: Winawer, 5. a3 cxd4'),
			moves => {
				'a3b4' => 1,
			},
		},
		'rnbqk1nr/pp3ppp/4p3/3pP3/1P1p4/2N5/1PP2PPP/R1BQKBNR b KQkq' => {
			eco => 'C17l',
			# TRANSLATORS: C17l: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 cxd4 6. axb4
			variation => N__('French: Winawer, 5. a3 cxd4'),
			moves => {
				'd4c3' => 1,
			},
		},
		'rnbqk1nr/pp3ppp/4p3/3pP3/1P6/2p5/1PP2PPP/R1BQKBNR w KQkq' => {
			eco => 'C17l',
			# TRANSLATORS: C17l: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 cxd4 6. axb4 dxc3
			variation => N__('French: Winawer, 5. a3 cxd4'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqk1nr/pp3ppp/4p3/3pP3/1P6/2p2N2/1PP2PPP/R1BQKB1R b KQkq' => {
			eco => 'C17l',
			# TRANSLATORS: C17l: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 cxd4 6. axb4 dxc3 7. Nf3
			variation => N__('French: Winawer, Rauzer Variation'),
			moves => {
			},
		},
		'rnbqk1nr/pp3ppp/4p3/b1ppP3/3P4/P1N5/1PP2PPP/R1BQKBNR w KQkq' => {
			eco => 'C17m',
			# TRANSLATORS: C17m: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Ba5
			variation => N__('French: Winawer, Swiss Variation'),
			moves => {
				'b2b4' => 1,
			},
		},
		'rnbqk1nr/pp3ppp/4p3/b1ppP3/1P1P4/P1N5/2P2PPP/R1BQKBNR b KQkq' => {
			eco => 'C17n',
			# TRANSLATORS: C17n: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Ba5 6. b4
			variation => N__('French: Winawer, Swiss, 6. b4'),
			moves => {
				'c5d4' => 1,
			},
		},
		'rnbqk1nr/pp3ppp/4p3/b2pP3/1P1p4/P1N5/2P2PPP/R1BQKBNR w KQkq' => {
			eco => 'C17n',
			# TRANSLATORS: C17n: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Ba5 6. b4 cxd4
			variation => N__('French: Winawer, Swiss, 6. b4'),
			moves => {
				'c3b5' => 1,
				'd1g4' => 1,
			},
		},
		'rnbqk1nr/pp3ppp/4p3/b2pP3/1P1p2Q1/P1N5/2P2PPP/R1B1KBNR b KQkq' => {
			eco => 'C17o',
			# TRANSLATORS: C17o: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Ba5 6. b4 cxd4 7. Qg4
			variation => N__('French: Winawer, Swiss, 6. b4 cxd4 7. Qg4'),
			moves => {
				'g8e7' => 1,
			},
		},
		'rnbqk2r/pp2nppp/4p3/b2pP3/1P1p2Q1/P1N5/2P2PPP/R1B1KBNR w KQkq' => {
			eco => 'C17o',
			# TRANSLATORS: C17o: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Ba5 6. b4 cxd4 7. Qg4 Ne7
			variation => N__('French: Winawer, Swiss, 6. b4 cxd4 7. Qg4'),
			moves => {
				'b4a5' => 1,
			},
		},
		'rnbqk2r/pp2nppp/4p3/P2pP3/3p2Q1/P1N5/2P2PPP/R1B1KBNR b KQkq' => {
			eco => 'C17p',
			# TRANSLATORS: C17p: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Ba5 6. b4 cxd4 7. Qg4 Ne7 8. bxa5
			variation => N__('French: Winawer, Swiss, 6. b4 cxd4 7. Qg4 Ne7 8.bxa5'),
			moves => {
			},
		},
		'rnbqk1nr/pp3ppp/4p3/bN1pP3/1P1p4/P7/2P2PPP/R1BQKBNR b KQkq' => {
			eco => 'C17q',
			# TRANSLATORS: C17q: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Ba5 6. b4 cxd4 7. Nb5
			variation => N__('French: Winawer, Swiss, 6. b4 cxd4 7. Nb5'),
			moves => {
				'a5c7' => 1,
			},
		},
		'rnbqk1nr/ppb2ppp/4p3/1N1pP3/1P1p4/P7/2P2PPP/R1BQKBNR w KQkq' => {
			eco => 'C17q',
			# TRANSLATORS: C17q: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Ba5 6. b4 cxd4 7. Nb5 Bc7
			variation => N__('French: Winawer, Swiss, 6. b4 cxd4 7. Nb5'),
			moves => {
				'f2f4' => 1,
			},
		},
		'rnbqk1nr/ppb2ppp/4p3/1N1pP3/1P1p1P2/P7/2P3PP/R1BQKBNR b KQkq' => {
			eco => 'C17r',
			# TRANSLATORS: C17r: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Ba5 6. b4 cxd4 7. Nb5 Bc7 8. f4
			variation => N__('French: Winawer, Swiss, 6. b4 cxd4 7. Nb5 Bc7 8. f4'),
			moves => {
				'c8d7' => 1,
			},
		},
		'rn1qk1nr/ppbb1ppp/4p3/1N1pP3/1P1p1P2/P7/2P3PP/R1BQKBNR w KQkq' => {
			eco => 'C17s',
			# TRANSLATORS: C17s: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Ba5 6. b4 cxd4 7. Nb5 Bc7 8. f4 Bd7
			variation => N__('French: Winawer, Swiss, 6. b4 cxd4 7. Nb5 Bc7 8. f4 Bd7'),
			moves => {
			},
		},
		'rnbqk1nr/pp3ppp/4p3/2ppP3/3P4/P1b5/1PP2PPP/R1BQKBNR w KQkq' => {
			eco => 'C18a',
			# TRANSLATORS: C18a: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+
			variation => N__('French: Winawer, 5...Bxc3+'),
			moves => {
				'b2c3' => 1,
			},
		},
		'rnbqk1nr/pp3ppp/4p3/2ppP3/3P4/P1P5/2P2PPP/R1BQKBNR b KQkq' => {
			eco => 'C18a',
			# TRANSLATORS: C18a: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3
			variation => N__('French: Winawer, 5...Bxc3+ 6.bxc3'),
			moves => {
				'd8a5' => 1,
				'd8c7' => 1,
				'g8e7' => 1,
			},
		},
		'rnb1k1nr/pp3ppp/4p3/q1ppP3/3P4/P1P5/2P2PPP/R1BQKBNR w KQkq' => {
			eco => 'C18b',
			# TRANSLATORS: C18b: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Qa5
			variation => N__('French: Winawer, 6... Qa5'),
			moves => {
			},
		},
		'rnb1k1nr/ppq2ppp/4p3/2ppP3/3P4/P1P5/2P2PPP/R1BQKBNR w KQkq' => {
			eco => 'C18c',
			# TRANSLATORS: C18c: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Qc7
			variation => N__('French: Winawer, 6... Qc7'),
			moves => {
				'd1g4' => 1,
			},
		},
		'rnb1k1nr/ppq2ppp/4p3/2ppP3/3P2Q1/P1P5/2P2PPP/R1B1KBNR b KQkq' => {
			eco => 'C18d',
			# TRANSLATORS: C18d: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Qc7 7. Qg4
			variation => N__('French: Winawer, 6... Qc7 7. Qg4'),
			moves => {
				'f7f5' => 1,
				'f7f6' => 1,
			},
		},
		'rnb1k1nr/ppq3pp/4pp2/2ppP3/3P2Q1/P1P5/2P2PPP/R1B1KBNR w KQkq' => {
			eco => 'C18d',
			# TRANSLATORS: C18d: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Qc7 7. Qg4 f6
			variation => N__('French: Winawer, 6... Qc7 7. Qg4 f6'),
			moves => {
			},
		},
		'rnb1k1nr/ppq3pp/4p3/2ppPp2/3P2Q1/P1P5/2P2PPP/R1B1KBNR w KQkq' => {
			eco => 'C18e',
			# TRANSLATORS: C18e: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Qc7 7. Qg4 f5
			variation => N__('French: Winawer, 6... Qc7 7. Qg4 f5'),
			moves => {
			},
		},
		'rnbqk2r/pp2nppp/4p3/2ppP3/3P4/P1P5/2P2PPP/R1BQKBNR w KQkq' => {
			eco => 'C18f',
			# TRANSLATORS: C18f: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7
			variation => N__('French: Winawer, 6... Ne7'),
			moves => {
				'a3a4' => 1,
				'd1g4' => 1,
				'g1f3' => 1,
				'h2h4' => 1,
			},
		},
		'rnbqk2r/pp2nppp/4p3/2ppP3/3P3P/P1P5/2P2PP1/R1BQKBNR b KQkq' => {
			eco => 'C18g',
			# TRANSLATORS: C18g: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. h4
			variation => N__('French: Winawer, 6... Ne7 7. h4'),
			moves => {
				'b8c6' => 1,
				'd8c7' => 1,
			},
		},
		'rnb1k2r/ppq1nppp/4p3/2ppP3/3P3P/P1P5/2P2PP1/R1BQKBNR w KQkq' => {
			eco => 'C18h',
			# TRANSLATORS: C18h: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. h4 Qc7
			variation => N__('French: Winawer, 6... Ne7 7. h4 Qc7'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnb1k2r/ppq1nppp/4p3/2ppP3/3P3P/P1P2N2/2P2PP1/R1BQKB1R b KQkq' => {
			eco => 'C18h',
			# TRANSLATORS: C18h: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. h4 Qc7 8. Nf3
			variation => N__('French: Winawer, 6... Ne7 7. h4 Qc7'),
			moves => {
			},
		},
		'r1bqk2r/pp2nppp/2n1p3/2ppP3/3P3P/P1P5/2P2PP1/R1BQKBNR w KQkq' => {
			eco => 'C18i',
			# TRANSLATORS: C18i: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. h4 Nbc6
			variation => N__('French: Winawer, 6... Ne7 7. h4 Nbc6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'r1bqk2r/pp2nppp/2n1p3/2ppP3/3P3P/P1P2N2/2P2PP1/R1BQKB1R b KQkq' => {
			eco => 'C18i',
			# TRANSLATORS: C18i: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. h4 Nbc6 8. Nf3
			variation => N__('French: Winawer, 6... Ne7 7. h4 Nbc6'),
			moves => {
			},
		},
		'rnbqk2r/pp2nppp/4p3/2ppP3/3P2Q1/P1P5/2P2PPP/R1B1KBNR b KQkq' => {
			eco => 'C18j',
			# TRANSLATORS: C18j: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Qg4
			variation => N__('French: Winawer, 6... Ne7 7. Qg4'),
			moves => {
				'b8c6' => 1,
				'c5d4' => 1,
				'd8c7' => 1,
				'e8f8' => 1,
				'e8g8' => 1,
			},
		},
		'r1bqk2r/pp2nppp/2n1p3/2ppP3/3P2Q1/P1P5/2P2PPP/R1B1KBNR w KQkq' => {
			eco => 'C18k',
			# TRANSLATORS: C18k: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Qg4 Nbc6
			variation => N__('French: Winawer, 6... Ne7 7. Qg4 Nbc6'),
			moves => {
			},
		},
		'rnbq1k1r/pp2nppp/4p3/2ppP3/3P2Q1/P1P5/2P2PPP/R1B1KBNR w KQ' => {
			eco => 'C18l',
			# TRANSLATORS: C18l: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Qg4 Kf8
			variation => N__('French: Winawer, 6... Ne7 7. Qg4 Kf8'),
			moves => {
			},
		},
		'rnbqk2r/pp2nppp/4p3/3pP3/3p2Q1/P1P5/2P2PPP/R1B1KBNR w KQkq' => {
			eco => 'C18m',
			# TRANSLATORS: C18m: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Qg4 cxd4
			variation => N__('French: Winawer, 6... Ne7 7. Qg4 cxd4'),
			moves => {
			},
		},
		'rnbq1rk1/pp2nppp/4p3/2ppP3/3P2Q1/P1P5/2P2PPP/R1B1KBNR w KQ' => {
			eco => 'C18n',
			# TRANSLATORS: C18n: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Qg4 O-O
			variation => N__('French: Winawer, 6... Ne7 7. Qg4 O-O'),
			moves => {
				'f1d3' => 1,
				'g1f3' => 1,
			},
		},
		'rnbq1rk1/pp2nppp/4p3/2ppP3/3P2Q1/P1PB4/2P2PPP/R1B1K1NR b KQ' => {
			eco => 'C18o',
			# TRANSLATORS: C18o: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Qg4 O-O 8. Bd3
			variation => N__('French: Winawer, 6... Ne7 7. Qg4 O-O 8. Bd3'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bq1rk1/pp2nppp/2n1p3/2ppP3/3P2Q1/P1PB4/2P2PPP/R1B1K1NR w KQ' => {
			eco => 'C18p',
			# TRANSLATORS: C18p: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Qg4 O-O 8. Bd3 Nbc6
			variation => N__('French: Winawer, 6... Ne7 7. Qg4 O-O 8. Bd3 Nbc6'),
			moves => {
			},
		},
		'rnbq1rk1/pp2nppp/4p3/2ppP3/3P2Q1/P1P2N2/2P2PPP/R1B1KB1R b KQ' => {
			eco => 'C18q',
			# TRANSLATORS: C18q: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Qg4 O-O 8. Nf3
			variation => N__('French: Winawer, 6... Ne7 7. Qg4 O-O 8. Nf3'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bq1rk1/pp2nppp/2n1p3/2ppP3/3P2Q1/P1P2N2/2P2PPP/R1B1KB1R w KQ' => {
			eco => 'C18q',
			# TRANSLATORS: C18q: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Qg4 O-O 8. Nf3 Nbc6
			variation => N__('French: Winawer, 6... Ne7 7. Qg4 O-O 8. Nf3 Nbc6'),
			moves => {
			},
		},
		'rnb1k2r/ppq1nppp/4p3/2ppP3/3P2Q1/P1P5/2P2PPP/R1B1KBNR w KQkq' => {
			eco => 'C18r',
			# TRANSLATORS: C18r: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Qg4 Qc7
			variation => N__('French: Winawer, Poisoned Pawn'),
			moves => {
				'g4g7' => 1,
			},
		},
		'rnb1k2r/ppq1npQp/4p3/2ppP3/3P4/P1P5/2P2PPP/R1B1KBNR b KQkq' => {
			eco => 'C18r',
			# TRANSLATORS: C18r: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Qg4 Qc7 8. Qxg7
			variation => N__('French: Winawer, Poisoned Pawn, 8.Qxg7'),
			moves => {
				'h8g8' => 1,
			},
		},
		'rnb1k1r1/ppq1npQp/4p3/2ppP3/3P4/P1P5/2P2PPP/R1B1KBNR w KQq' => {
			eco => 'C18r',
			# TRANSLATORS: C18r: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Qg4 Qc7 8. Qxg7 Rg8
			variation => N__('French: Winawer, Poisoned Pawn, 8.Qxg7'),
			moves => {
				'g7h7' => 1,
			},
		},
		'rnb1k1r1/ppq1np1Q/4p3/2ppP3/3P4/P1P5/2P2PPP/R1B1KBNR b KQq' => {
			eco => 'C18r',
			# TRANSLATORS: C18r: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Qg4 Qc7 8. Qxg7 Rg8 9. Qxh7
			variation => N__('French: Winawer, Poisoned Pawn, 8.Qxg7'),
			moves => {
				'c5d4' => 1,
			},
		},
		'rnb1k1r1/ppq1np1Q/4p3/3pP3/3p4/P1P5/2P2PPP/R1B1KBNR w KQq' => {
			eco => 'C18r',
			# TRANSLATORS: C18r: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Qg4 Qc7 8. Qxg7 Rg8 9. Qxh7 cxd4
			variation => N__('French: Winawer, Poisoned Pawn, 8.Qxg7'),
			moves => {
				'e1d1' => 1,
				'g1e2' => 1,
				'h7d3' => 1,
			},
		},
		'rnb1k1r1/ppq1np2/4p3/3pP3/3p4/P1PQ4/2P2PPP/R1B1KBNR b KQq' => {
			eco => 'C18r',
			# TRANSLATORS: C18r: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Qg4 Qc7 8. Qxg7 Rg8 9. Qxh7 cxd4 10. Qd3
			variation => N__('French: Winawer, Poisoned Pawn, 10. Qd3'),
			moves => {
			},
		},
		'rnb1k1r1/ppq1np1Q/4p3/3pP3/3p4/P1P5/2P2PPP/R1BK1BNR b q' => {
			eco => 'C18s',
			# TRANSLATORS: C18s: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Qg4 Qc7 8. Qxg7 Rg8 9. Qxh7 cxd4 10. Kd1
			variation => N__('French: Winawer, Poisoned Pawn, Euwe-Gligoric Variation'),
			moves => {
			},
		},
		'rnb1k1r1/ppq1np1Q/4p3/3pP3/3p4/P1P5/2P1NPPP/R1B1KB1R b KQq' => {
			eco => 'C18t',
			# TRANSLATORS: C18t: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Qg4 Qc7 8. Qxg7 Rg8 9. Qxh7 cxd4 10. Ne2
			variation => N__('French: Winawer, Poisoned Pawn, Konstantinopolsky Variation'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1b1k1r1/ppq1np1Q/2n1p3/3pP3/3p4/P1P5/2P1NPPP/R1B1KB1R w KQq' => {
			eco => 'C18t',
			# TRANSLATORS: C18t: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Qg4 Qc7 8. Qxg7 Rg8 9. Qxh7 cxd4 10. Ne2 Nbc6
			variation => N__('French: Winawer, Poisoned Pawn, Konstantinopolsky Variation'),
			moves => {
				'f2f4' => 1,
			},
		},
		'r1b1k1r1/ppq1np1Q/2n1p3/3pP3/3p1P2/P1P5/2P1N1PP/R1B1KB1R b KQq' => {
			eco => 'C18t',
			# TRANSLATORS: C18t: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Qg4 Qc7 8. Qxg7 Rg8 9. Qxh7 cxd4 10. Ne2 Nbc6 11. f4
			variation => N__('French: Winawer, Poisoned Pawn, Konstantinopolsky Variation'),
			moves => {
				'c8d7' => 1,
			},
		},
		'r3k1r1/ppqbnp1Q/2n1p3/3pP3/3p1P2/P1P5/2P1N1PP/R1B1KB1R w KQq' => {
			eco => 'C18t',
			# TRANSLATORS: C18t: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Qg4 Qc7 8. Qxg7 Rg8 9. Qxh7 cxd4 10. Ne2 Nbc6 11. f4 Bd7
			variation => N__('French: Winawer, Poisoned Pawn, Konstantinopolsky Variation'),
			moves => {
				'h7d3' => 1,
			},
		},
		'r3k1r1/ppqbnp2/2n1p3/3pP3/3p1P2/P1PQ4/2P1N1PP/R1B1KB1R b KQq' => {
			eco => 'C18t',
			# TRANSLATORS: C18t: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Qg4 Qc7 8. Qxg7 Rg8 9. Qxh7 cxd4 10. Ne2 Nbc6 11. f4 Bd7 12. Qd3
			variation => N__('French: Winawer, Poisoned Pawn, Konstantinopolsky Variation'),
			moves => {
				'd4c3' => 1,
			},
		},
		'r3k1r1/ppqbnp2/2n1p3/3pP3/5P2/P1pQ4/2P1N1PP/R1B1KB1R w KQq' => {
			eco => 'C18u',
			# TRANSLATORS: C18u: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Qg4 Qc7 8. Qxg7 Rg8 9. Qxh7 cxd4 10. Ne2 Nbc6 11. f4 Bd7 12. Qd3 dxc3
			variation => N__('French: Winawer, Poisoned Pawn, Main Line'),
			moves => {
				'e2c3' => 1,
			},
		},
		'r3k1r1/ppqbnp2/2n1p3/3pP3/5P2/P1NQ4/2P3PP/R1B1KB1R b KQq' => {
			eco => 'C18v',
			# TRANSLATORS: C18v: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Qg4 Qc7 8. Qxg7 Rg8 9. Qxh7 cxd4 10. Ne2 Nbc6 11. f4 Bd7 12. Qd3 dxc3 13. Nxc3
			variation => N__('French: Winawer, Poisoned Pawn, Main Line, 13.Nxc3'),
			moves => {
			},
		},
		'rnbqk2r/pp2nppp/4p3/2ppP3/P2P4/2P5/2P2PPP/R1BQKBNR b KQkq' => {
			eco => 'C19a',
			# TRANSLATORS: C19a: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. a4
			variation => N__('French: Winawer, Smyslov Variation'),
			moves => {
				'd8a5' => 1,
			},
		},
		'rnb1k2r/pp2nppp/4p3/q1ppP3/P2P4/2P5/2P2PPP/R1BQKBNR w KQkq' => {
			eco => 'C19b',
			# TRANSLATORS: C19b: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. a4 Qa5
			variation => N__('French: Winawer, Smyslov, 7... Qa5'),
			moves => {
			},
		},
		'rnbqk2r/pp2nppp/4p3/2ppP3/3P4/P1P2N2/2P2PPP/R1BQKB1R b KQkq' => {
			eco => 'C19c',
			# TRANSLATORS: C19c: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Nf3
			variation => N__('French: Winawer, 6... Ne7 7. Nf3'),
			moves => {
				'b7b6' => 1,
				'b8c6' => 1,
				'c8d7' => 1,
				'd8a5' => 1,
				'd8c7' => 1,
			},
		},
		'rnb1k2r/ppq1nppp/4p3/2ppP3/3P4/P1P2N2/2P2PPP/R1BQKB1R w KQkq' => {
			eco => 'C19d',
			# TRANSLATORS: C19d: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Nf3 Qc7
			variation => N__('French: Winawer, 6... Ne7 7. Nf3 Qc7'),
			moves => {
				'a3a4' => 1,
			},
		},
		'rnb1k2r/ppq1nppp/4p3/2ppP3/P2P4/2P2N2/2P2PPP/R1BQKB1R b KQkq' => {
			eco => 'C19e',
			# TRANSLATORS: C19e: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Nf3 Qc7 8. a4
			variation => N__('French: Winawer, 6... Ne7 7. Nf3 Qc7 8. a4'),
			moves => {
				'b7b6' => 1,
			},
		},
		'rnb1k2r/p1q1nppp/1p2p3/2ppP3/P2P4/2P2N2/2P2PPP/R1BQKB1R w KQkq' => {
			eco => 'C19f',
			# TRANSLATORS: C19f: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Nf3 Qc7 8. a4 b6
			variation => N__('French: Winawer, 6... Ne7 7. Nf3 Qc7 8. a4 b6'),
			moves => {
			},
		},
		'rnb1k2r/pp2nppp/4p3/q1ppP3/3P4/P1P2N2/2P2PPP/R1BQKB1R w KQkq' => {
			eco => 'C19g',
			# TRANSLATORS: C19g: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Nf3 Qa5
			variation => N__('French: Winawer, 6... Ne7 7. Nf3 Qa5'),
			moves => {
			},
		},
		'rnbqk2r/p3nppp/1p2p3/2ppP3/3P4/P1P2N2/2P2PPP/R1BQKB1R w KQkq' => {
			eco => 'C19h',
			# TRANSLATORS: C19h: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Nf3 b6
			variation => N__('French: Winawer, 6... Ne7 7. Nf3 b6'),
			moves => {
				'a3a4' => 1,
				'f1b5' => 1,
			},
		},
		'rnbqk2r/p3nppp/1p2p3/2ppP3/P2P4/2P2N2/2P2PPP/R1BQKB1R b KQkq' => {
			eco => 'C19h',
			# TRANSLATORS: C19h: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Nf3 b6 8. a4
			variation => N__('French: Winawer, 6... Ne7 7. Nf3 b6 8. a4'),
			moves => {
			},
		},
		'rnbqk2r/p3nppp/1p2p3/1BppP3/3P4/P1P2N2/2P2PPP/R1BQK2R b KQkq' => {
			eco => 'C19i',
			# TRANSLATORS: C19i: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Nf3 b6 8. Bb5+
			variation => N__('French: Winawer, 6... Ne7 7. Nf3 b6 8. Bb5+'),
			moves => {
			},
		},
		'rn1qk2r/pp1bnppp/4p3/2ppP3/3P4/P1P2N2/2P2PPP/R1BQKB1R w KQkq' => {
			eco => 'C19j',
			# TRANSLATORS: C19j: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Nf3 Bd7
			variation => N__('French: Winawer, 6... Ne7 7. Nf3 Bd7'),
			moves => {
				'a3a4' => 1,
			},
		},
		'rn1qk2r/pp1bnppp/4p3/2ppP3/P2P4/2P2N2/2P2PPP/R1BQKB1R b KQkq' => {
			eco => 'C19k',
			# TRANSLATORS: C19k: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Nf3 Bd7 8. a4
			variation => N__('French: Winawer, 6... Ne7 7. Nf3 Bd7 8. a4'),
			moves => {
			},
		},
		'r1bqk2r/pp2nppp/2n1p3/2ppP3/3P4/P1P2N2/2P2PPP/R1BQKB1R w KQkq' => {
			eco => 'C19l',
			# TRANSLATORS: C19l: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Nf3 Nbc6
			variation => N__('French: Winawer, 6... Ne7 7. Nf3 Nbc6'),
			moves => {
				'a3a4' => 1,
			},
		},
		'r1bqk2r/pp2nppp/2n1p3/2ppP3/P2P4/2P2N2/2P2PPP/R1BQKB1R b KQkq' => {
			eco => 'C19m',
			# TRANSLATORS: C19m: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Nf3 Nbc6 8. a4
			variation => N__('French: Winawer, 6... Ne7 7. Nf3 Nbc6 8. a4'),
			moves => {
				'c8d7' => 1,
				'd8a5' => 1,
			},
		},
		'r2qk2r/pp1bnppp/2n1p3/2ppP3/P2P4/2P2N2/2P2PPP/R1BQKB1R w KQkq' => {
			eco => 'C19m',
			# TRANSLATORS: C19m: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Nf3 Nbc6 8. a4 Bd7
			variation => N__('French: Winawer, 6... Ne7 7. Nf3 Nbc6 8. a4 Bd7'),
			moves => {
			},
		},
		'r1b1k2r/pp2nppp/2n1p3/q1ppP3/P2P4/2P2N2/2P2PPP/R1BQKB1R w KQkq' => {
			eco => 'C19n',
			# TRANSLATORS: C19n: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Nf3 Nbc6 8. a4 Qa5
			variation => N__('French: Winawer, 6... Ne7 7. Nf3 Nbc6 8. a4 Qa5'),
			moves => {
				'c1d2' => 1,
				'd1d2' => 1,
			},
		},
		'r1b1k2r/pp2nppp/2n1p3/q1ppP3/P2P4/2P2N2/2PQ1PPP/R1B1KB1R b KQkq' => {
			eco => 'C19n',
			# TRANSLATORS: C19n: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Nf3 Nbc6 8. a4 Qa5 9. Qd2
			variation => N__('French: Winawer, 6... Ne7 7. Nf3 Nbc6 8. a4 Qa5 9. Qd2'),
			moves => {
				'c8d7' => 1,
			},
		},
		'r3k2r/pp1bnppp/2n1p3/q1ppP3/P2P4/2P2N2/2PQ1PPP/R1B1KB1R w KQkq' => {
			eco => 'C19o',
			# TRANSLATORS: C19o: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Nf3 Nbc6 8. a4 Qa5 9. Qd2 Bd7
			variation => N__('French: Winawer, 6... Ne7 7. Nf3 Nbc6 8. a4 Qa5 9. Qd2 Bd7'),
			moves => {
			},
		},
		'r1b1k2r/pp2nppp/2n1p3/q1ppP3/P2P4/2P2N2/2PB1PPP/R2QKB1R b KQkq' => {
			eco => 'C19p',
			# TRANSLATORS: C19p: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Nf3 Nbc6 8. a4 Qa5 9. Bd2
			variation => N__('French: Winawer, 6... Ne7 7. Nf3 Nbc6 8. a4 Qa5+ 9. Bd2'),
			moves => {
				'c8d7' => 1,
			},
		},
		'r3k2r/pp1bnppp/2n1p3/q1ppP3/P2P4/2P2N2/2PB1PPP/R2QKB1R w KQkq' => {
			eco => 'C19q',
			# TRANSLATORS: C19q: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Nf3 Nbc6 8. a4 Qa5 9. Bd2 Bd7
			variation => N__('French: Winawer, 6... Ne7 7. Nf3 Nbc6 8. a4 Qa5+ 9. Bd2 Bd7'),
			moves => {
				'f1b5' => 1,
			},
		},
		'r3k2r/pp1bnppp/2n1p3/qBppP3/P2P4/2P2N2/2PB1PPP/R2QK2R b KQkq' => {
			eco => 'C19r',
			# TRANSLATORS: C19r: 1. e4 e6 2. d4 d5 3. Nc3 Bb4 4. e5 c5 5. a3 Bxc3+ 6. bxc3 Ne7 7. Nf3 Nbc6 8. a4 Qa5 9. Bd2 Bd7 10. Bb5
			variation => N__('French: Winawer, 6... Ne7 7. Nf3 Nbc6 8. a4 Qa5+ 9. Bd2 Bd7 10. Bb5'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/4p3/4P3/8/PPPP1PPP/RNBQKBNR w KQkq' => {
			eco => 'C20',
			# TRANSLATORS: C20: 1. e4 e5
			variation => N__('Open Game'),
			moves => {
				'a2a3' => 1,
				'b1c3' => 1,
				'c2c3' => 1,
				'c2c4' => 1,
				'd1f3' => 1,
				'd1h5' => 1,
				'd2d3' => 1,
				'd2d4' => 1,
				'f1b5' => 1,
				'f1c4' => 1,
				'f2f4' => 1,
				'g1e2' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pppp1ppp/8/4p3/4P3/P7/1PPP1PPP/RNBQKBNR b KQkq' => {
			eco => 'C20',
			# TRANSLATORS: C20: 1. e4 e5 2. a3
			variation => N__('Open Game: Mengarini Opening'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/4p3/4P3/2P5/PP1P1PPP/RNBQKBNR b KQkq' => {
			eco => 'C20',
			# TRANSLATORS: C20: 1. e4 e5 2. c3
			variation => N__('Open Game: Lopez/Mcleod Opening'),
			moves => {
				'f7f5' => 1,
			},
		},
		'rnbqkbnr/pppp2pp/8/4pp2/4P3/2P5/PP1P1PPP/RNBQKBNR w KQkq' => {
			eco => 'C20',
			# TRANSLATORS: C20: 1. e4 e5 2. c3 f5
			variation => N__('Open Game: Lopez/Mcleod, Lasa Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/4p3/2P1P3/8/PP1P1PPP/RNBQKBNR b KQkq' => {
			eco => 'C20',
			# TRANSLATORS: C20: 1. e4 e5 2. c4
			variation => N__('Open Game: 2. c4'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/4p3/4P3/5Q2/PPPP1PPP/RNB1KBNR b KQkq' => {
			eco => 'C20',
			# TRANSLATORS: C20: 1. e4 e5 2. Qf3
			variation => N__('Open Game: Napoleon\'s Opening'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/4p2Q/4P3/8/PPPP1PPP/RNB1KBNR b KQkq' => {
			eco => 'C20',
			# TRANSLATORS: C20: 1. e4 e5 2. Qh5
			variation => N__('Open Game: Patzer/Parnham Opening'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/4p3/4P3/3P4/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'C20',
			# TRANSLATORS: C20: 1. e4 e5 2. d3
			variation => N__('Open Game: 2. d3'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/8/3pp3/4P3/3P4/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'C20',
			# TRANSLATORS: C20: 1. e4 e5 2. d3 d5
			variation => N__('Open Game: 2. d3 d5'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/1B2p3/4P3/8/PPPP1PPP/RNBQK1NR b KQkq' => {
			eco => 'C20',
			# TRANSLATORS: C20: 1. e4 e5 2. Bb5
			variation => N__('Open Game: Portuguese Opening'),
			moves => {
				'b8c6' => 1,
				'c7c6' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/1B2p3/4P3/8/PPPP1PPP/RNBQK1NR w KQkq' => {
			eco => 'C20',
			# TRANSLATORS: C20: 1. e4 e5 2. Bb5 Nc6
			variation => N__('Open Game: Portuguese, 2... Nc6'),
			moves => {
			},
		},
		'rnbqkbnr/pp1p1ppp/2p5/1B2p3/4P3/8/PPPP1PPP/RNBQK1NR w KQkq' => {
			eco => 'C20',
			# TRANSLATORS: C20: 1. e4 e5 2. Bb5 c6
			variation => N__('Open Game: Portuguese, 2... c6'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/1B2p3/4P3/8/PPPP1PPP/RNBQK1NR w KQkq' => {
			eco => 'C20',
			# TRANSLATORS: C20: 1. e4 e5 2. Bb5 Nf6
			variation => N__('Open Game: Portuguese, 2... Nf6'),
			moves => {
				'd2d4' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/1B2p3/3PP3/8/PPP2PPP/RNBQK1NR b KQkq' => {
			eco => 'C20',
			# TRANSLATORS: C20: 1. e4 e5 2. Bb5 Nf6 3. d4
			variation => N__('Open Game: Portuguese Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/4p3/4P3/8/PPPPNPPP/RNBQKB1R b KQkq' => {
			eco => 'C20',
			# TRANSLATORS: C20: 1. e4 e5 2. Ne2
			variation => N__('Open Game: Alapin Opening'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/4p3/4P3/8/PPPPNPPP/RNBQKB1R w KQkq' => {
			eco => 'C20',
			# TRANSLATORS: C20: 1. e4 e5 2. Ne2 Nf6
			variation => N__('Open Game: Alapin Opening'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/4p3/3PP3/8/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'C21',
			# TRANSLATORS: C21: 1. e4 e5 2. d4
			variation => N__('Centre Game'),
			moves => {
				'd7d6' => 1,
				'e5d4' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/3p4/4p3/3PP3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'C21',
			# TRANSLATORS: C21: 1. e4 e5 2. d4 d6
			variation => N__('Centre Game: Maroczy Defence'),
			moves => {
				'd4e5' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/3p4/4P3/4P3/8/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'C21',
			# TRANSLATORS: C21: 1. e4 e5 2. d4 d6 3. dxe5
			variation => N__('Centre Game: Maroczy Defence, 3.dxe5'),
			moves => {
				'c8d7' => 1,
				'd6e5' => 1,
			},
		},
		'rn1qkbnr/pppb1ppp/3p4/4P3/4P3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'C21',
			# TRANSLATORS: C21: 1. e4 e5 2. d4 d6 3. dxe5 Bd7
			variation => N__('Centre Game: Maroczy Defence, Philidor Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/8/4p3/4P3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'C21',
			# TRANSLATORS: C21: 1. e4 e5 2. d4 d6 3. dxe5 dxe5
			variation => N__('Centre Game: Maroczy Defence, 3.dxe5'),
			moves => {
				'd1d8' => 1,
			},
		},
		'rnbQkbnr/ppp2ppp/8/4p3/4P3/8/PPP2PPP/RNB1KBNR b KQkq' => {
			eco => 'C21',
			# TRANSLATORS: C21: 1. e4 e5 2. d4 d6 3. dxe5 dxe5 4. Qxd8+
			variation => N__('Centre Game: Queenswap line'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/8/3pP3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'C21',
			# TRANSLATORS: C21: 1. e4 e5 2. d4 exd4
			variation => N__('Centre Game'),
			moves => {
				'c2c3' => 1,
				'd1d4' => 1,
				'f2f4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pppp1ppp/8/8/3pP3/2P5/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'C21',
			# TRANSLATORS: C21: 1. e4 e5 2. d4 exd4 3. c3
			variation => N__('Danish Gambit'),
			moves => {
				'd4c3' => 1,
				'd7d5' => 1,
				'g8e7' => 1,
			},
		},
		'rnbqkbnr/pppp1ppp/8/8/4P3/2p5/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'C21',
			# TRANSLATORS: C21: 1. e4 e5 2. d4 exd4 3. c3 dxc3
			variation => N__('Danish Gambit: Accepted'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnbqkbnr/pppp1ppp/8/8/2B1P3/2p5/PP3PPP/RNBQK1NR b KQkq' => {
			eco => 'C21',
			# TRANSLATORS: C21: 1. e4 e5 2. d4 exd4 3. c3 dxc3 4. Bc4
			variation => N__('Danish Gambit: Accepted, 4. Bc4'),
			moves => {
				'c3b2' => 1,
			},
		},
		'rnbqkbnr/pppp1ppp/8/8/2B1P3/8/Pp3PPP/RNBQK1NR w KQkq' => {
			eco => 'C21',
			# TRANSLATORS: C21: 1. e4 e5 2. d4 exd4 3. c3 dxc3 4. Bc4 cxb2
			variation => N__('Danish Gambit: Accepted, 4. Bc4'),
			moves => {
				'c1b2' => 1,
			},
		},
		'rnbqkbnr/pppp1ppp/8/8/2B1P3/8/PB3PPP/RN1QK1NR b KQkq' => {
			eco => 'C21',
			# TRANSLATORS: C21: 1. e4 e5 2. d4 exd4 3. c3 dxc3 4. Bc4 cxb2 5. Bxb2
			variation => N__('Danish Gambit: Accepted, 4. Bc4 cxb2 5.Bxb2'),
			moves => {
				'd7d5' => 1,
				'd8e7' => 1,
				'f8b4' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/8/3p4/2B1P3/8/PB3PPP/RN1QK1NR w KQkq' => {
			eco => 'C21',
			# TRANSLATORS: C21: 1. e4 e5 2. d4 exd4 3. c3 dxc3 4. Bc4 cxb2 5. Bxb2 d5
			variation => N__('Danish Gambit: Schlechter Defence'),
			moves => {
			},
		},
		'rnb1kbnr/ppppqppp/8/8/2B1P3/8/PB3PPP/RN1QK1NR w KQkq' => {
			eco => 'C21',
			# TRANSLATORS: C21: 1. e4 e5 2. d4 exd4 3. c3 dxc3 4. Bc4 cxb2 5. Bxb2 Qe7
			variation => N__('Danish Gambit: Chigorin Defence'),
			moves => {
			},
		},
		'rnbqk1nr/pppp1ppp/8/8/1bB1P3/8/PB3PPP/RN1QK1NR w KQkq' => {
			eco => 'C21',
			# TRANSLATORS: C21: 1. e4 e5 2. d4 exd4 3. c3 dxc3 4. Bc4 cxb2 5. Bxb2 Bb4+
			variation => N__('Danish Gambit: Copenhagen Defence'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/8/2B1P3/8/PB3PPP/RN1QK1NR w KQkq' => {
			eco => 'C21',
			# TRANSLATORS: C21: 1. e4 e5 2. d4 exd4 3. c3 dxc3 4. Bc4 cxb2 5. Bxb2 Nf6
			variation => N__('Danish Gambit: Classical Defence'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/8/3p4/3pP3/2P5/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'C21',
			# TRANSLATORS: C21: 1. e4 e5 2. d4 exd4 3. c3 d5
			variation => N__('Danish Gambit: Sörensen Defence'),
			moves => {
			},
		},
		'rnbqkb1r/ppppnppp/8/8/3pP3/2P5/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'C21',
			# TRANSLATORS: C21: 1. e4 e5 2. d4 exd4 3. c3 Ne7
			variation => N__('Danish Gambit: Svenonius Defence'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/8/3pPP2/8/PPP3PP/RNBQKBNR b KQkq' => {
			eco => 'C21',
			# TRANSLATORS: C21: 1. e4 e5 2. d4 exd4 3. f4
			variation => N__('Centre Game: Halasz Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/8/3pP3/5N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'C21',
			# TRANSLATORS: C21: 1. e4 e5 2. d4 exd4 3. Nf3
			variation => N__('Centre Game: 3. Nf3'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqkbnr/pp1p1ppp/8/2p5/3pP3/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C21',
			# TRANSLATORS: C21: 1. e4 e5 2. d4 exd4 3. Nf3 c5
			variation => N__('Centre Game: 3. Nf3'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnbqkbnr/pp1p1ppp/8/2p5/2BpP3/5N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C21',
			# TRANSLATORS: C21: 1. e4 e5 2. d4 exd4 3. Nf3 c5 4. Bc4
			variation => N__('Centre Game: 3. Nf3'),
			moves => {
				'b7b5' => 1,
			},
		},
		'rnbqkbnr/p2p1ppp/8/1pp5/2BpP3/5N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C21',
			# TRANSLATORS: C21: 1. e4 e5 2. d4 exd4 3. Nf3 c5 4. Bc4 b5
			variation => N__('Centre Game: Kieseritsky Variation'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/8/3QP3/8/PPP2PPP/RNB1KBNR b KQkq' => {
			eco => 'C22',
			# TRANSLATORS: C22: 1. e4 e5 2. d4 exd4 3. Qxd4
			variation => N__('Centre Game'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/8/3QP3/8/PPP2PPP/RNB1KBNR w KQkq' => {
			eco => 'C22',
			# TRANSLATORS: C22: 1. e4 e5 2. d4 exd4 3. Qxd4 Nc6
			variation => N__('Centre Game'),
			moves => {
				'd4c4' => 1,
				'd4e3' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/8/2Q1P3/8/PPP2PPP/RNB1KBNR b KQkq' => {
			eco => 'C22',
			# TRANSLATORS: C22: 1. e4 e5 2. d4 exd4 3. Qxd4 Nc6 4. Qc4
			variation => N__('Centre Game: Hall Variation'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/8/4P3/4Q3/PPP2PPP/RNB1KBNR b KQkq' => {
			eco => 'C22',
			# TRANSLATORS: C22: 1. e4 e5 2. d4 exd4 3. Qxd4 Nc6 4. Qe3
			variation => N__('Centre Game: Paulsen Attack'),
			moves => {
				'f8b4' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/8/1b2P3/4Q3/PPP2PPP/RNB1KBNR w KQkq' => {
			eco => 'C22',
			# TRANSLATORS: C22: 1. e4 e5 2. d4 exd4 3. Qxd4 Nc6 4. Qe3 Bb4+
			variation => N__('Centre Game: Paulsen Attack'),
			moves => {
				'c2c3' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/8/1b2P3/2P1Q3/PP3PPP/RNB1KBNR b KQkq' => {
			eco => 'C22',
			# TRANSLATORS: C22: 1. e4 e5 2. d4 exd4 3. Qxd4 Nc6 4. Qe3 Bb4+ 5. c3
			variation => N__('Centre Game: Paulsen Attack'),
			moves => {
				'b4e7' => 1,
			},
		},
		'r1bqk1nr/ppppbppp/2n5/8/4P3/2P1Q3/PP3PPP/RNB1KBNR w KQkq' => {
			eco => 'C22',
			# TRANSLATORS: C22: 1. e4 e5 2. d4 exd4 3. Qxd4 Nc6 4. Qe3 Bb4+ 5. c3 Be7
			variation => N__('Centre Game: Charousek Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/8/4P3/4Q3/PPP2PPP/RNB1KBNR w KQkq' => {
			eco => 'C22',
			# TRANSLATORS: C22: 1. e4 e5 2. d4 exd4 3. Qxd4 Nc6 4. Qe3 Nf6
			variation => N__('Centre Game: Berger Variation'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/8/4P3/2N1Q3/PPP2PPP/R1B1KBNR b KQkq' => {
			eco => 'C22',
			# TRANSLATORS: C22: 1. e4 e5 2. d4 exd4 3. Qxd4 Nc6 4. Qe3 Nf6 5. Nc3
			variation => N__('Centre Game: Berger Variation'),
			moves => {
				'f8b4' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/8/1b2P3/2N1Q3/PPP2PPP/R1B1KBNR w KQkq' => {
			eco => 'C22',
			# TRANSLATORS: C22: 1. e4 e5 2. d4 exd4 3. Qxd4 Nc6 4. Qe3 Nf6 5. Nc3 Bb4
			variation => N__('Centre Game: Berger Variation'),
			moves => {
				'c1d2' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/8/1b2P3/2N1Q3/PPPB1PPP/R3KBNR b KQkq' => {
			eco => 'C22',
			# TRANSLATORS: C22: 1. e4 e5 2. d4 exd4 3. Qxd4 Nc6 4. Qe3 Nf6 5. Nc3 Bb4 6. Bd2
			variation => N__('Centre Game: Berger Variation'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pppp1ppp/2n2n2/8/1b2P3/2N1Q3/PPPB1PPP/R3KBNR w KQ' => {
			eco => 'C22',
			# TRANSLATORS: C22: 1. e4 e5 2. d4 exd4 3. Qxd4 Nc6 4. Qe3 Nf6 5. Nc3 Bb4 6. Bd2 O-O
			variation => N__('Centre Game: Berger Variation'),
			moves => {
				'e1c1' => 1,
			},
		},
		'r1bq1rk1/pppp1ppp/2n2n2/8/1b2P3/2N1Q3/PPPB1PPP/2KR1BNR b -' => {
			eco => 'C22',
			# TRANSLATORS: C22: 1. e4 e5 2. d4 exd4 3. Qxd4 Nc6 4. Qe3 Nf6 5. Nc3 Bb4 6. Bd2 O-O 7. O-O-O
			variation => N__('Centre Game: Berger Variation'),
			moves => {
				'f8e8' => 1,
			},
		},
		'r1bqr1k1/pppp1ppp/2n2n2/8/1b2P3/2N1Q3/PPPB1PPP/2KR1BNR w -' => {
			eco => 'C22',
			# TRANSLATORS: C22: 1. e4 e5 2. d4 exd4 3. Qxd4 Nc6 4. Qe3 Nf6 5. Nc3 Bb4 6. Bd2 O-O 7. O-O-O Re8
			variation => N__('Centre Game: Berger Variation'),
			moves => {
				'f1c4' => 1,
			},
		},
		'r1bqr1k1/pppp1ppp/2n2n2/8/1bB1P3/2N1Q3/PPPB1PPP/2KR2NR b -' => {
			eco => 'C22',
			# TRANSLATORS: C22: 1. e4 e5 2. d4 exd4 3. Qxd4 Nc6 4. Qe3 Nf6 5. Nc3 Bb4 6. Bd2 O-O 7. O-O-O Re8 8. Bc4
			variation => N__('Centre Game: Berger Variation'),
			moves => {
				'd7d6' => 1,
			},
		},
		'r1bqr1k1/ppp2ppp/2np1n2/8/1bB1P3/2N1Q3/PPPB1PPP/2KR2NR w -' => {
			eco => 'C22',
			# TRANSLATORS: C22: 1. e4 e5 2. d4 exd4 3. Qxd4 Nc6 4. Qe3 Nf6 5. Nc3 Bb4 6. Bd2 O-O 7. O-O-O Re8 8. Bc4 d6
			variation => N__('Centre Game: Berger Variation'),
			moves => {
				'g1h3' => 1,
			},
		},
		'r1bqr1k1/ppp2ppp/2np1n2/8/1bB1P3/2N1Q2N/PPPB1PPP/2KR3R b -' => {
			eco => 'C22',
			# TRANSLATORS: C22: 1. e4 e5 2. d4 exd4 3. Qxd4 Nc6 4. Qe3 Nf6 5. Nc3 Bb4 6. Bd2 O-O 7. O-O-O Re8 8. Bc4 d6 9. Nh3
			variation => N__('Centre Game: Kupreichik Variation'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/4p3/2B1P3/8/PPPP1PPP/RNBQK1NR b KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4
			variation => N__('Bishop\'s Opening'),
			moves => {
				'b7b5' => 1,
				'c7c6' => 1,
				'f7f5' => 1,
				'f8c5' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/p1pp1ppp/8/1p2p3/2B1P3/8/PPPP1PPP/RNBQK1NR w KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 b5
			variation => N__('Bishop\'s Opening: Anderssen Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pp1p1ppp/2p5/4p3/2B1P3/8/PPPP1PPP/RNBQK1NR w KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 c6
			variation => N__('Bishop\'s Opening: Philidor Counterattack'),
			moves => {
				'd2d4' => 1,
			},
		},
		'rnbqkbnr/pp1p1ppp/2p5/4p3/2BPP3/8/PPP2PPP/RNBQK1NR b KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 c6 3. d4
			variation => N__('Bishop\'s Opening: Philidor Counterattack'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/2p5/3pp3/2BPP3/8/PPP2PPP/RNBQK1NR w KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 c6 3. d4 d5
			variation => N__('Bishop\'s Opening: Philidor Counterattack'),
			moves => {
				'e4d5' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/2p5/3Pp3/2BP4/8/PPP2PPP/RNBQK1NR b KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 c6 3. d4 d5 4. exd5
			variation => N__('Bishop\'s Opening: Philidor Counterattack'),
			moves => {
				'c6d5' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/8/3pp3/2BP4/8/PPP2PPP/RNBQK1NR w KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 c6 3. d4 d5 4. exd5 cxd5
			variation => N__('Bishop\'s Opening: Philidor Counterattack'),
			moves => {
				'c4b5' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/8/1B1pp3/3P4/8/PPP2PPP/RNBQK1NR b KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 c6 3. d4 d5 4. exd5 cxd5 5. Bb5+
			variation => N__('Bishop\'s Opening: Philidor Counterattack'),
			moves => {
				'c8d7' => 1,
			},
		},
		'rn1qkbnr/pp1b1ppp/8/1B1pp3/3P4/8/PPP2PPP/RNBQK1NR w KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 c6 3. d4 d5 4. exd5 cxd5 5. Bb5+ Bd7
			variation => N__('Bishop\'s Opening: Philidor Counterattack'),
			moves => {
				'b5d7' => 1,
			},
		},
		'rn1qkbnr/pp1B1ppp/8/3pp3/3P4/8/PPP2PPP/RNBQK1NR b KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 c6 3. d4 d5 4. exd5 cxd5 5. Bb5+ Bd7 6. Bxd7+
			variation => N__('Bishop\'s Opening: Philidor Counterattack'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r2qkbnr/pp1n1ppp/8/3pp3/3P4/8/PPP2PPP/RNBQK1NR w KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 c6 3. d4 d5 4. exd5 cxd5 5. Bb5+ Bd7 6. Bxd7+ Nxd7
			variation => N__('Bishop\'s Opening: Philidor Counterattack'),
			moves => {
				'd4e5' => 1,
			},
		},
		'r2qkbnr/pp1n1ppp/8/3pP3/8/8/PPP2PPP/RNBQK1NR b KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 c6 3. d4 d5 4. exd5 cxd5 5. Bb5+ Bd7 6. Bxd7+ Nxd7 7. dxe5
			variation => N__('Bishop\'s Opening: Philidor Counterattack'),
			moves => {
				'd7e5' => 1,
			},
		},
		'r2qkbnr/pp3ppp/8/3pn3/8/8/PPP2PPP/RNBQK1NR w KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 c6 3. d4 d5 4. exd5 cxd5 5. Bb5+ Bd7 6. Bxd7+ Nxd7 7. dxe5 Nxe5
			variation => N__('Bishop\'s Opening: Philidor Counterattack'),
			moves => {
				'g1e2' => 1,
			},
		},
		'r2qkbnr/pp3ppp/8/3pn3/8/8/PPP1NPPP/RNBQK2R b KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 c6 3. d4 d5 4. exd5 cxd5 5. Bb5+ Bd7 6. Bxd7+ Nxd7 7. dxe5 Nxe5 8. Ne2
			variation => N__('Bishop\'s Opening: Lisitsin Variation'),
			moves => {
			},
		},
		'rnbqkbnr/pppp2pp/8/4pp2/2B1P3/8/PPPP1PPP/RNBQK1NR w KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 f5
			variation => N__('Bishop\'s Opening: Calabrese Countergambit'),
			moves => {
				'd2d3' => 1,
			},
		},
		'rnbqkbnr/pppp2pp/8/4pp2/2B1P3/3P4/PPP2PPP/RNBQK1NR b KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 f5 3. d3
			variation => N__('Bishop\'s Opening: Calabrese Countergambit, Jänisch Variation'),
			moves => {
			},
		},
		'rnbqk1nr/pppp1ppp/8/2b1p3/2B1P3/8/PPPP1PPP/RNBQK1NR w KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 Bc5
			variation => N__('Bishop\'s Opening: Classical Variation'),
			moves => {
				'b2b4' => 1,
				'c2c3' => 1,
				'd1e2' => 1,
				'd2d4' => 1,
			},
		},
		'rnbqk1nr/pppp1ppp/8/2b1p3/1PB1P3/8/P1PP1PPP/RNBQK1NR b KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 Bc5 3. b4
			variation => N__('Bishop\'s Opening: MacDonnell Gambit'),
			moves => {
				'c5b4' => 1,
			},
		},
		'rnbqk1nr/pppp1ppp/8/4p3/1bB1P3/8/P1PP1PPP/RNBQK1NR w KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 Bc5 3. b4 Bxb4
			variation => N__('Bishop\'s Opening: MacDonnell Gambit'),
			moves => {
				'f2f4' => 1,
			},
		},
		'rnbqk1nr/pppp1ppp/8/4p3/1bB1PP2/8/P1PP2PP/RNBQK1NR b KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 Bc5 3. b4 Bxb4 4. f4
			variation => N__('Bishop\'s Opening: MacDonnell Double Gambit'),
			moves => {
				'e5f4' => 1,
			},
		},
		'rnbqk1nr/pppp1ppp/8/8/1bB1Pp2/8/P1PP2PP/RNBQK1NR w KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 Bc5 3. b4 Bxb4 4. f4 exf4
			variation => N__('Bishop\'s Opening: MacDonnell Double Gambit'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqk1nr/pppp1ppp/8/8/1bB1Pp2/5N2/P1PP2PP/RNBQK2R b KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 Bc5 3. b4 Bxb4 4. f4 exf4 5. Nf3
			variation => N__('Bishop\'s Opening: MacDonnell Double Gambit'),
			moves => {
				'b4e7' => 1,
			},
		},
		'rnbqk1nr/ppppbppp/8/8/2B1Pp2/5N2/P1PP2PP/RNBQK2R w KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 Bc5 3. b4 Bxb4 4. f4 exf4 5. Nf3 Be7
			variation => N__('Bishop\'s Opening: MacDonnell Double Gambit'),
			moves => {
				'd2d4' => 1,
			},
		},
		'rnbqk1nr/ppppbppp/8/8/2BPPp2/5N2/P1P3PP/RNBQK2R b KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 Bc5 3. b4 Bxb4 4. f4 exf4 5. Nf3 Be7 6. d4
			variation => N__('Bishop\'s Opening: MacDonnell Double Gambit'),
			moves => {
				'e7h4' => 1,
			},
		},
		'rnbqk1nr/pppp1ppp/8/8/2BPPp1b/5N2/P1P3PP/RNBQK2R w KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 Bc5 3. b4 Bxb4 4. f4 exf4 5. Nf3 Be7 6. d4 Bh4+
			variation => N__('Bishop\'s Opening: MacDonnell Double Gambit'),
			moves => {
				'g2g3' => 1,
			},
		},
		'rnbqk1nr/pppp1ppp/8/8/2BPPp1b/5NP1/P1P4P/RNBQK2R b KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 Bc5 3. b4 Bxb4 4. f4 exf4 5. Nf3 Be7 6. d4 Bh4+ 7. g3
			variation => N__('Bishop\'s Opening: MacDonnell Double Gambit'),
			moves => {
				'f4g3' => 1,
			},
		},
		'rnbqk1nr/pppp1ppp/8/8/2BPP2b/5Np1/P1P4P/RNBQK2R w KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 Bc5 3. b4 Bxb4 4. f4 exf4 5. Nf3 Be7 6. d4 Bh4+ 7. g3 fxg3
			variation => N__('Bishop\'s Opening: MacDonnell Double Gambit'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbqk1nr/pppp1ppp/8/8/2BPP2b/5Np1/P1P4P/RNBQ1RK1 b kq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 Bc5 3. b4 Bxb4 4. f4 exf4 5. Nf3 Be7 6. d4 Bh4+ 7. g3 fxg3 8. O-O
			variation => N__('Bishop\'s Opening: MacDonnell Double Gambit'),
			moves => {
				'g3h2' => 1,
			},
		},
		'rnbqk1nr/pppp1ppp/8/8/2BPP2b/5N2/P1P4p/RNBQ1RK1 w kq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 Bc5 3. b4 Bxb4 4. f4 exf4 5. Nf3 Be7 6. d4 Bh4+ 7. g3 fxg3 8. O-O gxh2+
			variation => N__('Bishop\'s Opening: MacDonnell Double Gambit'),
			moves => {
				'g1h1' => 1,
			},
		},
		'rnbqk1nr/pppp1ppp/8/8/2BPP2b/5N2/P1P4p/RNBQ1R1K b kq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 Bc5 3. b4 Bxb4 4. f4 exf4 5. Nf3 Be7 6. d4 Bh4+ 7. g3 fxg3 8. O-O gxh2+ 9. Kh1
			variation => N__('Bishop\'s Opening: MacDonnell, Four Pawns Gambit'),
			moves => {
			},
		},
		'rnbqk1nr/pppp1ppp/8/2b1p3/2B1P3/2P5/PP1P1PPP/RNBQK1NR b KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 Bc5 3. c3
			variation => N__('Bishop\'s Opening: Philidor Variation'),
			moves => {
				'd7d5' => 1,
				'd8g5' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqk1nr/ppp2ppp/8/2bpp3/2B1P3/2P5/PP1P1PPP/RNBQK1NR w KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 Bc5 3. c3 d5
			variation => N__('Bishop\'s Opening: Lewis Countergambit'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rnbqk1nr/ppp2ppp/8/2bBp3/4P3/2P5/PP1P1PPP/RNBQK1NR b KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 Bc5 3. c3 d5 4. Bxd5
			variation => N__('Bishop\'s Opening: Lewis Countergambit'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/5n2/2bBp3/4P3/2P5/PP1P1PPP/RNBQK1NR w KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 Bc5 3. c3 d5 4. Bxd5 Nf6
			variation => N__('Bishop\'s Opening: Lewis Countergambit'),
			moves => {
				'd1f3' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/5n2/2bBp3/4P3/2P2Q2/PP1P1PPP/RNB1K1NR b KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 Bc5 3. c3 d5 4. Bxd5 Nf6 5. Qf3
			variation => N__('Bishop\'s Opening: Lewis Countergambit, Jänisch'),
			moves => {
			},
		},
		'rnb1k1nr/pppp1ppp/8/2b1p1q1/2B1P3/2P5/PP1P1PPP/RNBQK1NR w KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 Bc5 3. c3 Qg5
			variation => N__('Bishop\'s Opening: del Rio Variation'),
			moves => {
			},
		},
		'rnbqk2r/pppp1ppp/5n2/2b1p3/2B1P3/2P5/PP1P1PPP/RNBQK1NR w KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 Bc5 3. c3 Nf6
			variation => N__('Bishop\'s Opening: 2... Bc5 3. c3 Nf6'),
			moves => {
				'd2d4' => 1,
			},
		},
		'rnbqk2r/pppp1ppp/5n2/2b1p3/2BPP3/2P5/PP3PPP/RNBQK1NR b KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 Bc5 3. c3 Nf6 4. d4
			variation => N__('Bishop\'s Opening: 2... Bc5 3. c3 Nf6'),
			moves => {
				'e5d4' => 1,
			},
		},
		'rnbqk2r/pppp1ppp/5n2/2b5/2BpP3/2P5/PP3PPP/RNBQK1NR w KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 Bc5 3. c3 Nf6 4. d4 exd4
			variation => N__('Bishop\'s Opening: 2... Bc5 3. c3 Nf6'),
			moves => {
				'e4e5' => 1,
			},
		},
		'rnbqk2r/pppp1ppp/5n2/2b1P3/2Bp4/2P5/PP3PPP/RNBQK1NR b KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 Bc5 3. c3 Nf6 4. d4 exd4 5. e5
			variation => N__('Bishop\'s Opening: 2... Bc5 3. c3 Nf6'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/5n2/2bpP3/2Bp4/2P5/PP3PPP/RNBQK1NR w KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 Bc5 3. c3 Nf6 4. d4 exd4 5. e5 d5
			variation => N__('Bishop\'s Opening: 2... Bc5 3. c3 Nf6'),
			moves => {
				'e5f6' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/5P2/2bp4/2Bp4/2P5/PP3PPP/RNBQK1NR b KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 Bc5 3. c3 Nf6 4. d4 exd4 5. e5 d5 6. exf6
			variation => N__('Bishop\'s Opening: 2... Bc5 3. c3 Nf6'),
			moves => {
				'd5c4' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/5P2/2b5/2pp4/2P5/PP3PPP/RNBQK1NR w KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 Bc5 3. c3 Nf6 4. d4 exd4 5. e5 d5 6. exf6 dxc4
			variation => N__('Bishop\'s Opening: 2... Bc5 3. c3 Nf6'),
			moves => {
				'd1h5' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/5P2/2b4Q/2pp4/2P5/PP3PPP/RNB1K1NR b KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 Bc5 3. c3 Nf6 4. d4 exd4 5. e5 d5 6. exf6 dxc4 7. Qh5
			variation => N__('Bishop\'s Opening: 2... Bc5 3. c3 Nf6'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppp2ppp/5P2/2b4Q/2pp4/2P5/PP3PPP/RNB1K1NR w KQ' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 Bc5 3. c3 Nf6 4. d4 exd4 5. e5 d5 6. exf6 dxc4 7. Qh5 O-O
			variation => N__('Bishop\'s Opening: Pratt Variation'),
			moves => {
			},
		},
		'rnbqk1nr/pppp1ppp/8/2b1p3/2B1P3/8/PPPPQPPP/RNB1K1NR b KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 Bc5 3. Qe2
			variation => N__('Bishop\'s Opening: 2... Bc5 3. Qe2'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/2b1p3/2B1P3/8/PPPPQPPP/RNB1K1NR w KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 Bc5 3. Qe2 Nc6
			variation => N__('Bishop\'s Opening: 2... Bc5 3. Qe2'),
			moves => {
				'c2c3' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/2b1p3/2B1P3/2P5/PP1PQPPP/RNB1K1NR b KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 Bc5 3. Qe2 Nc6 4. c3
			variation => N__('Bishop\'s Opening: 2... Bc5 3. Qe2'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/2b1p3/2B1P3/2P5/PP1PQPPP/RNB1K1NR w KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 Bc5 3. Qe2 Nc6 4. c3 Nf6
			variation => N__('Bishop\'s Opening: 2... Bc5 3. Qe2'),
			moves => {
				'f2f4' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/2b1p3/2B1PP2/2P5/PP1PQ1PP/RNB1K1NR b KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 Bc5 3. Qe2 Nc6 4. c3 Nf6 5. f4
			variation => N__('Bishop\'s Opening: Lopez Gambit'),
			moves => {
			},
		},
		'rnbqk1nr/pppp1ppp/8/2b1p3/2BPP3/8/PPP2PPP/RNBQK1NR b KQkq' => {
			eco => 'C23',
			# TRANSLATORS: C23: 1. e4 e5 2. Bc4 Bc5 3. d4
			variation => N__('Bishop\'s Opening: Lewis Gambit'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/4p3/2B1P3/8/PPPP1PPP/RNBQK1NR w KQkq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6
			variation => N__('Bishop\'s Opening: Berlin Defence'),
			moves => {
				'd2d3' => 1,
				'd2d4' => 1,
				'f2f4' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/4p3/2B1P3/3P4/PPP2PPP/RNBQK1NR b KQkq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d3
			variation => N__('Bishop\'s Opening: 3. d3'),
			moves => {
				'c7c6' => 1,
				'd7d5' => 1,
			},
		},
		'rnbqkb1r/pp1p1ppp/2p2n2/4p3/2B1P3/3P4/PPP2PPP/RNBQK1NR w KQkq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d3 c6
			variation => N__('Bishop\'s Opening: Paulsen Defence'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/pp1p1ppp/2p2n2/4p3/2B1P3/3P1N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d3 c6 4. Nf3
			variation => N__('Bishop\'s Opening: Paulsen, 4. Nf3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3pp3/2B1P3/3P4/PPP2PPP/RNBQK1NR w KQkq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d3 d5
			variation => N__('Bishop\'s Opening: 3. d3 d5'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/4p3/2BPP3/8/PPP2PPP/RNBQK1NR b KQkq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4
			variation => N__('Bishop\'s Opening: 3. d4'),
			moves => {
				'e5d4' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/8/2BpP3/8/PPP2PPP/RNBQK1NR w KQkq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4 exd4
			variation => N__('Bishop\'s Opening: 3. d4'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/8/2BpP3/5N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4 exd4 4. Nf3
			variation => N__('Bishop\'s Opening: Urusov Gambit'),
			moves => {
				'd7d5' => 1,
				'f6e4' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3p4/2BpP3/5N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4 exd4 4. Nf3 d5
			variation => N__('Bishop\'s Opening: Urusov Gambit'),
			moves => {
				'e4d5' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3P4/2Bp4/5N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4 exd4 4. Nf3 d5 5. exd5
			variation => N__('Bishop\'s Opening: Urusov Gambit'),
			moves => {
				'f8b4' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/5n2/3P4/1bBp4/5N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4 exd4 4. Nf3 d5 5. exd5 Bb4+
			variation => N__('Bishop\'s Opening: Urusov Gambit'),
			moves => {
				'c2c3' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/5n2/3P4/1bBp4/2P2N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4 exd4 4. Nf3 d5 5. exd5 Bb4+ 6. c3
			variation => N__('Bishop\'s Opening: Urusov Gambit'),
			moves => {
				'd8e7' => 1,
			},
		},
		'rnb1k2r/ppp1qppp/5n2/3P4/1bBp4/2P2N2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4 exd4 4. Nf3 d5 5. exd5 Bb4+ 6. c3 Qe7+
			variation => N__('Bishop\'s Opening: Urusov Gambit, Panov Variation'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/8/8/2Bpn3/5N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4 exd4 4. Nf3 Nxe4
			variation => N__('Bishop\'s Opening: Urusov Gambit'),
			moves => {
				'd1d4' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/8/8/2BQn3/5N2/PPP2PPP/RNB1K2R b KQkq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4 exd4 4. Nf3 Nxe4 5. Qxd4
			variation => N__('Bishop\'s Opening: Urusov Gambit'),
			moves => {
				'e4f6' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/8/2BQ4/5N2/PPP2PPP/RNB1K2R w KQkq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4 exd4 4. Nf3 Nxe4 5. Qxd4 Nf6
			variation => N__('Bishop\'s Opening: Urusov Gambit'),
			moves => {
				'b1c3' => 1,
				'c1g5' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/8/2BQ4/2N2N2/PPP2PPP/R1B1K2R b KQkq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4 exd4 4. Nf3 Nxe4 5. Qxd4 Nf6 6. Nc3
			variation => N__('Bishop\'s Opening: Urusov Gambit'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/8/2BQ4/2N2N2/PPP2PPP/R1B1K2R w KQkq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4 exd4 4. Nf3 Nxe4 5. Qxd4 Nf6 6. Nc3 Nc6
			variation => N__('Bishop\'s Opening: Urusov Gambit'),
			moves => {
				'd4h4' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/8/2B4Q/2N2N2/PPP2PPP/R1B1K2R b KQkq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4 exd4 4. Nf3 Nxe4 5. Qxd4 Nf6 6. Nc3 Nc6 7. Qh4
			variation => N__('Bishop\'s Opening: Urusov Gambit, Marshall Variation'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/6B1/2BQ4/5N2/PPP2PPP/RN2K2R b KQkq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4 exd4 4. Nf3 Nxe4 5. Qxd4 Nf6 6. Bg5
			variation => N__('Bishop\'s Opening: Urusov Gambit'),
			moves => {
				'b8c6' => 1,
				'f8e7' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/6B1/2BQ4/5N2/PPP2PPP/RN2K2R w KQkq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4 exd4 4. Nf3 Nxe4 5. Qxd4 Nf6 6. Bg5 Nc6
			variation => N__('Bishop\'s Opening: Urusov Gambit, 6. Bg5 Nc6 Defence'),
			moves => {
			},
		},
		'rnbqk2r/ppppbppp/5n2/6B1/2BQ4/5N2/PPP2PPP/RN2K2R w KQkq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4 exd4 4. Nf3 Nxe4 5. Qxd4 Nf6 6. Bg5 Be7
			variation => N__('Bishop\'s Opening: Urusov Gambit'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqk2r/ppppbppp/5n2/6B1/2BQ4/2N2N2/PPP2PPP/R3K2R b KQkq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4 exd4 4. Nf3 Nxe4 5. Qxd4 Nf6 6. Bg5 Be7 7. Nc3
			variation => N__('Bishop\'s Opening: Urusov Gambit'),
			moves => {
				'b8c6' => 1,
				'c7c6' => 1,
			},
		},
		'r1bqk2r/ppppbppp/2n2n2/6B1/2BQ4/2N2N2/PPP2PPP/R3K2R w KQkq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4 exd4 4. Nf3 Nxe4 5. Qxd4 Nf6 6. Bg5 Be7 7. Nc3 Nc6
			variation => N__('Bishop\'s Opening: Urusov Gambit, 7... Nc6 Defence'),
			moves => {
				'd4h4' => 1,
			},
		},
		'r1bqk2r/ppppbppp/2n2n2/6B1/2B4Q/2N2N2/PPP2PPP/R3K2R b KQkq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4 exd4 4. Nf3 Nxe4 5. Qxd4 Nf6 6. Bg5 Be7 7. Nc3 Nc6 8. Qh4
			variation => N__('Bishop\'s Opening: Urusov Gambit, 7... Nc6 Defence'),
			moves => {
				'd7d5' => 1,
				'd7d6' => 1,
			},
		},
		'r1bqk2r/ppp1bppp/2n2n2/3p2B1/2B4Q/2N2N2/PPP2PPP/R3K2R w KQkq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4 exd4 4. Nf3 Nxe4 5. Qxd4 Nf6 6. Bg5 Be7 7. Nc3 Nc6 8. Qh4 d5
			variation => N__('Bishop\'s Opening: Urusov Gambit, Estrin Variation'),
			moves => {
			},
		},
		'r1bqk2r/ppp1bppp/2np1n2/6B1/2B4Q/2N2N2/PPP2PPP/R3K2R w KQkq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4 exd4 4. Nf3 Nxe4 5. Qxd4 Nf6 6. Bg5 Be7 7. Nc3 Nc6 8. Qh4 d6
			variation => N__('Bishop\'s Opening: Urusov Gambit, Keres Variation'),
			moves => {
			},
		},
		'rnbqk2r/pp1pbppp/2p2n2/6B1/2BQ4/2N2N2/PPP2PPP/R3K2R w KQkq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4 exd4 4. Nf3 Nxe4 5. Qxd4 Nf6 6. Bg5 Be7 7. Nc3 c6
			variation => N__('Bishop\'s Opening: Urusov Gambit, 7... c6 Defence'),
			moves => {
				'e1c1' => 1,
			},
		},
		'rnbqk2r/pp1pbppp/2p2n2/6B1/2BQ4/2N2N2/PPP2PPP/2KR3R b kq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4 exd4 4. Nf3 Nxe4 5. Qxd4 Nf6 6. Bg5 Be7 7. Nc3 c6 8. O-O-O
			variation => N__('Bishop\'s Opening: Urusov Gambit, 7... c6 Defence'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqk2r/pp2bppp/2p2n2/3p2B1/2BQ4/2N2N2/PPP2PPP/2KR3R w kq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4 exd4 4. Nf3 Nxe4 5. Qxd4 Nf6 6. Bg5 Be7 7. Nc3 c6 8. O-O-O d5
			variation => N__('Bishop\'s Opening: Urusov Gambit, 7... c6 Defence'),
			moves => {
				'h1e1' => 1,
			},
		},
		'rnbqk2r/pp2bppp/2p2n2/3p2B1/2BQ4/2N2N2/PPP2PPP/2KRR3 b kq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4 exd4 4. Nf3 Nxe4 5. Qxd4 Nf6 6. Bg5 Be7 7. Nc3 c6 8. O-O-O d5 9. Rhe1
			variation => N__('Bishop\'s Opening: Urusov Gambit, 7... c6 Defence'),
			moves => {
				'c8e6' => 1,
				'e8g8' => 1,
			},
		},
		'rn1qk2r/pp2bppp/2p1bn2/3p2B1/2BQ4/2N2N2/PPP2PPP/2KRR3 w kq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4 exd4 4. Nf3 Nxe4 5. Qxd4 Nf6 6. Bg5 Be7 7. Nc3 c6 8. O-O-O d5 9. Rhe1 Be6
			variation => N__('Bishop\'s Opening: Urusov Gambit, 7... c6 Defence'),
			moves => {
				'c4d3' => 1,
			},
		},
		'rn1qk2r/pp2bppp/2p1bn2/3p2B1/3Q4/2NB1N2/PPP2PPP/2KRR3 b kq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4 exd4 4. Nf3 Nxe4 5. Qxd4 Nf6 6. Bg5 Be7 7. Nc3 c6 8. O-O-O d5 9. Rhe1 Be6 10. Bd3
			variation => N__('Bishop\'s Opening: Urusov Gambit, 7... c6 Defence'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r2qk2r/pp1nbppp/2p1bn2/3p2B1/3Q4/2NB1N2/PPP2PPP/2KRR3 w kq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4 exd4 4. Nf3 Nxe4 5. Qxd4 Nf6 6. Bg5 Be7 7. Nc3 c6 8. O-O-O d5 9. Rhe1 Be6 10. Bd3 Nbd7
			variation => N__('Bishop\'s Opening: Urusov Gambit, 7... c6 Defence'),
			moves => {
				'd4h4' => 1,
			},
		},
		'r2qk2r/pp1nbppp/2p1bn2/3p2B1/7Q/2NB1N2/PPP2PPP/2KRR3 b kq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4 exd4 4. Nf3 Nxe4 5. Qxd4 Nf6 6. Bg5 Be7 7. Nc3 c6 8. O-O-O d5 9. Rhe1 Be6 10. Bd3 Nbd7 11. Qh4
			variation => N__('Bishop\'s Opening: Urusov Gambit, 7... c6 Defence'),
			moves => {
				'c6c5' => 1,
				'd7c5' => 1,
			},
		},
		'r2qk2r/pp1nbppp/4bn2/2pp2B1/7Q/2NB1N2/PPP2PPP/2KRR3 w kq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4 exd4 4. Nf3 Nxe4 5. Qxd4 Nf6 6. Bg5 Be7 7. Nc3 c6 8. O-O-O d5 9. Rhe1 Be6 10. Bd3 Nbd7 11. Qh4 c5
			variation => N__('Bishop\'s Opening: Urusov Gambit, Karpov Variation'),
			moves => {
			},
		},
		'r2qk2r/pp2bppp/2p1bn2/2np2B1/7Q/2NB1N2/PPP2PPP/2KRR3 w kq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4 exd4 4. Nf3 Nxe4 5. Qxd4 Nf6 6. Bg5 Be7 7. Nc3 c6 8. O-O-O d5 9. Rhe1 Be6 10. Bd3 Nbd7 11. Qh4 Nc5
			variation => N__('Bishop\'s Opening: Urusov Gambit, 7... c6 Defence'),
			moves => {
				'f3d4' => 1,
			},
		},
		'r2qk2r/pp2bppp/2p1bn2/2np2B1/3N3Q/2NB4/PPP2PPP/2KRR3 b kq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4 exd4 4. Nf3 Nxe4 5. Qxd4 Nf6 6. Bg5 Be7 7. Nc3 c6 8. O-O-O d5 9. Rhe1 Be6 10. Bd3 Nbd7 11. Qh4 Nc5 12. Nd4
			variation => N__('Bishop\'s Opening: Urusov Gambit, 7... c6 Defence'),
			moves => {
				'f6g8' => 1,
			},
		},
		'r2qk1nr/pp2bppp/2p1b3/2np2B1/3N3Q/2NB4/PPP2PPP/2KRR3 w kq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4 exd4 4. Nf3 Nxe4 5. Qxd4 Nf6 6. Bg5 Be7 7. Nc3 c6 8. O-O-O d5 9. Rhe1 Be6 10. Bd3 Nbd7 11. Qh4 Nc5 12. Nd4 Ng8
			variation => N__('Bishop\'s Opening: Urusov Gambit, Forintos/Haag Variation'),
			moves => {
			},
		},
		'rnbq1rk1/pp2bppp/2p2n2/3p2B1/2BQ4/2N2N2/PPP2PPP/2KRR3 w -' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4 exd4 4. Nf3 Nxe4 5. Qxd4 Nf6 6. Bg5 Be7 7. Nc3 c6 8. O-O-O d5 9. Rhe1 O-O
			variation => N__('Bishop\'s Opening: Urusov Gambit, 7... c6 Defence'),
			moves => {
				'd4h4' => 1,
			},
		},
		'rnbq1rk1/pp2bppp/2p2n2/3p2B1/2B4Q/2N2N2/PPP2PPP/2KRR3 b -' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. d4 exd4 4. Nf3 Nxe4 5. Qxd4 Nf6 6. Bg5 Be7 7. Nc3 c6 8. O-O-O d5 9. Rhe1 O-O 10. Qh4
			variation => N__('Bishop\'s Opening: Urusov Gambit, Larsen Variation'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/4p3/2B1PP2/8/PPPP2PP/RNBQK1NR b KQkq' => {
			eco => 'C24',
			# TRANSLATORS: C24: 1. e4 e5 2. Bc4 Nf6 3. f4
			variation => N__('Bishop\'s Opening: Greco Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/4p3/4P3/2N5/PPPP1PPP/R1BQKBNR b KQkq' => {
			eco => 'C25a',
			# TRANSLATORS: C25a: 1. e4 e5 2. Nc3
			variation => N__('Vienna Game'),
			moves => {
				'b8c6' => 1,
				'd7d6' => 1,
				'f8b4' => 1,
				'f8c5' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqk1nr/pppp1ppp/8/4p3/1b2P3/2N5/PPPP1PPP/R1BQKBNR w KQkq' => {
			eco => 'C25b',
			# TRANSLATORS: C25b: 1. e4 e5 2. Nc3 Bb4
			variation => N__('Vienna: 2... Bb4'),
			moves => {
				'd1g4' => 1,
			},
		},
		'rnbqk1nr/pppp1ppp/8/4p3/1b2P1Q1/2N5/PPPP1PPP/R1B1KBNR b KQkq' => {
			eco => 'C25b',
			# TRANSLATORS: C25b: 1. e4 e5 2. Nc3 Bb4 3. Qg4
			variation => N__('Vienna: Zhuravlev'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/3p4/4p3/4P3/2N5/PPPP1PPP/R1BQKBNR w KQkq' => {
			eco => 'C25c',
			# TRANSLATORS: C25c: 1. e4 e5 2. Nc3 d6
			variation => N__('Vienna: 2... d6'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/3p4/4p3/2B1P3/2N5/PPPP1PPP/R1BQK1NR b KQkq' => {
			eco => 'C25c',
			# TRANSLATORS: C25c: 1. e4 e5 2. Nc3 d6 3. Bc4
			variation => N__('Vienna: 2... d6 3. Bc4'),
			moves => {
			},
		},
		'rnbqk1nr/pppp1ppp/8/2b1p3/4P3/2N5/PPPP1PPP/R1BQKBNR w KQkq' => {
			eco => 'C25d',
			# TRANSLATORS: C25d: 1. e4 e5 2. Nc3 Bc5
			variation => N__('Vienna: 2... Bc5'),
			moves => {
				'c3a4' => 1,
				'f1c4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqk1nr/pppp1ppp/8/2b1p3/N3P3/8/PPPP1PPP/R1BQKBNR b KQkq' => {
			eco => 'C25d',
			# TRANSLATORS: C25d: 1. e4 e5 2. Nc3 Bc5 3. Na4
			variation => N__('Vienna: Hammpe-Meitner'),
			moves => {
			},
		},
		'rnbqk1nr/pppp1ppp/8/2b1p3/2B1P3/2N5/PPPP1PPP/R1BQK1NR b KQkq' => {
			eco => 'C25e',
			# TRANSLATORS: C25e: 1. e4 e5 2. Nc3 Bc5 3. Bc4
			variation => N__('Vienna: 2... Bc5 3. Bc4'),
			moves => {
			},
		},
		'rnbqk1nr/pppp1ppp/8/2b1p3/4P3/2N2N2/PPPP1PPP/R1BQKB1R b KQkq' => {
			eco => 'C25f',
			# TRANSLATORS: C25f: 1. e4 e5 2. Nc3 Bc5 3. Nf3
			variation => N__('Vienna: 2... Bc5 3. Nf3'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4p3/4P3/2N5/PPPP1PPP/R1BQKBNR w KQkq' => {
			eco => 'C25g',
			# TRANSLATORS: C25g: 1. e4 e5 2. Nc3 Nc6
			variation => N__('Vienna: 2... Nc6'),
			moves => {
				'd2d4' => 1,
				'f1c4' => 1,
				'f2f4' => 1,
				'g2g3' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4p3/3PP3/2N5/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'C25g',
			# TRANSLATORS: C25g: 1. e4 e5 2. Nc3 Nc6 3. d4
			variation => N__('Vienna: Fyfe Gambit'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4p3/4P3/2N3P1/PPPP1P1P/R1BQKBNR b KQkq' => {
			eco => 'C25h',
			# TRANSLATORS: C25h: 1. e4 e5 2. Nc3 Nc6 3. g3
			variation => N__('Vienna: Paulsen Variation'),
			moves => {
				'f8c5' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/2b1p3/4P3/2N3P1/PPPP1P1P/R1BQKBNR w KQkq' => {
			eco => 'C25i',
			# TRANSLATORS: C25i: 1. e4 e5 2. Nc3 Nc6 3. g3 Bc5
			variation => N__('Vienna: Paulsen, 3... Bc5'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4p3/2B1P3/2N5/PPPP1PPP/R1BQK1NR b KQkq' => {
			eco => 'C25j',
			# TRANSLATORS: C25j: 1. e4 e5 2. Nc3 Nc6 3. Bc4
			variation => N__('Vienna: 2... Nc6 3. Bc4'),
			moves => {
				'f8c5' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/2b1p3/2B1P3/2N5/PPPP1PPP/R1BQK1NR w KQkq' => {
			eco => 'C25j',
			# TRANSLATORS: C25j: 1. e4 e5 2. Nc3 Nc6 3. Bc4 Bc5
			variation => N__('Vienna: 2... Nc6 3. Bc4 Bc5'),
			moves => {
				'd1g4' => 1,
				'd2d3' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/2b1p3/2B1P3/2NP4/PPP2PPP/R1BQK1NR b KQkq' => {
			eco => 'C25k',
			# TRANSLATORS: C25k: 1. e4 e5 2. Nc3 Nc6 3. Bc4 Bc5 4. d3
			variation => N__('Vienna: 2... Nc6 3. Bc4 Bc5 4. d3'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/2b1p3/2B1P1Q1/2N5/PPPP1PPP/R1B1K1NR b KQkq' => {
			eco => 'C25l',
			# TRANSLATORS: C25l: 1. e4 e5 2. Nc3 Nc6 3. Bc4 Bc5 4. Qg4
			variation => N__('Vienna: 2... Nc6 3. Bc4 Bc5 4. Qg4'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4p3/4PP2/2N5/PPPP2PP/R1BQKBNR b KQkq' => {
			eco => 'C25m',
			# TRANSLATORS: C25m: 1. e4 e5 2. Nc3 Nc6 3. f4
			variation => N__('Vienna: 2... Nc6 3. f4'),
			moves => {
				'e5f4' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/8/4Pp2/2N5/PPPP2PP/R1BQKBNR w KQkq' => {
			eco => 'C25m',
			# TRANSLATORS: C25m: 1. e4 e5 2. Nc3 Nc6 3. f4 exf4
			variation => N__('Vienna: 2... Nc6 3. f4'),
			moves => {
				'd2d4' => 1,
				'g1f3' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/8/3PPp2/2N5/PPP3PP/R1BQKBNR b KQkq' => {
			eco => 'C25n',
			# TRANSLATORS: C25n: 1. e4 e5 2. Nc3 Nc6 3. f4 exf4 4. d4
			variation => N__('Vienna: Steinitz Gambit'),
			moves => {
				'd8h4' => 1,
			},
		},
		'r1b1kbnr/pppp1ppp/2n5/8/3PPp1q/2N5/PPP3PP/R1BQKBNR w KQkq' => {
			eco => 'C25n',
			# TRANSLATORS: C25n: 1. e4 e5 2. Nc3 Nc6 3. f4 exf4 4. d4 Qh4+
			variation => N__('Vienna: Steinitz Gambit'),
			moves => {
				'e1e2' => 1,
			},
		},
		'r1b1kbnr/pppp1ppp/2n5/8/3PPp1q/2N5/PPP1K1PP/R1BQ1BNR b kq' => {
			eco => 'C25n',
			# TRANSLATORS: C25n: 1. e4 e5 2. Nc3 Nc6 3. f4 exf4 4. d4 Qh4+ 5. Ke2
			variation => N__('Vienna: Steinitz Gambit'),
			moves => {
				'b7b6' => 1,
				'd7d5' => 1,
			},
		},
		'r1b1kbnr/p1pp1ppp/1pn5/8/3PPp1q/2N5/PPP1K1PP/R1BQ1BNR w kq' => {
			eco => 'C25n',
			# TRANSLATORS: C25n: 1. e4 e5 2. Nc3 Nc6 3. f4 exf4 4. d4 Qh4+ 5. Ke2 b6
			variation => N__('Vienna: Steinitz Gambit, Fraser-Minckwitz Variation'),
			moves => {
			},
		},
		'r1b1kbnr/ppp2ppp/2n5/3p4/3PPp1q/2N5/PPP1K1PP/R1BQ1BNR w kq' => {
			eco => 'C25o',
			# TRANSLATORS: C25o: 1. e4 e5 2. Nc3 Nc6 3. f4 exf4 4. d4 Qh4+ 5. Ke2 d5
			variation => N__('Vienna: Steinitz Gambit, Zukertort Defence'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/8/4Pp2/2N2N2/PPPP2PP/R1BQKB1R b KQkq' => {
			eco => 'C25p',
			# TRANSLATORS: C25p: 1. e4 e5 2. Nc3 Nc6 3. f4 exf4 4. Nf3
			variation => N__('Vienna: 2... Nc6 3. f4 exf4 4. Nf3'),
			moves => {
				'g7g5' => 1,
			},
		},
		'r1bqkbnr/pppp1p1p/2n5/6p1/4Pp2/2N2N2/PPPP2PP/R1BQKB1R w KQkq' => {
			eco => 'C25p',
			# TRANSLATORS: C25p: 1. e4 e5 2. Nc3 Nc6 3. f4 exf4 4. Nf3 g5
			variation => N__('Vienna: 2... Nc6 3. f4 exf4 4. Nf3 g5'),
			moves => {
				'd2d4' => 1,
				'f1c4' => 1,
				'h2h4' => 1,
			},
		},
		'r1bqkbnr/pppp1p1p/2n5/6p1/2B1Pp2/2N2N2/PPPP2PP/R1BQK2R b KQkq' => {
			eco => 'C25p',
			# TRANSLATORS: C25p: 1. e4 e5 2. Nc3 Nc6 3. f4 exf4 4. Nf3 g5 5. Bc4
			variation => N__('Vienna: 2... Nc6 3. f4 exf4 4. Nf3 g5'),
			moves => {
				'g5g4' => 1,
			},
		},
		'r1bqkbnr/pppp1p1p/2n5/8/2B1Ppp1/2N2N2/PPPP2PP/R1BQK2R w KQkq' => {
			eco => 'C25p',
			# TRANSLATORS: C25p: 1. e4 e5 2. Nc3 Nc6 3. f4 exf4 4. Nf3 g5 5. Bc4 g4
			variation => N__('Vienna: 2... Nc6 3. f4 exf4 4. Nf3 g5'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqkbnr/pppp1p1p/2n5/8/2B1Ppp1/2N2N2/PPPP2PP/R1BQ1RK1 b kq' => {
			eco => 'C25p',
			# TRANSLATORS: C25p: 1. e4 e5 2. Nc3 Nc6 3. f4 exf4 4. Nf3 g5 5. Bc4 g4 6. O-O
			variation => N__('Vienna: Hamppe-Muzio Gambit'),
			moves => {
				'g4f3' => 1,
			},
		},
		'r1bqkbnr/pppp1p1p/2n5/8/2B1Pp2/2N2p2/PPPP2PP/R1BQ1RK1 w kq' => {
			eco => 'C25p',
			# TRANSLATORS: C25p: 1. e4 e5 2. Nc3 Nc6 3. f4 exf4 4. Nf3 g5 5. Bc4 g4 6. O-O gxf3
			variation => N__('Vienna: Hamppe-Muzio Gambit'),
			moves => {
				'd1f3' => 1,
			},
		},
		'r1bqkbnr/pppp1p1p/2n5/8/2B1Pp2/2N2Q2/PPPP2PP/R1B2RK1 b kq' => {
			eco => 'C25p',
			# TRANSLATORS: C25p: 1. e4 e5 2. Nc3 Nc6 3. f4 exf4 4. Nf3 g5 5. Bc4 g4 6. O-O gxf3 7. Qxf3
			variation => N__('Vienna: Hamppe-Muzio Gambit'),
			moves => {
				'c6e5' => 1,
			},
		},
		'r1bqkbnr/pppp1p1p/8/4n3/2B1Pp2/2N2Q2/PPPP2PP/R1B2RK1 w kq' => {
			eco => 'C25p',
			# TRANSLATORS: C25p: 1. e4 e5 2. Nc3 Nc6 3. f4 exf4 4. Nf3 g5 5. Bc4 g4 6. O-O gxf3 7. Qxf3 Ne5
			variation => N__('Vienna: Hamppe-Muzio Gambit'),
			moves => {
				'f3f4' => 1,
			},
		},
		'r1bqkbnr/pppp1p1p/8/4n3/2B1PQ2/2N5/PPPP2PP/R1B2RK1 b kq' => {
			eco => 'C25p',
			# TRANSLATORS: C25p: 1. e4 e5 2. Nc3 Nc6 3. f4 exf4 4. Nf3 g5 5. Bc4 g4 6. O-O gxf3 7. Qxf3 Ne5 8. Qxf4
			variation => N__('Vienna: Hamppe-Muzio Gambit'),
			moves => {
				'd8f6' => 1,
			},
		},
		'r1b1kbnr/pppp1p1p/5q2/4n3/2B1PQ2/2N5/PPPP2PP/R1B2RK1 w kq' => {
			eco => 'C25p',
			# TRANSLATORS: C25p: 1. e4 e5 2. Nc3 Nc6 3. f4 exf4 4. Nf3 g5 5. Bc4 g4 6. O-O gxf3 7. Qxf3 Ne5 8. Qxf4 Qf6
			variation => N__('Vienna: Hamppe-Muzio, Dubois Variation'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1p1p/2n5/6p1/4Pp1P/2N2N2/PPPP2P1/R1BQKB1R b KQkq' => {
			eco => 'C25q',
			# TRANSLATORS: C25q: 1. e4 e5 2. Nc3 Nc6 3. f4 exf4 4. Nf3 g5 5. h4
			variation => N__('Vienna: Hamppe-Allgaier Gambit'),
			moves => {
				'g5g4' => 1,
			},
		},
		'r1bqkbnr/pppp1p1p/2n5/8/4PppP/2N2N2/PPPP2P1/R1BQKB1R w KQkq' => {
			eco => 'C25q',
			# TRANSLATORS: C25q: 1. e4 e5 2. Nc3 Nc6 3. f4 exf4 4. Nf3 g5 5. h4 g4
			variation => N__('Vienna: Hamppe-Allgaier Gambit'),
			moves => {
				'f3g5' => 1,
			},
		},
		'r1bqkbnr/pppp1p1p/2n5/6N1/4PppP/2N5/PPPP2P1/R1BQKB1R b KQkq' => {
			eco => 'C25q',
			# TRANSLATORS: C25q: 1. e4 e5 2. Nc3 Nc6 3. f4 exf4 4. Nf3 g5 5. h4 g4 6. Ng5
			variation => N__('Vienna: Hamppe-Allgaier Gambit'),
			moves => {
				'd7d6' => 1,
			},
		},
		'r1bqkbnr/ppp2p1p/2np4/6N1/4PppP/2N5/PPPP2P1/R1BQKB1R w KQkq' => {
			eco => 'C25q',
			# TRANSLATORS: C25q: 1. e4 e5 2. Nc3 Nc6 3. f4 exf4 4. Nf3 g5 5. h4 g4 6. Ng5 d6
			variation => N__('Vienna: Hamppe-Allgaier Gambit, Alapin Variation'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1p1p/2n5/6p1/3PPp2/2N2N2/PPP3PP/R1BQKB1R b KQkq' => {
			eco => 'C25r',
			# TRANSLATORS: C25r: 1. e4 e5 2. Nc3 Nc6 3. f4 exf4 4. Nf3 g5 5. d4
			variation => N__('Vienna: Pierce Gambit'),
			moves => {
				'g5g4' => 1,
			},
		},
		'r1bqkbnr/pppp1p1p/2n5/8/3PPpp1/2N2N2/PPP3PP/R1BQKB1R w KQkq' => {
			eco => 'C25r',
			# TRANSLATORS: C25r: 1. e4 e5 2. Nc3 Nc6 3. f4 exf4 4. Nf3 g5 5. d4 g4
			variation => N__('Vienna: Pierce Gambit'),
			moves => {
				'f1c4' => 1,
			},
		},
		'r1bqkbnr/pppp1p1p/2n5/8/2BPPpp1/2N2N2/PPP3PP/R1BQK2R b KQkq' => {
			eco => 'C25r',
			# TRANSLATORS: C25r: 1. e4 e5 2. Nc3 Nc6 3. f4 exf4 4. Nf3 g5 5. d4 g4 6. Bc4
			variation => N__('Vienna: Pierce Gambit'),
			moves => {
				'g4f3' => 1,
			},
		},
		'r1bqkbnr/pppp1p1p/2n5/8/2BPPp2/2N2p2/PPP3PP/R1BQK2R w KQkq' => {
			eco => 'C25r',
			# TRANSLATORS: C25r: 1. e4 e5 2. Nc3 Nc6 3. f4 exf4 4. Nf3 g5 5. d4 g4 6. Bc4 gxf3
			variation => N__('Vienna: Pierce Gambit'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqkbnr/pppp1p1p/2n5/8/2BPPp2/2N2p2/PPP3PP/R1BQ1RK1 b kq' => {
			eco => 'C25r',
			# TRANSLATORS: C25r: 1. e4 e5 2. Nc3 Nc6 3. f4 exf4 4. Nf3 g5 5. d4 g4 6. Bc4 gxf3 7. O-O
			variation => N__('Vienna: Pierce Gambit'),
			moves => {
				'd7d5' => 1,
			},
		},
		'r1bqkbnr/ppp2p1p/2n5/3p4/2BPPp2/2N2p2/PPP3PP/R1BQ1RK1 w kq' => {
			eco => 'C25r',
			# TRANSLATORS: C25r: 1. e4 e5 2. Nc3 Nc6 3. f4 exf4 4. Nf3 g5 5. d4 g4 6. Bc4 gxf3 7. O-O d5
			variation => N__('Vienna: Pierce Gambit'),
			moves => {
				'e4d5' => 1,
			},
		},
		'r1bqkbnr/ppp2p1p/2n5/3P4/2BP1p2/2N2p2/PPP3PP/R1BQ1RK1 b kq' => {
			eco => 'C25r',
			# TRANSLATORS: C25r: 1. e4 e5 2. Nc3 Nc6 3. f4 exf4 4. Nf3 g5 5. d4 g4 6. Bc4 gxf3 7. O-O d5 8. exd5
			variation => N__('Vienna: Pierce Gambit'),
			moves => {
				'c8g4' => 1,
			},
		},
		'r2qkbnr/ppp2p1p/2n5/3P4/2BP1pb1/2N2p2/PPP3PP/R1BQ1RK1 w kq' => {
			eco => 'C25r',
			# TRANSLATORS: C25r: 1. e4 e5 2. Nc3 Nc6 3. f4 exf4 4. Nf3 g5 5. d4 g4 6. Bc4 gxf3 7. O-O d5 8. exd5 Bg4
			variation => N__('Vienna: Pierce Gambit'),
			moves => {
				'd5c6' => 1,
			},
		},
		'r2qkbnr/ppp2p1p/2P5/8/2BP1pb1/2N2p2/PPP3PP/R1BQ1RK1 b kq' => {
			eco => 'C25r',
			# TRANSLATORS: C25r: 1. e4 e5 2. Nc3 Nc6 3. f4 exf4 4. Nf3 g5 5. d4 g4 6. Bc4 gxf3 7. O-O d5 8. exd5 Bg4 9. dxc6
			variation => N__('Vienna: Pierce Gambit, Rushmere Attack'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/4p3/4P3/2N5/PPPP1PPP/R1BQKBNR w KQkq' => {
			eco => 'C26a',
			# TRANSLATORS: C26a: 1. e4 e5 2. Nc3 Nf6
			variation => N__('Vienna: 2... Nf6'),
			moves => {
				'a2a3' => 1,
				'd2d3' => 1,
				'f1c4' => 1,
				'f2f4' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/4p3/4P3/P1N5/1PPP1PPP/R1BQKBNR b KQkq' => {
			eco => 'C26a',
			# TRANSLATORS: C26a: 1. e4 e5 2. Nc3 Nf6 3. a3
			variation => N__('Vienna: Mengarini Variation'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/4p3/4P3/2NP4/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'C26b',
			# TRANSLATORS: C26b: 1. e4 e5 2. Nc3 Nf6 3. d3
			variation => N__('Vienna: 2... Nf6 3. d3'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/4p3/4P3/2N3P1/PPPP1P1P/R1BQKBNR b KQkq' => {
			eco => 'C26c',
			# TRANSLATORS: C26c: 1. e4 e5 2. Nc3 Nf6 3. g3
			variation => N__('Vienna: Smyslov Variation'),
			moves => {
				'b8c6' => 1,
				'd7d5' => 1,
				'f8c5' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4p3/4P3/2N3P1/PPPP1P1P/R1BQKBNR w KQkq' => {
			eco => 'C26d',
			# TRANSLATORS: C26d: 1. e4 e5 2. Nc3 Nf6 3. g3 Nc6
			variation => N__('Vienna: Smyslov, 3... Nc6'),
			moves => {
				'f1g2' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4p3/4P3/2N3P1/PPPP1PBP/R1BQK1NR b KQkq' => {
			eco => 'C26d',
			# TRANSLATORS: C26d: 1. e4 e5 2. Nc3 Nf6 3. g3 Nc6 4. Bg2
			variation => N__('Vienna: Smyslov, 3... Nc6'),
			moves => {
			},
		},
		'rnbqk2r/pppp1ppp/5n2/2b1p3/4P3/2N3P1/PPPP1P1P/R1BQKBNR w KQkq' => {
			eco => 'C26e',
			# TRANSLATORS: C26e: 1. e4 e5 2. Nc3 Nf6 3. g3 Bc5
			variation => N__('Vienna: Smyslov, 3... Bc5'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqk2r/pppp1ppp/5n2/2b1p3/4P3/2N3P1/PPPP1PBP/R1BQK1NR b KQkq' => {
			eco => 'C26e',
			# TRANSLATORS: C26e: 1. e4 e5 2. Nc3 Nf6 3. g3 Bc5 4. Bg2
			variation => N__('Vienna: Smyslov, 3... Bc5'),
			moves => {
				'b8c6' => 1,
				'd7d6' => 1,
				'e8g8' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/3p1n2/2b1p3/4P3/2N3P1/PPPP1PBP/R1BQK1NR w KQkq' => {
			eco => 'C26f',
			# TRANSLATORS: C26f: 1. e4 e5 2. Nc3 Nf6 3. g3 Bc5 4. Bg2 d6
			variation => N__('Vienna: Smyslov, 3... Bc5 4. Bg2 d6'),
			moves => {
			},
		},
		'rnbq1rk1/pppp1ppp/5n2/2b1p3/4P3/2N3P1/PPPP1PBP/R1BQK1NR w KQ' => {
			eco => 'C26g',
			# TRANSLATORS: C26g: 1. e4 e5 2. Nc3 Nf6 3. g3 Bc5 4. Bg2 O-O
			variation => N__('Vienna: Smyslov, 3... Bc5 4. Bg2 O-O'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/2b1p3/4P3/2N3P1/PPPP1PBP/R1BQK1NR w KQkq' => {
			eco => 'C26h',
			# TRANSLATORS: C26h: 1. e4 e5 2. Nc3 Nf6 3. g3 Bc5 4. Bg2 Nc6
			variation => N__('Vienna: Smyslov, 3... Bc5 4. Bg2 Nc6'),
			moves => {
				'g1e2' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/2b1p3/4P3/2N3P1/PPPPNPBP/R1BQK2R b KQkq' => {
			eco => 'C26h',
			# TRANSLATORS: C26h: 1. e4 e5 2. Nc3 Nf6 3. g3 Bc5 4. Bg2 Nc6 5. Nge2
			variation => N__('Vienna: Smyslov, 3... Bc5 4. Bg2 Nc6 5.Nge2'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3pp3/4P3/2N3P1/PPPP1P1P/R1BQKBNR w KQkq' => {
			eco => 'C26i',
			# TRANSLATORS: C26i: 1. e4 e5 2. Nc3 Nf6 3. g3 d5
			variation => N__('Vienna: Smyslov, 3... d5'),
			moves => {
				'e4d5' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3Pp3/8/2N3P1/PPPP1P1P/R1BQKBNR b KQkq' => {
			eco => 'C26i',
			# TRANSLATORS: C26i: 1. e4 e5 2. Nc3 Nf6 3. g3 d5 4. exd5
			variation => N__('Vienna: Smyslov, 3... d5'),
			moves => {
				'f6d5' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/8/3np3/8/2N3P1/PPPP1P1P/R1BQKBNR w KQkq' => {
			eco => 'C26i',
			# TRANSLATORS: C26i: 1. e4 e5 2. Nc3 Nf6 3. g3 d5 4. exd5 Nxd5
			variation => N__('Vienna: Smyslov, 3... d5'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/8/3np3/8/2N3P1/PPPP1PBP/R1BQK1NR b KQkq' => {
			eco => 'C26i',
			# TRANSLATORS: C26i: 1. e4 e5 2. Nc3 Nf6 3. g3 d5 4. exd5 Nxd5 5. Bg2
			variation => N__('Vienna: Smyslov, 3... d5'),
			moves => {
				'd5c3' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/8/4p3/8/2n3P1/PPPP1PBP/R1BQK1NR w KQkq' => {
			eco => 'C26j',
			# TRANSLATORS: C26j: 1. e4 e5 2. Nc3 Nf6 3. g3 d5 4. exd5 Nxd5 5. Bg2 Nxc3
			variation => N__('Vienna: Smyslov, 3... d5, 5...Nxc3'),
			moves => {
				'b2c3' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/8/4p3/8/2P3P1/P1PP1PBP/R1BQK1NR b KQkq' => {
			eco => 'C26j',
			# TRANSLATORS: C26j: 1. e4 e5 2. Nc3 Nf6 3. g3 d5 4. exd5 Nxd5 5. Bg2 Nxc3 6. bxc3
			variation => N__('Vienna: Smyslov, 3... d5, 5...Nxc3'),
			moves => {
				'f8d6' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/3b4/4p3/8/2P3P1/P1PP1PBP/R1BQK1NR w KQkq' => {
			eco => 'C26k',
			# TRANSLATORS: C26k: 1. e4 e5 2. Nc3 Nf6 3. g3 d5 4. exd5 Nxd5 5. Bg2 Nxc3 6. bxc3 Bd6
			variation => N__('Vienna: Smyslov, 3... d5, 5...Nxc3 6.bxc3 Bd6'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/4p3/2B1P3/2N5/PPPP1PPP/R1BQK1NR b KQkq' => {
			eco => 'C26l',
			# TRANSLATORS: C26l: 1. e4 e5 2. Nc3 Nf6 3. Bc4
			variation => N__('Vienna: 3. Bc4'),
			moves => {
				'b7b5' => 1,
				'b8c6' => 1,
				'f6e4' => 1,
				'f8b4' => 1,
				'f8c5' => 1,
			},
		},
		'rnbqkb1r/p1pp1ppp/5n2/1p2p3/2B1P3/2N5/PPPP1PPP/R1BQK1NR w KQkq' => {
			eco => 'C26l',
			# TRANSLATORS: C26l: 1. e4 e5 2. Nc3 Nf6 3. Bc4 b5
			variation => N__('Vienna: Horwitz Gambit'),
			moves => {
			},
		},
		'rnbqk2r/pppp1ppp/5n2/4p3/1bB1P3/2N5/PPPP1PPP/R1BQK1NR w KQkq' => {
			eco => 'C26m',
			# TRANSLATORS: C26m: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Bb4
			variation => N__('Vienna: 3. Bc4 Bb4'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqk2r/pppp1ppp/5n2/4p3/1bB1P3/2N2N2/PPPP1PPP/R1BQK2R b KQkq' => {
			eco => 'C26n',
			# TRANSLATORS: C26n: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Bb4 4. Nf3
			variation => N__('Vienna: 3. Bc4 Bb4 4. Nf3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/pppp1ppp/5n2/4p3/1bB1P3/2N2N2/PPPP1PPP/R1BQK2R w KQ' => {
			eco => 'C26o',
			# TRANSLATORS: C26o: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Bb4 4. Nf3 O-O
			variation => N__('Vienna: 3. Bc4 Bb4 4. Nf3 O-O'),
			moves => {
			},
		},
		'rnbqk2r/pppp1ppp/5n2/2b1p3/2B1P3/2N5/PPPP1PPP/R1BQK1NR w KQkq' => {
			eco => 'C26p',
			# TRANSLATORS: C26p: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Bc5
			variation => N__('Vienna: 3. Bc4 Bc5'),
			moves => {
				'd2d3' => 1,
				'f2f4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqk2r/pppp1ppp/5n2/2b1p3/2B1PP2/2N5/PPPP2PP/R1BQK1NR b KQkq' => {
			eco => 'C26p',
			# TRANSLATORS: C26p: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Bc5 4. f4
			variation => N__('Vienna: 3. Bc4 Bc5 4. f4'),
			moves => {
			},
		},
		'rnbqk2r/pppp1ppp/5n2/2b1p3/2B1P3/2N2N2/PPPP1PPP/R1BQK2R b KQkq' => {
			eco => 'C26q',
			# TRANSLATORS: C26q: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Bc5 4. Nf3
			variation => N__('Vienna: 3. Bc4 Bc5 4. Nf3'),
			moves => {
			},
		},
		'rnbqk2r/pppp1ppp/5n2/2b1p3/2B1P3/2NP4/PPP2PPP/R1BQK1NR b KQkq' => {
			eco => 'C26r',
			# TRANSLATORS: C26r: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Bc5 4. d3
			variation => N__('Vienna: 3. Bc4 Bc5 4. d3'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/3p1n2/2b1p3/2B1P3/2NP4/PPP2PPP/R1BQK1NR w KQkq' => {
			eco => 'C26s',
			# TRANSLATORS: C26s: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Bc5 4. d3 d6
			variation => N__('Vienna: 3. Bc4 Bc5 4. d3 d6'),
			moves => {
				'c3a4' => 1,
				'f2f4' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/3p1n2/2b1p3/N1B1P3/3P4/PPP2PPP/R1BQK1NR b KQkq' => {
			eco => 'C26t',
			# TRANSLATORS: C26t: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Bc5 4. d3 d6 5. Na4
			variation => N__('Vienna: 3. Bc4 Bc5 4. d3 d6 5. Na4'),
			moves => {
			},
		},
		'rnbqk2r/ppp2ppp/3p1n2/2b1p3/2B1PP2/2NP4/PPP3PP/R1BQK1NR b KQkq' => {
			eco => 'C26u',
			# TRANSLATORS: C26u: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Bc5 4. d3 d6 5. f4
			variation => N__('Vienna: 3. Bc4 Bc5 4. d3 d6 5. f4'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/8/4p3/2B1n3/2N5/PPPP1PPP/R1BQK1NR w KQkq' => {
			eco => 'C27a',
			# TRANSLATORS: C27a: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nxe4
			variation => N__('Vienna: 3. Bc4 Nxe4'),
			moves => {
				'c3e4' => 1,
				'd1h5' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/8/4p3/2B1N3/8/PPPP1PPP/R1BQK1NR b KQkq' => {
			eco => 'C27b',
			# TRANSLATORS: C27b: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nxe4 4. Nxe4
			variation => N__('Vienna: 3. Bc4 Nxe4 4.Nxe4'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/8/4p2Q/2B1n3/2N5/PPPP1PPP/R1B1K1NR b KQkq' => {
			eco => 'C27c',
			# TRANSLATORS: C27c: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nxe4 4. Qh5
			variation => N__('Vienna: 3. Bc4 Nxe4 4. Qh5'),
			moves => {
				'e4d6' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/3n4/4p2Q/2B5/2N5/PPPP1PPP/R1B1K1NR w KQkq' => {
			eco => 'C27c',
			# TRANSLATORS: C27c: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nxe4 4. Qh5 Nd6
			variation => N__('Vienna: 3. Bc4 Nxe4 4. Qh5'),
			moves => {
				'c4b3' => 1,
				'h5e5' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/3n4/4Q3/2B5/2N5/PPPP1PPP/R1B1K1NR b KQkq' => {
			eco => 'C27d',
			# TRANSLATORS: C27d: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nxe4 4. Qh5 Nd6 5. Qxe5+
			variation => N__('Vienna: 3. Bc4 Nxe4 4. Qh5 Nd6 5.Qxe5+'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/3n4/4p2Q/8/1BN5/PPPP1PPP/R1B1K1NR b KQkq' => {
			eco => 'C27e',
			# TRANSLATORS: C27e: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nxe4 4. Qh5 Nd6 5. Bb3
			variation => N__('Vienna: 3. Bc4 Nxe4 4. Qh5 Nd6 5. Bb3'),
			moves => {
				'b8c6' => 1,
				'f8e7' => 1,
			},
		},
		'rnbqk2r/ppppbppp/3n4/4p2Q/8/1BN5/PPPP1PPP/R1B1K1NR w KQkq' => {
			eco => 'C27f',
			# TRANSLATORS: C27f: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nxe4 4. Qh5 Nd6 5. Bb3 Be7
			variation => N__('Vienna: 3. Bc4 Nxe4 4. Qh5 Nd6 5. Bb3 Be7'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqk2r/ppppbppp/3n4/4p2Q/8/1BN2N2/PPPP1PPP/R1B1K2R b KQkq' => {
			eco => 'C27f',
			# TRANSLATORS: C27f: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nxe4 4. Qh5 Nd6 5. Bb3 Be7 6. Nf3
			variation => N__('Vienna: 3. Bc4 Nxe4 4. Qh5 Nd6 5. Bb3 Be7'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqk2r/ppppbppp/2nn4/4p2Q/8/1BN2N2/PPPP1PPP/R1B1K2R w KQkq' => {
			eco => 'C27f',
			# TRANSLATORS: C27f: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nxe4 4. Qh5 Nd6 5. Bb3 Be7 6. Nf3 Nc6
			variation => N__('Vienna: 3. Bc4 Nxe4 4. Qh5 Nd6 5. Bb3 Be7'),
			moves => {
				'f3e5' => 1,
			},
		},
		'r1bqk2r/ppppbppp/2nn4/4N2Q/8/1BN5/PPPP1PPP/R1B1K2R b KQkq' => {
			eco => 'C27g',
			# TRANSLATORS: C27g: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nxe4 4. Qh5 Nd6 5. Bb3 Be7 6. Nf3 Nc6 7. Nxe5
			variation => N__('Vienna: Alekhine Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2nn4/4p2Q/8/1BN5/PPPP1PPP/R1B1K1NR w KQkq' => {
			eco => 'C27h',
			# TRANSLATORS: C27h: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nxe4 4. Qh5 Nd6 5. Bb3 Nc6
			variation => N__('Vienna: 3. Bc4 Nxe4 4. Qh5 Nd6 5. Bb3 Nc6'),
			moves => {
				'c3b5' => 1,
				'd2d4' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2nn4/1N2p2Q/8/1B6/PPPP1PPP/R1B1K1NR b KQkq' => {
			eco => 'C27h',
			# TRANSLATORS: C27h: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nxe4 4. Qh5 Nd6 5. Bb3 Nc6 6. Nb5
			variation => N__('Vienna: 3. Bc4 Nxe4 4. Qh5 Nd6 5. Bb3 Nc6'),
			moves => {
				'g7g6' => 1,
			},
		},
		'r1bqkb1r/pppp1p1p/2nn2p1/1N2p2Q/8/1B6/PPPP1PPP/R1B1K1NR w KQkq' => {
			eco => 'C27h',
			# TRANSLATORS: C27h: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nxe4 4. Qh5 Nd6 5. Bb3 Nc6 6. Nb5 g6
			variation => N__('Vienna: 3. Bc4 Nxe4 4. Qh5 Nd6 5. Bb3 Nc6'),
			moves => {
				'h5f3' => 1,
			},
		},
		'r1bqkb1r/pppp1p1p/2nn2p1/1N2p3/8/1B3Q2/PPPP1PPP/R1B1K1NR b KQkq' => {
			eco => 'C27h',
			# TRANSLATORS: C27h: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nxe4 4. Qh5 Nd6 5. Bb3 Nc6 6. Nb5 g6 7. Qf3
			variation => N__('Vienna: 3. Bc4 Nxe4 4. Qh5 Nd6 5. Bb3 Nc6'),
			moves => {
				'f7f5' => 1,
			},
		},
		'r1bqkb1r/pppp3p/2nn2p1/1N2pp2/8/1B3Q2/PPPP1PPP/R1B1K1NR w KQkq' => {
			eco => 'C27h',
			# TRANSLATORS: C27h: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nxe4 4. Qh5 Nd6 5. Bb3 Nc6 6. Nb5 g6 7. Qf3 f5
			variation => N__('Vienna: 3. Bc4 Nxe4 4. Qh5 Nd6 5. Bb3 Nc6'),
			moves => {
				'f3d5' => 1,
			},
		},
		'r1bqkb1r/pppp3p/2nn2p1/1N1Qpp2/8/1B6/PPPP1PPP/R1B1K1NR b KQkq' => {
			eco => 'C27h',
			# TRANSLATORS: C27h: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nxe4 4. Qh5 Nd6 5. Bb3 Nc6 6. Nb5 g6 7. Qf3 f5 8. Qd5
			variation => N__('Vienna: 3. Bc4 Nxe4 4. Qh5 Nd6 5. Bb3 Nc6'),
			moves => {
				'd8e7' => 1,
			},
		},
		'r1b1kb1r/ppppq2p/2nn2p1/1N1Qpp2/8/1B6/PPPP1PPP/R1B1K1NR w KQkq' => {
			eco => 'C27h',
			# TRANSLATORS: C27h: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nxe4 4. Qh5 Nd6 5. Bb3 Nc6 6. Nb5 g6 7. Qf3 f5 8. Qd5 Qe7
			variation => N__('Vienna: 3. Bc4 Nxe4 4. Qh5 Nd6 5. Bb3 Nc6'),
			moves => {
				'b5c7' => 1,
			},
		},
		'r1b1kb1r/ppNpq2p/2nn2p1/3Qpp2/8/1B6/PPPP1PPP/R1B1K1NR b KQkq' => {
			eco => 'C27h',
			# TRANSLATORS: C27h: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nxe4 4. Qh5 Nd6 5. Bb3 Nc6 6. Nb5 g6 7. Qf3 f5 8. Qd5 Qe7 9. Nxc7+
			variation => N__('Vienna: 3. Bc4 Nxe4 4. Qh5 Nd6 5. Bb3 Nc6'),
			moves => {
				'e8d8' => 1,
			},
		},
		'r1bk1b1r/ppNpq2p/2nn2p1/3Qpp2/8/1B6/PPPP1PPP/R1B1K1NR w KQ' => {
			eco => 'C27h',
			# TRANSLATORS: C27h: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nxe4 4. Qh5 Nd6 5. Bb3 Nc6 6. Nb5 g6 7. Qf3 f5 8. Qd5 Qe7 9. Nxc7+ Kd8
			variation => N__('Vienna: 3. Bc4 Nxe4 4. Qh5 Nd6 5. Bb3 Nc6'),
			moves => {
				'c7a8' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2nn4/4p2Q/3P4/1BN5/PPP2PPP/R1B1K1NR b KQkq' => {
			eco => 'C27h',
			# TRANSLATORS: C27h: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nxe4 4. Qh5 Nd6 5. Bb3 Nc6 6. d4
			variation => N__('Vienna: Adams\' Gambit'),
			moves => {
			},
		},
		'N1bk1b1r/pp1pq2p/2nn2p1/3Qpp2/8/1B6/PPPP1PPP/R1B1K1NR b KQ' => {
			eco => 'C27i',
			# TRANSLATORS: C27i: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nxe4 4. Qh5 Nd6 5. Bb3 Nc6 6. Nb5 g6 7. Qf3 f5 8. Qd5 Qe7 9. Nxc7+ Kd8 10. Nxa8
			variation => N__('Vienna: Frankenstein-Dracula Variation'),
			moves => {
				'b7b6' => 1,
			},
		},
		'N1bk1b1r/p2pq2p/1pnn2p1/3Qpp2/8/1B6/PPPP1PPP/R1B1K1NR w KQ' => {
			eco => 'C27i',
			# TRANSLATORS: C27i: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nxe4 4. Qh5 Nd6 5. Bb3 Nc6 6. Nb5 g6 7. Qf3 f5 8. Qd5 Qe7 9. Nxc7+ Kd8 10. Nxa8 b6
			variation => N__('Vienna: Frankenstein-Dracula Variation'),
			moves => {
				'd2d3' => 1,
			},
		},
		'N1bk1b1r/p2pq2p/1pnn2p1/3Qpp2/8/1B1P4/PPP2PPP/R1B1K1NR b KQ' => {
			eco => 'C27j',
			# TRANSLATORS: C27j: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nxe4 4. Qh5 Nd6 5. Bb3 Nc6 6. Nb5 g6 7. Qf3 f5 8. Qd5 Qe7 9. Nxc7+ Kd8 10. Nxa8 b6 11. d3
			variation => N__('Vienna: Frankenstein-Dracula, 11. d3'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4p3/2B1P3/2N5/PPPP1PPP/R1BQK1NR w KQkq' => {
			eco => 'C28a',
			# TRANSLATORS: C28a: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nc6
			variation => N__('Vienna: 3. Bc4 Nc6'),
			moves => {
				'd2d3' => 1,
				'f2f4' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4p3/2B1PP2/2N5/PPPP2PP/R1BQK1NR b KQkq' => {
			eco => 'C28b',
			# TRANSLATORS: C28b: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nc6 4. f4
			variation => N__('Vienna: 3. Bc4 Nc6 4. f4'),
			moves => {
				'f6e4' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n5/4p3/2B1nP2/2N5/PPPP2PP/R1BQK1NR w KQkq' => {
			eco => 'C28b',
			# TRANSLATORS: C28b: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nc6 4. f4 Nxe4
			variation => N__('Vienna: 3. Bc4 Nc6 4. f4'),
			moves => {
				'g1f3' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n5/4p3/2B1nP2/2N2N2/PPPP2PP/R1BQK2R b KQkq' => {
			eco => 'C28b',
			# TRANSLATORS: C28b: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nc6 4. f4 Nxe4 5. Nf3
			variation => N__('Vienna: Bronstein Gambit'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4p3/2B1P3/2NP4/PPP2PPP/R1BQK1NR b KQkq' => {
			eco => 'C28c',
			# TRANSLATORS: C28c: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nc6 4. d3
			variation => N__('Vienna: 3. Bc4 Nc6 4. d3'),
			moves => {
				'c6a5' => 1,
				'f8b4' => 1,
				'f8c5' => 1,
				'f8e7' => 1,
			},
		},
		'r1bqk2r/ppppbppp/2n2n2/4p3/2B1P3/2NP4/PPP2PPP/R1BQK1NR w KQkq' => {
			eco => 'C28d',
			# TRANSLATORS: C28d: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nc6 4. d3 Be7
			variation => N__('Vienna: 3. Bc4 Nc6 4. d3 Be7'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/5n2/n3p3/2B1P3/2NP4/PPP2PPP/R1BQK1NR w KQkq' => {
			eco => 'C28e',
			# TRANSLATORS: C28e: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nc6 4. d3 Na5
			variation => N__('Vienna: 3. Bc4 Nc6 4. d3 Na5'),
			moves => {
				'g1e2' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/5n2/n3p3/2B1P3/2NP4/PPP1NPPP/R1BQK2R b KQkq' => {
			eco => 'C28f',
			# TRANSLATORS: C28f: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nc6 4. d3 Na5 5. Nge2
			variation => N__('Vienna: 3. Bc4 Nc6 4. d3 Na5 5.Nge2'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/2b1p3/2B1P3/2NP4/PPP2PPP/R1BQK1NR w KQkq' => {
			eco => 'C28g',
			# TRANSLATORS: C28g: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nc6 4. d3 Bc5
			variation => N__('Vienna: 3. Bc4 Nc6 4. d3 Bc5'),
			moves => {
				'c1g5' => 1,
				'f2f4' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/2b1p1B1/2B1P3/2NP4/PPP2PPP/R2QK1NR b KQkq' => {
			eco => 'C28h',
			# TRANSLATORS: C28h: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nc6 4. d3 Bc5 5. Bg5
			variation => N__('Vienna: 3. Bc4 Nc6 4. d3 Bc5 5. Bg5'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/2b1p3/2B1PP2/2NP4/PPP3PP/R1BQK1NR b KQkq' => {
			eco => 'C28i',
			# TRANSLATORS: C28i: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nc6 4. d3 Bc5 5. f4
			variation => N__('Vienna: 3. Bc4 Nc6 4. d3 Bc5 5. f4'),
			moves => {
				'd7d6' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2np1n2/2b1p3/2B1PP2/2NP4/PPP3PP/R1BQK1NR w KQkq' => {
			eco => 'C28i',
			# TRANSLATORS: C28i: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nc6 4. d3 Bc5 5. f4 d6
			variation => N__('Vienna: 3. Bc4 Nc6 4. d3 Bc5 5. f4'),
			moves => {
				'g1f3' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2np1n2/2b1p3/2B1PP2/2NP1N2/PPP3PP/R1BQK2R b KQkq' => {
			eco => 'C28j',
			# TRANSLATORS: C28j: 1. e4 e5 2. f4 Bc5 3. Nf3 d6 4. Nc3 Nf6 5. Bc4 Nc6 6. d3
			variation => N__('Vienna: 3. Bc4 Nc6 4. d3 Bc5 5. f4 d6 6. Nf3'),
			moves => {
				'a7a6' => 1,
				'c8g4' => 1,
			},
		},
		'r2qk2r/ppp2ppp/2np1n2/2b1p3/2B1PPb1/2NP1N2/PPP3PP/R1BQK2R w KQkq' => {
			eco => 'C28k',
			# TRANSLATORS: C28k: 1. e4 e5 2. f4 Bc5 3. Nf3 d6 4. Nc3 Nf6 5. Bc4 Nc6 6. d3 Bg4
			variation => N__('Vienna: 3. Bc4 Nc6 4. d3 Bc5 5. f4 d6 6. Nf3 Bg4'),
			moves => {
				'h2h3' => 1,
			},
		},
		'r2qk2r/ppp2ppp/2np1n2/2b1p3/2B1PPb1/2NP1N1P/PPP3P1/R1BQK2R b KQkq' => {
			eco => 'C28k',
			# TRANSLATORS: C28k: 1. e4 e5 2. f4 Bc5 3. Nf3 d6 4. Nc3 Nf6 5. Bc4 Nc6 6. d3 Bg4 7. h3
			variation => N__('Vienna: 3. Bc4 Nc6 4. d3 Bc5 5. f4 d6 6. Nf3 Bg4'),
			moves => {
				'g4f3' => 1,
			},
		},
		'r2qk2r/ppp2ppp/2np1n2/2b1p3/2B1PP2/2NP1b1P/PPP3P1/R1BQK2R w KQkq' => {
			eco => 'C28k',
			# TRANSLATORS: C28k: 1. e4 e5 2. f4 Bc5 3. Nf3 d6 4. Nc3 Nf6 5. Bc4 Nc6 6. d3 Bg4 7. h3 Bxf3
			variation => N__('Vienna: 3. Bc4 Nc6 4. d3 Bc5 5. f4 d6 6. Nf3 Bg4'),
			moves => {
				'd1f3' => 1,
			},
		},
		'r2qk2r/ppp2ppp/2np1n2/2b1p3/2B1PP2/2NP1Q1P/PPP3P1/R1B1K2R b KQkq' => {
			eco => 'C28k',
			# TRANSLATORS: C28k: 1. e4 e5 2. f4 Bc5 3. Nf3 d6 4. Nc3 Nf6 5. Bc4 Nc6 6. d3 Bg4 7. h3 Bxf3 8. Qxf3
			variation => N__('Vienna: 3. Bc4 Nc6 4. d3 Bc5 5. f4 d6 6. Nf3 Bg4'),
			moves => {
				'e5f4' => 1,
			},
		},
		'r1bqk2r/1pp2ppp/p1np1n2/2b1p3/2B1PP2/2NP1N2/PPP3PP/R1BQK2R w KQkq' => {
			eco => 'C28l',
			# TRANSLATORS: C28l: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nc6 4. d3 Bc5 5. f4 d6 6. Nf3 a6
			variation => N__('Vienna: 3. Bc4 Nc6 4. d3 Bc5 5. f4 d6 6. Nf3 a6'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/4p3/1bB1P3/2NP4/PPP2PPP/R1BQK1NR w KQkq' => {
			eco => 'C28m',
			# TRANSLATORS: C28m: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nc6 4. d3 Bb4
			variation => N__('Vienna: 3. Bc4 Nc6 4. d3 Bb4'),
			moves => {
				'c1g5' => 1,
				'g1e2' => 1,
				'g1f3' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/4p3/1bB1P3/2NP1N2/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'C28n',
			# TRANSLATORS: C28n: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nc6 4. d3 Bb4 5. Nf3
			variation => N__('Vienna: 3. Bc4 Nc6 4. d3 Bb4 5. Nf3'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/4p1B1/1bB1P3/2NP4/PPP2PPP/R2QK1NR b KQkq' => {
			eco => 'C28o',
			# TRANSLATORS: C28o: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nc6 4. d3 Bb4 5. Bg5
			variation => N__('Vienna: 3. Bc4 Nc6 4. d3 Bb4 5. Bg5'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/4p3/1bB1P3/2NP4/PPP1NPPP/R1BQK2R b KQkq' => {
			eco => 'C28p',
			# TRANSLATORS: C28p: 1. e4 e5 2. Nc3 Nf6 3. Bc4 Nc6 4. d3 Bb4 5. Ne2
			variation => N__('Vienna: 3. Bc4 Nc6 4. d3 Bb4 5. Ne2'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/4p3/4PP2/2N5/PPPP2PP/R1BQKBNR b KQkq' => {
			eco => 'C29a',
			# TRANSLATORS: C29a: 1. e4 e5 2. Nc3 Nf6 3. f4
			variation => N__('Vienna Gambit'),
			moves => {
				'd7d5' => 1,
				'd7d6' => 1,
				'e5f4' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/8/4Pp2/2N5/PPPP2PP/R1BQKBNR w KQkq' => {
			eco => 'C29a',
			# TRANSLATORS: C29a: 1. e4 e5 2. Nc3 Nf6 3. f4 exf4
			variation => N__('Vienna Gambit: 3...exf4'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/3p1n2/4p3/4PP2/2N5/PPPP2PP/R1BQKBNR w KQkq' => {
			eco => 'C29b',
			# TRANSLATORS: C29b: 1. e4 e5 2. Nc3 Nf6 3. f4 d6
			variation => N__('Vienna Gambit: 3... d6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/3p1n2/4p3/4PP2/2N2N2/PPPP2PP/R1BQKB1R b KQkq' => {
			eco => 'C29b',
			# TRANSLATORS: C29b: 1. e4 e5 2. Nc3 Nf6 3. f4 d6 4. Nf3
			variation => N__('Vienna Gambit: 3... d6 4. Nf3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3pp3/4PP2/2N5/PPPP2PP/R1BQKBNR w KQkq' => {
			eco => 'C29c',
			# TRANSLATORS: C29c: 1. e4 e5 2. Nc3 Nf6 3. f4 d5
			variation => N__('Vienna Gambit: 3... d5'),
			moves => {
				'd2d3' => 1,
				'e4d5' => 1,
				'f4e5' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3Pp3/5P2/2N5/PPPP2PP/R1BQKBNR b KQkq' => {
			eco => 'C29d',
			# TRANSLATORS: C29d: 1. e4 e5 2. Nc3 Nf6 3. f4 d5 4. exd5
			variation => N__('Vienna Gambit: 3... d5 4.exd5'),
			moves => {
				'e5f4' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3P4/5p2/2N5/PPPP2PP/R1BQKBNR w KQkq' => {
			eco => 'C29d',
			# TRANSLATORS: C29d: 1. e4 e5 2. Nc3 Nf6 3. f4 d5 4. exd5 exf4
			variation => N__('Vienna Gambit: 3... d5 4.exd5 exf4'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3pp3/4PP2/2NP4/PPP3PP/R1BQKBNR b KQkq' => {
			eco => 'C29e',
			# TRANSLATORS: C29e: 1. e4 e5 2. Nc3 Nf6 3. f4 d5 4. d3
			variation => N__('Vienna Gambit: Steinitz Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3pP3/4P3/2N5/PPPP2PP/R1BQKBNR b KQkq' => {
			eco => 'C29f',
			# TRANSLATORS: C29f: 1. e4 e5 2. Nc3 Nf6 3. f4 d5 4. fxe5
			variation => N__('Vienna Gambit: 4.fxe5'),
			moves => {
				'f6e4' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/8/3pP3/4n3/2N5/PPPP2PP/R1BQKBNR w KQkq' => {
			eco => 'C29f',
			# TRANSLATORS: C29f: 1. e4 e5 2. Nc3 Nf6 3. f4 d5 4. fxe5 Nxe4
			variation => N__('Vienna Gambit: 4.fxe5'),
			moves => {
				'd1f3' => 1,
				'd2d3' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/8/3pP3/4n3/2NP4/PPP3PP/R1BQKBNR b KQkq' => {
			eco => 'C29g',
			# TRANSLATORS: C29g: 1. e4 e5 2. Nc3 Nf6 3. f4 d5 4. fxe5 Nxe4 5. d3
			variation => N__('Vienna Gambit: Oxford Variation'),
			moves => {
				'd8h4' => 1,
				'e4c3' => 1,
				'f8b4' => 1,
			},
		},
		'rnb1kb1r/ppp2ppp/8/3pP3/4n2q/2NP4/PPP3PP/R1BQKBNR w KQkq' => {
			eco => 'C29g',
			# TRANSLATORS: C29g: 1. e4 e5 2. Nc3 Nf6 3. f4 d5 4. fxe5 Nxe4 5. d3 Qh4+
			variation => N__('Vienna Gambit: Oxford Variation'),
			moves => {
				'g2g3' => 1,
			},
		},
		'rnb1kb1r/ppp2ppp/8/3pP3/4n2q/2NP2P1/PPP4P/R1BQKBNR b KQkq' => {
			eco => 'C29g',
			# TRANSLATORS: C29g: 1. e4 e5 2. Nc3 Nf6 3. f4 d5 4. fxe5 Nxe4 5. d3 Qh4+ 6. g3
			variation => N__('Vienna Gambit: Oxford Variation'),
			moves => {
				'e4g3' => 1,
			},
		},
		'rnb1kb1r/ppp2ppp/8/3pP3/7q/2NP2n1/PPP4P/R1BQKBNR w KQkq' => {
			eco => 'C29g',
			# TRANSLATORS: C29g: 1. e4 e5 2. Nc3 Nf6 3. f4 d5 4. fxe5 Nxe4 5. d3 Qh4+ 6. g3 Nxg3
			variation => N__('Vienna Gambit: Oxford Variation'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnb1kb1r/ppp2ppp/8/3pP3/7q/2NP1Nn1/PPP4P/R1BQKB1R b KQkq' => {
			eco => 'C29g',
			# TRANSLATORS: C29g: 1. e4 e5 2. Nc3 Nf6 3. f4 d5 4. fxe5 Nxe4 5. d3 Qh4+ 6. g3 Nxg3 7. Nf3
			variation => N__('Vienna Gambit: Oxford Variation'),
			moves => {
				'h4h5' => 1,
			},
		},
		'rnb1kb1r/ppp2ppp/8/3pP2q/8/2NP1Nn1/PPP4P/R1BQKB1R w KQkq' => {
			eco => 'C29g',
			# TRANSLATORS: C29g: 1. e4 e5 2. Nc3 Nf6 3. f4 d5 4. fxe5 Nxe4 5. d3 Qh4+ 6. g3 Nxg3 7. Nf3 Qh5
			variation => N__('Vienna Gambit: Oxford Variation'),
			moves => {
				'c3d5' => 1,
			},
		},
		'rnb1kb1r/ppp2ppp/8/3NP2q/8/3P1Nn1/PPP4P/R1BQKB1R b KQkq' => {
			eco => 'C29g',
			# TRANSLATORS: C29g: 1. e4 e5 2. Nc3 Nf6 3. f4 d5 4. fxe5 Nxe4 5. d3 Qh4+ 6. g3 Nxg3 7. Nf3 Qh5 8. Nxd5
			variation => N__('Vienna Gambit: Wurzburger Trap'),
			moves => {
			},
		},
		'rnbqk2r/ppp2ppp/8/3pP3/1b2n3/2NP4/PPP3PP/R1BQKBNR w KQkq' => {
			eco => 'C29h',
			# TRANSLATORS: C29h: 1. e4 e5 2. Nc3 Nf6 3. f4 d5 4. fxe5 Nxe4 5. d3 Bb4
			variation => N__('Vienna Gambit: Oxford, 5... Bb4'),
			moves => {
				'd3e4' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/8/3pP3/1b2P3/2N5/PPP3PP/R1BQKBNR b KQkq' => {
			eco => 'C29h',
			# TRANSLATORS: C29h: 1. e4 e5 2. Nc3 Nf6 3. f4 d5 4. fxe5 Nxe4 5. d3 Bb4 6. dxe4
			variation => N__('Vienna Gambit: Oxford, 5... Bb4'),
			moves => {
				'd8h4' => 1,
			},
		},
		'rnb1k2r/ppp2ppp/8/3pP3/1b2P2q/2N5/PPP3PP/R1BQKBNR w KQkq' => {
			eco => 'C29h',
			# TRANSLATORS: C29h: 1. e4 e5 2. Nc3 Nf6 3. f4 d5 4. fxe5 Nxe4 5. d3 Bb4 6. dxe4 Qh4+
			variation => N__('Vienna Gambit: Oxford, 5... Bb4'),
			moves => {
				'e1e2' => 1,
			},
		},
		'rnb1k2r/ppp2ppp/8/3pP3/1b2P2q/2N5/PPP1K1PP/R1BQ1BNR b kq' => {
			eco => 'C29h',
			# TRANSLATORS: C29h: 1. e4 e5 2. Nc3 Nf6 3. f4 d5 4. fxe5 Nxe4 5. d3 Bb4 6. dxe4 Qh4+ 7. Ke2
			variation => N__('Vienna Gambit: Oxford, 5... Bb4 6.dxe4 Qh4+ 7. Ke2'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/8/3pP3/8/2nP4/PPP3PP/R1BQKBNR w KQkq' => {
			eco => 'C29i',
			# TRANSLATORS: C29i: 1. e4 e5 2. Nc3 Nf6 3. f4 d5 4. fxe5 Nxe4 5. d3 Nxc3
			variation => N__('Vienna Gambit: Oxford, 5...Nxc3'),
			moves => {
				'b2c3' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/8/3pP3/8/2PP4/P1P3PP/R1BQKBNR b KQkq' => {
			eco => 'C29i',
			# TRANSLATORS: C29i: 1. e4 e5 2. Nc3 Nf6 3. f4 d5 4. fxe5 Nxe4 5. d3 Nxc3 6. bxc3
			variation => N__('Vienna Gambit: Oxford, 5...Nxc3'),
			moves => {
				'd5d4' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/8/4P3/3p4/2PP4/P1P3PP/R1BQKBNR w KQkq' => {
			eco => 'C29j',
			# TRANSLATORS: C29j: 1. e4 e5 2. Nc3 Nf6 3. f4 d5 4. fxe5 Nxe4 5. d3 Nxc3 6. bxc3 d4
			variation => N__('Vienna Gambit: Oxford, 5...Nxc3 6.bxc3 d4'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/8/3pP3/4n3/2N2Q2/PPPP2PP/R1B1KBNR b KQkq' => {
			eco => 'C29k',
			# TRANSLATORS: C29k: 1. e4 e5 2. Nc3 Nf6 3. f4 d5 4. fxe5 Nxe4 5. Qf3
			variation => N__('Vienna Gambit: Paulsen Attack'),
			moves => {
				'b8c6' => 1,
				'e4c3' => 1,
				'f7f5' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2n5/3pP3/4n3/2N2Q2/PPPP2PP/R1B1KBNR w KQkq' => {
			eco => 'C29k',
			# TRANSLATORS: C29k: 1. e4 e5 2. Nc3 Nf6 3. f4 d5 4. fxe5 Nxe4 5. Qf3 Nc6
			variation => N__('Vienna Gambit: Paulsen Attack, 5... Nc6'),
			moves => {
			},
		},
		'rnbqkb1r/ppp3pp/8/3pPp2/4n3/2N2Q2/PPPP2PP/R1B1KBNR w KQkq' => {
			eco => 'C29l',
			# TRANSLATORS: C29l: 1. e4 e5 2. Nc3 Nf6 3. f4 d5 4. fxe5 Nxe4 5. Qf3 f5
			variation => N__('Vienna Gambit: Paulsen Attack, Bardeleben Variation'),
			moves => {
				'd2d4' => 1,
			},
		},
		'rnbqkb1r/ppp3pp/8/3pPp2/3Pn3/2N2Q2/PPP3PP/R1B1KBNR b KQkq' => {
			eco => 'C29l',
			# TRANSLATORS: C29l: 1. e4 e5 2. Nc3 Nf6 3. f4 d5 4. fxe5 Nxe4 5. Qf3 f5 6. d4
			variation => N__('Vienna Gambit: Paulsen Attack, Heyde Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/8/3pP3/8/2n2Q2/PPPP2PP/R1B1KBNR w KQkq' => {
			eco => 'C29m',
			# TRANSLATORS: C29m: 1. e4 e5 2. Nc3 Nf6 3. f4 d5 4. fxe5 Nxe4 5. Qf3 Nxc3
			variation => N__('Vienna Gambit: Paulsen Attack, 5...Nxc3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/8/3pP3/4n3/2N2N2/PPPP2PP/R1BQKB1R b KQkq' => {
			eco => 'C29n',
			# TRANSLATORS: C29n: 1. e4 e5 2. Nc3 Nf6 3. f4 d5 4. fxe5 Nxe4 5. Nf3
			variation => N__('Vienna Gambit: 5. Nf3'),
			moves => {
				'b8c6' => 1,
				'c8g4' => 1,
				'f8b4' => 1,
				'f8e7' => 1,
			},
		},
		'rn1qkb1r/ppp2ppp/8/3pP3/4n1b1/2N2N2/PPPP2PP/R1BQKB1R w KQkq' => {
			eco => 'C29o',
			# TRANSLATORS: C29o: 1. e4 e5 2. Nc3 Nf6 3. f4 d5 4. fxe5 Nxe4 5. Nf3 Bg4
			variation => N__('Vienna Gambit: 5. Nf3 Bg4'),
			moves => {
				'd1e2' => 1,
			},
		},
		'rn1qkb1r/ppp2ppp/8/3pP3/4n1b1/2N2N2/PPPPQ1PP/R1B1KB1R b KQkq' => {
			eco => 'C29o',
			# TRANSLATORS: C29o: 1. e4 e5 2. Nc3 Nf6 3. f4 d5 4. fxe5 Nxe4 5. Nf3 Bg4 6. Qe2
			variation => N__('Vienna Gambit: Kaufmann Variation'),
			moves => {
			},
		},
		'rnbqk2r/ppp2ppp/8/3pP3/1b2n3/2N2N2/PPPP2PP/R1BQKB1R w KQkq' => {
			eco => 'C29p',
			# TRANSLATORS: C29p: 1. e4 e5 2. Nc3 Nf6 3. f4 d5 4. fxe5 Nxe4 5. Nf3 Bb4
			variation => N__('Vienna Gambit: 5. Nf3 Bb4'),
			moves => {
			},
		},
		'r1bqkb1r/ppp2ppp/2n5/3pP3/4n3/2N2N2/PPPP2PP/R1BQKB1R w KQkq' => {
			eco => 'C29q',
			# TRANSLATORS: C29q: 1. e4 e5 2. Nc3 Nf6 3. f4 d5 4. fxe5 Nxe4 5. Nf3 Nc6
			variation => N__('Vienna Gambit: 5. Nf3 Nc6'),
			moves => {
			},
		},
		'rnbqk2r/ppp1bppp/8/3pP3/4n3/2N2N2/PPPP2PP/R1BQKB1R w KQkq' => {
			eco => 'C29r',
			# TRANSLATORS: C29r: 1. e4 e5 2. Nc3 Nf6 3. f4 d5 4. fxe5 Nxe4 5. Nf3 Be7
			variation => N__('Vienna Gambit: Breyer Variation'),
			moves => {
				'd1e2' => 1,
			},
		},
		'rnbqk2r/ppp1bppp/8/3pP3/4n3/2N2N2/PPPPQ1PP/R1B1KB1R b KQkq' => {
			eco => 'C29s',
			# TRANSLATORS: C29s: 1. e4 e5 2. Nc3 Nf6 3. f4 d5 4. fxe5 Nxe4 5. Nf3 Be7 6. Qe2
			variation => N__('Vienna Gambit: Breyer, 6. Qe2'),
			moves => {
				'e4c3' => 1,
			},
		},
		'rnbqk2r/ppp1bppp/8/3pP3/8/2n2N2/PPPPQ1PP/R1B1KB1R w KQkq' => {
			eco => 'C29t',
			# TRANSLATORS: C29t: 1. e4 e5 2. Nc3 Nf6 3. f4 d5 4. fxe5 Nxe4 5. Nf3 Be7 6. Qe2 Nxc3
			variation => N__('Vienna Gambit: Breyer, 6. Qe2 Nxc3'),
			moves => {
				'd2c3' => 1,
			},
		},
		'rnbqk2r/ppp1bppp/8/3pP3/8/2P2N2/PPP1Q1PP/R1B1KB1R b KQkq' => {
			eco => 'C29t',
			# TRANSLATORS: C29t: 1. e4 e5 2. Nc3 Nf6 3. f4 d5 4. fxe5 Nxe4 5. Nf3 Be7 6. Qe2 Nxc3 7. dxc3
			variation => N__('Vienna Gambit: Breyer, 6. Qe2 Nxc3 7.dxc3'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/4p3/4PP2/8/PPPP2PP/RNBQKBNR b KQkq' => {
			eco => 'C30a',
			# TRANSLATORS: C30a: 1. e4 e5 2. f4
			variation => N__('King\'s Gambit'),
			moves => {
				'b8c6' => 1,
				'c7c5' => 1,
				'd7d5' => 1,
				'd7d6' => 1,
				'd8f6' => 1,
				'd8h4' => 1,
				'e5f4' => 1,
				'f8c5' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/pp1p1ppp/8/2p1p3/4PP2/8/PPPP2PP/RNBQKBNR w KQkq' => {
			eco => 'C30b',
			# TRANSLATORS: C30b: 1. e4 e5 2. f4 c5
			variation => N__('King\'s Gambit: Mafia Defence'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/3p4/4p3/4PP2/8/PPPP2PP/RNBQKBNR w KQkq' => {
			eco => 'C30c',
			# TRANSLATORS: C30c: 1. e4 e5 2. f4 d6
			variation => N__('King\'s Gambit: 2... d6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/3p4/4p3/4PP2/5N2/PPPP2PP/RNBQKB1R b KQkq' => {
			eco => 'C30c',
			# TRANSLATORS: C30c: 1. e4 e5 2. f4 d6 3. Nf3
			variation => N__('King\'s Gambit: 2... d6 3. Nf3'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkbnr/ppp2ppp/2np4/4p3/4PP2/5N2/PPPP2PP/RNBQKB1R w KQkq' => {
			eco => 'C30c',
			# TRANSLATORS: C30c: 1. e4 e5 2. f4 d6 3. Nf3 Nc6
			variation => N__('King\'s Gambit: 2... d6 3. Nf3 Nc6'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/4p3/4PP2/8/PPPP2PP/RNBQKBNR w KQkq' => {
			eco => 'C30d',
			# TRANSLATORS: C30d: 1. e4 e5 2. f4 Nf6
			variation => N__('King\'s Gambit: Wade Variation'),
			moves => {
			},
		},
		'rnb1kbnr/pppp1ppp/5q2/4p3/4PP2/8/PPPP2PP/RNBQKBNR w KQkq' => {
			eco => 'C30e',
			# TRANSLATORS: C30e: 1. e4 e5 2. f4 Qf6
			variation => N__('King\'s Gambit: Norwald Variation'),
			moves => {
				'b1c3' => 1,
				'g1f3' => 1,
			},
		},
		'rnb1kbnr/pppp1ppp/5q2/4p3/4PP2/2N5/PPPP2PP/R1BQKBNR b KQkq' => {
			eco => 'C30e',
			# TRANSLATORS: C30e: 1. e4 e5 2. f4 Qf6 3. Nc3
			variation => N__('King\'s Gambit: Norwald Variation'),
			moves => {
				'f6f4' => 1,
			},
		},
		'rnb1kbnr/pppp1ppp/8/4p3/4Pq2/2N5/PPPP2PP/R1BQKBNR w KQkq' => {
			eco => 'C30e',
			# TRANSLATORS: C30e: 1. e4 e5 2. f4 Qf6 3. Nc3 Qxf4
			variation => N__('King\'s Gambit: Norwald Variation'),
			moves => {
				'd2d4' => 1,
			},
		},
		'rnb1kbnr/pppp1ppp/8/4p3/3PPq2/2N5/PPP3PP/R1BQKBNR b KQkq' => {
			eco => 'C30e',
			# TRANSLATORS: C30e: 1. e4 e5 2. f4 Qf6 3. Nc3 Qxf4 4. d4
			variation => N__('King\'s Gambit: Norwald Variation, Schubert line'),
			moves => {
			},
		},
		'rnb1kbnr/pppp1ppp/5q2/4p3/4PP2/5N2/PPPP2PP/RNBQKB1R b KQkq' => {
			eco => 'C30e',
			# TRANSLATORS: C30e: 1. e4 e5 2. f4 Qf6 3. Nf3
			variation => N__('King\'s Gambit: Norwald Variation'),
			moves => {
				'f6f4' => 1,
			},
		},
		'rnb1kbnr/pppp1ppp/8/4p3/4Pq2/5N2/PPPP2PP/RNBQKB1R w KQkq' => {
			eco => 'C30e',
			# TRANSLATORS: C30e: 1. e4 e5 2. f4 Qf6 3. Nf3 Qxf4
			variation => N__('King\'s Gambit: Norwald Variation'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnb1kbnr/pppp1ppp/8/4p3/4Pq2/2N2N2/PPPP2PP/R1BQKB1R b KQkq' => {
			eco => 'C30e',
			# TRANSLATORS: C30e: 1. e4 e5 2. f4 Qf6 3. Nf3 Qxf4 4. Nc3
			variation => N__('King\'s Gambit: Norwald Variation'),
			moves => {
				'f8b4' => 1,
			},
		},
		'rnb1k1nr/pppp1ppp/8/4p3/1b2Pq2/2N2N2/PPPP2PP/R1BQKB1R w KQkq' => {
			eco => 'C30e',
			# TRANSLATORS: C30e: 1. e4 e5 2. f4 Qf6 3. Nf3 Qxf4 4. Nc3 Bb4
			variation => N__('King\'s Gambit: Norwald Variation'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnb1k1nr/pppp1ppp/8/4p3/1bB1Pq2/2N2N2/PPPP2PP/R1BQK2R b KQkq' => {
			eco => 'C30e',
			# TRANSLATORS: C30e: 1. e4 e5 2. f4 Qf6 3. Nf3 Qxf4 4. Nc3 Bb4 5. Bc4
			variation => N__('King\'s Gambit: Norwald Variation, Bücker Gambit'),
			moves => {
			},
		},
		'rnb1kbnr/pppp1ppp/8/4p3/4PP1q/8/PPPP2PP/RNBQKBNR w KQkq' => {
			eco => 'C30f',
			# TRANSLATORS: C30f: 1. e4 e5 2. f4 Qh4+
			variation => N__('King\'s Gambit: Keene Defence'),
			moves => {
				'g2g3' => 1,
			},
		},
		'rnb1kbnr/pppp1ppp/8/4p3/4PP1q/6P1/PPPP3P/RNBQKBNR b KQkq' => {
			eco => 'C30f',
			# TRANSLATORS: C30f: 1. e4 e5 2. f4 Qh4+ 3. g3
			variation => N__('King\'s Gambit: Keene Defence'),
			moves => {
				'h4e7' => 1,
			},
		},
		'rnb1kbnr/ppppqppp/8/4p3/4PP2/6P1/PPPP3P/RNBQKBNR w KQkq' => {
			eco => 'C30f',
			# TRANSLATORS: C30f: 1. e4 e5 2. f4 Qh4+ 3. g3 Qe7
			variation => N__('King\'s Gambit: Keene Defence, 3. g3 Qe7'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4p3/4PP2/8/PPPP2PP/RNBQKBNR w KQkq' => {
			eco => 'C30g',
			# TRANSLATORS: C30g: 1. e4 e5 2. f4 Nc6
			variation => N__('King\'s Gambit: 2... Nc6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4p3/4PP2/5N2/PPPP2PP/RNBQKB1R b KQkq' => {
			eco => 'C30g',
			# TRANSLATORS: C30g: 1. e4 e5 2. f4 Nc6 3. Nf3
			variation => N__('King\'s Gambit: 2... Nc6'),
			moves => {
				'f7f5' => 1,
			},
		},
		'r1bqkbnr/pppp2pp/2n5/4pp2/4PP2/5N2/PPPP2PP/RNBQKB1R w KQkq' => {
			eco => 'C30h',
			# TRANSLATORS: C30h: 1. e4 e5 2. f4 Nc6 3. Nf3 f5
			variation => N__('King\'s Gambit: Adelaide-Wahls Variation'),
			moves => {
				'e4f5' => 1,
			},
		},
		'r1bqkbnr/pppp2pp/2n5/4pP2/5P2/5N2/PPPP2PP/RNBQKB1R b KQkq' => {
			eco => 'C30i',
			# TRANSLATORS: C30i: 1. e4 e5 2. f4 Nc6 3. Nf3 f5 4. exf5
			variation => N__('King\'s Gambit: Adelaide-Wahls, 4.exf5'),
			moves => {
				'e5e4' => 1,
			},
		},
		'r1bqkbnr/pppp2pp/2n5/5P2/4pP2/5N2/PPPP2PP/RNBQKB1R w KQkq' => {
			eco => 'C30i',
			# TRANSLATORS: C30i: 1. e4 e5 2. f4 Nc6 3. Nf3 f5 4. exf5 e4
			variation => N__('King\'s Gambit: Adelaide-Wahls, 4.exf5 e4'),
			moves => {
				'f3e5' => 1,
			},
		},
		'r1bqkbnr/pppp2pp/2n5/4NP2/4pP2/8/PPPP2PP/RNBQKB1R b KQkq' => {
			eco => 'C30i',
			# TRANSLATORS: C30i: 1. e4 e5 2. f4 Nc6 3. Nf3 f5 4. exf5 e4 5. Ne5
			variation => N__('King\'s Gambit: Adelaide-Wahls, 4.exf5 e4'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r1bqkb1r/pppp2pp/2n2n2/4NP2/4pP2/8/PPPP2PP/RNBQKB1R w KQkq' => {
			eco => 'C30i',
			# TRANSLATORS: C30i: 1. e4 e5 2. f4 Nc6 3. Nf3 f5 4. exf5 e4 5. Ne5 Nf6
			variation => N__('King\'s Gambit: Adelaide-Wahls, 4.exf5 e4 5. Ne5 Nf6'),
			moves => {
			},
		},
		'rnbqk1nr/pppp1ppp/8/2b1p3/4PP2/8/PPPP2PP/RNBQKBNR w KQkq' => {
			eco => 'C30j',
			# TRANSLATORS: C30j: 1. e4 e5 2. f4 Bc5
			variation => N__('King\'s Gambit: Classical KGD'),
			moves => {
				'f1c4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqk1nr/pppp1ppp/8/2b1p3/2B1PP2/8/PPPP2PP/RNBQK1NR b KQkq' => {
			eco => 'C30j',
			# TRANSLATORS: C30j: 1. e4 e5 2. f4 Bc5 3. Bc4
			variation => N__('KGD: Classical, 3. Bc4'),
			moves => {
			},
		},
		'rnbqk1nr/pppp1ppp/8/2b1p3/4PP2/5N2/PPPP2PP/RNBQKB1R b KQkq' => {
			eco => 'C30j',
			# TRANSLATORS: C30j: 1. e4 e5 2. f4 Bc5 3. Nf3
			variation => N__('KGD: Classical, 3. Nf3'),
			moves => {
				'd7d6' => 1,
				'g7g5' => 1,
			},
		},
		'rnbqk1nr/pppp1p1p/8/2b1p1p1/4PP2/5N2/PPPP2PP/RNBQKB1R w KQkq' => {
			eco => 'C30j',
			# TRANSLATORS: C30j: 1. e4 e5 2. f4 Bc5 3. Nf3 g5
			variation => N__('KGD: Classical, Senechaud Countergambit'),
			moves => {
			},
		},
		'rnbqk1nr/ppp2ppp/3p4/2b1p3/4PP2/5N2/PPPP2PP/RNBQKB1R w KQkq' => {
			eco => 'C30k',
			# TRANSLATORS: C30k: 1. e4 e5 2. f4 Bc5 3. Nf3 d6
			variation => N__('KGD: Classical, 3. Nf3 d6'),
			moves => {
				'b1c3' => 1,
				'b2b4' => 1,
				'c2c3' => 1,
				'f4e5' => 1,
			},
		},
		'rnbqk1nr/ppp2ppp/3p4/2b1p3/1P2PP2/5N2/P1PP2PP/RNBQKB1R b KQkq' => {
			eco => 'C30k',
			# TRANSLATORS: C30k: 1. e4 e5 2. f4 Bc5 3. Nf3 d6 4. b4
			variation => N__('KGD: Classical, Heath Variation'),
			moves => {
			},
		},
		'rnbqk1nr/ppp2ppp/3p4/2b1P3/4P3/5N2/PPPP2PP/RNBQKB1R b KQkq' => {
			eco => 'C30k',
			# TRANSLATORS: C30k: 1. e4 e5 2. f4 Bc5 3. Nf3 d6 4. fxe5
			variation => N__('KGD: Classical, Soldatenkov Variation'),
			moves => {
			},
		},
		'rnbqk1nr/ppp2ppp/3p4/2b1p3/4PP2/2N2N2/PPPP2PP/R1BQKB1R b KQkq' => {
			eco => 'C30l',
			# TRANSLATORS: C30l: 1. e4 e5 2. f4 Bc5 3. Nf3 d6 4. Nc3
			variation => N__('KGD: Classical, 3. Nf3 d6 4. Nc3'),
			moves => {
				'b8d7' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqk1nr/pppn1ppp/3p4/2b1p3/4PP2/2N2N2/PPPP2PP/R1BQKB1R w KQkq' => {
			eco => 'C30l',
			# TRANSLATORS: C30l: 1. e4 e5 2. f4 Bc5 3. Nf3 d6 4. Nc3 Nd7
			variation => N__('KGD: Classical, Hanham Variation'),
			moves => {
			},
		},
		'rnbqk2r/ppp2ppp/3p1n2/2b1p3/4PP2/2N2N2/PPPP2PP/R1BQKB1R w KQkq' => {
			eco => 'C30l',
			# TRANSLATORS: C30l: 1. e4 e5 2. f4 Bc5 3. Nf3 d6 4. Nc3 Nf6
			variation => N__('KGD: Classical, 3. Nf3 d6 4. Nc3'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/3p1n2/2b1p3/2B1PP2/2N2N2/PPPP2PP/R1BQK2R b KQkq' => {
			eco => 'C30m',
			# TRANSLATORS: C30m: 1. e4 e5 2. f4 Bc5 3. Nf3 d6 4. Nc3 Nf6 5. Bc4
			variation => N__('KGD: Classical, 3. Nf3 d6 4. Nc3 Nf6 5. Bc4'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2np1n2/2b1p3/2B1PP2/2N2N2/PPPP2PP/R1BQK2R w KQkq' => {
			eco => 'C30m',
			# TRANSLATORS: C30m: 1. e4 e5 2. f4 Bc5 3. Nf3 d6 4. Nc3 Nf6 5. Bc4 Nc6
			variation => N__('KGD: Classical, 3. Nf3 d6 4. Nc3 Nf6 5. Bc4'),
			moves => {
				'd2d3' => 1,
			},
		},
		'r2qk2r/ppp2ppp/2np1n2/2b5/2B1Pp2/2NP1Q1P/PPP3P1/R1B1K2R w KQkq' => {
			eco => 'C30m',
			# TRANSLATORS: C30m: 1. e4 e5 2. f4 Bc5 3. Nf3 d6 4. Nc3 Nf6 5. Bc4 Nc6 6. d3 Bg4 7. h3 Bxf3 8. Qxf3 exf4
			variation => N__('KGD: Classical, Svenonius Variation'),
			moves => {
			},
		},
		'rnbqk1nr/ppp2ppp/3p4/2b1p3/4PP2/2P2N2/PP1P2PP/RNBQKB1R b KQkq' => {
			eco => 'C30n',
			# TRANSLATORS: C30n: 1. e4 e5 2. f4 Bc5 3. Nf3 d6 4. c3
			variation => N__('KGD: Classical, 4. c3'),
			moves => {
				'c5b6' => 1,
				'c8g4' => 1,
				'f7f5' => 1,
				'g8f6' => 1,
			},
		},
		'rn1qk1nr/ppp2ppp/3p4/2b1p3/4PPb1/2P2N2/PP1P2PP/RNBQKB1R w KQkq' => {
			eco => 'C30n',
			# TRANSLATORS: C30n: 1. e4 e5 2. f4 Bc5 3. Nf3 d6 4. c3 Bg4
			variation => N__('KGD: Classical, 4. c3'),
			moves => {
				'f4e5' => 1,
			},
		},
		'rn1qk1nr/ppp2ppp/3p4/2b1P3/4P1b1/2P2N2/PP1P2PP/RNBQKB1R b KQkq' => {
			eco => 'C30n',
			# TRANSLATORS: C30n: 1. e4 e5 2. f4 Bc5 3. Nf3 d6 4. c3 Bg4 5. fxe5
			variation => N__('KGD: Classical, 4. c3'),
			moves => {
				'd6e5' => 1,
			},
		},
		'rn1qk1nr/ppp2ppp/8/2b1p3/4P1b1/2P2N2/PP1P2PP/RNBQKB1R w KQkq' => {
			eco => 'C30n',
			# TRANSLATORS: C30n: 1. e4 e5 2. f4 Bc5 3. Nf3 d6 4. c3 Bg4 5. fxe5 dxe5
			variation => N__('KGD: Classical, 4. c3'),
			moves => {
				'd1a4' => 1,
			},
		},
		'rn1qk1nr/ppp2ppp/8/2b1p3/Q3P1b1/2P2N2/PP1P2PP/RNB1KB1R b KQkq' => {
			eco => 'C30n',
			# TRANSLATORS: C30n: 1. e4 e5 2. f4 Bc5 3. Nf3 d6 4. c3 Bg4 5. fxe5 dxe5 6. Qa4+
			variation => N__('KGD: Classical, Marshall Attack'),
			moves => {
			},
		},
		'rnbqk1nr/ppp2ppp/1b1p4/4p3/4PP2/2P2N2/PP1P2PP/RNBQKB1R w KQkq' => {
			eco => 'C30o',
			# TRANSLATORS: C30o: 1. e4 e5 2. f4 Bc5 3. Nf3 d6 4. c3 Bb6
			variation => N__('KGD: Classical, 4. c3 Bb6'),
			moves => {
			},
		},
		'rnbqk2r/ppp2ppp/3p1n2/2b1p3/4PP2/2P2N2/PP1P2PP/RNBQKB1R w KQkq' => {
			eco => 'C30p',
			# TRANSLATORS: C30p: 1. e4 e5 2. f4 Bc5 3. Nf3 d6 4. c3 Nf6
			variation => N__('KGD: Classical, 4. c3 Nf6'),
			moves => {
				'd2d4' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/3p1n2/2b1p3/3PPP2/2P2N2/PP4PP/RNBQKB1R b KQkq' => {
			eco => 'C30q',
			# TRANSLATORS: C30q: 1. e4 e5 2. f4 Bc5 3. Nf3 d6 4. c3 Nf6 5. d4
			variation => N__('KGD: Classical, 4. c3 Nf6 5. d4'),
			moves => {
				'c5b6' => 1,
				'e5d4' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/1b1p1n2/4p3/3PPP2/2P2N2/PP4PP/RNBQKB1R w KQkq' => {
			eco => 'C30q',
			# TRANSLATORS: C30q: 1. e4 e5 2. f4 Bc5 3. Nf3 d6 4. c3 Nf6 5. d4 Bb6
			variation => N__('KGD: Classical, 4. c3 Nf6 5. d4'),
			moves => {
			},
		},
		'rnbqk2r/ppp2ppp/3p1n2/2b5/3pPP2/2P2N2/PP4PP/RNBQKB1R w KQkq' => {
			eco => 'C30q',
			# TRANSLATORS: C30q: 1. e4 e5 2. f4 Bc5 3. Nf3 d6 4. c3 Nf6 5. d4 exd4
			variation => N__('KGD: Classical, 4. c3 Nf6 5. d4'),
			moves => {
				'c3d4' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/3p1n2/2b5/3PPP2/5N2/PP4PP/RNBQKB1R b KQkq' => {
			eco => 'C30q',
			# TRANSLATORS: C30q: 1. e4 e5 2. f4 Bc5 3. Nf3 d6 4. c3 Nf6 5. d4 exd4 6. cxd4
			variation => N__('KGD: Classical, 4. c3 Nf6 5. d4'),
			moves => {
				'c5b6' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/1b1p1n2/8/3PPP2/5N2/PP4PP/RNBQKB1R w KQkq' => {
			eco => 'C30q',
			# TRANSLATORS: C30q: 1. e4 e5 2. f4 Bc5 3. Nf3 d6 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb6
			variation => N__('KGD: Classical, 4. c3 Nf6 5. d4'),
			moves => {
			},
		},
		'rnbqk1nr/ppp3pp/3p4/2b1pp2/4PP2/2P2N2/PP1P2PP/RNBQKB1R w KQkq' => {
			eco => 'C30r',
			# TRANSLATORS: C30r: 1. e4 e5 2. f4 Bc5 3. Nf3 d6 4. c3 f5
			variation => N__('KGD: Classical Countergambit'),
			moves => {
				'f4e5' => 1,
			},
		},
		'rnbqk1nr/ppp3pp/3p4/2b1Pp2/4P3/2P2N2/PP1P2PP/RNBQKB1R b KQkq' => {
			eco => 'C30r',
			# TRANSLATORS: C30r: 1. e4 e5 2. f4 Bc5 3. Nf3 d6 4. c3 f5 5. fxe5
			variation => N__('KGD: Classical Countergambit'),
			moves => {
				'd6e5' => 1,
			},
		},
		'rnbqk1nr/ppp3pp/8/2b1pp2/4P3/2P2N2/PP1P2PP/RNBQKB1R w KQkq' => {
			eco => 'C30r',
			# TRANSLATORS: C30r: 1. e4 e5 2. f4 Bc5 3. Nf3 d6 4. c3 f5 5. fxe5 dxe5
			variation => N__('KGD: Classical Countergambit'),
			moves => {
				'd2d4' => 1,
			},
		},
		'rnbqk1nr/ppp3pp/8/2b1pp2/3PP3/2P2N2/PP4PP/RNBQKB1R b KQkq' => {
			eco => 'C30r',
			# TRANSLATORS: C30r: 1. e4 e5 2. f4 Bc5 3. Nf3 d6 4. c3 f5 5. fxe5 dxe5 6. d4
			variation => N__('KGD: Classical Countergambit'),
			moves => {
				'e5d4' => 1,
			},
		},
		'rnbqk1nr/ppp3pp/8/2b2p2/3pP3/2P2N2/PP4PP/RNBQKB1R w KQkq' => {
			eco => 'C30r',
			# TRANSLATORS: C30r: 1. e4 e5 2. f4 Bc5 3. Nf3 d6 4. c3 f5 5. fxe5 dxe5 6. d4 exd4
			variation => N__('KGD: Classical Countergambit'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnbqk1nr/ppp3pp/8/2b2p2/2BpP3/2P2N2/PP4PP/RNBQK2R b KQkq' => {
			eco => 'C30r',
			# TRANSLATORS: C30r: 1. e4 e5 2. f4 Bc5 3. Nf3 d6 4. c3 f5 5. fxe5 dxe5 6. d4 exd4 7. Bc4
			variation => N__('KGD: Classical, Reti Variation'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/8/3pp3/4PP2/8/PPPP2PP/RNBQKBNR w KQkq' => {
			eco => 'C31',
			# TRANSLATORS: C31: 1. e4 e5 2. f4 d5
			variation => N__('KGD: Falkbeer Countergambit'),
			moves => {
				'b1c3' => 1,
				'e4d5' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/8/3pp3/4PP2/2N5/PPPP2PP/R1BQKBNR b KQkq' => {
			eco => 'C31',
			# TRANSLATORS: C31: 1. e4 e5 2. f4 d5 3. Nc3
			variation => N__('KGD: Falkbeer, Milner-Barry Variation'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/8/3Pp3/5P2/8/PPPP2PP/RNBQKBNR b KQkq' => {
			eco => 'C31',
			# TRANSLATORS: C31: 1. e4 e5 2. f4 d5 3. exd5
			variation => N__('KGD: Falkbeer, 3.exd5'),
			moves => {
				'c7c6' => 1,
				'e5e4' => 1,
				'e5f4' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/2p5/3Pp3/5P2/8/PPPP2PP/RNBQKBNR w KQkq' => {
			eco => 'C31',
			# TRANSLATORS: C31: 1. e4 e5 2. f4 d5 3. exd5 c6
			variation => N__('KGD: Falkbeer, Marshall/Nimzowitsch Countergambit'),
			moves => {
				'b1c3' => 1,
				'd1e2' => 1,
				'd5c6' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/2p5/3Pp3/5P2/2N5/PPPP2PP/R1BQKBNR b KQkq' => {
			eco => 'C31',
			# TRANSLATORS: C31: 1. e4 e5 2. f4 d5 3. exd5 c6 4. Nc3
			variation => N__('KGD: Falkbeer, Marshall/Nimzowitsch, 4. Nc3'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/2p5/3Pp3/5P2/8/PPPPQ1PP/RNB1KBNR b KQkq' => {
			eco => 'C31',
			# TRANSLATORS: C31: 1. e4 e5 2. f4 d5 3. exd5 c6 4. Qe2
			variation => N__('KGD: Falkbeer, Marshall/Nimzowitsch, 4. Qe2'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/2P5/4p3/5P2/8/PPPP2PP/RNBQKBNR b KQkq' => {
			eco => 'C31',
			# TRANSLATORS: C31: 1. e4 e5 2. f4 d5 3. exd5 c6 4. dxc6
			variation => N__('KGD: Falkbeer, Marshall/Nimzowitsch, 4.dxc6'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/8/3P4/4pP2/8/PPPP2PP/RNBQKBNR w KQkq' => {
			eco => 'C31',
			# TRANSLATORS: C31: 1. e4 e5 2. f4 d5 3. exd5 e4
			variation => N__('KGD: Falkbeer, 3.exd5 e4'),
			moves => {
				'b1c3' => 1,
				'd2d3' => 1,
				'f1b5' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/8/3P4/4pP2/2N5/PPPP2PP/R1BQKBNR b KQkq' => {
			eco => 'C31',
			# TRANSLATORS: C31: 1. e4 e5 2. f4 d5 3. exd5 e4 4. Nc3
			variation => N__('KGD: Falkbeer, 3.exd5 e4'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3P4/4pP2/2N5/PPPP2PP/R1BQKBNR w KQkq' => {
			eco => 'C31',
			# TRANSLATORS: C31: 1. e4 e5 2. f4 d5 3. exd5 e4 4. Nc3 Nf6
			variation => N__('KGD: Falkbeer, 3.exd5 e4'),
			moves => {
				'd1e2' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3P4/4pP2/2N5/PPPPQ1PP/R1B1KBNR b KQkq' => {
			eco => 'C31',
			# TRANSLATORS: C31: 1. e4 e5 2. f4 d5 3. exd5 e4 4. Nc3 Nf6 5. Qe2
			variation => N__('KGD: Falkbeer, Rubinstein Variation'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/8/3P4/4pP2/3P4/PPP3PP/RNBQKBNR b KQkq' => {
			eco => 'C31',
			# TRANSLATORS: C31: 1. e4 e5 2. f4 d5 3. exd5 e4 4. d3
			variation => N__('KGD: Falkbeer, 4. d3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/8/1B1P4/4pP2/8/PPPP2PP/RNBQK1NR b KQkq' => {
			eco => 'C31',
			# TRANSLATORS: C31: 1. e4 e5 2. f4 d5 3. exd5 e4 4. Bb5+
			variation => N__('KGD: Falkbeer, Nimzowitsch Variation'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/8/3P4/5p2/8/PPPP2PP/RNBQKBNR w KQkq' => {
			eco => 'C31',
			# TRANSLATORS: C31: 1. e4 e5 2. f4 d5 3. exd5 exf4
			variation => N__('KGD: Falkbeer, 3.exd5 exf4'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/8/3pp3/4PP2/5N2/PPPP2PP/RNBQKB1R b KQkq' => {
			eco => 'C31',
			# TRANSLATORS: C31: 1. e4 e5 2. f4 d5 3. Nf3
			variation => N__('KGD: Falkbeer, Tartakower Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3P4/4pP2/3P4/PPP3PP/RNBQKBNR w KQkq' => {
			eco => 'C32',
			# TRANSLATORS: C32: 1. e4 e5 2. f4 d5 3. exd5 e4 4. d3 Nf6
			variation => N__('KGD: Falkbeer, 4. d3 Nf6'),
			moves => {
				'b1c3' => 1,
				'b1d2' => 1,
				'd1e2' => 1,
				'd3e4' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3P4/4pP2/2NP4/PPP3PP/R1BQKBNR b KQkq' => {
			eco => 'C32',
			# TRANSLATORS: C32: 1. e4 e5 2. f4 d5 3. exd5 e4 4. d3 Nf6 5. Nc3
			variation => N__('KGD: Falkbeer, 4. d3 Nf6 5. Nc3'),
			moves => {
				'f8b4' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/5n2/3P4/1b2pP2/2NP4/PPP3PP/R1BQKBNR w KQkq' => {
			eco => 'C32',
			# TRANSLATORS: C32: 1. e4 e5 2. f4 d5 3. exd5 e4 4. d3 Nf6 5. Nc3 Bb4
			variation => N__('KGD: Falkbeer, 4. d3 Nf6 5. Nc3 Bb4'),
			moves => {
				'c1d2' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/5n2/3P4/1b2pP2/2NP4/PPPB2PP/R2QKBNR b KQkq' => {
			eco => 'C32',
			# TRANSLATORS: C32: 1. e4 e5 2. f4 d5 3. exd5 e4 4. d3 Nf6 5. Nc3 Bb4 6. Bd2
			variation => N__('KGD: Falkbeer, 4. d3 Nf6 5. Nc3 Bb4'),
			moves => {
				'e4e3' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/5n2/3P4/1b3P2/2NPp3/PPPB2PP/R2QKBNR w KQkq' => {
			eco => 'C32',
			# TRANSLATORS: C32: 1. e4 e5 2. f4 d5 3. exd5 e4 4. d3 Nf6 5. Nc3 Bb4 6. Bd2 e3
			variation => N__('KGD: Falkbeer, Morphy Gambit'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3P4/4pP2/3P4/PPPN2PP/R1BQKBNR b KQkq' => {
			eco => 'C32',
			# TRANSLATORS: C32: 1. e4 e5 2. f4 d5 3. exd5 e4 4. d3 Nf6 5. Nd2
			variation => N__('KGD: Falkbeer, Keres Variation'),
			moves => {
				'e4d3' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3P4/5P2/3p4/PPPN2PP/R1BQKBNR w KQkq' => {
			eco => 'C32',
			# TRANSLATORS: C32: 1. e4 e5 2. f4 d5 3. exd5 e4 4. d3 Nf6 5. Nd2 exd3
			variation => N__('KGD: Falkbeer, Keres, 5...exd3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3P4/4pP2/3P4/PPP1Q1PP/RNB1KBNR b KQkq' => {
			eco => 'C32',
			# TRANSLATORS: C32: 1. e4 e5 2. f4 d5 3. exd5 e4 4. d3 Nf6 5. Qe2
			variation => N__('KGD: Falkbeer, Reti Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3P4/4PP2/8/PPP3PP/RNBQKBNR b KQkq' => {
			eco => 'C32',
			# TRANSLATORS: C32: 1. e4 e5 2. f4 d5 3. exd5 e4 4. d3 Nf6 5. dxe4
			variation => N__('KGD: Falkbeer, 5.dxe4'),
			moves => {
				'f6e4' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/8/3P4/4nP2/8/PPP3PP/RNBQKBNR w KQkq' => {
			eco => 'C32',
			# TRANSLATORS: C32: 1. e4 e5 2. f4 d5 3. exd5 e4 4. d3 Nf6 5. dxe4 Nxe4
			variation => N__('KGD: Falkbeer, 5.dxe4'),
			moves => {
				'c1e3' => 1,
				'd1e2' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/8/3P4/4nP2/4B3/PPP3PP/RN1QKBNR b KQkq' => {
			eco => 'C32',
			# TRANSLATORS: C32: 1. e4 e5 2. f4 d5 3. exd5 e4 4. d3 Nf6 5. dxe4 Nxe4 6. Be3
			variation => N__('KGD: Falkbeer, 5.dxe4 Nxe4 6. Be3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/8/3P4/4nP2/8/PPP1Q1PP/RNB1KBNR b KQkq' => {
			eco => 'C32',
			# TRANSLATORS: C32: 1. e4 e5 2. f4 d5 3. exd5 e4 4. d3 Nf6 5. dxe4 Nxe4 6. Qe2
			variation => N__('KGD: Falkbeer, Charousek Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/8/3P4/4nP2/5N2/PPP3PP/RNBQKB1R b KQkq' => {
			eco => 'C32',
			# TRANSLATORS: C32: 1. e4 e5 2. f4 d5 3. exd5 e4 4. d3 Nf6 5. dxe4 Nxe4 6. Nf3
			variation => N__('KGD: Falkbeer, 5.dxe4 Nxe4 6. Nf3'),
			moves => {
				'f8c5' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/8/2bP4/4nP2/5N2/PPP3PP/RNBQKB1R w KQkq' => {
			eco => 'C32',
			# TRANSLATORS: C32: 1. e4 e5 2. f4 d5 3. exd5 e4 4. d3 Nf6 5. dxe4 Nxe4 6. Nf3 Bc5
			variation => N__('KGD: Falkbeer, 5.dxe4 Nxe4 6. Nf3'),
			moves => {
				'd1e2' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/8/2bP4/4nP2/5N2/PPP1Q1PP/RNB1KB1R b KQkq' => {
			eco => 'C32',
			# TRANSLATORS: C32: 1. e4 e5 2. f4 d5 3. exd5 e4 4. d3 Nf6 5. dxe4 Nxe4 6. Nf3 Bc5 7. Qe2
			variation => N__('KGD: Falkbeer, 5.dxe4 Nxe4 6. Nf3 Bc5 7. Qe2'),
			moves => {
				'c5f2' => 1,
				'c8f5' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/8/3P4/4nP2/5N2/PPP1QbPP/RNB1KB1R w KQkq' => {
			eco => 'C32',
			# TRANSLATORS: C32: 1. e4 e5 2. f4 d5 3. exd5 e4 4. d3 Nf6 5. dxe4 Nxe4 6. Nf3 Bc5 7. Qe2 Bf2+
			variation => N__('KGD: Falkbeer, 5.dxe4 Nxe4 6. Nf3 Bc5 7. Qe2'),
			moves => {
				'e1d1' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/8/3P4/4nP2/5N2/PPP1QbPP/RNBK1B1R b kq' => {
			eco => 'C32',
			# TRANSLATORS: C32: 1. e4 e5 2. f4 d5 3. exd5 e4 4. d3 Nf6 5. dxe4 Nxe4 6. Nf3 Bc5 7. Qe2 Bf2+ 8. Kd1
			variation => N__('KGD: Falkbeer, 5.dxe4 Nxe4 6. Nf3 Bc5 7. Qe2'),
			moves => {
				'd8d5' => 1,
			},
		},
		'rnb1k2r/ppp2ppp/8/3q4/4nP2/5N2/PPP1QbPP/RNBK1B1R w kq' => {
			eco => 'C32',
			# TRANSLATORS: C32: 1. e4 e5 2. f4 d5 3. exd5 e4 4. d3 Nf6 5. dxe4 Nxe4 6. Nf3 Bc5 7. Qe2 Bf2+ 8. Kd1 Qxd5+
			variation => N__('KGD: Falkbeer, 5.dxe4 Nxe4 6. Nf3 Bc5 7. Qe2'),
			moves => {
				'f3d2' => 1,
			},
		},
		'rnb1k2r/ppp2ppp/8/3q4/4nP2/8/PPPNQbPP/RNBK1B1R b kq' => {
			eco => 'C32',
			# TRANSLATORS: C32: 1. e4 e5 2. f4 d5 3. exd5 e4 4. d3 Nf6 5. dxe4 Nxe4 6. Nf3 Bc5 7. Qe2 Bf2+ 8. Kd1 Qxd5+ 9. Nfd2
			variation => N__('KGD: Falkbeer, Alapin Variation'),
			moves => {
			},
		},
		'rn1qk2r/ppp2ppp/8/2bP1b2/4nP2/5N2/PPP1Q1PP/RNB1KB1R w KQkq' => {
			eco => 'C32',
			# TRANSLATORS: C32: 1. e4 e5 2. f4 d5 3. exd5 e4 4. d3 Nf6 5. dxe4 Nxe4 6. Nf3 Bc5 7. Qe2 Bf5
			variation => N__('KGD: Falkbeer, Main Line, 7... Bf5'),
			moves => {
				'b1c3' => 1,
				'g2g4' => 1,
			},
		},
		'rn1qk2r/ppp2ppp/8/2bP1b2/4nP2/2N2N2/PPP1Q1PP/R1B1KB1R b KQkq' => {
			eco => 'C32',
			# TRANSLATORS: C32: 1. e4 e5 2. f4 d5 3. exd5 e4 4. d3 Nf6 5. dxe4 Nxe4 6. Nf3 Bc5 7. Qe2 Bf5 8. Nc3
			variation => N__('KGD: Falkbeer, Main Line, 7... Bf5 8. Nc3'),
			moves => {
			},
		},
		'rn1qk2r/ppp2ppp/8/2bP1b2/4nPP1/5N2/PPP1Q2P/RNB1KB1R b KQkq' => {
			eco => 'C32',
			# TRANSLATORS: C32: 1. e4 e5 2. f4 d5 3. exd5 e4 4. d3 Nf6 5. dxe4 Nxe4 6. Nf3 Bc5 7. Qe2 Bf5 8. g4
			variation => N__('KGD: Falkbeer, Main Line, 7... Bf5'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rn1q1rk1/ppp2ppp/8/2bP1b2/4nPP1/5N2/PPP1Q2P/RNB1KB1R w KQ' => {
			eco => 'C32',
			# TRANSLATORS: C32: 1. e4 e5 2. f4 d5 3. exd5 e4 4. d3 Nf6 5. dxe4 Nxe4 6. Nf3 Bc5 7. Qe2 Bf5 8. g4 O-O
			variation => N__('KGD: Falkbeer, Tarrasch Variation'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/8/4Pp2/8/PPPP2PP/RNBQKBNR w KQkq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4
			variation => N__('King\'s Gambit Accepted (KGA)'),
			moves => {
				'b1c3' => 1,
				'b2b3' => 1,
				'd1e2' => 1,
				'd1f3' => 1,
				'd1h5' => 1,
				'd2d4' => 1,
				'e1f2' => 1,
				'f1c4' => 1,
				'f1d3' => 1,
				'f1e2' => 1,
				'g1e2' => 1,
				'g1f3' => 1,
				'g1h3' => 1,
				'h2h4' => 1,
			},
		},
		'rnbqkbnr/pppp1ppp/8/8/4Pp2/2N5/PPPP2PP/R1BQKBNR b KQkq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Nc3
			variation => N__('KGA: Keres Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/8/4Pp2/1P6/P1PP2PP/RNBQKBNR b KQkq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. b3
			variation => N__('KGA: Orsini Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/8/4Pp2/8/PPPPQ1PP/RNB1KBNR b KQkq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Qe2
			variation => N__('KGA: Basman Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/8/4Pp2/5Q2/PPPP2PP/RNB1KBNR b KQkq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Qf3
			variation => N__('KGA: Breyer Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/7Q/4Pp2/8/PPPP2PP/RNB1KBNR b KQkq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Qh5
			variation => N__('KGA: Carrera Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/8/3PPp2/8/PPP3PP/RNBQKBNR b KQkq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. d4
			variation => N__('KGA: Villemson Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/8/4Pp2/8/PPPP1KPP/RNBQ1BNR b kq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Kf2
			variation => N__('KGA: Tumbleweed/Drunken King'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/8/2B1Pp2/8/PPPP2PP/RNBQK1NR b KQkq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4
			variation => N__('KGA: Bishop\'s Gambit'),
			moves => {
				'b7b5' => 1,
				'b8c6' => 1,
				'c7c6' => 1,
				'd7d5' => 1,
				'd8h4' => 1,
				'f7f5' => 1,
				'g8e7' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/p1pp1ppp/8/1p6/2B1Pp2/8/PPPP2PP/RNBQK1NR w KQkq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 b5
			variation => N__('KGA: Bishop\'s Gambit, Bryan Countergambit'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/8/2B1Pp2/8/PPPP2PP/RNBQK1NR w KQkq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 Nc6
			variation => N__('KGA: Bishop\'s Gambit, Maurian Defence'),
			moves => {
			},
		},
		'rnbqkbnr/pp1p1ppp/2p5/8/2B1Pp2/8/PPPP2PP/RNBQK1NR w KQkq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 c6
			variation => N__('KGA: Bishop\'s Gambit, Ruy Lopez Defence'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/8/3p4/2B1Pp2/8/PPPP2PP/RNBQK1NR w KQkq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 d5
			variation => N__('KGA: Bishop\'s Gambit, Bledow Variation'),
			moves => {
				'c4d5' => 1,
				'e4d5' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/8/3B4/4Pp2/8/PPPP2PP/RNBQK1NR b KQkq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 d5 4. Bxd5
			variation => N__('KGA: Bishop\'s Gambit, Bledow, 4.Bxd5'),
			moves => {
				'c7c6' => 1,
				'd8h4' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/2p5/3B4/4Pp2/8/PPPP2PP/RNBQK1NR w KQkq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 d5 4. Bxd5 c6
			variation => N__('KGA: Bishop\'s Gambit, Anderssen Variation'),
			moves => {
			},
		},
		'rnb1kbnr/ppp2ppp/8/3B4/4Pp1q/8/PPPP2PP/RNBQK1NR w KQkq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 d5 4. Bxd5 Qh4+
			variation => N__('KGA: Bishop\'s Gambit, Bledow, 4.Bxd5'),
			moves => {
				'e1f1' => 1,
			},
		},
		'rnb1kbnr/ppp2ppp/8/3B4/4Pp1q/8/PPPP2PP/RNBQ1KNR b kq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 d5 4. Bxd5 Qh4+ 5. Kf1
			variation => N__('KGA: Bishop\'s Gambit, Bledow, 4.Bxd5'),
			moves => {
				'f8d6' => 1,
				'g7g5' => 1,
			},
		},
		'rnb1k1nr/ppp2ppp/3b4/3B4/4Pp1q/8/PPPP2PP/RNBQ1KNR w kq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 d5 4. Bxd5 Qh4+ 5. Kf1 Bd6
			variation => N__('KGA: Bishop\'s Gambit, Boren-Svenonius Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3B4/4Pp2/8/PPPP2PP/RNBQK1NR w KQkq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 d5 4. Bxd5 Nf6
			variation => N__('KGA: Bishop\'s Gambit, Morphy Variation'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/8/3P4/2B2p2/8/PPPP2PP/RNBQK1NR b KQkq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 d5 4. exd5
			variation => N__('KGA: Bishop\'s Gambit, Bledow, 4.exd5'),
			moves => {
			},
		},
		'rnb1kbnr/pppp1ppp/8/8/2B1Pp1q/8/PPPP2PP/RNBQK1NR w KQkq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 Qh4+
			variation => N__('KGA: Bishop\'s Gambit'),
			moves => {
				'e1f1' => 1,
			},
		},
		'rnb1kbnr/pppp1ppp/8/8/2B1Pp1q/8/PPPP2PP/RNBQ1KNR b kq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 Qh4+ 4. Kf1
			variation => N__('KGA: Bishop\'s Gambit'),
			moves => {
				'b7b5' => 1,
				'b8c6' => 1,
				'd7d5' => 1,
				'f8c5' => 1,
				'g7g5' => 1,
			},
		},
		'rnb1kbnr/p1pp1ppp/8/1p6/2B1Pp1q/8/PPPP2PP/RNBQ1KNR w kq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 Qh4+ 4. Kf1 b5
			variation => N__('KGA: Bishop\'s Gambit, Bryan Countergambit'),
			moves => {
			},
		},
		'r1b1kbnr/pppp1ppp/2n5/8/2B1Pp1q/8/PPPP2PP/RNBQ1KNR w kq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 Qh4+ 4. Kf1 Nc6
			variation => N__('KGA: Bishop\'s Gambit, Boden Defence'),
			moves => {
			},
		},
		'rnb1kbnr/ppp2ppp/8/3p4/2B1Pp1q/8/PPPP2PP/RNBQ1KNR w kq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 Qh4+ 4. Kf1 d5
			variation => N__('KGA: Bishop\'s Gambit'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rnb1kbnr/ppp2p1p/8/3B2p1/4Pp1q/8/PPPP2PP/RNBQ1KNR w kq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 Qh4+ 4. Kf1 d5 5. Bxd5 g5
			variation => N__('KGA: Bishop\'s Gambit, Bledow, 4.Bxd5'),
			moves => {
				'g2g3' => 1,
			},
		},
		'rnb1kbnr/ppp2p1p/8/3B2p1/4Pp1q/6P1/PPPP3P/RNBQ1KNR b kq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 Qh4+ 4. Kf1 d5 5. Bxd5 g5 6. g3
			variation => N__('KGA: Bishop\'s Gambit, Chigorin Attack'),
			moves => {
			},
		},
		'rnb1k1nr/pppp1ppp/8/2b5/2B1Pp1q/8/PPPP2PP/RNBQ1KNR w kq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 Qh4+ 4. Kf1 Bc5
			variation => N__('KGA: Bishop\'s Gambit, Greco Variation'),
			moves => {
			},
		},
		'rnb1kbnr/pppp1p1p/8/6p1/2B1Pp1q/8/PPPP2PP/RNBQ1KNR w kq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 Qh4+ 4. Kf1 g5
			variation => N__('KGA: Bishop\'s Gambit, Classical Defence'),
			moves => {
				'b1c3' => 1,
				'd1f3' => 1,
			},
		},
		'rnb1kbnr/pppp1p1p/8/6p1/2B1Pp1q/2N5/PPPP2PP/R1BQ1KNR b kq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 Qh4+ 4. Kf1 g5 5. Nc3
			variation => N__('KGA: Bishop\'s Gambit, Classical Defence'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnb1k1nr/pppp1pbp/8/6p1/2B1Pp1q/2N5/PPPP2PP/R1BQ1KNR w kq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 Qh4+ 4. Kf1 g5 5. Nc3 Bg7
			variation => N__('KGA: Bishop\'s Gambit, Classical Defence'),
			moves => {
				'd2d4' => 1,
				'g2g3' => 1,
			},
		},
		'rnb1k1nr/pppp1pbp/8/6p1/2BPPp1q/2N5/PPP3PP/R1BQ1KNR b kq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 Qh4+ 4. Kf1 g5 5. Nc3 Bg7 6. d4
			variation => N__('KGA: Bishop\'s Gambit, Classical Defence'),
			moves => {
				'd7d6' => 1,
				'g8e7' => 1,
			},
		},
		'rnb1k1nr/ppp2pbp/3p4/6p1/2BPPp1q/2N5/PPP3PP/R1BQ1KNR w kq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 Qh4+ 4. Kf1 g5 5. Nc3 Bg7 6. d4 d6
			variation => N__('KGA: Bishop\'s Gambit, Classical Defence'),
			moves => {
				'e4e5' => 1,
			},
		},
		'rnb1k1nr/ppp2pbp/3p4/4P1p1/2BP1p1q/2N5/PPP3PP/R1BQ1KNR b kq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 Qh4+ 4. Kf1 g5 5. Nc3 Bg7 6. d4 d6 7. e5
			variation => N__('KGA: Bishop\'s Gambit, Grimm Attack'),
			moves => {
			},
		},
		'rnb1k2r/ppppnpbp/8/6p1/2BPPp1q/2N5/PPP3PP/R1BQ1KNR w kq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 Qh4+ 4. Kf1 g5 5. Nc3 Bg7 6. d4 Ne7
			variation => N__('KGA: Bishop\'s Gambit, Classical Defence'),
			moves => {
				'g2g3' => 1,
			},
		},
		'rnb1k2r/ppppnpbp/8/6p1/2BPPp1q/2N3P1/PPP4P/R1BQ1KNR b kq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 Qh4+ 4. Kf1 g5 5. Nc3 Bg7 6. d4 Ne7 7. g3
			variation => N__('KGA: Bishop\'s Gambit, McDonnell Attack'),
			moves => {
			},
		},
		'rnb1k1nr/pppp1pbp/8/6p1/2B1Pp1q/2N3P1/PPPP3P/R1BQ1KNR b kq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 Qh4+ 4. Kf1 g5 5. Nc3 Bg7 6. g3
			variation => N__('KGA: bishop\'s Gambit, McDonnell Attack'),
			moves => {
				'f4g3' => 1,
			},
		},
		'rnb1k1nr/pppp1pbp/8/6p1/2B1P2q/2N3p1/PPPP3P/R1BQ1KNR w kq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 Qh4+ 4. Kf1 g5 5. Nc3 Bg7 6. g3 fxg3
			variation => N__('KGA: bishop\'s Gambit, McDonnell Attack'),
			moves => {
				'd1f3' => 1,
			},
		},
		'rnb1k1nr/pppp1pbp/8/6p1/2B1P2q/2N2Qp1/PPPP3P/R1B2KNR b kq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 Qh4+ 4. Kf1 g5 5. Nc3 Bg7 6. g3 fxg3 7. Qf3
			variation => N__('KGA: Bishop\'s Gambit, Fraser Variation'),
			moves => {
			},
		},
		'rnb1kbnr/pppp1p1p/8/6p1/2B1Pp1q/5Q2/PPPP2PP/RNB2KNR b kq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 Qh4+ 4. Kf1 g5 5. Qf3
			variation => N__('KGA: Bishop\'s Gambit, Classical Defence, Cozio Attack'),
			moves => {
			},
		},
		'rnbqkbnr/pppp2pp/8/5p2/2B1Pp2/8/PPPP2PP/RNBQK1NR w KQkq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 f5
			variation => N__('KGA: Bishop\'s Gambit, Lopez-Gianutio Countergambit'),
			moves => {
				'd1e2' => 1,
			},
		},
		'rnbqkbnr/pppp2pp/8/5p2/2B1Pp2/8/PPPPQ1PP/RNB1K1NR b KQkq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 f5 4. Qe2
			variation => N__('KGA: Bishop\'s Gambit, Lopez-Gianutio Countergambit'),
			moves => {
				'd8h4' => 1,
			},
		},
		'rnb1kbnr/pppp2pp/8/5p2/2B1Pp1q/8/PPPPQ1PP/RNB1K1NR w KQkq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 f5 4. Qe2 Qh4+
			variation => N__('KGA: Bishop\'s Gambit, Lopez-Gianutio Countergambit'),
			moves => {
				'e1d1' => 1,
			},
		},
		'rnb1kbnr/pppp2pp/8/5p2/2B1Pp1q/8/PPPPQ1PP/RNBK2NR b kq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 f5 4. Qe2 Qh4+ 5. Kd1
			variation => N__('KGA: Bishop\'s Gambit, Lopez-Gianutio Countergambit'),
			moves => {
				'f5e4' => 1,
			},
		},
		'rnb1kbnr/pppp2pp/8/8/2B1pp1q/8/PPPPQ1PP/RNBK2NR w kq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 f5 4. Qe2 Qh4+ 5. Kd1 fxe4
			variation => N__('KGA: Bishop\'s Gambit, Lopez-Gianutio Countergambit'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnb1kbnr/pppp2pp/8/8/2B1pp1q/2N5/PPPPQ1PP/R1BK2NR b kq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 f5 4. Qe2 Qh4+ 5. Kd1 fxe4 6. Nc3
			variation => N__('KGA: Bishop\'s Gambit, Lopez-Gianutio Countergambit'),
			moves => {
				'e8d8' => 1,
			},
		},
		'rnbk1bnr/pppp2pp/8/8/2B1pp1q/2N5/PPPPQ1PP/R1BK2NR w -' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 f5 4. Qe2 Qh4+ 5. Kd1 fxe4 6. Nc3 Kd8
			variation => N__('KGA: Bishop\'s Gambit, Lopez-Gianutio Countergambit, Hein Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppppnppp/8/8/2B1Pp2/8/PPPP2PP/RNBQK1NR w KQkq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 Ne7
			variation => N__('KGA: Bishop\'s Gambit, Steinitz Defence'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/8/2B1Pp2/8/PPPP2PP/RNBQK1NR w KQkq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 Nf6
			variation => N__('KGA: Bishop\'s Gambit, Cozio Defence'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/8/2B1Pp2/2N5/PPPP2PP/R1BQK1NR b KQkq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 Nf6 4. Nc3
			variation => N__('KGA: Bishop\'s Gambit, Bogoljubow Variation'),
			moves => {
				'c7c6' => 1,
				'f8b4' => 1,
			},
		},
		'rnbqkb1r/pp1p1ppp/2p2n2/8/2B1Pp2/2N5/PPPP2PP/R1BQK1NR w KQkq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 Nf6 4. Nc3 c6
			variation => N__('KGA: Bishop\'s Gambit, Jänisch Variation'),
			moves => {
			},
		},
		'rnbqk2r/pppp1ppp/5n2/8/1bB1Pp2/2N5/PPPP2PP/R1BQK1NR w KQkq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 Nf6 4. Nc3 Bb4
			variation => N__('KGA: Bishop\'s Gambit, Bogoljubow Variation'),
			moves => {
				'e4e5' => 1,
			},
		},
		'rnbqk2r/pppp1ppp/5n2/4P3/1bB2p2/2N5/PPPP2PP/R1BQK1NR b KQkq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bc4 Nf6 4. Nc3 Bb4 5. e5
			variation => N__('KGA: Bishop\'s Gambit, Paulsen Attack'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/8/4Pp2/3B4/PPPP2PP/RNBQK1NR b KQkq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Bd3
			variation => N__('KGA: Schurig Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/8/4Pp2/8/PPPPB1PP/RNBQK1NR b KQkq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Be2
			variation => N__('KGA: Lesser Bishop\'s (Tartakower) Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/8/4Pp2/8/PPPPN1PP/RNBQKB1R b KQkq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Ne2
			variation => N__('KGA: Eisenberg Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/8/4Pp2/7N/PPPP2PP/RNBQKB1R b KQkq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. Nh3
			variation => N__('KGA: Eisenberg Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/8/4Pp1P/8/PPPP2P1/RNBQKBNR b KQkq' => {
			eco => 'C33',
			# TRANSLATORS: C33: 1. e4 e5 2. f4 exf4 3. h4
			variation => N__('KGA: Stamma (Leonardo) Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/8/4Pp2/5N2/PPPP2PP/RNBQKB1R b KQkq' => {
			eco => 'C34',
			# TRANSLATORS: C34: 1. e4 e5 2. f4 exf4 3. Nf3
			variation => N__('KGA: King\'s Knight Gambit'),
			moves => {
				'd7d5' => 1,
				'd7d6' => 1,
				'f7f5' => 1,
				'f8e7' => 1,
				'g7g5' => 1,
				'g8e7' => 1,
				'g8f6' => 1,
				'h7h6' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/3p4/8/4Pp2/5N2/PPPP2PP/RNBQKB1R w KQkq' => {
			eco => 'C34',
			# TRANSLATORS: C34: 1. e4 e5 2. f4 exf4 3. Nf3 d6
			variation => N__('KGA: Fischer Defence'),
			moves => {
				'd2d4' => 1,
				'f1c4' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/3p4/8/3PPp2/5N2/PPP3PP/RNBQKB1R b KQkq' => {
			eco => 'C34',
			# TRANSLATORS: C34: 1. e4 e5 2. f4 exf4 3. Nf3 d6 4. d4
			variation => N__('KGA: Fischer, 4. d4'),
			moves => {
				'g7g5' => 1,
			},
		},
		'rnbqkbnr/ppp2p1p/3p4/6p1/3PPp2/5N2/PPP3PP/RNBQKB1R w KQkq' => {
			eco => 'C34',
			# TRANSLATORS: C34: 1. e4 e5 2. f4 exf4 3. Nf3 d6 4. d4 g5
			variation => N__('KGA: Fischer, 4. d4'),
			moves => {
				'h2h4' => 1,
			},
		},
		'rnbqkbnr/ppp2p1p/3p4/6p1/3PPp1P/5N2/PPP3P1/RNBQKB1R b KQkq' => {
			eco => 'C34',
			# TRANSLATORS: C34: 1. e4 e5 2. f4 exf4 3. Nf3 d6 4. d4 g5 5. h4
			variation => N__('KGA: Fischer, 4. d4'),
			moves => {
				'g5g4' => 1,
			},
		},
		'rnbqkbnr/ppp2p1p/3p4/8/3PPppP/5N2/PPP3P1/RNBQKB1R w KQkq' => {
			eco => 'C34',
			# TRANSLATORS: C34: 1. e4 e5 2. f4 exf4 3. Nf3 d6 4. d4 g5 5. h4 g4
			variation => N__('KGA: Fischer, 4. d4'),
			moves => {
				'f3g1' => 1,
			},
		},
		'rnbqkbnr/ppp2p1p/3p4/8/3PPppP/8/PPP3P1/RNBQKBNR b KQkq' => {
			eco => 'C34',
			# TRANSLATORS: C34: 1. e4 e5 2. f4 exf4 3. Nf3 d6 4. d4 g5 5. h4 g4 6. Ng1
			variation => N__('KGA: Fischer, Main Line'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/3p4/8/2B1Pp2/5N2/PPPP2PP/RNBQK2R b KQkq' => {
			eco => 'C34',
			# TRANSLATORS: C34: 1. e4 e5 2. f4 exf4 3. Nf3 d6 4. Bc4
			variation => N__('KGA: Fischer, 4. Bc4'),
			moves => {
			},
		},
		'rnbqkbnr/pppp2pp/8/5p2/4Pp2/5N2/PPPP2PP/RNBQKB1R w KQkq' => {
			eco => 'C34',
			# TRANSLATORS: C34: 1. e4 e5 2. f4 exf4 3. Nf3 f5
			variation => N__('KGA: Gianutio Countergambit'),
			moves => {
			},
		},
		'rnbqkb1r/ppppnppp/8/8/4Pp2/5N2/PPPP2PP/RNBQKB1R w KQkq' => {
			eco => 'C34',
			# TRANSLATORS: C34: 1. e4 e5 2. f4 exf4 3. Nf3 Ne7
			variation => N__('KGA: Bonsch-Osmolovsky Variation'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/8/4Pp2/5N2/PPPP2PP/RNBQKB1R w KQkq' => {
			eco => 'C34',
			# TRANSLATORS: C34: 1. e4 e5 2. f4 exf4 3. Nf3 Nf6
			variation => N__('KGA: Schallop Defence'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1pp1/7p/8/4Pp2/5N2/PPPP2PP/RNBQKB1R w KQkq' => {
			eco => 'C34',
			# TRANSLATORS: C34: 1. e4 e5 2. f4 exf4 3. Nf3 h6
			variation => N__('KGA: Becker Defence (Anti-Kieseritzky)'),
			moves => {
			},
		},
		'rnbqk1nr/ppppbppp/8/8/4Pp2/5N2/PPPP2PP/RNBQKB1R w KQkq' => {
			eco => 'C35',
			# TRANSLATORS: C35: 1. e4 e5 2. f4 exf4 3. Nf3 Be7
			variation => N__('KGA: Cunningham Defence'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnbqk1nr/ppppbppp/8/8/2B1Pp2/5N2/PPPP2PP/RNBQK2R b KQkq' => {
			eco => 'C35',
			# TRANSLATORS: C35: 1. e4 e5 2. f4 exf4 3. Nf3 Be7 4. Bc4
			variation => N__('KGA: Cunningham Defence'),
			moves => {
				'e7h4' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqk1nr/pppp1ppp/8/8/2B1Pp1b/5N2/PPPP2PP/RNBQK2R w KQkq' => {
			eco => 'C35',
			# TRANSLATORS: C35: 1. e4 e5 2. f4 exf4 3. Nf3 Be7 4. Bc4 Bh4+
			variation => N__('KGA: Cunningham Defence'),
			moves => {
				'g2g3' => 1,
			},
		},
		'rnbqk1nr/pppp1ppp/8/8/2B1Pp1b/5NP1/PPPP3P/RNBQK2R b KQkq' => {
			eco => 'C35',
			# TRANSLATORS: C35: 1. e4 e5 2. f4 exf4 3. Nf3 Be7 4. Bc4 Bh4+ 5. g3
			variation => N__('KGA: Cunningham, Bertin Gambit'),
			moves => {
				'f4g3' => 1,
			},
		},
		'rnbqk1nr/pppp1ppp/8/8/2B1P2b/5Np1/PPPP3P/RNBQK2R w KQkq' => {
			eco => 'C35',
			# TRANSLATORS: C35: 1. e4 e5 2. f4 exf4 3. Nf3 Be7 4. Bc4 Bh4+ 5. g3 fxg3
			variation => N__('KGA: Cunningham, Bertin Gambit'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbqk1nr/pppp1ppp/8/8/2B1P2b/5Np1/PPPP3P/RNBQ1RK1 b kq' => {
			eco => 'C35',
			# TRANSLATORS: C35: 1. e4 e5 2. f4 exf4 3. Nf3 Be7 4. Bc4 Bh4+ 5. g3 fxg3 6. O-O
			variation => N__('KGA: Cunningham, Bertin Gambit'),
			moves => {
				'g3h2' => 1,
			},
		},
		'rnbqk1nr/pppp1ppp/8/8/2B1P2b/5N2/PPPP3p/RNBQ1RK1 w kq' => {
			eco => 'C35',
			# TRANSLATORS: C35: 1. e4 e5 2. f4 exf4 3. Nf3 Be7 4. Bc4 Bh4+ 5. g3 fxg3 6. O-O gxh2+
			variation => N__('KGA: Cunningham, Bertin Gambit'),
			moves => {
				'g1h1' => 1,
			},
		},
		'rnbqk1nr/pppp1ppp/8/8/2B1P2b/5N2/PPPP3p/RNBQ1R1K b kq' => {
			eco => 'C35',
			# TRANSLATORS: C35: 1. e4 e5 2. f4 exf4 3. Nf3 Be7 4. Bc4 Bh4+ 5. g3 fxg3 6. O-O gxh2+ 7. Kh1
			variation => N__('KGA: Cunningham, Three Pawns Gambit'),
			moves => {
			},
		},
		'rnbqk2r/ppppbppp/5n2/8/2B1Pp2/5N2/PPPP2PP/RNBQK2R w KQkq' => {
			eco => 'C35',
			# TRANSLATORS: C35: 1. e4 e5 2. f4 exf4 3. Nf3 Be7 4. Bc4 Nf6
			variation => N__('KGA: Cunningham, Euwe Defence'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/8/3p4/4Pp2/5N2/PPPP2PP/RNBQKB1R w KQkq' => {
			eco => 'C36',
			# TRANSLATORS: C36: 1. e4 e5 2. f4 exf4 3. Nf3 d5
			variation => N__('KGA: Scandinavian (Abbazia) Variation'),
			moves => {
				'e4d5' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/8/3P4/5p2/5N2/PPPP2PP/RNBQKB1R b KQkq' => {
			eco => 'C36',
			# TRANSLATORS: C36: 1. e4 e5 2. f4 exf4 3. Nf3 d5 4. exd5
			variation => N__('KGA: Scandinavian, 4.exd5'),
			moves => {
				'f8d6' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqk1nr/ppp2ppp/3b4/3P4/5p2/5N2/PPPP2PP/RNBQKB1R w KQkq' => {
			eco => 'C36',
			# TRANSLATORS: C36: 1. e4 e5 2. f4 exf4 3. Nf3 d5 4. exd5 Bd6
			variation => N__('KGA: Scandinavian, 4.exd5 Bd6'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3P4/5p2/5N2/PPPP2PP/RNBQKB1R w KQkq' => {
			eco => 'C36',
			# TRANSLATORS: C36: 1. e4 e5 2. f4 exf4 3. Nf3 d5 4. exd5 Nf6
			variation => N__('KGA: Scandinavian, Modern Variation'),
			moves => {
				'b1c3' => 1,
				'f1b5' => 1,
				'f1c4' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3P4/5p2/2N2N2/PPPP2PP/R1BQKB1R b KQkq' => {
			eco => 'C36',
			# TRANSLATORS: C36: 1. e4 e5 2. f4 exf4 3. Nf3 d5 4. exd5 Nf6 5. Nc3
			variation => N__('KGA: Scandinavian, Modern, 5. Nc3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/1B1P4/5p2/5N2/PPPP2PP/RNBQK2R b KQkq' => {
			eco => 'C36',
			# TRANSLATORS: C36: 1. e4 e5 2. f4 exf4 3. Nf3 d5 4. exd5 Nf6 5. Bb5+
			variation => N__('KGA: Scandinavian, Modern, 5. Bb5+ '),
			moves => {
				'c7c6' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/2p2n2/1B1P4/5p2/5N2/PPPP2PP/RNBQK2R w KQkq' => {
			eco => 'C36',
			# TRANSLATORS: C36: 1. e4 e5 2. f4 exf4 3. Nf3 d5 4. exd5 Nf6 5. Bb5+ c6
			variation => N__('KGA: Scandinavian, Modern, 5. Bb5+ c6'),
			moves => {
				'd5c6' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/2P2n2/1B6/5p2/5N2/PPPP2PP/RNBQK2R b KQkq' => {
			eco => 'C36',
			# TRANSLATORS: C36: 1. e4 e5 2. f4 exf4 3. Nf3 d5 4. exd5 Nf6 5. Bb5+ c6 6. dxc6
			variation => N__('KGA: Scandinavian, Modern, 5. Bb5+ c6'),
			moves => {
				'b7c6' => 1,
				'b8c6' => 1,
			},
		},
		'rnbqkb1r/p4ppp/2p2n2/1B6/5p2/5N2/PPPP2PP/RNBQK2R w KQkq' => {
			eco => 'C36',
			# TRANSLATORS: C36: 1. e4 e5 2. f4 exf4 3. Nf3 d5 4. exd5 Nf6 5. Bb5+ c6 6. dxc6 bxc6
			variation => N__('KGA: Scandinavian, Modern, 5. Bb5+ c6 6.dxc6 bxc6'),
			moves => {
				'b5c4' => 1,
			},
		},
		'rnbqkb1r/p4ppp/2p2n2/8/2B2p2/5N2/PPPP2PP/RNBQK2R b KQkq' => {
			eco => 'C36',
			# TRANSLATORS: C36: 1. e4 e5 2. f4 exf4 3. Nf3 d5 4. exd5 Nf6 5. Bb5+ c6 6. dxc6 bxc6 7. Bc4
			variation => N__('KGA: Scandinavian, Modern, 5. Bb5+ c6 6.dxc6 bxc6'),
			moves => {
				'f6d5' => 1,
			},
		},
		'rnbqkb1r/p4ppp/2p5/3n4/2B2p2/5N2/PPPP2PP/RNBQK2R w KQkq' => {
			eco => 'C36',
			# TRANSLATORS: C36: 1. e4 e5 2. f4 exf4 3. Nf3 d5 4. exd5 Nf6 5. Bb5+ c6 6. dxc6 bxc6 7. Bc4 Nd5
			variation => N__('KGA: Scandinavian, Botvinnik Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2n2n2/1B6/5p2/5N2/PPPP2PP/RNBQK2R w KQkq' => {
			eco => 'C36',
			# TRANSLATORS: C36: 1. e4 e5 2. f4 exf4 3. Nf3 d5 4. exd5 Nf6 5. Bb5+ c6 6. dxc6 Nxc6
			variation => N__('KGA: Scandinavian, Modern, 5. Bb5+ c6 6.dxc6 Nxc6'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3P4/2B2p2/5N2/PPPP2PP/RNBQK2R b KQkq' => {
			eco => 'C36',
			# TRANSLATORS: C36: 1. e4 e5 2. f4 exf4 3. Nf3 d5 4. exd5 Nf6 5. Bc4
			variation => N__('KGA: Scandinavian, Modern, 5. Bc4'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1p1p/8/6p1/4Pp2/5N2/PPPP2PP/RNBQKB1R w KQkq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5
			variation => N__('KGA: 3. Nf3 g5'),
			moves => {
				'b1c3' => 1,
				'd2d4' => 1,
				'f1c4' => 1,
				'h2h4' => 1,
			},
		},
		'rnbqkbnr/pppp1p1p/8/6p1/4Pp2/2N2N2/PPPP2PP/R1BQKB1R b KQkq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Nc3
			variation => N__('KGA: Quaade Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1p1p/8/6p1/3PPp2/5N2/PPP3PP/RNBQKB1R b KQkq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. d4
			variation => N__('KGA: Rosentreter Gambit'),
			moves => {
				'g5g4' => 1,
			},
		},
		'rnbqkbnr/pppp1p1p/8/8/3PPpp1/5N2/PPP3PP/RNBQKB1R w KQkq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. d4 g4
			variation => N__('KGA: Rosentreter Gambit'),
			moves => {
				'f3e5' => 1,
			},
		},
		'rnbqkbnr/pppp1p1p/8/4N3/3PPpp1/8/PPP3PP/RNBQKB1R b KQkq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. d4 g4 5. Ne5
			variation => N__('KGA: Sörensen Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1p1p/8/6p1/2B1Pp2/5N2/PPPP2PP/RNBQK2R b KQkq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4
			variation => N__('KGA: 3. Nf3 g5 4. Bc4'),
			moves => {
				'b8c6' => 1,
				'f8g7' => 1,
				'g5g4' => 1,
			},
		},
		'r1bqkbnr/pppp1p1p/2n5/6p1/2B1Pp2/5N2/PPPP2PP/RNBQK2R w KQkq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 Nc6
			variation => N__('KGA: Blachly Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1p1p/8/8/2B1Ppp1/5N2/PPPP2PP/RNBQK2R w KQkq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4
			variation => N__('KGA: 3. Nf3 g5 4. Bc4 g4'),
			moves => {
				'b1c3' => 1,
				'c4f7' => 1,
				'd2d4' => 1,
				'e1g1' => 1,
				'f3e5' => 1,
			},
		},
		'rnbqkbnr/pppp1p1p/8/8/2B1Ppp1/2N2N2/PPPP2PP/R1BQK2R b KQkq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. Nc3
			variation => N__('KGA: MacDonnell Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1B1p/8/8/4Ppp1/5N2/PPPP2PP/RNBQK2R b KQkq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. Bxf7+
			variation => N__('KGA: Lolli Gambit (Wild Muzio)'),
			moves => {
				'e8f7' => 1,
			},
		},
		'rnbq1bnr/pppp1k1p/8/8/4Ppp1/5N2/PPPP2PP/RNBQK2R w KQ' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. Bxf7+ Kxf7
			variation => N__('KGA: Lolli Gambit (Wild Muzio)'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbq1bnr/pppp1k1p/8/8/4Ppp1/5N2/PPPP2PP/RNBQ1RK1 b -' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. Bxf7+ Kxf7 6. O-O
			variation => N__('KGA: Lolli Gambit (Wild Muzio)'),
			moves => {
				'g4f3' => 1,
			},
		},
		'rnbq1bnr/pppp1k1p/8/8/4Pp2/5p2/PPPP2PP/RNBQ1RK1 w -' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. Bxf7+ Kxf7 6. O-O gxf3
			variation => N__('KGA: Lolli Gambit (Wild Muzio)'),
			moves => {
				'd1f3' => 1,
			},
		},
		'rnbq1bnr/pppp1k1p/8/8/4Pp2/5Q2/PPPP2PP/RNB2RK1 b -' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. Bxf7+ Kxf7 6. O-O gxf3 7. Qxf3
			variation => N__('KGA: Lolli Gambit (Wild Muzio)'),
			moves => {
				'd8f6' => 1,
			},
		},
		'rnb2bnr/pppp1k1p/5q2/8/4Pp2/5Q2/PPPP2PP/RNB2RK1 w -' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. Bxf7+ Kxf7 6. O-O gxf3 7. Qxf3 Qf6
			variation => N__('KGA: Lolli Gambit (Wild Muzio)'),
			moves => {
				'd2d4' => 1,
			},
		},
		'rnb2bnr/pppp1k1p/5q2/8/3PPp2/5Q2/PPP3PP/RNB2RK1 b -' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. Bxf7+ Kxf7 6. O-O gxf3 7. Qxf3 Qf6 8. d4
			variation => N__('KGA: Lolli Gambit (Wild Muzio)'),
			moves => {
				'f6d4' => 1,
			},
		},
		'rnb2bnr/pppp1k1p/8/8/3qPp2/5Q2/PPP3PP/RNB2RK1 w -' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. Bxf7+ Kxf7 6. O-O gxf3 7. Qxf3 Qf6 8. d4 Qxd4+
			variation => N__('KGA: Lolli Gambit (Wild Muzio)'),
			moves => {
				'c1e3' => 1,
			},
		},
		'rnb2bnr/pppp1k1p/8/8/3qPp2/4BQ2/PPP3PP/RN3RK1 b -' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. Bxf7+ Kxf7 6. O-O gxf3 7. Qxf3 Qf6 8. d4 Qxd4+ 9. Be3
			variation => N__('KGA: Lolli Gambit (Wild Muzio)'),
			moves => {
				'd4f6' => 1,
			},
		},
		'rnb2bnr/pppp1k1p/5q2/8/4Pp2/4BQ2/PPP3PP/RN3RK1 w -' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. Bxf7+ Kxf7 6. O-O gxf3 7. Qxf3 Qf6 8. d4 Qxd4+ 9. Be3 Qf6
			variation => N__('KGA: Lolli Gambit (Wild Muzio)'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnb2bnr/pppp1k1p/5q2/8/4Pp2/2N1BQ2/PPP3PP/R4RK1 b -' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. Bxf7+ Kxf7 6. O-O gxf3 7. Qxf3 Qf6 8. d4 Qxd4+ 9. Be3 Qf6 10. Nc3
			variation => N__('KGA: Lolli Gambit, Young Variation'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1p1p/8/8/2BPPpp1/5N2/PPP3PP/RNBQK2R b KQkq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. d4
			variation => N__('KGA: Ghulam-Kassim Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1p1p/8/8/2B1Ppp1/5N2/PPPP2PP/RNBQ1RK1 b kq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. O-O
			variation => N__('KGA: Muzio Gambit'),
			moves => {
				'd7d5' => 1,
				'd8e7' => 1,
				'g4f3' => 1,
			},
		},
		'rnbqkbnr/ppp2p1p/8/3p4/2B1Ppp1/5N2/PPPP2PP/RNBQ1RK1 w kq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. O-O d5
			variation => N__('KGA: Muzio Gambit, Brentano Defence'),
			moves => {
			},
		},
		'rnb1kbnr/ppppqp1p/8/8/2B1Ppp1/5N2/PPPP2PP/RNBQ1RK1 w kq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. O-O Qe7
			variation => N__('KGA: Muzio Gambit, Kling and Horwitz Counterattack'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1p1p/8/8/2B1Pp2/5p2/PPPP2PP/RNBQ1RK1 w kq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. O-O gxf3
			variation => N__('KGA: Muzio Gambit'),
			moves => {
				'd1f3' => 1,
			},
		},
		'rnbqkbnr/pppp1p1p/8/8/2B1Pp2/5Q2/PPPP2PP/RNB2RK1 b kq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. O-O gxf3 6. Qxf3
			variation => N__('KGA: Muzio Gambit'),
			moves => {
				'b8c6' => 1,
				'd8e7' => 1,
				'd8f6' => 1,
			},
		},
		'r1bqkbnr/pppp1p1p/2n5/8/2B1Pp2/5Q2/PPPP2PP/RNB2RK1 w kq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. O-O gxf3 6. Qxf3 Nc6
			variation => N__('KGA: Muzio Gambit, Holloway Defence'),
			moves => {
			},
		},
		'rnb1kbnr/ppppqp1p/8/8/2B1Pp2/5Q2/PPPP2PP/RNB2RK1 w kq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. O-O gxf3 6. Qxf3 Qe7
			variation => N__('KGA: Muzio Gambit, From Defence'),
			moves => {
			},
		},
		'rnb1kbnr/pppp1p1p/5q2/8/2B1Pp2/5Q2/PPPP2PP/RNB2RK1 w kq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. O-O gxf3 6. Qxf3 Qf6
			variation => N__('KGA: Muzio Gambit'),
			moves => {
				'e4e5' => 1,
			},
		},
		'rnb1kbnr/pppp1p1p/5q2/4P3/2B2p2/5Q2/PPPP2PP/RNB2RK1 b kq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. O-O gxf3 6. Qxf3 Qf6 7. e5
			variation => N__('KGA: Muzio Gambit'),
			moves => {
				'f6e5' => 1,
			},
		},
		'rnb1kbnr/pppp1p1p/8/4q3/2B2p2/5Q2/PPPP2PP/RNB2RK1 w kq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. O-O gxf3 6. Qxf3 Qf6 7. e5 Qxe5
			variation => N__('KGA: Muzio Gambit'),
			moves => {
				'c4f7' => 1,
				'd2d3' => 1,
			},
		},
		'rnb1kbnr/pppp1B1p/8/4q3/5p2/5Q2/PPPP2PP/RNB2RK1 b kq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. O-O gxf3 6. Qxf3 Qf6 7. e5 Qxe5 8. Bxf7+
			variation => N__('KGA: Double Muzio Gambit'),
			moves => {
			},
		},
		'rnb1kbnr/pppp1p1p/8/4q3/2B2p2/3P1Q2/PPP3PP/RNB2RK1 b kq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. O-O gxf3 6. Qxf3 Qf6 7. e5 Qxe5 8. d3
			variation => N__('KGA: Muzio Gambit'),
			moves => {
				'f8h6' => 1,
			},
		},
		'rnb1k1nr/pppp1p1p/7b/4q3/2B2p2/3P1Q2/PPP3PP/RNB2RK1 w kq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. O-O gxf3 6. Qxf3 Qf6 7. e5 Qxe5 8. d3 Bh6
			variation => N__('KGA: Muzio Gambit'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnb1k1nr/pppp1p1p/7b/4q3/2B2p2/2NP1Q2/PPP3PP/R1B2RK1 b kq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. O-O gxf3 6. Qxf3 Qf6 7. e5 Qxe5 8. d3 Bh6 9. Nc3
			variation => N__('KGA: Muzio Gambit'),
			moves => {
				'g8e7' => 1,
			},
		},
		'rnb1k2r/ppppnp1p/7b/4q3/2B2p2/2NP1Q2/PPP3PP/R1B2RK1 w kq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. O-O gxf3 6. Qxf3 Qf6 7. e5 Qxe5 8. d3 Bh6 9. Nc3 Ne7
			variation => N__('KGA: Muzio Gambit'),
			moves => {
				'c1d2' => 1,
			},
		},
		'rnb1k2r/ppppnp1p/7b/4q3/2B2p2/2NP1Q2/PPPB2PP/R4RK1 b kq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. O-O gxf3 6. Qxf3 Qf6 7. e5 Qxe5 8. d3 Bh6 9. Nc3 Ne7 10. Bd2
			variation => N__('KGA: Muzio Gambit'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1b1k2r/ppppnp1p/2n4b/4q3/2B2p2/2NP1Q2/PPPB2PP/R4RK1 w kq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. O-O gxf3 6. Qxf3 Qf6 7. e5 Qxe5 8. d3 Bh6 9. Nc3 Ne7 10. Bd2 Nbc6
			variation => N__('KGA: Muzio Gambit'),
			moves => {
				'a1e1' => 1,
			},
		},
		'r1b1k2r/ppppnp1p/2n4b/4q3/2B2p2/2NP1Q2/PPPB2PP/4RRK1 b kq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. O-O gxf3 6. Qxf3 Qf6 7. e5 Qxe5 8. d3 Bh6 9. Nc3 Ne7 10. Bd2 Nbc6 11. Rae1
			variation => N__('KGA: Muzio Gambit, Paulsen Variation'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1p1p/8/4N3/2B1Ppp1/8/PPPP2PP/RNBQK2R b KQkq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. Ne5
			variation => N__('KGA: Salvio Gambit'),
			moves => {
				'd8h4' => 1,
			},
		},
		'rnb1kbnr/pppp1p1p/8/4N3/2B1Pppq/8/PPPP2PP/RNBQK2R w KQkq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. Ne5 Qh4+
			variation => N__('KGA: Salvio Gambit'),
			moves => {
				'e1f1' => 1,
			},
		},
		'rnb1kbnr/pppp1p1p/8/4N3/2B1Pppq/8/PPPP2PP/RNBQ1K1R b kq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. Ne5 Qh4+ 6. Kf1
			variation => N__('KGA: Salvio Gambit'),
			moves => {
				'b8c6' => 1,
				'f4f3' => 1,
				'g8h6' => 1,
			},
		},
		'r1b1kbnr/pppp1p1p/2n5/4N3/2B1Pppq/8/PPPP2PP/RNBQ1K1R w kq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. Ne5 Qh4+ 6. Kf1 Nc6
			variation => N__('KGA: Salvio, Herzfeld Gambit'),
			moves => {
			},
		},
		'rnb1kbnr/pppp1p1p/8/4N3/2B1P1pq/5p2/PPPP2PP/RNBQ1K1R w kq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. Ne5 Qh4+ 6. Kf1 f3
			variation => N__('KGA: Salvio, Cochrane Gambit'),
			moves => {
			},
		},
		'rnb1kb1r/pppp1p1p/7n/4N3/2B1Pppq/8/PPPP2PP/RNBQ1K1R w kq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. Ne5 Qh4+ 6. Kf1 Nh6
			variation => N__('KGA: Salvio Gambit'),
			moves => {
				'd2d4' => 1,
			},
		},
		'rnb1kb1r/pppp1p1p/7n/4N3/2BPPppq/8/PPP3PP/RNBQ1K1R b kq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. Ne5 Qh4+ 6. Kf1 Nh6 7. d4
			variation => N__('KGA: Salvio Gambit'),
			moves => {
				'd7d6' => 1,
				'f4f3' => 1,
			},
		},
		'rnb1kb1r/ppp2p1p/3p3n/4N3/2BPPppq/8/PPP3PP/RNBQ1K1R w kq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. Ne5 Qh4+ 6. Kf1 Nh6 7. d4 d6
			variation => N__('KGA: Salvio, Anderssen Counterattack'),
			moves => {
			},
		},
		'rnb1kb1r/pppp1p1p/7n/4N3/2BPP1pq/5p2/PPP3PP/RNBQ1K1R w kq' => {
			eco => 'C37',
			# TRANSLATORS: C37: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 g4 5. Ne5 Qh4+ 6. Kf1 Nh6 7. d4 f3
			variation => N__('KGA: Salvio, Silberschmidt Gambit'),
			moves => {
			},
		},
		'rnbqk1nr/pppp1pbp/8/6p1/2B1Pp2/5N2/PPPP2PP/RNBQK2R w KQkq' => {
			eco => 'C38',
			# TRANSLATORS: C38: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 Bg7
			variation => N__('KGA: 3. Nf3 g5 4. Bc4 Bg7'),
			moves => {
				'd2d4' => 1,
				'e1g1' => 1,
				'h2h4' => 1,
			},
		},
		'rnbqk1nr/pppp1pbp/8/6p1/2BPPp2/5N2/PPP3PP/RNBQK2R b KQkq' => {
			eco => 'C38',
			# TRANSLATORS: C38: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 Bg7 5. d4
			variation => N__('KGA: Hanstein Gambit'),
			moves => {
			},
		},
		'rnbqk1nr/pppp1pbp/8/6p1/2B1Pp2/5N2/PPPP2PP/RNBQ1RK1 b kq' => {
			eco => 'C38',
			# TRANSLATORS: C38: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 Bg7 5. O-O
			variation => N__('KGA: 3. Nf3 g5 4. Bc4 Bg7'),
			moves => {
				'h7h6' => 1,
			},
		},
		'rnbqk1nr/pppp1pb1/7p/6p1/2B1Pp2/5N2/PPPP2PP/RNBQ1RK1 w kq' => {
			eco => 'C38',
			# TRANSLATORS: C38: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 Bg7 5. O-O h6
			variation => N__('KGA: 3. Nf3 g5 4. Bc4 Bg7'),
			moves => {
				'd2d4' => 1,
			},
		},
		'rnbqk1nr/pppp1pb1/7p/6p1/2BPPp2/5N2/PPP3PP/RNBQ1RK1 b kq' => {
			eco => 'C38',
			# TRANSLATORS: C38: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 Bg7 5. O-O h6 6. d4
			variation => N__('KGA: 3. Nf3 g5 4. Bc4 Bg7'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rnbqk1nr/ppp2pb1/3p3p/6p1/2BPPp2/5N2/PPP3PP/RNBQ1RK1 w kq' => {
			eco => 'C38',
			# TRANSLATORS: C38: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 Bg7 5. O-O h6 6. d4 d6
			variation => N__('KGA: Hanstein Gambit'),
			moves => {
			},
		},
		'rnbqk1nr/pppp1pbp/8/6p1/2B1Pp1P/5N2/PPPP2P1/RNBQK2R b KQkq' => {
			eco => 'C38',
			# TRANSLATORS: C38: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 Bg7 5. h4
			variation => N__('KGA: Philidor Gambit'),
			moves => {
				'h7h6' => 1,
			},
		},
		'rnbqk1nr/pppp1pb1/7p/6p1/2B1Pp1P/5N2/PPPP2P1/RNBQK2R w KQkq' => {
			eco => 'C38',
			# TRANSLATORS: C38: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 Bg7 5. h4 h6
			variation => N__('KGA: Philidor Gambit'),
			moves => {
				'd2d4' => 1,
			},
		},
		'rnbqk1nr/pppp1pb1/7p/6p1/2BPPp1P/5N2/PPP3P1/RNBQK2R b KQkq' => {
			eco => 'C38',
			# TRANSLATORS: C38: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 Bg7 5. h4 h6 6. d4
			variation => N__('KGA: Philidor Gambit'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rnbqk1nr/ppp2pb1/3p3p/6p1/2BPPp1P/5N2/PPP3P1/RNBQK2R w KQkq' => {
			eco => 'C38',
			# TRANSLATORS: C38: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 Bg7 5. h4 h6 6. d4 d6
			variation => N__('KGA: Philidor Gambit'),
			moves => {
				'b1c3' => 1,
				'd1d3' => 1,
			},
		},
		'rnbqk1nr/ppp2pb1/3p3p/6p1/2BPPp1P/2N2N2/PPP3P1/R1BQK2R b KQkq' => {
			eco => 'C38',
			# TRANSLATORS: C38: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 Bg7 5. h4 h6 6. d4 d6 7. Nc3
			variation => N__('KGA: Philidor Gambit'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rnbqk1nr/pp3pb1/2pp3p/6p1/2BPPp1P/2N2N2/PPP3P1/R1BQK2R w KQkq' => {
			eco => 'C38',
			# TRANSLATORS: C38: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 Bg7 5. h4 h6 6. d4 d6 7. Nc3 c6
			variation => N__('KGA: Philidor Gambit'),
			moves => {
				'h4g5' => 1,
			},
		},
		'rnbqk1nr/pp3pb1/2pp3p/6P1/2BPPp2/2N2N2/PPP3P1/R1BQK2R b KQkq' => {
			eco => 'C38',
			# TRANSLATORS: C38: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 Bg7 5. h4 h6 6. d4 d6 7. Nc3 c6 8. hxg5
			variation => N__('KGA: Philidor Gambit'),
			moves => {
				'h6g5' => 1,
			},
		},
		'rnbqk1nr/pp3pb1/2pp4/6p1/2BPPp2/2N2N2/PPP3P1/R1BQK2R w KQkq' => {
			eco => 'C38',
			# TRANSLATORS: C38: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 Bg7 5. h4 h6 6. d4 d6 7. Nc3 c6 8. hxg5 hxg5
			variation => N__('KGA: Philidor Gambit'),
			moves => {
				'h1h8' => 1,
			},
		},
		'rnbqk1nR/pp3pb1/2pp4/6p1/2BPPp2/2N2N2/PPP3P1/R1BQK3 b Qq' => {
			eco => 'C38',
			# TRANSLATORS: C38: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 Bg7 5. h4 h6 6. d4 d6 7. Nc3 c6 8. hxg5 hxg5 9. Rxh8
			variation => N__('KGA: Philidor Gambit'),
			moves => {
				'g7h8' => 1,
			},
		},
		'rnbqk1nb/pp3p2/2pp4/6p1/2BPPp2/2N2N2/PPP3P1/R1BQK3 w Qq' => {
			eco => 'C38',
			# TRANSLATORS: C38: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 Bg7 5. h4 h6 6. d4 d6 7. Nc3 c6 8. hxg5 hxg5 9. Rxh8 Bxh8
			variation => N__('KGA: Philidor Gambit'),
			moves => {
				'f3e5' => 1,
			},
		},
		'rnbqk1nb/pp3p2/2pp4/4N1p1/2BPPp2/2N5/PPP3P1/R1BQK3 b Qq' => {
			eco => 'C38',
			# TRANSLATORS: C38: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 Bg7 5. h4 h6 6. d4 d6 7. Nc3 c6 8. hxg5 hxg5 9. Rxh8 Bxh8 10. Ne5
			variation => N__('KGA: Greco Gambit'),
			moves => {
			},
		},
		'rnbqk1nr/ppp2pb1/3p3p/6p1/2BPPp1P/3Q1N2/PPP3P1/RNB1K2R b KQkq' => {
			eco => 'C38',
			# TRANSLATORS: C38: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. Bc4 Bg7 5. h4 h6 6. d4 d6 7. Qd3
			variation => N__('KGA: Philidor Gambit, Schultz Variation'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1p1p/8/6p1/4Pp1P/5N2/PPPP2P1/RNBQKB1R b KQkq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4
			variation => N__('KGA: 3. Nf3 g5 4. h4'),
			moves => {
				'g5g4' => 1,
			},
		},
		'rnbqkbnr/pppp1p1p/8/8/4PppP/5N2/PPPP2P1/RNBQKB1R w KQkq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4
			variation => N__('KGA: 3. Nf3 g5 4. h4'),
			moves => {
				'f3e5' => 1,
				'f3g5' => 1,
			},
		},
		'rnbqkbnr/pppp1p1p/8/4N3/4PppP/8/PPPP2P1/RNBQKB1R b KQkq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ne5
			variation => N__('KGA: Kieseritsky'),
			moves => {
				'b8c6' => 1,
				'd7d5' => 1,
				'd7d6' => 1,
				'd8e7' => 1,
				'f8e7' => 1,
				'f8g7' => 1,
				'g8f6' => 1,
				'h7h5' => 1,
			},
		},
		'r1bqkbnr/pppp1p1p/2n5/4N3/4PppP/8/PPPP2P1/RNBQKB1R w KQkq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ne5 Nc6
			variation => N__('KGA: Kieseritsky, Neumann Defence'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2p1p/8/3pN3/4PppP/8/PPPP2P1/RNBQKB1R w KQkq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ne5 d5
			variation => N__('KGA: Kieseritsky, Brentano (Campbell) Defence'),
			moves => {
				'd2d4' => 1,
			},
		},
		'rnbqkbnr/ppp2p1p/8/3pN3/3PPppP/8/PPP3P1/RNBQKB1R b KQkq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ne5 d5 6. d4
			variation => N__('KGA: Kieseritsky, Brentano (Campbell) Defence'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/ppp2p1p/5n2/3pN3/3PPppP/8/PPP3P1/RNBQKB1R w KQkq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ne5 d5 6. d4 Nf6
			variation => N__('KGA: Kieseritsky, Brentano (Campbell) Defence'),
			moves => {
				'c1f4' => 1,
				'e4d5' => 1,
			},
		},
		'rnbqkb1r/ppp2p1p/5n2/3pN3/3PPBpP/8/PPP3P1/RN1QKB1R b KQkq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ne5 d5 6. d4 Nf6 7. Bxf4
			variation => N__('KGA: Kieseritsky, Brentano Defence'),
			moves => {
				'f6e4' => 1,
			},
		},
		'rnbqkb1r/ppp2p1p/8/3pN3/3PnBpP/8/PPP3P1/RN1QKB1R w KQkq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ne5 d5 6. d4 Nf6 7. Bxf4 Nxe4
			variation => N__('KGA: Kieseritsky, Brentano Defence'),
			moves => {
				'b1d2' => 1,
			},
		},
		'rnbqkb1r/ppp2p1p/8/3pN3/3PnBpP/8/PPPN2P1/R2QKB1R b KQkq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ne5 d5 6. d4 Nf6 7. Bxf4 Nxe4 8. Nd2
			variation => N__('KGA: Kieseritsky, Brentano Defence, Caro Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2p1p/5n2/3PN3/3P1ppP/8/PPP3P1/RNBQKB1R b KQkq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ne5 d5 6. d4 Nf6 7. exd5
			variation => N__('KGA: Kieseritsky, Brentano (Campbell) Defence'),
			moves => {
				'd8d5' => 1,
			},
		},
		'rnb1kb1r/ppp2p1p/5n2/3qN3/3P1ppP/8/PPP3P1/RNBQKB1R w KQkq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ne5 d5 6. d4 Nf6 7. exd5 Qxd5
			variation => N__('KGA: Kieseritsky, Brentano (Campbell) Defence'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnb1kb1r/ppp2p1p/5n2/3qN3/3P1ppP/2N5/PPP3P1/R1BQKB1R b KQkq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ne5 d5 6. d4 Nf6 7. exd5 Qxd5 8. Nc3
			variation => N__('KGA: Kieseritsky, Brentano (Campbell) Defence'),
			moves => {
				'f8b4' => 1,
			},
		},
		'rnb1k2r/ppp2p1p/5n2/3qN3/1b1P1ppP/2N5/PPP3P1/R1BQKB1R w KQkq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ne5 d5 6. d4 Nf6 7. exd5 Qxd5 8. Nc3 Bb4
			variation => N__('KGA: Kieseritsky, Brentano (Campbell) Defence'),
			moves => {
				'e1f2' => 1,
			},
		},
		'rnb1k2r/ppp2p1p/5n2/3qN3/1b1P1ppP/2N5/PPP2KP1/R1BQ1B1R b kq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ne5 d5 6. d4 Nf6 7. exd5 Qxd5 8. Nc3 Bb4 9. Kf2
			variation => N__('KGA: Kieseritsky, Brentano Defence, Kaplanek Variation'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2p1p/3p4/4N3/4PppP/8/PPPP2P1/RNBQKB1R w KQkq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ne5 d6
			variation => N__('KGA: Kieseritsky, Green Variation'),
			moves => {
			},
		},
		'rnb1kbnr/ppppqp1p/8/4N3/4PppP/8/PPPP2P1/RNBQKB1R w KQkq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ne5 Qe7
			variation => N__('KGA: Kieseritsky, Salvio (Rosenthal) Defence'),
			moves => {
				'd2d4' => 1,
			},
		},
		'rnb1kbnr/ppppqp1p/8/4N3/3PPppP/8/PPP3P1/RNBQKB1R b KQkq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ne5 Qe7 6. d4
			variation => N__('KGA: Kieseritsky, Salvio (Rosenthal) Defence'),
			moves => {
				'f7f5' => 1,
			},
		},
		'rnb1kbnr/ppppq2p/8/4Np2/3PPppP/8/PPP3P1/RNBQKB1R w KQkq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ne5 Qe7 6. d4 f5
			variation => N__('KGA: Kieseritsky, Salvio (Rosenthal) Defence'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnb1kbnr/ppppq2p/8/4Np2/2BPPppP/8/PPP3P1/RNBQK2R b KQkq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ne5 Qe7 6. d4 f5 7. Bc4
			variation => N__('KGA: Kieseritsky, Salvio Defence, Cozio Variation'),
			moves => {
			},
		},
		'rnbqk1nr/ppppbp1p/8/4N3/4PppP/8/PPPP2P1/RNBQKB1R w KQkq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ne5 Be7
			variation => N__('KGA: Kieseritsky, Polerio Defence'),
			moves => {
			},
		},
		'rnbqk1nr/pppp1pbp/8/4N3/4PppP/8/PPPP2P1/RNBQKB1R w KQkq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ne5 Bg7
			variation => N__('KGA: Kieseritsky, Paulsen Defence'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1p1p/5n2/4N3/4PppP/8/PPPP2P1/RNBQKB1R w KQkq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ne5 Nf6
			variation => N__('KGA: Kieseritsky, Berlin Defence'),
			moves => {
				'e5g4' => 1,
				'f1c4' => 1,
			},
		},
		'rnbqkb1r/pppp1p1p/5n2/8/4PpNP/8/PPPP2P1/RNBQKB1R b KQkq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ne5 Nf6 6. Nxg4
			variation => N__('KGA: Kieseritsky, Berlin Defence'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqkb1r/ppp2p1p/5n2/3p4/4PpNP/8/PPPP2P1/RNBQKB1R w KQkq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ne5 Nf6 6. Nxg4 d5
			variation => N__('KGA: Kieseritsky, Berlin Defence, Riviere Variation'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1p1p/5n2/4N3/2B1PppP/8/PPPP2P1/RNBQK2R b KQkq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ne5 Nf6 6. Bc4
			variation => N__('KGA: Kieseritsky, Berlin Defence, 6. Bc4'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqkb1r/ppp2p1p/5n2/3pN3/2B1PppP/8/PPPP2P1/RNBQK2R w KQkq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ne5 Nf6 6. Bc4 d5
			variation => N__('KGA: Kieseritsky, Berlin Defence, 6. Bc4'),
			moves => {
				'e4d5' => 1,
			},
		},
		'rnbqkb1r/ppp2p1p/5n2/3PN3/2B2ppP/8/PPPP2P1/RNBQK2R b KQkq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ne5 Nf6 6. Bc4 d5 7. exd5
			variation => N__('KGA: Kieseritsky, Berlin Defence, 6. Bc4'),
			moves => {
				'f8d6' => 1,
			},
		},
		'rnbqk2r/ppp2p1p/3b1n2/3PN3/2B2ppP/8/PPPP2P1/RNBQK2R w KQkq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ne5 Nf6 6. Bc4 d5 7. exd5 Bd6
			variation => N__('KGA: Kieseritsky, Berlin Defence, 6. Bc4'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbqk2r/ppp2p1p/3b1n2/3PN3/2B2ppP/8/PPPP2P1/RNBQ1RK1 b kq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ne5 Nf6 6. Bc4 d5 7. exd5 Bd6 8. O-O
			variation => N__('KGA: Kieseritsky, Rice Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1p2/8/4N2p/4PppP/8/PPPP2P1/RNBQKB1R w KQkq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ne5 h5
			variation => N__('KGA: Kieseritsky, Long Whip Defence'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnbqkbnr/pppp1p2/8/4N2p/2B1PppP/8/PPPP2P1/RNBQK2R b KQkq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ne5 h5 6. Bc4
			variation => N__('KGA: Kieseritsky, Long Whip Defence'),
			moves => {
				'h8h7' => 1,
			},
		},
		'rnbqkbn1/pppp1p1r/8/4N2p/2B1PppP/8/PPPP2P1/RNBQK2R w KQq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ne5 h5 6. Bc4 Rh7
			variation => N__('KGA: Kieseritsky, Long Whip Defence'),
			moves => {
				'd2d4' => 1,
			},
		},
		'rnbqkbn1/pppp1p1r/8/4N2p/2BPPppP/8/PPP3P1/RNBQK2R b KQq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ne5 h5 6. Bc4 Rh7 7. d4
			variation => N__('KGA: Kieseritsky, Long Whip Defence'),
			moves => {
				'f8h6' => 1,
			},
		},
		'rnbqk1n1/pppp1p1r/7b/4N2p/2BPPppP/8/PPP3P1/RNBQK2R w KQq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ne5 h5 6. Bc4 Rh7 7. d4 Bh6
			variation => N__('KGA: Kieseritsky, Long Whip Defence'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqk1n1/pppp1p1r/7b/4N2p/2BPPppP/2N5/PPP3P1/R1BQK2R b KQq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ne5 h5 6. Bc4 Rh7 7. d4 Bh6 8. Nc3
			variation => N__('KGA: Kieseritsky, Long Whip Defence, Jänisch Variation'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1p1p/8/6N1/4PppP/8/PPPP2P1/RNBQKB1R b KQkq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ng5
			variation => N__('KGA: Allgaier Gambit'),
			moves => {
				'g8f6' => 1,
				'h7h6' => 1,
			},
		},
		'rnbqkb1r/pppp1p1p/5n2/6N1/4PppP/8/PPPP2P1/RNBQKB1R w KQkq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ng5 Nf6
			variation => N__('KGA: Allgaier, Schlechter Defence'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1p2/7p/6N1/4PppP/8/PPPP2P1/RNBQKB1R w KQkq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ng5 h6
			variation => N__('KGA: Allgaier Gambit'),
			moves => {
				'g5f7' => 1,
			},
		},
		'rnbqkbnr/pppp1N2/7p/8/4PppP/8/PPPP2P1/RNBQKB1R b KQkq' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ng5 h6 6. Nxf7
			variation => N__('KGA: Allgaier Gambit'),
			moves => {
				'e8f7' => 1,
			},
		},
		'rnbq1bnr/pppp1k2/7p/8/4PppP/8/PPPP2P1/RNBQKB1R w KQ' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ng5 h6 6. Nxf7 Kxf7
			variation => N__('KGA: Allgaier Gambit'),
			moves => {
				'b1c3' => 1,
				'd1g4' => 1,
				'd2d4' => 1,
				'f1c4' => 1,
			},
		},
		'rnbq1bnr/pppp1k2/7p/8/4PppP/2N5/PPPP2P1/R1BQKB1R b KQ' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ng5 h6 6. Nxf7 Kxf7 7. Nc3
			variation => N__('KGA: Allgaier, Blackburne Gambit'),
			moves => {
			},
		},
		'rnbq1bnr/pppp1k2/7p/8/4PpQP/8/PPPP2P1/RNB1KB1R b KQ' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ng5 h6 6. Nxf7 Kxf7 7. Qxg4
			variation => N__('KGA: Allgaier Gambit'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbq1b1r/pppp1k2/5n1p/8/4PpQP/8/PPPP2P1/RNB1KB1R w KQ' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ng5 h6 6. Nxf7 Kxf7 7. Qxg4 Nf6
			variation => N__('KGA: Allgaier Gambit'),
			moves => {
				'g4f4' => 1,
			},
		},
		'rnbq1b1r/pppp1k2/5n1p/8/4PQ1P/8/PPPP2P1/RNB1KB1R b KQ' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ng5 h6 6. Nxf7 Kxf7 7. Qxg4 Nf6 8. Qxf4
			variation => N__('KGA: Allgaier Gambit'),
			moves => {
				'f8d6' => 1,
			},
		},
		'rnbq3r/pppp1k2/3b1n1p/8/4PQ1P/8/PPPP2P1/RNB1KB1R w KQ' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ng5 h6 6. Nxf7 Kxf7 7. Qxg4 Nf6 8. Qxf4 Bd6
			variation => N__('KGA: Allgaier, Horny Defence'),
			moves => {
			},
		},
		'rnbq1bnr/pppp1k2/7p/8/3PPppP/8/PPP3P1/RNBQKB1R b KQ' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ng5 h6 6. Nxf7 Kxf7 7. d4
			variation => N__('KGA: Allgaier, Thorold Variation'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbq1bnr/ppp2k2/7p/3p4/3PPppP/8/PPP3P1/RNBQKB1R w KQ' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ng5 h6 6. Nxf7 Kxf7 7. d4 d5
			variation => N__('KGA: Allgaier, Thorold Variation'),
			moves => {
				'c1f4' => 1,
			},
		},
		'rnbq1bnr/ppp2k2/7p/3p4/3PPBpP/8/PPP3P1/RN1QKB1R b KQ' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ng5 h6 6. Nxf7 Kxf7 7. d4 d5 8. Bxf4
			variation => N__('KGA: Allgaier, Thorold Variation'),
			moves => {
				'd5e4' => 1,
			},
		},
		'rnbq1bnr/ppp2k2/7p/8/3PpBpP/8/PPP3P1/RN1QKB1R w KQ' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ng5 h6 6. Nxf7 Kxf7 7. d4 d5 8. Bxf4 dxe4
			variation => N__('KGA: Allgaier, Thorold Variation'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnbq1bnr/ppp2k2/7p/8/2BPpBpP/8/PPP3P1/RN1QK2R b KQ' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ng5 h6 6. Nxf7 Kxf7 7. d4 d5 8. Bxf4 dxe4 9. Bc4+
			variation => N__('KGA: Allgaier, Thorold Variation'),
			moves => {
				'f7g7' => 1,
			},
		},
		'rnbq1bnr/ppp3k1/7p/8/2BPpBpP/8/PPP3P1/RN1QK2R w KQ' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ng5 h6 6. Nxf7 Kxf7 7. d4 d5 8. Bxf4 dxe4 9. Bc4+ Kg7
			variation => N__('KGA: Allgaier, Thorold Variation'),
			moves => {
				'f4e5' => 1,
			},
		},
		'rnbq1bnr/ppp3k1/7p/4B3/2BPp1pP/8/PPP3P1/RN1QK2R b KQ' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ng5 h6 6. Nxf7 Kxf7 7. d4 d5 8. Bxf4 dxe4 9. Bc4+ Kg7 10. Be5+
			variation => N__('KGA: Allgaier, Cook Variation'),
			moves => {
			},
		},
		'rnbq1bnr/pppp1k2/7p/8/2B1PppP/8/PPPP2P1/RNBQK2R b KQ' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ng5 h6 6. Nxf7 Kxf7 7. Bc4+
			variation => N__('KGA: Allgaier, Walker Attack'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbq1bnr/ppp2k2/7p/3p4/2B1PppP/8/PPPP2P1/RNBQK2R w KQ' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ng5 h6 6. Nxf7 Kxf7 7. Bc4+ d5
			variation => N__('KGA: Allgaier, Walker Attack'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rnbq1bnr/ppp2k2/7p/3B4/4PppP/8/PPPP2P1/RNBQK2R b KQ' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ng5 h6 6. Nxf7 Kxf7 7. Bc4+ d5 8. Bxd5+
			variation => N__('KGA: Allgaier, Walker Attack'),
			moves => {
				'f7g7' => 1,
			},
		},
		'rnbq1bnr/ppp3k1/7p/3B4/4PppP/8/PPPP2P1/RNBQK2R w KQ' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ng5 h6 6. Nxf7 Kxf7 7. Bc4+ d5 8. Bxd5+ Kg7
			variation => N__('KGA: Allgaier, Walker Attack'),
			moves => {
				'd2d4' => 1,
			},
		},
		'rnbq1bnr/ppp3k1/7p/3B4/3PPppP/8/PPP3P1/RNBQK2R b KQ' => {
			eco => 'C39',
			# TRANSLATORS: C39: 1. e4 e5 2. f4 exf4 3. Nf3 g5 4. h4 g4 5. Ng5 h6 6. Nxf7 Kxf7 7. Bc4+ d5 8. Bxd5+ Kg7 9. d4
			variation => N__('KGA: Allgaier, Urusov Attack'),
			moves => {
			},
		},
		'rnbqkbnr/pppp1ppp/8/4p3/4P3/5N2/PPPP1PPP/RNBQKB1R b KQkq' => {
			eco => 'C40a',
			# TRANSLATORS: C40a: 1. e4 e5 2. Nf3
			variation => N__('Open Game'),
			moves => {
				'b8c6' => 1,
				'd7d5' => 1,
				'd7d6' => 1,
				'd8e7' => 1,
				'd8f6' => 1,
				'f7f5' => 1,
				'f7f6' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/pppp2pp/5p2/4p3/4P3/5N2/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'C40a',
			# TRANSLATORS: C40a: 1. e4 e5 2. Nf3 f6
			variation => N__('Open Game: Damiano Defence'),
			moves => {
			},
		},
		'rnb1kbnr/pppp1ppp/5q2/4p3/4P3/5N2/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'C40b',
			# TRANSLATORS: C40b: 1. e4 e5 2. Nf3 Qf6
			variation => N__('Open Game: Greco Defence'),
			moves => {
			},
		},
		'rnb1kbnr/ppppqppp/8/4p3/4P3/5N2/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'C40c',
			# TRANSLATORS: C40c: 1. e4 e5 2. Nf3 Qe7
			variation => N__('Open Game: Gunderam Defence'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnb1kbnr/ppppqppp/8/4p3/4P3/2N2N2/PPPP1PPP/R1BQKB1R b KQkq' => {
			eco => 'C40d',
			# TRANSLATORS: C40d: 1. e4 e5 2. Nf3 Qe7 3. Nc3
			variation => N__('Open Game: Gunderam Defence, 3. Nc3'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/8/3pp3/4P3/5N2/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'C40e',
			# TRANSLATORS: C40e: 1. e4 e5 2. Nf3 d5
			variation => N__('Elephant Gambit'),
			moves => {
				'e4d5' => 1,
				'f3e5' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/8/3pN3/4P3/8/PPPP1PPP/RNBQKB1R b KQkq' => {
			eco => 'C40f',
			# TRANSLATORS: C40f: 1. e4 e5 2. Nf3 d5 3. Nxe5
			variation => N__('Elephant Gambit: 3.Nxe5'),
			moves => {
				'd5e4' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/8/4N3/4p3/8/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'C40f',
			# TRANSLATORS: C40f: 1. e4 e5 2. Nf3 d5 3. Nxe5 dxe4
			variation => N__('Elephant Gambit: 3.Nxe5'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/8/4N3/2B1p3/8/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'C40f',
			# TRANSLATORS: C40f: 1. e4 e5 2. Nf3 d5 3. Nxe5 dxe4 4. Bc4
			variation => N__('Elephant Gambit: 3.Nxe5 dxe4 4. Bc4'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/8/3Pp3/8/5N2/PPPP1PPP/RNBQKB1R b KQkq' => {
			eco => 'C40g',
			# TRANSLATORS: C40g: 1. e4 e5 2. Nf3 d5 3. exd5
			variation => N__('Elephant Gambit: 3.exd5'),
			moves => {
				'e5e4' => 1,
				'f8d6' => 1,
			},
		},
		'rnbqk1nr/ppp2ppp/3b4/3Pp3/8/5N2/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'C40h',
			# TRANSLATORS: C40h: 1. e4 e5 2. Nf3 d5 3. exd5 Bd6
			variation => N__('Elephant Gambit: Maroczy'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/8/3P4/4p3/5N2/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'C40i',
			# TRANSLATORS: C40i: 1. e4 e5 2. Nf3 d5 3. exd5 e4
			variation => N__('Elephant Gambit: Paulsen'),
			moves => {
			},
		},
		'rnbqkbnr/pppp2pp/8/4pp2/4P3/5N2/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'C40j',
			# TRANSLATORS: C40j: 1. e4 e5 2. Nf3 f5
			variation => N__('Latvian Gambit'),
			moves => {
				'b1c3' => 1,
				'd2d3' => 1,
				'd2d4' => 1,
				'e4f5' => 1,
				'f1c4' => 1,
				'f3e5' => 1,
			},
		},
		'rnbqkbnr/pppp2pp/8/4pp2/4P3/3P1N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'C40k',
			# TRANSLATORS: C40k: 1. e4 e5 2. Nf3 f5 3. d3
			variation => N__('Latvian Gambit: 3. d3'),
			moves => {
			},
		},
		'rnbqkbnr/pppp2pp/8/4pp2/4P3/2N2N2/PPPP1PPP/R1BQKB1R b KQkq' => {
			eco => 'C40l',
			# TRANSLATORS: C40l: 1. e4 e5 2. Nf3 f5 3. Nc3
			variation => N__('Latvian Gambit: 3. Nc3'),
			moves => {
			},
		},
		'rnbqkbnr/pppp2pp/8/4pp2/3PP3/5N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'C40m',
			# TRANSLATORS: C40m: 1. e4 e5 2. Nf3 f5 3. d4
			variation => N__('Latvian Gambit: 3. d4'),
			moves => {
				'f5e4' => 1,
			},
		},
		'rnbqkbnr/pppp2pp/8/4p3/3Pp3/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C40m',
			# TRANSLATORS: C40m: 1. e4 e5 2. Nf3 f5 3. d4 fxe4
			variation => N__('Latvian Gambit: 3. d4'),
			moves => {
				'f3e5' => 1,
			},
		},
		'rnbqkbnr/pppp2pp/8/4N3/3Pp3/8/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'C40m',
			# TRANSLATORS: C40m: 1. e4 e5 2. Nf3 f5 3. d4 fxe4 4. Nxe5
			variation => N__('Latvian Gambit: 3. d4'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/pppp2pp/5n2/4N3/3Pp3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C40m',
			# TRANSLATORS: C40m: 1. e4 e5 2. Nf3 f5 3. d4 fxe4 4. Nxe5 Nf6
			variation => N__('Latvian Gambit: 3. d4 fxe4 5.Nxe5 Nf6'),
			moves => {
			},
		},
		'rnbqkbnr/pppp2pp/8/4pP2/8/5N2/PPPP1PPP/RNBQKB1R b KQkq' => {
			eco => 'C40n',
			# TRANSLATORS: C40n: 1. e4 e5 2. Nf3 f5 3. exf5
			variation => N__('Latvian Gambit: 3.exf5'),
			moves => {
				'e5e4' => 1,
			},
		},
		'rnbqkbnr/pppp2pp/8/5P2/4p3/5N2/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'C40n',
			# TRANSLATORS: C40n: 1. e4 e5 2. Nf3 f5 3. exf5 e4
			variation => N__('Latvian Gambit: 3.exf5 e4'),
			moves => {
			},
		},
		'rnbqkbnr/pppp2pp/8/4pp2/2B1P3/5N2/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'C40o',
			# TRANSLATORS: C40o: 1. e4 e5 2. Nf3 f5 3. Bc4
			variation => N__('Latvian Gambit: 3. Bc4'),
			moves => {
				'b7b5' => 1,
				'f5e4' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/p1pp2pp/8/1p2pp2/2B1P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C40o',
			# TRANSLATORS: C40o: 1. e4 e5 2. Nf3 f5 3. Bc4 b5
			variation => N__('Latvian Gambit: Strautins Variation'),
			moves => {
			},
		},
		'rnbqkb1r/pppp2pp/5n2/4pp2/2B1P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C40o',
			# TRANSLATORS: C40o: 1. e4 e5 2. Nf3 f5 3. Bc4 Nf6
			variation => N__('Latvian Gambit: Morgado Variation'),
			moves => {
			},
		},
		'rnbqkbnr/pppp2pp/8/4p3/2B1p3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C40p',
			# TRANSLATORS: C40p: 1. e4 e5 2. Nf3 f5 3. Bc4 fxe4
			variation => N__('Latvian Gambit: 3. Bc4 fxe4'),
			moves => {
				'f3e5' => 1,
			},
		},
		'rnbqkbnr/pppp2pp/8/4N3/2B1p3/8/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'C40p',
			# TRANSLATORS: C40p: 1. e4 e5 2. Nf3 f5 3. Bc4 fxe4 4. Nxe5
			variation => N__('Latvian Gambit: 3. Bc4 fxe4'),
			moves => {
				'd7d5' => 1,
				'd8g5' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/ppp3pp/8/3pN3/2B1p3/8/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C40p',
			# TRANSLATORS: C40p: 1. e4 e5 2. Nf3 f5 3. Bc4 fxe4 4. Nxe5 d5
			variation => N__('Latvian Gambit: Svedenborg Variation'),
			moves => {
				'd1h5' => 1,
			},
		},
		'rnbqkbnr/ppp3pp/8/3pN2Q/2B1p3/8/PPPP1PPP/RNB1K2R b KQkq' => {
			eco => 'C40p',
			# TRANSLATORS: C40p: 1. e4 e5 2. Nf3 f5 3. Bc4 fxe4 4. Nxe5 d5 5. Qh5+
			variation => N__('Latvian Gambit: Svedenborg Variation'),
			moves => {
				'g7g6' => 1,
			},
		},
		'rnbqkbnr/ppp4p/6p1/3pN2Q/2B1p3/8/PPPP1PPP/RNB1K2R w KQkq' => {
			eco => 'C40p',
			# TRANSLATORS: C40p: 1. e4 e5 2. Nf3 f5 3. Bc4 fxe4 4. Nxe5 d5 5. Qh5+ g6
			variation => N__('Latvian Gambit: Svedenborg Variation'),
			moves => {
				'e5g6' => 1,
			},
		},
		'rnbqkbnr/ppp4p/6N1/3p3Q/2B1p3/8/PPPP1PPP/RNB1K2R b KQkq' => {
			eco => 'C40p',
			# TRANSLATORS: C40p: 1. e4 e5 2. Nf3 f5 3. Bc4 fxe4 4. Nxe5 d5 5. Qh5+ g6 6. Nxg6
			variation => N__('Latvian Gambit: Svedenborg Variation'),
			moves => {
				'g8f6' => 1,
				'h7g6' => 1,
			},
		},
		'rnbqkb1r/ppp4p/5nN1/3p3Q/2B1p3/8/PPPP1PPP/RNB1K2R w KQkq' => {
			eco => 'C40p',
			# TRANSLATORS: C40p: 1. e4 e5 2. Nf3 f5 3. Bc4 fxe4 4. Nxe5 d5 5. Qh5+ g6 6. Nxg6 Nf6
			variation => N__('Latvian Gambit: Svedenborg, 6.Nxg6 Nf6'),
			moves => {
			},
		},
		'rnbqkbnr/ppp5/6p1/3p3Q/2B1p3/8/PPPP1PPP/RNB1K2R w KQkq' => {
			eco => 'C40p',
			# TRANSLATORS: C40p: 1. e4 e5 2. Nf3 f5 3. Bc4 fxe4 4. Nxe5 d5 5. Qh5+ g6 6. Nxg6 hxg6
			variation => N__('Latvian Gambit: Svedenborg, 6.Nxg6 hxg6'),
			moves => {
			},
		},
		'rnbqkb1r/pppp2pp/5n2/4N3/2B1p3/8/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C40p',
			# TRANSLATORS: C40p: 1. e4 e5 2. Nf3 f5 3. Bc4 fxe4 4. Nxe5 Nf6
			variation => N__('Latvian: Blackburne Variation (Corkscrew Countergambit)'),
			moves => {
			},
		},
		'rnb1kbnr/pppp2pp/8/4N1q1/2B1p3/8/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C40q',
			# TRANSLATORS: C40q: 1. e4 e5 2. Nf3 f5 3. Bc4 fxe4 4. Nxe5 Qg5
			variation => N__('Latvian Gambit: Poisoned Pawn Variation'),
			moves => {
				'd2d4' => 1,
			},
		},
		'rnb1kbnr/pppp2pp/8/4N1q1/2BPp3/8/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C40q',
			# TRANSLATORS: C40q: 1. e4 e5 2. Nf3 f5 3. Bc4 fxe4 4. Nxe5 Qg5 5. d4
			variation => N__('Latvian Gambit: Poisoned Pawn Variation'),
			moves => {
				'g5g2' => 1,
			},
		},
		'rnb1kbnr/pppp2pp/8/4N3/2BPp3/8/PPP2PqP/RNBQK2R w KQkq' => {
			eco => 'C40q',
			# TRANSLATORS: C40q: 1. e4 e5 2. Nf3 f5 3. Bc4 fxe4 4. Nxe5 Qg5 5. d4 Qxg2
			variation => N__('Latvian Gambit: Poisoned Pawn Variation'),
			moves => {
				'd1h5' => 1,
			},
		},
		'rnb1kbnr/pppp2pp/8/4N2Q/2BPp3/8/PPP2PqP/RNB1K2R b KQkq' => {
			eco => 'C40q',
			# TRANSLATORS: C40q: 1. e4 e5 2. Nf3 f5 3. Bc4 fxe4 4. Nxe5 Qg5 5. d4 Qxg2 6. Qh5+
			variation => N__('Latvian Gambit: Poisoned Pawn Variation'),
			moves => {
				'g7g6' => 1,
			},
		},
		'rnb1kbnr/pppp3p/6p1/4N2Q/2BPp3/8/PPP2PqP/RNB1K2R w KQkq' => {
			eco => 'C40q',
			# TRANSLATORS: C40q: 1. e4 e5 2. Nf3 f5 3. Bc4 fxe4 4. Nxe5 Qg5 5. d4 Qxg2 6. Qh5+ g6
			variation => N__('Latvian Gambit: Poisoned Pawn Variation'),
			moves => {
				'c4f7' => 1,
			},
		},
		'rnb1kbnr/pppp1B1p/6p1/4N2Q/3Pp3/8/PPP2PqP/RNB1K2R b KQkq' => {
			eco => 'C40q',
			# TRANSLATORS: C40q: 1. e4 e5 2. Nf3 f5 3. Bc4 fxe4 4. Nxe5 Qg5 5. d4 Qxg2 6. Qh5+ g6 7. Bf7+
			variation => N__('Latvian Gambit: Poisoned Pawn Variation'),
			moves => {
				'e8d8' => 1,
			},
		},
		'rnbk1bnr/pppp1B1p/6p1/4N2Q/3Pp3/8/PPP2PqP/RNB1K2R w KQ' => {
			eco => 'C40q',
			# TRANSLATORS: C40q: 1. e4 e5 2. Nf3 f5 3. Bc4 fxe4 4. Nxe5 Qg5 5. d4 Qxg2 6. Qh5+ g6 7. Bf7+ Kd8
			variation => N__('Latvian Gambit: Poisoned Pawn, Main Line'),
			moves => {
			},
		},
		'rnbqkbnr/pppp2pp/8/4Np2/4P3/8/PPPP1PPP/RNBQKB1R b KQkq' => {
			eco => 'C40r',
			# TRANSLATORS: C40r: 1. e4 e5 2. Nf3 f5 3. Nxe5
			variation => N__('Latvian Gambit: 3.Nxe5'),
			moves => {
				'b8c6' => 1,
				'd8f6' => 1,
			},
		},
		'r1bqkbnr/pppp2pp/2n5/4Np2/4P3/8/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'C40s',
			# TRANSLATORS: C40s: 1. e4 e5 2. Nf3 f5 3. Nxe5 Nc6
			variation => N__('Latvian Gambit: 3.Nxe5 Nc6'),
			moves => {
			},
		},
		'rnb1kbnr/pppp2pp/5q2/4Np2/4P3/8/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'C40t',
			# TRANSLATORS: C40t: 1. e4 e5 2. Nf3 f5 3. Nxe5 Qf6
			variation => N__('Latvian Gambit: 3.Nxe5 Qf6'),
			moves => {
				'd2d4' => 1,
				'e5c4' => 1,
			},
		},
		'rnb1kbnr/pppp2pp/5q2/5p2/2N1P3/8/PPPP1PPP/RNBQKB1R b KQkq' => {
			eco => 'C40t',
			# TRANSLATORS: C40t: 1. e4 e5 2. Nf3 f5 3. Nxe5 Qf6 4. Nc4
			variation => N__('Latvian Gambit: 3.Nxe5 Qf6 4. Nc4'),
			moves => {
			},
		},
		'rnb1kbnr/pppp2pp/5q2/4Np2/3PP3/8/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'C40u',
			# TRANSLATORS: C40u: 1. e4 e5 2. Nf3 f5 3. Nxe5 Qf6 4. d4
			variation => N__('Latvian Gambit: 3.Nxe5 Qf6 4. d4'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rnb1kbnr/ppp3pp/3p1q2/4Np2/3PP3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C40u',
			# TRANSLATORS: C40u: 1. e4 e5 2. Nf3 f5 3. Nxe5 Qf6 4. d4 d6
			variation => N__('Latvian Gambit: 3.Nxe5 Qf6 4. d4 d6'),
			moves => {
				'e5c4' => 1,
			},
		},
		'rnb1kbnr/ppp3pp/3p1q2/5p2/2NPP3/8/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'C40u',
			# TRANSLATORS: C40u: 1. e4 e5 2. Nf3 f5 3. Nxe5 Qf6 4. d4 d6 5. Nc4
			variation => N__('Latvian Gambit: 3.Nxe5 Qf6 4. d4 d6 5. Nc4'),
			moves => {
				'f5e4' => 1,
			},
		},
		'rnb1kbnr/ppp3pp/3p1q2/8/2NPp3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C40u',
			# TRANSLATORS: C40u: 1. e4 e5 2. Nf3 f5 3. Nxe5 Qf6 4. d4 d6 5. Nc4 fxe4
			variation => N__('Latvian Gambit: 3.Nxe5 Qf6 4. d4 d6 5. Nc4 fxe4'),
			moves => {
				'b1c3' => 1,
				'c4e3' => 1,
				'f1e2' => 1,
			},
		},
		'rnb1kbnr/ppp3pp/3p1q2/8/2NPp3/8/PPP1BPPP/RNBQK2R b KQkq' => {
			eco => 'C40v',
			# TRANSLATORS: C40v: 1. e4 e5 2. Nf3 f5 3. Nxe5 Qf6 4. d4 d6 5. Nc4 fxe4 6. Be2
			variation => N__('Latvian Gambit: 3.Nxe5 Qf6 4. d4 d6 5. Nc4 fxe4 6. Be2'),
			moves => {
			},
		},
		'rnb1kbnr/ppp3pp/3p1q2/8/3Pp3/4N3/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'C40w',
			# TRANSLATORS: C40w: 1. e4 e5 2. Nf3 f5 3. Nxe5 Qf6 4. d4 d6 5. Nc4 fxe4 6. Ne3
			variation => N__('Latvian Gambit: Nimzowitsch Variation'),
			moves => {
			},
		},
		'rnb1kbnr/ppp3pp/3p1q2/8/2NPp3/2N5/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'C40x',
			# TRANSLATORS: C40x: 1. e4 e5 2. Nf3 f5 3. Nxe5 Qf6 4. d4 d6 5. Nc4 fxe4 6. Nc3
			variation => N__('Latvian Gambit: 3.Nxe5 Qf6 4. d4 d6 5. Nc4 fxe4 6. Nc3'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/3p4/4p3/4P3/5N2/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'C41a',
			# TRANSLATORS: C41a: 1. e4 e5 2. Nf3 d6
			variation => N__('Philidor Defence'),
			moves => {
				'd2d4' => 1,
				'f1c4' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/3p4/4p3/2B1P3/5N2/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'C41b',
			# TRANSLATORS: C41b: 1. e4 e5 2. Nf3 d6 3. Bc4
			variation => N__('Philidor: 3. Bc4'),
			moves => {
				'f7f5' => 1,
				'f8e7' => 1,
			},
		},
		'rnbqkbnr/ppp3pp/3p4/4pp2/2B1P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C41b',
			# TRANSLATORS: C41b: 1. e4 e5 2. Nf3 d6 3. Bc4 f5
			variation => N__('Philidor: Lopez Countergambit'),
			moves => {
				'd2d4' => 1,
			},
		},
		'rnbqkbnr/ppp3pp/3p4/4pp2/2BPP3/5N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C41b',
			# TRANSLATORS: C41b: 1. e4 e5 2. Nf3 d6 3. Bc4 f5 4. d4
			variation => N__('Philidor: Lopez Countergambit'),
			moves => {
				'e5d4' => 1,
			},
		},
		'rnbqkbnr/ppp3pp/3p4/5p2/2BpP3/5N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C41b',
			# TRANSLATORS: C41b: 1. e4 e5 2. Nf3 d6 3. Bc4 f5 4. d4 exd4
			variation => N__('Philidor: Lopez Countergambit'),
			moves => {
				'f3g5' => 1,
			},
		},
		'rnbqkbnr/ppp3pp/3p4/5pN1/2BpP3/8/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C41b',
			# TRANSLATORS: C41b: 1. e4 e5 2. Nf3 d6 3. Bc4 f5 4. d4 exd4 5. Ng5
			variation => N__('Philidor: Lopez Countergambit'),
			moves => {
				'g8h6' => 1,
			},
		},
		'rnbqkb1r/ppp3pp/3p3n/5pN1/2BpP3/8/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C41b',
			# TRANSLATORS: C41b: 1. e4 e5 2. Nf3 d6 3. Bc4 f5 4. d4 exd4 5. Ng5 Nh6
			variation => N__('Philidor: Lopez Countergambit'),
			moves => {
				'g5h7' => 1,
			},
		},
		'rnbqkb1r/ppp3pN/3p3n/5p2/2BpP3/8/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C41b',
			# TRANSLATORS: C41b: 1. e4 e5 2. Nf3 d6 3. Bc4 f5 4. d4 exd4 5. Ng5 Nh6 6. Nxh7
			variation => N__('Philidor: Lopez Countergambit, Jänisch Variation'),
			moves => {
			},
		},
		'rnbqk1nr/ppp1bppp/3p4/4p3/2B1P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C41b',
			# TRANSLATORS: C41b: 1. e4 e5 2. Nf3 d6 3. Bc4 Be7
			variation => N__('Philidor: 3. Bc4'),
			moves => {
				'c2c3' => 1,
			},
		},
		'rnbqk1nr/ppp1bppp/3p4/4p3/2B1P3/2P2N2/PP1P1PPP/RNBQK2R b KQkq' => {
			eco => 'C41b',
			# TRANSLATORS: C41b: 1. e4 e5 2. Nf3 d6 3. Bc4 Be7 4. c3
			variation => N__('Philidor: Steinitz Variation'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/3p4/4p3/3PP3/5N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'C41c',
			# TRANSLATORS: C41c: 1. e4 e5 2. Nf3 d6 3. d4
			variation => N__('Philidor: 3. d4'),
			moves => {
				'b8d7' => 1,
				'e5d4' => 1,
				'f7f5' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/ppp3pp/3p4/4pp2/3PP3/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C41d',
			# TRANSLATORS: C41d: 1. e4 e5 2. Nf3 d6 3. d4 f5
			variation => N__('Philidor: Philidor Countergambit'),
			moves => {
				'b1c3' => 1,
				'd4e5' => 1,
			},
		},
		'rnbqkbnr/ppp3pp/3p4/4pp2/3PP3/2N2N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'C41d',
			# TRANSLATORS: C41d: 1. e4 e5 2. Nf3 d6 3. d4 f5 4. Nc3
			variation => N__('Philidor: Philidor Countergambit, Zukertort Variation'),
			moves => {
			},
		},
		'rnbqkbnr/ppp3pp/3p4/4Pp2/4P3/5N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'C41e',
			# TRANSLATORS: C41e: 1. e4 e5 2. Nf3 d6 3. d4 f5 4. dxe5
			variation => N__('Philidor: Philidor Countergambit, 4.dxe5'),
			moves => {
				'f5e4' => 1,
			},
		},
		'rnbqkbnr/ppp3pp/3p4/4P3/4p3/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C41e',
			# TRANSLATORS: C41e: 1. e4 e5 2. Nf3 d6 3. d4 f5 4. dxe5 fxe4
			variation => N__('Philidor: Philidor Countergambit, 4.dxe5'),
			moves => {
				'f3g5' => 1,
			},
		},
		'rnbqkbnr/ppp3pp/3p4/4P1N1/4p3/8/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'C41e',
			# TRANSLATORS: C41e: 1. e4 e5 2. Nf3 d6 3. d4 f5 4. dxe5 fxe4 5. Ng5
			variation => N__('Philidor: Philidor Countergambit, 4.dxe5'),
			moves => {
				'd6d5' => 1,
			},
		},
		'rnbqkbnr/ppp3pp/8/3pP1N1/4p3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C41e',
			# TRANSLATORS: C41e: 1. e4 e5 2. Nf3 d6 3. d4 f5 4. dxe5 fxe4 5. Ng5 d5
			variation => N__('Philidor: Philidor Countergambit, 4.dxe5'),
			moves => {
				'b1c3' => 1,
				'e5e6' => 1,
			},
		},
		'rnbqkbnr/ppp3pp/8/3pP1N1/4p3/2N5/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'C41e',
			# TRANSLATORS: C41e: 1. e4 e5 2. Nf3 d6 3. d4 f5 4. dxe5 fxe4 5. Ng5 d5 6. Nc3
			variation => N__('Philidor: Philidor Countergambit, Steinitz Variation'),
			moves => {
			},
		},
		'rnbqkbnr/ppp3pp/4P3/3p2N1/4p3/8/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'C41e',
			# TRANSLATORS: C41e: 1. e4 e5 2. Nf3 d6 3. d4 f5 4. dxe5 fxe4 5. Ng5 d5 6. e6
			variation => N__('Philidor: Philidor Countergambit, del Rio Attack'),
			moves => {
				'f8c5' => 1,
			},
		},
		'rnbqk1nr/ppp3pp/4P3/2bp2N1/4p3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C41e',
			# TRANSLATORS: C41e: 1. e4 e5 2. Nf3 d6 3. d4 f5 4. dxe5 fxe4 5. Ng5 d5 6. e6 Bc5
			variation => N__('Philidor: Philidor Countergambit, del Rio Attack'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqk1nr/ppp3pp/4P3/2bp2N1/4p3/2N5/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'C41e',
			# TRANSLATORS: C41e: 1. e4 e5 2. Nf3 d6 3. d4 f5 4. dxe5 fxe4 5. Ng5 d5 6. e6 Bc5 7. Nc3
			variation => N__('Philidor: Philidor Countergambit, Berger Variation'),
			moves => {
			},
		},
		'r1bqkbnr/pppn1ppp/3p4/4p3/3PP3/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C41f',
			# TRANSLATORS: C41f: 1. e4 e5 2. Nf3 d6 3. d4 Nd7
			variation => N__('Philidor: Hanham Variation'),
			moves => {
				'f1c4' => 1,
			},
		},
		'r1bqkbnr/pppn1ppp/3p4/4p3/2BPP3/5N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C41f',
			# TRANSLATORS: C41f: 1. e4 e5 2. Nf3 d6 3. d4 Nd7 4. Bc4
			variation => N__('Philidor: Hanham, 4. Bc4'),
			moves => {
				'c7c6' => 1,
			},
		},
		'r1bqkbnr/pp1n1ppp/2pp4/4p3/2BPP3/5N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C41g',
			# TRANSLATORS: C41g: 1. e4 e5 2. Nf3 d6 3. d4 Nd7 4. Bc4 c6
			variation => N__('Philidor: Hanham, 4. Bc4 c6'),
			moves => {
				'b1c3' => 1,
				'c2c3' => 1,
				'e1g1' => 1,
				'f3g5' => 1,
			},
		},
		'r1bqkbnr/pp1n1ppp/2pp4/4p3/2BPP3/2N2N2/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'C41g',
			# TRANSLATORS: C41g: 1. e4 e5 2. Nf3 d6 3. d4 Nd7 4. Bc4 c6 5. Nc3
			variation => N__('Philidor: Hanham, Schlechter Variation'),
			moves => {
			},
		},
		'r1bqkbnr/pp1n1ppp/2pp4/4p3/2BPP3/2P2N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'C41g',
			# TRANSLATORS: C41g: 1. e4 e5 2. Nf3 d6 3. d4 Nd7 4. Bc4 c6 5. c3
			variation => N__('Philidor: Hanham, Delmar Variation'),
			moves => {
			},
		},
		'r1bqkbnr/pp1n1ppp/2pp4/4p3/2BPP3/5N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C41g',
			# TRANSLATORS: C41g: 1. e4 e5 2. Nf3 d6 3. d4 Nd7 4. Bc4 c6 5. O-O
			variation => N__('Philidor: Hanham, Krause Variation'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r1bqk1nr/pp1nbppp/2pp4/4p3/2BPP3/5N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C41g',
			# TRANSLATORS: C41g: 1. e4 e5 2. Nf3 d6 3. d4 Nd7 4. Bc4 c6 5. O-O Be7
			variation => N__('Philidor: Hanham, Krause Variation'),
			moves => {
				'd4e5' => 1,
			},
		},
		'r1bqk1nr/pp1nbppp/2pp4/4P3/2B1P3/5N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C41g',
			# TRANSLATORS: C41g: 1. e4 e5 2. Nf3 d6 3. d4 Nd7 4. Bc4 c6 5. O-O Be7 6. dxe5
			variation => N__('Philidor: Hanham, Steiner Variation'),
			moves => {
			},
		},
		'r1bqkbnr/pp1n1ppp/2pp4/4p1N1/2BPP3/8/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C41g',
			# TRANSLATORS: C41g: 1. e4 e5 2. Nf3 d6 3. d4 Nd7 4. Bc4 c6 5. Ng5
			variation => N__('Philidor: Hanham, Kmoch Variation'),
			moves => {
				'g8h6' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/2pp3n/4p1N1/2BPP3/8/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C41g',
			# TRANSLATORS: C41g: 1. e4 e5 2. Nf3 d6 3. d4 Nd7 4. Bc4 c6 5. Ng5 Nh6
			variation => N__('Philidor: Hanham, Kmoch Variation'),
			moves => {
				'f2f4' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/2pp3n/4p1N1/2BPPP2/8/PPP3PP/RNBQK2R b KQkq' => {
			eco => 'C41g',
			# TRANSLATORS: C41g: 1. e4 e5 2. Nf3 d6 3. d4 Nd7 4. Bc4 c6 5. Ng5 Nh6 6. f4
			variation => N__('Philidor: Hanham, Kmoch Variation'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r1bqk2r/pp1nbppp/2pp3n/4p1N1/2BPPP2/8/PPP3PP/RNBQK2R w KQkq' => {
			eco => 'C41g',
			# TRANSLATORS: C41g: 1. e4 e5 2. Nf3 d6 3. d4 Nd7 4. Bc4 c6 5. Ng5 Nh6 6. f4 Be7
			variation => N__('Philidor: Hanham, Kmoch Variation'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqk2r/pp1nbppp/2pp3n/4p1N1/2BPPP2/8/PPP3PP/RNBQ1RK1 b kq' => {
			eco => 'C41g',
			# TRANSLATORS: C41g: 1. e4 e5 2. Nf3 d6 3. d4 Nd7 4. Bc4 c6 5. Ng5 Nh6 6. f4 Be7 7. O-O
			variation => N__('Philidor: Hanham, Kmoch Variation'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/2pp3n/4p1N1/2BPPP2/8/PPP3PP/RNBQ1RK1 w -' => {
			eco => 'C41g',
			# TRANSLATORS: C41g: 1. e4 e5 2. Nf3 d6 3. d4 Nd7 4. Bc4 c6 5. Ng5 Nh6 6. f4 Be7 7. O-O O-O
			variation => N__('Philidor: Hanham, Kmoch Variation'),
			moves => {
				'c2c3' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/2pp3n/4p1N1/2BPPP2/2P5/PP4PP/RNBQ1RK1 b -' => {
			eco => 'C41g',
			# TRANSLATORS: C41g: 1. e4 e5 2. Nf3 d6 3. d4 Nd7 4. Bc4 c6 5. Ng5 Nh6 6. f4 Be7 7. O-O O-O 8. c3
			variation => N__('Philidor: Hanham, Kmoch Variation'),
			moves => {
				'd6d5' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/2p4n/3pp1N1/2BPPP2/2P5/PP4PP/RNBQ1RK1 w -' => {
			eco => 'C41g',
			# TRANSLATORS: C41g: 1. e4 e5 2. Nf3 d6 3. d4 Nd7 4. Bc4 c6 5. Ng5 Nh6 6. f4 Be7 7. O-O O-O 8. c3 d5
			variation => N__('Philidor: Hanham, Berger Variation'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/3p4/8/3pP3/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C41h',
			# TRANSLATORS: C41h: 1. e4 e5 2. Nf3 d6 3. d4 exd4
			variation => N__('Philidor: 3...exd4'),
			moves => {
				'c2c3' => 1,
				'd1d4' => 1,
				'f3d4' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/3p4/8/3pP3/2P2N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'C41h',
			# TRANSLATORS: C41h: 1. e4 e5 2. Nf3 d6 3. d4 exd4 4. c3
			variation => N__('Philidor: Bird Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/3p4/8/3QP3/5N2/PPP2PPP/RNB1KB1R b KQkq' => {
			eco => 'C41i',
			# TRANSLATORS: C41i: 1. e4 e5 2. Nf3 d6 3. d4 exd4 4. Qxd4
			variation => N__('Philidor: Morphy Variation'),
			moves => {
				'b8c6' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkbnr/ppp2ppp/2np4/8/3QP3/5N2/PPP2PPP/RNB1KB1R w KQkq' => {
			eco => 'C41i',
			# TRANSLATORS: C41i: 1. e4 e5 2. Nf3 d6 3. d4 exd4 4. Qxd4 Nc6
			variation => N__('Philidor: Morphy, 4... Nc6'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/3p1n2/8/3QP3/5N2/PPP2PPP/RNB1KB1R w KQkq' => {
			eco => 'C41i',
			# TRANSLATORS: C41i: 1. e4 e5 2. Nf3 d6 3. d4 exd4 4. Qxd4 Nf6
			variation => N__('Philidor: Morphy, 4... Nf6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/3p1n2/8/3QP3/2N2N2/PPP2PPP/R1B1KB1R b KQkq' => {
			eco => 'C41i',
			# TRANSLATORS: C41i: 1. e4 e5 2. Nf3 d6 3. d4 exd4 4. Qxd4 Nf6 5. Nc3
			variation => N__('Philidor: Morphy, 4... Nf6 5. Nc3'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/3p4/8/3NP3/8/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'C41j',
			# TRANSLATORS: C41j: 1. e4 e5 2. Nf3 d6 3. d4 exd4 4. Nxd4
			variation => N__('Philidor: 3...exd4 4.Nxd4'),
			moves => {
				'd6d5' => 1,
				'g7g6' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/8/3p4/3NP3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C41j',
			# TRANSLATORS: C41j: 1. e4 e5 2. Nf3 d6 3. d4 exd4 4. Nxd4 d5
			variation => N__('Philidor: 3...exd4 4.Nxd4'),
			moves => {
				'e4d5' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/8/3P4/3N4/8/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'C41j',
			# TRANSLATORS: C41j: 1. e4 e5 2. Nf3 d6 3. d4 exd4 4. Nxd4 d5 5. exd5
			variation => N__('Philidor: Paulsen Attack'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/3p1n2/8/3NP3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C41k',
			# TRANSLATORS: C41k: 1. e4 e5 2. Nf3 d6 3. d4 exd4 4. Nxd4 Nf6
			variation => N__('Philidor: 3...exd4 4.Nxd4 Nf6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/3p1n2/8/3NP3/2N5/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'C41k',
			# TRANSLATORS: C41k: 1. e4 e5 2. Nf3 d6 3. d4 exd4 4. Nxd4 Nf6 5. Nc3
			variation => N__('Philidor: 3...exd4 4.Nxd4 Nf6 5. Nc3'),
			moves => {
				'f8e7' => 1,
			},
		},
		'rnbqk2r/ppp1bppp/3p1n2/8/3NP3/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'C41k',
			# TRANSLATORS: C41k: 1. e4 e5 2. Nf3 d6 3. d4 exd4 4. Nxd4 Nf6 5. Nc3 Be7
			variation => N__('Philidor: 3...exd4 4.Nxd4 Nf6 5. Nc3 Be7'),
			moves => {
				'f1c4' => 1,
				'f1e2' => 1,
			},
		},
		'rnbqk2r/ppp1bppp/3p1n2/8/2BNP3/2N5/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'C41l',
			# TRANSLATORS: C41l: 1. e4 e5 2. Nf3 d6 3. d4 exd4 4. Nxd4 Nf6 5. Nc3 Be7 6. Bc4
			variation => N__('Philidor: 3...exd4 4.Nxd4 Nf6 5. Nc3 Be7 6. Bc4'),
			moves => {
			},
		},
		'rnbqk2r/ppp1bppp/3p1n2/8/3NP3/2N5/PPP1BPPP/R1BQK2R b KQkq' => {
			eco => 'C41m',
			# TRANSLATORS: C41m: 1. e4 e5 2. Nf3 d6 3. d4 exd4 4. Nxd4 Nf6 5. Nc3 Be7 6. Be2
			variation => N__('Philidor: Antoshin Variation'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppp1bppp/3p1n2/8/3NP3/2N5/PPP1BPPP/R1BQK2R w KQ' => {
			eco => 'C41m',
			# TRANSLATORS: C41m: 1. e4 e5 2. Nf3 d6 3. d4 exd4 4. Nxd4 Nf6 5. Nc3 Be7 6. Be2 O-O
			variation => N__('Philidor: Antoshin Variation'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbq1rk1/ppp1bppp/3p1n2/8/3NP3/2N5/PPP1BPPP/R1BQ1RK1 b -' => {
			eco => 'C41m',
			# TRANSLATORS: C41m: 1. e4 e5 2. Nf3 d6 3. d4 exd4 4. Nxd4 Nf6 5. Nc3 Be7 6. Be2 O-O 7. O-O
			variation => N__('Philidor: Antoshin Variation'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbq1rk1/pp2bppp/3p1n2/2p5/3NP3/2N5/PPP1BPPP/R1BQ1RK1 w -' => {
			eco => 'C41m',
			# TRANSLATORS: C41m: 1. e4 e5 2. Nf3 d6 3. d4 exd4 4. Nxd4 Nf6 5. Nc3 Be7 6. Be2 O-O 7. O-O c5
			variation => N__('Philidor: Antoshin Variation'),
			moves => {
				'd4f3' => 1,
			},
		},
		'rnbq1rk1/pp2bppp/3p1n2/2p5/4P3/2N2N2/PPP1BPPP/R1BQ1RK1 b -' => {
			eco => 'C41m',
			# TRANSLATORS: C41m: 1. e4 e5 2. Nf3 d6 3. d4 exd4 4. Nxd4 Nf6 5. Nc3 Be7 6. Be2 O-O 7. O-O c5 8. Nf3
			variation => N__('Philidor: Antoshin Variation'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2np1n2/2p5/4P3/2N2N2/PPP1BPPP/R1BQ1RK1 w -' => {
			eco => 'C41m',
			# TRANSLATORS: C41m: 1. e4 e5 2. Nf3 d6 3. d4 exd4 4. Nxd4 Nf6 5. Nc3 Be7 6. Be2 O-O 7. O-O c5 8. Nf3 Nc6
			variation => N__('Philidor: Antoshin Variation'),
			moves => {
				'c1g5' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2np1n2/2p3B1/4P3/2N2N2/PPP1BPPP/R2Q1RK1 b -' => {
			eco => 'C41m',
			# TRANSLATORS: C41m: 1. e4 e5 2. Nf3 d6 3. d4 exd4 4. Nxd4 Nf6 5. Nc3 Be7 6. Be2 O-O 7. O-O c5 8. Nf3 Nc6 9. Bg5
			variation => N__('Philidor: Antoshin Variation'),
			moves => {
				'c8e6' => 1,
			},
		},
		'r2q1rk1/pp2bppp/2npbn2/2p3B1/4P3/2N2N2/PPP1BPPP/R2Q1RK1 w -' => {
			eco => 'C41m',
			# TRANSLATORS: C41m: 1. e4 e5 2. Nf3 d6 3. d4 exd4 4. Nxd4 Nf6 5. Nc3 Be7 6. Be2 O-O 7. O-O c5 8. Nf3 Nc6 9. Bg5 Be6
			variation => N__('Philidor: Antoshin Variation'),
			moves => {
				'f1e1' => 1,
			},
		},
		'r2q1rk1/pp2bppp/2npbn2/2p3B1/4P3/2N2N2/PPP1BPPP/R2QR1K1 b -' => {
			eco => 'C41m',
			# TRANSLATORS: C41m: 1. e4 e5 2. Nf3 d6 3. d4 exd4 4. Nxd4 Nf6 5. Nc3 Be7 6. Be2 O-O 7. O-O c5 8. Nf3 Nc6 9. Bg5 Be6 10. Re1
			variation => N__('Philidor: Berger Variation'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2p1p/3p2p1/8/3NP3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C41n',
			# TRANSLATORS: C41n: 1. e4 e5 2. Nf3 d6 3. d4 exd4 4. Nxd4 g6
			variation => N__('Philidor: Larsen Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/3p1n2/4p3/3PP3/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C41o',
			# TRANSLATORS: C41o: 1. e4 e5 2. Nf3 d6 3. d4 Nf6
			variation => N__('Philidor: Nimzowitsch Variation'),
			moves => {
				'b1c3' => 1,
				'd4e5' => 1,
				'f1c4' => 1,
				'f3g5' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/3p1n2/4p3/2BPP3/5N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C41o',
			# TRANSLATORS: C41o: 1. e4 e5 2. Nf3 d6 3. d4 Nf6 4. Bc4
			variation => N__('Philidor: Nimzowitsch, Klein Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/3p1n2/4p1N1/3PP3/8/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'C41o',
			# TRANSLATORS: C41o: 1. e4 e5 2. Nf3 d6 3. d4 Nf6 4. Ng5
			variation => N__('Philidor: Nimzowitsch, Locock Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/3p1n2/4P3/4P3/5N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'C41p',
			# TRANSLATORS: C41p: 1. e4 e5 2. Nf3 d6 3. d4 Nf6 4. dxe5
			variation => N__('Philidor: Exchange Variation'),
			moves => {
				'f6e4' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/3p4/4P3/4n3/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C41p',
			# TRANSLATORS: C41p: 1. e4 e5 2. Nf3 d6 3. d4 Nf6 4. dxe5 Nxe4
			variation => N__('Philidor: Exchange Variation'),
			moves => {
				'b1d2' => 1,
				'd1d5' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/3p4/4P3/4n3/5N2/PPPN1PPP/R1BQKB1R b KQkq' => {
			eco => 'C41p',
			# TRANSLATORS: C41p: 1. e4 e5 2. Nf3 d6 3. d4 Nf6 4. dxe5 Nxe4 5. Nbd2
			variation => N__('Philidor: Exchange, Sokolsky Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/3p4/3QP3/4n3/5N2/PPP2PPP/RNB1KB1R b KQkq' => {
			eco => 'C41p',
			# TRANSLATORS: C41p: 1. e4 e5 2. Nf3 d6 3. d4 Nf6 4. dxe5 Nxe4 5. Qd5
			variation => N__('Philidor: Exchange, Rellstab Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/3p1n2/4p3/3PP3/2N2N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'C41q',
			# TRANSLATORS: C41q: 1. e4 e5 2. Nf3 d6 3. d4 Nf6 4. Nc3
			variation => N__('Philidor: Nimzowitsch Variation'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r1bqkb1r/pppn1ppp/3p1n2/4p3/3PP3/2N2N2/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'C41r',
			# TRANSLATORS: C41r: 1. e4 e5 2. Nf3 d6 3. d4 Nf6 4. Nc3 Nbd7
			variation => N__('Philidor: Improved Hanham'),
			moves => {
				'f1c4' => 1,
			},
		},
		'r1bqkb1r/pppn1ppp/3p1n2/4p3/2BPP3/2N2N2/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'C41s',
			# TRANSLATORS: C41s: 1. e4 e5 2. Nf3 d6 3. d4 Nf6 4. Nc3 Nbd7 5. Bc4
			variation => N__('Philidor: Improved Hanham, 5. Bc4'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r1bqk2r/pppnbppp/3p1n2/4p3/2BPP3/2N2N2/PPP2PPP/R1BQK2R w KQkq' => {
			eco => 'C41s',
			# TRANSLATORS: C41s: 1. e4 e5 2. Nf3 d6 3. d4 Nf6 4. Nc3 Nbd7 5. Bc4 Be7
			variation => N__('Philidor: Improved Hanham, 5. Bc4 Be7'),
			moves => {
				'c4f7' => 1,
				'd4e5' => 1,
				'e1g1' => 1,
				'f3g5' => 1,
			},
		},
		'r1bqk2r/pppnbBpp/3p1n2/4p3/3PP3/2N2N2/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'C41s',
			# TRANSLATORS: C41s: 1. e4 e5 2. Nf3 d6 3. d4 Nf6 4. Nc3 Nbd7 5. Bc4 Be7 6. Bxf7+
			variation => N__('Philidor: Improved Hanham, 6.Bxf7+'),
			moves => {
			},
		},
		'r1bqk2r/pppnbppp/3p1n2/4P3/2B1P3/2N2N2/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'C41s',
			# TRANSLATORS: C41s: 1. e4 e5 2. Nf3 d6 3. d4 Nf6 4. Nc3 Nbd7 5. Bc4 Be7 6. dxe5
			variation => N__('Philidor: Improved Hanham, 6.dxe5'),
			moves => {
				'd6e5' => 1,
				'd7e5' => 1,
			},
		},
		'r1bqk2r/pppnbppp/5n2/4p3/2B1P3/2N2N2/PPP2PPP/R1BQK2R w KQkq' => {
			eco => 'C41s',
			# TRANSLATORS: C41s: 1. e4 e5 2. Nf3 d6 3. d4 Nf6 4. Nc3 Nbd7 5. Bc4 Be7 6. dxe5 dxe5
			variation => N__('Philidor: Improved Hanham, 6.dxe5 dxe5'),
			moves => {
			},
		},
		'r1bqk2r/ppp1bppp/3p1n2/4n3/2B1P3/2N2N2/PPP2PPP/R1BQK2R w KQkq' => {
			eco => 'C41s',
			# TRANSLATORS: C41s: 1. e4 e5 2. Nf3 d6 3. d4 Nf6 4. Nc3 Nbd7 5. Bc4 Be7 6. dxe5 Nxe5
			variation => N__('Philidor: Improved Hanham, 6.dxe5 Nxe5'),
			moves => {
			},
		},
		'r1bqk2r/pppnbppp/3p1n2/4p1N1/2BPP3/2N5/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'C41s',
			# TRANSLATORS: C41s: 1. e4 e5 2. Nf3 d6 3. d4 Nf6 4. Nc3 Nbd7 5. Bc4 Be7 6. Ng5
			variation => N__('Philidor: Improved Hanham, 6. Ng5'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pppnbppp/3p1n2/4p1N1/2BPP3/2N5/PPP2PPP/R1BQK2R w KQ' => {
			eco => 'C41s',
			# TRANSLATORS: C41s: 1. e4 e5 2. Nf3 d6 3. d4 Nf6 4. Nc3 Nbd7 5. Bc4 Be7 6. Ng5 O-O
			variation => N__('Philidor: Improved Hanham, 6. Ng5'),
			moves => {
				'c4f7' => 1,
			},
		},
		'r1bq1rk1/pppnbBpp/3p1n2/4p1N1/3PP3/2N5/PPP2PPP/R1BQK2R b KQ' => {
			eco => 'C41s',
			# TRANSLATORS: C41s: 1. e4 e5 2. Nf3 d6 3. d4 Nf6 4. Nc3 Nbd7 5. Bc4 Be7 6. Ng5 O-O 7. Bxf7+
			variation => N__('Philidor: Improved Hanham, Larobok Variation'),
			moves => {
			},
		},
		'r1bqk2r/pppnbppp/3p1n2/4p3/2BPP3/2N2N2/PPP2PPP/R1BQ1RK1 b kq' => {
			eco => 'C41t',
			# TRANSLATORS: C41t: 1. e4 e5 2. Nf3 d6 3. d4 Nf6 4. Nc3 Nbd7 5. Bc4 Be7 6. O-O
			variation => N__('Philidor: Improved Hanham 6.O-O'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pppnbppp/3p1n2/4p3/2BPP3/2N2N2/PPP2PPP/R1BQ1RK1 w -' => {
			eco => 'C41u',
			# TRANSLATORS: C41u: 1. e4 e5 2. Nf3 d6 3. d4 Nf6 4. Nc3 Nbd7 5. Bc4 Be7 6. O-O O-O
			variation => N__('Philidor: Improved Hanham, Main Line'),
			moves => {
				'a2a4' => 1,
				'd1e2' => 1,
				'f1e1' => 1,
			},
		},
		'r1bq1rk1/pppnbppp/3p1n2/4p3/P1BPP3/2N2N2/1PP2PPP/R1BQ1RK1 b -' => {
			eco => 'C41v',
			# TRANSLATORS: C41v: 1. e4 e5 2. Nf3 d6 3. d4 Nf6 4. Nc3 Nbd7 5. Bc4 Be7 6. O-O O-O 7. a4
			variation => N__('Philidor: Improved Hanham, 7. a4'),
			moves => {
				'c7c6' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/2pp1n2/4p3/P1BPP3/2N2N2/1PP2PPP/R1BQ1RK1 w -' => {
			eco => 'C41v',
			# TRANSLATORS: C41v: 1. e4 e5 2. Nf3 d6 3. d4 Nf6 4. Nc3 Nbd7 5. Bc4 Be7 6. O-O O-O 7. a4 c6
			variation => N__('Philidor: Improved Hanham, 7. a4 c6'),
			moves => {
				'd1e2' => 1,
			},
		},
		'r1bq1rk1/pppnbppp/3p1n2/4p3/2BPP3/2N2N2/PPP1QPPP/R1B2RK1 b -' => {
			eco => 'C41w',
			# TRANSLATORS: C41w: 1. e4 e5 2. Nf3 d6 3. d4 Nf6 4. Nc3 Nbd7 5. Bc4 Be7 6. O-O O-O 7. Qe2
			variation => N__('Philidor: Improved Hanham, 7. Qe2'),
			moves => {
				'c7c6' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/2pp1n2/4p3/2BPP3/2N2N2/PPP1QPPP/R1B2RK1 w -' => {
			eco => 'C41w',
			# TRANSLATORS: C41w: 1. e4 e5 2. Nf3 d6 3. d4 Nf6 4. Nc3 Nbd7 5. Bc4 Be7 6. O-O O-O 7. Qe2 c6
			variation => N__('Philidor: Improved Hanham, 7. Qe2'),
			moves => {
				'a2a4' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/2pp1n2/4p3/P1BPP3/2N2N2/1PP1QPPP/R1B2RK1 b -' => {
			eco => 'C41w',
			# TRANSLATORS: C41w: 1. e4 e5 2. Nf3 d6 3. d4 Nf6 4. Nc3 Nbd7 5. Bc4 Be7 6. O-O O-O 7. Qe2 c6 8. a4
			variation => N__('Philidor: Improved Hanham, 7. Qe2 c6 8. a4'),
			moves => {
				'e5d4' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/2pp1n2/8/P1BpP3/2N2N2/1PP1QPPP/R1B2RK1 w -' => {
			eco => 'C41w',
			# TRANSLATORS: C41w: 1. e4 e5 2. Nf3 d6 3. d4 Nf6 4. Nc3 Nbd7 5. Bc4 Be7 6. O-O O-O 7. Qe2 c6 8. a4 exd4
			variation => N__('Philidor: Improved Hanham, Sozin Variation'),
			moves => {
			},
		},
		'r1bq1rk1/pppnbppp/3p1n2/4p3/2BPP3/2N2N2/PPP2PPP/R1BQR1K1 b -' => {
			eco => 'C41x',
			# TRANSLATORS: C41x: 1. e4 e5 2. Nf3 d6 3. d4 Nf6 4. Nc3 Nbd7 5. Bc4 Be7 6. O-O O-O 7. Re1
			variation => N__('Philidor: Improved Hanham, 7. Re1'),
			moves => {
				'c7c6' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/2pp1n2/4p3/2BPP3/2N2N2/PPP2PPP/R1BQR1K1 w -' => {
			eco => 'C41x',
			# TRANSLATORS: C41x: 1. e4 e5 2. Nf3 d6 3. d4 Nf6 4. Nc3 Nbd7 5. Bc4 Be7 6. O-O O-O 7. Re1 c6
			variation => N__('Philidor: Improved Hanham, 7. Re1'),
			moves => {
				'a2a4' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/2pp1n2/4p3/P1BPP3/2N2N2/1PP2PPP/R1BQR1K1 b -' => {
			eco => 'C41x',
			# TRANSLATORS: C41x: 1. e4 e5 2. Nf3 d6 3. d4 Nf6 4. Nc3 Nbd7 5. Bc4 Be7 6. O-O O-O 7. Re1 c6 8. a4
			variation => N__('Philidor: Improved Hanham, 7. Re1 c6 8. a4'),
			moves => {
				'a7a5' => 1,
				'b7b6' => 1,
			},
		},
		'r1bq1rk1/1p1nbppp/2pp1n2/p3p3/P1BPP3/2N2N2/1PP2PPP/R1BQR1K1 w -' => {
			eco => 'C41y',
			# TRANSLATORS: C41y: 1. e4 e5 2. Nf3 d6 3. d4 Nf6 4. Nc3 Nbd7 5. Bc4 Be7 6. O-O O-O 7. Re1 c6 8. a4 a5
			variation => N__('Philidor: Improved Hanham, 7. Re1 c6 8. a4 a5'),
			moves => {
			},
		},
		'r1bq1rk1/p2nbppp/1ppp1n2/4p3/P1BPP3/2N2N2/1PP2PPP/R1BQR1K1 w -' => {
			eco => 'C41z',
			# TRANSLATORS: C41z: 1. e4 e5 2. Nf3 d6 3. d4 Nf6 4. Nc3 Nbd7 5. Bc4 Be7 6. O-O O-O 7. Re1 c6 8. a4 b6
			variation => N__('Philidor: Improved Hanham, 7. Re1 c6 8. a4 b6'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/4p3/4P3/5N2/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'C42a',
			# TRANSLATORS: C42a: 1. e4 e5 2. Nf3 Nf6
			variation => N__('Russian Game (Petroff Defence)'),
			moves => {
				'b1c3' => 1,
				'd2d3' => 1,
				'd2d4' => 1,
				'f1c4' => 1,
				'f3e5' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/4p3/4P3/3P1N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'C42b',
			# TRANSLATORS: C42b: 1. e4 e5 2. Nf3 Nf6 3. d3
			variation => N__('Russian Game: 3. d3'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/4p3/4P3/2N2N2/PPPP1PPP/R1BQKB1R b KQkq' => {
			eco => 'C42c',
			# TRANSLATORS: C42c: 1. e4 e5 2. Nf3 Nf6 3. Nc3
			variation => N__('Russian-Three Knights Game'),
			moves => {
				'f8b4' => 1,
			},
		},
		'rnbqk2r/pppp1ppp/5n2/4p3/1b2P3/2N2N2/PPPP1PPP/R1BQKB1R w KQkq' => {
			eco => 'C42c',
			# TRANSLATORS: C42c: 1. e4 e5 2. Nf3 Nf6 3. Nc3 Bb4
			variation => N__('Russian-Three Knights Game'),
			moves => {
				'f3e5' => 1,
			},
		},
		'rnbqk2r/pppp1ppp/5n2/4N3/1b2P3/2N5/PPPP1PPP/R1BQKB1R b KQkq' => {
			eco => 'C42d',
			# TRANSLATORS: C42d: 1. e4 e5 2. Nf3 Nf6 3. Nc3 Bb4 4. Nxe5
			variation => N__('Russian-Three Knights Game, 4.Nxe5'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/4p3/2B1P3/5N2/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'C42e',
			# TRANSLATORS: C42e: 1. e4 e5 2. Nf3 Nf6 3. Bc4
			variation => N__('Russian Game: Italian Variation'),
			moves => {
				'f6e4' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/8/4p3/2B1n3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C42e',
			# TRANSLATORS: C42e: 1. e4 e5 2. Nf3 Nf6 3. Bc4 Nxe4
			variation => N__('Russian Game: Italian Variation'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/8/4p3/2B1n3/2N2N2/PPPP1PPP/R1BQK2R b KQkq' => {
			eco => 'C42f',
			# TRANSLATORS: C42f: 1. e4 e5 2. Nf3 Nf6 3. Bc4 Nxe4 4. Nc3
			variation => N__('Russian Game: Boden-Kieseritsky Gambit'),
			moves => {
				'e4c3' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/8/4p3/2B5/2n2N2/PPPP1PPP/R1BQK2R w KQkq' => {
			eco => 'C42f',
			# TRANSLATORS: C42f: 1. e4 e5 2. Nf3 Nf6 3. Bc4 Nxe4 4. Nc3 Nxc3
			variation => N__('Russian Game: Boden-Kieseritsky Gambit Accepted'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/4N3/4P3/8/PPPP1PPP/RNBQKB1R b KQkq' => {
			eco => 'C42g',
			# TRANSLATORS: C42g: 1. e4 e5 2. Nf3 Nf6 3. Nxe5
			variation => N__('Russian Game: 3.Nxe5'),
			moves => {
				'd7d6' => 1,
				'f6e4' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/3p1n2/4N3/4P3/8/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'C42g',
			# TRANSLATORS: C42g: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6
			variation => N__('Russian Game: 3.Nxe5 d6'),
			moves => {
				'e5c4' => 1,
				'e5f3' => 1,
				'e5f7' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/8/4N3/4n3/8/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'C42g',
			# TRANSLATORS: C42g: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 Nxe4
			variation => N__('Russian Game: Damiano Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2Npp/3p1n2/8/4P3/8/PPPP1PPP/RNBQKB1R b KQkq' => {
			eco => 'C42h',
			# TRANSLATORS: C42h: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nxf7
			variation => N__('Russian Game: Cochrane Gambit'),
			moves => {
				'e8f7' => 1,
			},
		},
		'rnbq1b1r/ppp2kpp/3p1n2/8/4P3/8/PPPP1PPP/RNBQKB1R w KQ' => {
			eco => 'C42h',
			# TRANSLATORS: C42h: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nxf7 Kxf7
			variation => N__('Russian Game: Cochrane Gambit'),
			moves => {
				'd2d4' => 1,
			},
		},
		'rnbq1b1r/ppp2kpp/3p1n2/8/3PP3/8/PPP2PPP/RNBQKB1R b KQ' => {
			eco => 'C42h',
			# TRANSLATORS: C42h: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nxf7 Kxf7 5. d4
			variation => N__('Russian Game: Cochrane Gambit, 5. d4'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/3p1n2/8/2N1P3/8/PPPP1PPP/RNBQKB1R b KQkq' => {
			eco => 'C42i',
			# TRANSLATORS: C42i: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nc4
			variation => N__('Russian Game: Paulsen Attack'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/3p1n2/8/4P3/5N2/PPPP1PPP/RNBQKB1R b KQkq' => {
			eco => 'C42j',
			# TRANSLATORS: C42j: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3
			variation => N__('Russian Game: 3.Nxe5 d6 4. Nf3'),
			moves => {
				'f6e4' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/3p4/8/4n3/5N2/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'C42j',
			# TRANSLATORS: C42j: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4
			variation => N__('Russian Game: 3.Nxe5 d6 4. Nf3'),
			moves => {
				'b1c3' => 1,
				'c2c4' => 1,
				'd1e2' => 1,
				'd2d3' => 1,
				'd2d4' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/3p4/8/4n3/3P1N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'C42k',
			# TRANSLATORS: C42k: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. d3
			variation => N__('Russian Game: French Attack'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/3p4/8/2P1n3/5N2/PP1P1PPP/RNBQKB1R b KQkq' => {
			eco => 'C42l',
			# TRANSLATORS: C42l: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. c4
			variation => N__('Russian Game: Vienna/Kaufmann'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/3p4/8/4n3/2N2N2/PPPP1PPP/R1BQKB1R b KQkq' => {
			eco => 'C42m',
			# TRANSLATORS: C42m: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. Nc3
			variation => N__('Russian Game: Nimzowitsch Attack'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/3p4/8/4n3/5N2/PPPPQPPP/RNB1KB1R b KQkq' => {
			eco => 'C42n',
			# TRANSLATORS: C42n: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. Qe2
			variation => N__('Russian Game: Cozio/Lasker'),
			moves => {
				'd8e7' => 1,
			},
		},
		'rnb1kb1r/ppp1qppp/3p4/8/4n3/5N2/PPPPQPPP/RNB1KB1R w KQkq' => {
			eco => 'C42n',
			# TRANSLATORS: C42n: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. Qe2 Qe7
			variation => N__('Russian Game: Cozio/Lasker'),
			moves => {
				'd2d3' => 1,
			},
		},
		'rnb1kb1r/ppp1qppp/3p4/8/4n3/3P1N2/PPP1QPPP/RNB1KB1R b KQkq' => {
			eco => 'C42n',
			# TRANSLATORS: C42n: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. Qe2 Qe7 6. d3
			variation => N__('Russian Game: Cozio/Lasker'),
			moves => {
				'e4f6' => 1,
			},
		},
		'rnb1kb1r/ppp1qppp/3p1n2/8/8/3P1N2/PPP1QPPP/RNB1KB1R w KQkq' => {
			eco => 'C42n',
			# TRANSLATORS: C42n: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. Qe2 Qe7 6. d3 Nf6
			variation => N__('Russian Game: Cozio/Lasker'),
			moves => {
				'c1g5' => 1,
			},
		},
		'rnb1kb1r/ppp1qppp/3p1n2/6B1/8/3P1N2/PPP1QPPP/RN2KB1R b KQkq' => {
			eco => 'C42n',
			# TRANSLATORS: C42n: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. Qe2 Qe7 6. d3 Nf6 7. Bg5
			variation => N__('Russian Game: Cozio/Lasker'),
			moves => {
				'b8d7' => 1,
				'e7e2' => 1,
			},
		},
		'r1b1kb1r/pppnqppp/3p1n2/6B1/8/3P1N2/PPP1QPPP/RN2KB1R w KQkq' => {
			eco => 'C42n',
			# TRANSLATORS: C42n: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. Qe2 Qe7 6. d3 Nf6 7. Bg5 Nbd7
			variation => N__('Russian Game: Milner-Barry Variation'),
			moves => {
			},
		},
		'rnb1kb1r/ppp2ppp/3p1n2/6B1/8/3P1N2/PPP1qPPP/RN2KB1R w KQkq' => {
			eco => 'C42o',
			# TRANSLATORS: C42o: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. Qe2 Qe7 6. d3 Nf6 7. Bg5 Qxe2+
			variation => N__('Russian Game: 5. Qe2, Queenswap'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/3p4/8/3Pn3/5N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'C42p',
			# TRANSLATORS: C42p: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. d4
			variation => N__('Russian Game: Classical'),
			moves => {
				'd6d5' => 1,
				'e4f6' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/8/3p4/3Pn3/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C42p',
			# TRANSLATORS: C42p: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. d4 d5
			variation => N__('Russian Game: Classical, 5... d5'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/3p1n2/8/3P4/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C42p',
			# TRANSLATORS: C42p: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. d4 Nf6
			variation => N__('Russian Game: Classical, Close Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/8/3p4/3Pn3/3B1N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C42q',
			# TRANSLATORS: C42q: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. d4 d5 6. Bd3
			variation => N__('Russian Game: Classical, 6. Bd3'),
			moves => {
				'f8d6' => 1,
				'f8e7' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/3b4/3p4/3Pn3/3B1N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C42q',
			# TRANSLATORS: C42q: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. d4 d5 6. Bd3 Bd6
			variation => N__('Russian Game: Classical, Marshall Variation'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/3b4/3p4/3Pn3/3B1N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C42q',
			# TRANSLATORS: C42q: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. d4 d5 6. Bd3 Bd6 7. O-O
			variation => N__('Russian Game: Classical, Marshall Variation'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppp2ppp/3b4/3p4/3Pn3/3B1N2/PPP2PPP/RNBQ1RK1 w -' => {
			eco => 'C42q',
			# TRANSLATORS: C42q: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. d4 d5 6. Bd3 Bd6 7. O-O O-O
			variation => N__('Russian Game: Classical, Marshall Variation'),
			moves => {
				'c2c4' => 1,
			},
		},
		'rnbq1rk1/ppp2ppp/3b4/3p4/2PPn3/3B1N2/PP3PPP/RNBQ1RK1 b -' => {
			eco => 'C42q',
			# TRANSLATORS: C42q: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. d4 d5 6. Bd3 Bd6 7. O-O O-O 8. c4
			variation => N__('Russian Game: Classical, Marshall Variation'),
			moves => {
				'c7c6' => 1,
				'c8g4' => 1,
			},
		},
		'rn1q1rk1/ppp2ppp/3b4/3p4/2PPn1b1/3B1N2/PP3PPP/RNBQ1RK1 w -' => {
			eco => 'C42q',
			# TRANSLATORS: C42q: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. d4 d5 6. Bd3 Bd6 7. O-O O-O 8. c4 Bg4
			variation => N__('Russian Game: Classical, Tarrasch Variation'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rn1q1rk1/ppp2ppp/3b4/3P4/3Pn1b1/3B1N2/PP3PPP/RNBQ1RK1 b -' => {
			eco => 'C42q',
			# TRANSLATORS: C42q: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. d4 d5 6. Bd3 Bd6 7. O-O O-O 8. c4 Bg4 9. cxd5
			variation => N__('Russian Game: Classical, Tarrasch Variation'),
			moves => {
				'f7f5' => 1,
			},
		},
		'rn1q1rk1/ppp3pp/3b4/3P1p2/3Pn1b1/3B1N2/PP3PPP/RNBQ1RK1 w -' => {
			eco => 'C42q',
			# TRANSLATORS: C42q: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. d4 d5 6. Bd3 Bd6 7. O-O O-O 8. c4 Bg4 9. cxd5 f5
			variation => N__('Russian Game: Classical, Tarrasch Variation'),
			moves => {
				'f1e1' => 1,
			},
		},
		'rn1q1rk1/ppp3pp/3b4/3P1p2/3Pn1b1/3B1N2/PP3PPP/RNBQR1K1 b -' => {
			eco => 'C42q',
			# TRANSLATORS: C42q: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. d4 d5 6. Bd3 Bd6 7. O-O O-O 8. c4 Bg4 9. cxd5 f5 10. Re1
			variation => N__('Russian Game: Classical, Tarrasch Variation'),
			moves => {
				'd6h2' => 1,
			},
		},
		'rn1q1rk1/ppp3pp/8/3P1p2/3Pn1b1/3B1N2/PP3PPb/RNBQR1K1 w -' => {
			eco => 'C42q',
			# TRANSLATORS: C42q: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. d4 d5 6. Bd3 Bd6 7. O-O O-O 8. c4 Bg4 9. cxd5 f5 10. Re1 Bxh2+
			variation => N__('Russian Game: Classical, Marshall Trap'),
			moves => {
			},
		},
		'rnbq1rk1/pp3ppp/2pb4/3p4/2PPn3/3B1N2/PP3PPP/RNBQ1RK1 w -' => {
			eco => 'C42r',
			# TRANSLATORS: C42r: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. d4 d5 6. Bd3 Bd6 7. O-O O-O 8. c4 c6
			variation => N__('Russian Game: Classical, Marshall, 8. c4 c6'),
			moves => {
			},
		},
		'rnbqk2r/ppp1bppp/8/3p4/3Pn3/3B1N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C42s',
			# TRANSLATORS: C42s: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. d4 d5 6. Bd3 Be7
			variation => N__('Russian Game: Classical, 6. Bd3 Be7'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbqk2r/ppp1bppp/8/3p4/3Pn3/3B1N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C42s',
			# TRANSLATORS: C42s: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. d4 d5 6. Bd3 Be7 7. O-O
			variation => N__('Russian Game: Classical, 6. Bd3 Be7'),
			moves => {
				'b8c6' => 1,
				'e8g8' => 1,
			},
		},
		'r1bqk2r/ppp1bppp/2n5/3p4/3Pn3/3B1N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C42s',
			# TRANSLATORS: C42s: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. d4 d5 6. Bd3 Be7 7. O-O Nc6
			variation => N__('Russian Game: Classical, 6. Bd3 Be7 7.O-O Nc6'),
			moves => {
				'c2c4' => 1,
				'f1e1' => 1,
			},
		},
		'rnbq1rk1/ppp1bppp/8/3p4/3Pn3/3B1N2/PPP2PPP/RNBQ1RK1 w -' => {
			eco => 'C42s',
			# TRANSLATORS: C42s: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. d4 d5 6. Bd3 Be7 7. O-O O-O
			variation => N__('Russian Game: Classical, Mason Variation'),
			moves => {
			},
		},
		'r1bqk2r/ppp1bppp/2n5/3p4/2PPn3/3B1N2/PP3PPP/RNBQ1RK1 b kq' => {
			eco => 'C42t',
			# TRANSLATORS: C42t: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. d4 d5 6. Bd3 Be7 7. O-O Nc6 8. c4
			variation => N__('Russian Game: Classical, Jänisch Variation'),
			moves => {
				'c6b4' => 1,
			},
		},
		'r1bqk2r/ppp1bppp/8/3p4/1nPPn3/3B1N2/PP3PPP/RNBQ1RK1 w kq' => {
			eco => 'C42t',
			# TRANSLATORS: C42t: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. d4 d5 6. Bd3 Be7 7. O-O Nc6 8. c4 Nb4
			variation => N__('Russian Game: Classical, Jänisch Variation'),
			moves => {
				'd3e2' => 1,
			},
		},
		'r1bqk2r/ppp1bppp/8/3p4/1nPPn3/5N2/PP2BPPP/RNBQ1RK1 b kq' => {
			eco => 'C42t',
			# TRANSLATORS: C42t: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. d4 d5 6. Bd3 Be7 7. O-O Nc6 8. c4 Nb4 9. Be2
			variation => N__('Russian Game: Classical, Jänisch Variation'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/ppp1bppp/8/3p4/1nPPn3/5N2/PP2BPPP/RNBQ1RK1 w -' => {
			eco => 'C42u',
			# TRANSLATORS: C42u: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. d4 d5 6. Bd3 Be7 7. O-O Nc6 8. c4 Nb4 9. Be2 O-O
			variation => N__('Russian Game: Classical, Jänisch, Main Line'),
			moves => {
			},
		},
		'r1bqk2r/ppp1bppp/2n5/3p4/3Pn3/3B1N2/PPP2PPP/RNBQR1K1 b kq' => {
			eco => 'C42v',
			# TRANSLATORS: C42v: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. d4 d5 6. Bd3 Be7 7. O-O Nc6 8. Re1
			variation => N__('Russian Game: Classical, Chigorin Variation'),
			moves => {
				'c8f5' => 1,
				'c8g4' => 1,
			},
		},
		'r2qk2r/ppp1bppp/2n5/3p1b2/3Pn3/3B1N2/PPP2PPP/RNBQR1K1 w kq' => {
			eco => 'C42v',
			# TRANSLATORS: C42v: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. d4 d5 6. Bd3 Be7 7. O-O Nc6 8. Re1 Bf5
			variation => N__('Russian Game: Classical, Chigorin, 8... Bf5'),
			moves => {
			},
		},
		'r2qk2r/ppp1bppp/2n5/3p4/3Pn1b1/3B1N2/PPP2PPP/RNBQR1K1 w kq' => {
			eco => 'C42w',
			# TRANSLATORS: C42w: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. d4 d5 6. Bd3 Be7 7. O-O Nc6 8. Re1 Bg4
			variation => N__('Russian Game: Classical, Chigorin, 8... Bg4'),
			moves => {
				'c2c3' => 1,
				'c2c4' => 1,
			},
		},
		'r2qk2r/ppp1bppp/2n5/3p4/2PPn1b1/3B1N2/PP3PPP/RNBQR1K1 b kq' => {
			eco => 'C42w',
			# TRANSLATORS: C42w: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. d4 d5 6. Bd3 Be7 7. O-O Nc6 8. Re1 Bg4 9. c4
			variation => N__('Russian Game: Classical, Chigorin, 8... Bg4 9. c4'),
			moves => {
			},
		},
		'r2qk2r/ppp1bppp/2n5/3p4/3Pn1b1/2PB1N2/PP3PPP/RNBQR1K1 b kq' => {
			eco => 'C42x',
			# TRANSLATORS: C42x: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. d4 d5 6. Bd3 Be7 7. O-O Nc6 8. Re1 Bg4 9. c3
			variation => N__('Russian Game: Classical, Chigorin, 8... Bg4 9. c3'),
			moves => {
				'f7f5' => 1,
			},
		},
		'r2qk2r/ppp1b1pp/2n5/3p1p2/3Pn1b1/2PB1N2/PP3PPP/RNBQR1K1 w kq' => {
			eco => 'C42x',
			# TRANSLATORS: C42x: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. d4 d5 6. Bd3 Be7 7. O-O Nc6 8. Re1 Bg4 9. c3 f5
			variation => N__('Russian Game: Classical, Chigorin, 8... Bg4 9. c3'),
			moves => {
				'b1d2' => 1,
				'c3c4' => 1,
			},
		},
		'r2qk2r/ppp1b1pp/2n5/3p1p2/3Pn1b1/2PB1N2/PP1N1PPP/R1BQR1K1 b kq' => {
			eco => 'C42x',
			# TRANSLATORS: C42x: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. d4 d5 6. Bd3 Be7 7. O-O Nc6 8. Re1 Bg4 9. c3 f5 10. Nbd2
			variation => N__('Russian Game: Classical, Berger Variation'),
			moves => {
			},
		},
		'r2qk2r/ppp1b1pp/2n5/3p1p2/2PPn1b1/3B1N2/PP3PPP/RNBQR1K1 b kq' => {
			eco => 'C42x',
			# TRANSLATORS: C42x: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. d4 d5 6. Bd3 Be7 7. O-O Nc6 8. Re1 Bg4 9. c3 f5 10. c4
			variation => N__('Russian Game: Classical, Krause Variation'),
			moves => {
				'e7h4' => 1,
			},
		},
		'r2qk2r/ppp3pp/2n5/3p1p2/2PPn1bb/3B1N2/PP3PPP/RNBQR1K1 w kq' => {
			eco => 'C42x',
			# TRANSLATORS: C42x: 1. e4 e5 2. Nf3 Nf6 3. Nxe5 d6 4. Nf3 Nxe4 5. d4 d5 6. Bd3 Be7 7. O-O Nc6 8. Re1 Bg4 9. c3 f5 10. c4 Bh4
			variation => N__('Russian Game: Classical, Maroczy Variation'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/4p3/3PP3/5N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'C43a',
			# TRANSLATORS: C43a: 1. e4 e5 2. Nf3 Nf6 3. d4
			variation => N__('Russian Game: Modern (Steinitz) Attack'),
			moves => {
				'e5d4' => 1,
				'f6e4' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/8/3pP3/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C43b',
			# TRANSLATORS: C43b: 1. e4 e5 2. Nf3 Nf6 3. d4 exd4
			variation => N__('Russian Game: Modern Attack'),
			moves => {
				'e4e5' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/4P3/3p4/5N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'C43b',
			# TRANSLATORS: C43b: 1. e4 e5 2. Nf3 Nf6 3. d4 exd4 4. e5
			variation => N__('Russian Game: Modern Attack'),
			moves => {
				'f6e4' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/8/4P3/3pn3/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C43c',
			# TRANSLATORS: C43c: 1. e4 e5 2. Nf3 Nf6 3. d4 exd4 4. e5 Ne4
			variation => N__('Russian Game: Modern Attack'),
			moves => {
				'd1d4' => 1,
				'd1e2' => 1,
				'f1b5' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/8/4P3/3pn3/5N2/PPP1QPPP/RNB1KB1R b KQkq' => {
			eco => 'C43c',
			# TRANSLATORS: C43c: 1. e4 e5 2. Nf3 Nf6 3. d4 exd4 4. e5 Ne4 5. Qe2
			variation => N__('Russian Game: Modern Attack, Steinitz Variation'),
			moves => {
				'e4c5' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/8/2n1P3/3p4/5N2/PPP1QPPP/RNB1KB1R w KQkq' => {
			eco => 'C43c',
			# TRANSLATORS: C43c: 1. e4 e5 2. Nf3 Nf6 3. d4 exd4 4. e5 Ne4 5. Qe2 Nc5
			variation => N__('Russian Game: Modern Attack, Steinitz Variation'),
			moves => {
				'f3d4' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/8/2n1P3/3N4/8/PPP1QPPP/RNB1KB1R b KQkq' => {
			eco => 'C43c',
			# TRANSLATORS: C43c: 1. e4 e5 2. Nf3 Nf6 3. d4 exd4 4. e5 Ne4 5. Qe2 Nc5 6. Nxd4
			variation => N__('Russian Game: Modern Attack, Steinitz Variation'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n5/2n1P3/3N4/8/PPP1QPPP/RNB1KB1R w KQkq' => {
			eco => 'C43c',
			# TRANSLATORS: C43c: 1. e4 e5 2. Nf3 Nf6 3. d4 exd4 4. e5 Ne4 5. Qe2 Nc5 6. Nxd4 Nc6
			variation => N__('Russian Game: Modern Attack, Bardeleben Variation'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/8/1B2P3/3pn3/5N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C43c',
			# TRANSLATORS: C43c: 1. e4 e5 2. Nf3 Nf6 3. d4 exd4 4. e5 Ne4 5. Bb5
			variation => N__('Russian Game: Modern Attack, Tal Gambit'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/8/4P3/3Qn3/5N2/PPP2PPP/RNB1KB1R b KQkq' => {
			eco => 'C43d',
			# TRANSLATORS: C43d: 1. e4 e5 2. Nf3 Nf6 3. d4 exd4 4. e5 Ne4 5. Qxd4
			variation => N__('Russian Game: Modern Attack, 3...exd4, Main Line'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/8/3pP3/3Qn3/5N2/PPP2PPP/RNB1KB1R w KQkq' => {
			eco => 'C43d',
			# TRANSLATORS: C43d: 1. e4 e5 2. Nf3 Nf6 3. d4 exd4 4. e5 Ne4 5. Qxd4 d5
			variation => N__('Russian Game: Modern Attack, 3...exd4, Main Line'),
			moves => {
				'e5d6' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/3P4/8/3Qn3/5N2/PPP2PPP/RNB1KB1R b KQkq' => {
			eco => 'C43d',
			# TRANSLATORS: C43d: 1. e4 e5 2. Nf3 Nf6 3. d4 exd4 4. e5 Ne4 5. Qxd4 d5 6. exd6
			variation => N__('Russian Game: Modern Attack, 3...exd4, Main Line'),
			moves => {
				'e4d6' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/3n4/8/3Q4/5N2/PPP2PPP/RNB1KB1R w KQkq' => {
			eco => 'C43d',
			# TRANSLATORS: C43d: 1. e4 e5 2. Nf3 Nf6 3. d4 exd4 4. e5 Ne4 5. Qxd4 d5 6. exd6 Nxd6
			variation => N__('Russian Game: Modern Attack, 3...exd4, Main Line'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/3n4/8/3Q4/2N2N2/PPP2PPP/R1B1KB1R b KQkq' => {
			eco => 'C43e',
			# TRANSLATORS: C43e: 1. e4 e5 2. Nf3 Nf6 3. d4 exd4 4. e5 Ne4 5. Qxd4 d5 6. exd6 Nxd6 7. Nc3
			variation => N__('Russian Game: Modern Attack, 3...exd4, Main Line, 7. Nc3'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2nn4/8/3Q4/2N2N2/PPP2PPP/R1B1KB1R w KQkq' => {
			eco => 'C43e',
			# TRANSLATORS: C43e: 1. e4 e5 2. Nf3 Nf6 3. d4 exd4 4. e5 Ne4 5. Qxd4 d5 6. exd6 Nxd6 7. Nc3 Nc6
			variation => N__('Russian Game: Modern Attack, 3...exd4, Main Line, 7. Nc3'),
			moves => {
				'd4f4' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2nn4/8/5Q2/2N2N2/PPP2PPP/R1B1KB1R b KQkq' => {
			eco => 'C43e',
			# TRANSLATORS: C43e: 1. e4 e5 2. Nf3 Nf6 3. d4 exd4 4. e5 Ne4 5. Qxd4 d5 6. exd6 Nxd6 7. Nc3 Nc6 8. Qf4
			variation => N__('Russian Game: Modern Attack, 3...exd4, Main Line, 7. Nc3'),
			moves => {
				'c8f5' => 1,
			},
		},
		'r2qkb1r/ppp2ppp/2nn4/5b2/5Q2/2N2N2/PPP2PPP/R1B1KB1R w KQkq' => {
			eco => 'C43e',
			# TRANSLATORS: C43e: 1. e4 e5 2. Nf3 Nf6 3. d4 exd4 4. e5 Ne4 5. Qxd4 d5 6. exd6 Nxd6 7. Nc3 Nc6 8. Qf4 Bf5
			variation => N__('Russian Game: Modern Attack, Pillsbury Variation'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/8/4p3/3Pn3/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C43f',
			# TRANSLATORS: C43f: 1. e4 e5 2. Nf3 Nf6 3. d4 Nxe4
			variation => N__('Russian Game: Modern Attack, 3...Nxe4'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/8/4p3/3Pn3/3B1N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C43g',
			# TRANSLATORS: C43g: 1. e4 e5 2. Nf3 Nf6 3. d4 Nxe4 4. Bd3
			variation => N__('Russian Game: Modern Attack, 3...Nxe4 4. Bd3'),
			moves => {
				'b8c6' => 1,
				'd7d5' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n5/4p3/3Pn3/3B1N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C43g',
			# TRANSLATORS: C43g: 1. e4 e5 2. Nf3 Nf6 3. d4 Nxe4 4. Bd3 Nc6
			variation => N__('Russian Game: Modern Attack, 3...Nxe4 4. Bd3 Nc6'),
			moves => {
				'd3e4' => 1,
				'd4d5' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n5/3Pp3/4n3/3B1N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C43g',
			# TRANSLATORS: C43g: 1. e4 e5 2. Nf3 Nf6 3. d4 Nxe4 4. Bd3 Nc6 5. d5
			variation => N__('Russian Game: Modern Attack, 3...Nxe4 4. Bd3 Nc6 5. d5'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n5/4p3/3PB3/5N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C43h',
			# TRANSLATORS: C43h: 1. e4 e5 2. Nf3 Nf6 3. d4 Nxe4 4. Bd3 Nc6 5. Bxe4
			variation => N__('Russian Game: Modern Attack, 3...Nxe4 4. Bd3 Nc6 5.Bxe4'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/8/3pp3/3Pn3/3B1N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C43i',
			# TRANSLATORS: C43i: 1. e4 e5 2. Nf3 Nf6 3. d4 Nxe4 4. Bd3 d5
			variation => N__('Russian Game: Modern Attack, 3...Nxe4 4. Bd3 d5'),
			moves => {
				'd4e5' => 1,
				'f3e5' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/8/3pP3/4n3/3B1N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C43i',
			# TRANSLATORS: C43i: 1. e4 e5 2. Nf3 Nf6 3. d4 Nxe4 4. Bd3 d5 5. dxe5
			variation => N__('Russian Game: Modern Attack, 3...Nxe4 4. Bd3 d5 5.dxe5'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/8/3pN3/3Pn3/3B4/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C43j',
			# TRANSLATORS: C43j: 1. e4 e5 2. Nf3 Nf6 3. d4 Nxe4 4. Bd3 d5 5. Nxe5
			variation => N__('Russian Game: Modern Attack, 3...Nxe4 4. Bd3 d5 5.Nxe5'),
			moves => {
				'b8c6' => 1,
				'b8d7' => 1,
				'f8d6' => 1,
				'f8e7' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2n5/3pN3/3Pn3/3B4/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C43k',
			# TRANSLATORS: C43k: 1. e4 e5 2. Nf3 Nf6 3. d4 Nxe4 4. Bd3 d5 5. Nxe5 Nc6
			variation => N__('Russian Game: Modern Attack, 3...Nxe4 4. Bd3 d5 5.Nxe5 Nc6'),
			moves => {
			},
		},
		'rnbqk2r/ppp1bppp/8/3pN3/3Pn3/3B4/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C43l',
			# TRANSLATORS: C43l: 1. e4 e5 2. Nf3 Nf6 3. d4 Nxe4 4. Bd3 d5 5. Nxe5 Be7
			variation => N__('Russian Game: Modern Attack, 3...Nxe4 4. Bd3 d5 5.Nxe5 Be7'),
			moves => {
			},
		},
		'rnbqk2r/ppp2ppp/3b4/3pN3/3Pn3/3B4/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C43m',
			# TRANSLATORS: C43m: 1. e4 e5 2. Nf3 Nf6 3. d4 Nxe4 4. Bd3 d5 5. Nxe5 Bd6
			variation => N__('Russian Game: Modern Attack, 3...Nxe4 4. Bd3 d5 5.Nxe5 Bd6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/3b4/3pN3/3Pn3/3B4/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C43m',
			# TRANSLATORS: C43m: 1. e4 e5 2. Nf3 Nf6 3. d4 Nxe4 4. Bd3 d5 5. Nxe5 Bd6 6. O-O
			variation => N__('Russian Game: Modern Attack, 3...Nxe4 4. Bd3 d5 5.Nxe5 Bd6'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppp2ppp/3b4/3pN3/3Pn3/3B4/PPP2PPP/RNBQ1RK1 w -' => {
			eco => 'C43m',
			# TRANSLATORS: C43m: 1. e4 e5 2. Nf3 Nf6 3. d4 Nxe4 4. Bd3 d5 5. Nxe5 Bd6 6. O-O O-O
			variation => N__('Russian Game: Modern Attack, 3...Nxe4 4. Bd3 d5 5.Nxe5 Bd6'),
			moves => {
				'c2c4' => 1,
			},
		},
		'rnbq1rk1/ppp2ppp/3b4/3pN3/2PPn3/3B4/PP3PPP/RNBQ1RK1 b -' => {
			eco => 'C43m',
			# TRANSLATORS: C43m: 1. e4 e5 2. Nf3 Nf6 3. d4 Nxe4 4. Bd3 d5 5. Nxe5 Bd6 6. O-O O-O 7. c4
			variation => N__('Russian Game: Modern Attack, 3...Nxe4 4. Bd3 d5 5.Nxe5 Bd6'),
			moves => {
				'd6e5' => 1,
			},
		},
		'rnbq1rk1/ppp2ppp/8/3pb3/2PPn3/3B4/PP3PPP/RNBQ1RK1 w -' => {
			eco => 'C43n',
			# TRANSLATORS: C43n: 1. e4 e5 2. Nf3 Nf6 3. d4 Nxe4 4. Bd3 d5 5. Nxe5 Bd6 6. O-O O-O 7. c4 Bxe5
			variation => N__('Russian Game: Modern Attack, Trifunovic Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pppn1ppp/8/3pN3/3Pn3/3B4/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C43o',
			# TRANSLATORS: C43o: 1. e4 e5 2. Nf3 Nf6 3. d4 Nxe4 4. Bd3 d5 5. Nxe5 Nd7
			variation => N__('Russian Game: Modern Attack, 3...Nxe4 4. Bd3 d5 5.Nxe5 Nd7'),
			moves => {
				'd1e2' => 1,
				'e5d7' => 1,
			},
		},
		'r1bqkb1r/pppn1ppp/8/3pN3/3Pn3/3B4/PPP1QPPP/RNB1K2R b KQkq' => {
			eco => 'C43p',
			# TRANSLATORS: C43p: 1. e4 e5 2. Nf3 Nf6 3. d4 Nxe4 4. Bd3 d5 5. Nxe5 Nd7 6. Qe2
			variation => N__('Russian Game: Modern Attack, 3...Nxe4 4. Bd3 d5 5.Nxe5 Nd7 6. Qe2'),
			moves => {
			},
		},
		'r1bqkb1r/pppN1ppp/8/3p4/3Pn3/3B4/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C43q',
			# TRANSLATORS: C43q: 1. e4 e5 2. Nf3 Nf6 3. d4 Nxe4 4. Bd3 d5 5. Nxe5 Nd7 6. Nxd7
			variation => N__('Russian Game: Modern Attack, 3...Nxe4 4. Bd3 d5 5.Nxe5 Nd7 6.Nxd7'),
			moves => {
				'c8d7' => 1,
			},
		},
		'r2qkb1r/pppb1ppp/8/3p4/3Pn3/3B4/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C43q',
			# TRANSLATORS: C43q: 1. e4 e5 2. Nf3 Nf6 3. d4 Nxe4 4. Bd3 d5 5. Nxe5 Nd7 6. Nxd7 Bxd7
			variation => N__('Russian Game: Modern Attack, 3...Nxe4 4. Bd3 d5 5.Nxe5 Nd7 6.Nxd7'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r2qkb1r/pppb1ppp/8/3p4/3Pn3/3B4/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C43r',
			# TRANSLATORS: C43r: 1. e4 e5 2. Nf3 Nf6 3. d4 Nxe4 4. Bd3 d5 5. Nxe5 Nd7 6. Nxd7 Bxd7 7. O-O
			variation => N__('Russian Game: Modern Attack, 3...Nxe4, Main Line'),
			moves => {
				'd8h4' => 1,
				'f8d6' => 1,
			},
		},
		'r3kb1r/pppb1ppp/8/3p4/3Pn2q/3B4/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C43s',
			# TRANSLATORS: C43s: 1. e4 e5 2. Nf3 Nf6 3. d4 Nxe4 4. Bd3 d5 5. Nxe5 Nd7 6. Nxd7 Bxd7 7. O-O Qh4
			variation => N__('Russian Game: Modern Attack, 3...Nxe4, Main Line, 7... Qh4'),
			moves => {
			},
		},
		'r2qk2r/pppb1ppp/3b4/3p4/3Pn3/3B4/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C43t',
			# TRANSLATORS: C43t: 1. e4 e5 2. Nf3 Nf6 3. d4 Nxe4 4. Bd3 d5 5. Nxe5 Nd7 6. Nxd7 Bxd7 7. O-O Bd6
			variation => N__('Russian Game: Modern Attack, 3...Nxe4, Main Line, 7... Bd6'),
			moves => {
				'c2c4' => 1,
			},
		},
		'r2qk2r/pppb1ppp/3b4/3p4/2PPn3/3B4/PP3PPP/RNBQ1RK1 b kq' => {
			eco => 'C43u',
			# TRANSLATORS: C43u: 1. e4 e5 2. Nf3 Nf6 3. d4 Nxe4 4. Bd3 d5 5. Nxe5 Nd7 6. Nxd7 Bxd7 7. O-O Bd6 8. c4
			variation => N__('Russian Game: Modern Attack, 3...Nxe4, Main Line, 7... Bd6 8. c4'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4p3/4P3/5N2/PPPP1PPP/RNBQKB1R w KQkq' => {
			eco => 'C44a',
			# TRANSLATORS: C44a: 1. e4 e5 2. Nf3 Nc6
			variation => N__('Open Game'),
			moves => {
				'b1c3' => 1,
				'b2b4' => 1,
				'c2c3' => 1,
				'c2c4' => 1,
				'd2d3' => 1,
				'd2d4' => 1,
				'f1b5' => 1,
				'f1c4' => 1,
				'f1e2' => 1,
				'f3e5' => 1,
				'g2g3' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4p3/1P2P3/5N2/P1PP1PPP/RNBQKB1R b KQkq' => {
			eco => 'C44a',
			# TRANSLATORS: C44a: 1. e4 e5 2. Nf3 Nc6 3. b4
			variation => N__('Open Game: Paschman Wing Gambit'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4p3/2P1P3/5N2/PP1P1PPP/RNBQKB1R b KQkq' => {
			eco => 'C44a',
			# TRANSLATORS: C44a: 1. e4 e5 2. Nf3 Nc6 3. c4
			variation => N__('Open Game: Dresden Opening'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4N3/4P3/8/PPPP1PPP/RNBQKB1R b KQkq' => {
			eco => 'C44a',
			# TRANSLATORS: C44a: 1. e4 e5 2. Nf3 Nc6 3. Nxe5
			variation => N__('Open Game: Irish (Chicago) Gambit'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4p3/4P3/5NP1/PPPP1P1P/RNBQKB1R b KQkq' => {
			eco => 'C44b',
			# TRANSLATORS: C44b: 1. e4 e5 2. Nf3 Nc6 3. g3
			variation => N__('Open Game: Konstantinopolsky'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4p3/4P3/5N2/PPPPBPPP/RNBQK2R b KQkq' => {
			eco => 'C44c',
			# TRANSLATORS: C44c: 1. e4 e5 2. Nf3 Nc6 3. Be2
			variation => N__('Open Game: Inverted Hungarian'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4p3/4P3/5N2/PPPPBPPP/RNBQK2R w KQkq' => {
			eco => 'C44c',
			# TRANSLATORS: C44c: 1. e4 e5 2. Nf3 Nc6 3. Be2 Nf6
			variation => N__('Open Game: Inverted Hungarian'),
			moves => {
				'd2d3' => 1,
				'd2d4' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4p3/3PP3/5N2/PPP1BPPP/RNBQK2R b KQkq' => {
			eco => 'C44c',
			# TRANSLATORS: C44c: 1. e4 e5 2. Nf3 Nc6 3. Be2 Nf6 4. d4
			variation => N__('Open Game: Tayler Opening'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4p3/4P3/3P1N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'C44d',
			# TRANSLATORS: C44d: 1. e4 e5 2. Nf3 Nc6 3. d3
			variation => N__('Open Game: Inverted Philidor'),
			moves => {
				'd7d5' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkbnr/ppp2ppp/2n5/3pp3/4P3/3P1N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C44d',
			# TRANSLATORS: C44d: 1. e4 e5 2. Nf3 Nc6 3. d3 d5
			variation => N__('Open Game: Inverted Philidor'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4p3/4P3/3P1N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C44e',
			# TRANSLATORS: C44e: 1. e4 e5 2. Nf3 Nc6 3. d3 Nf6
			variation => N__('Open Game: Inverted Philidor'),
			moves => {
				'f1e2' => 1,
				'g2g3' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4p3/4P3/3P1NP1/PPP2P1P/RNBQKB1R b KQkq' => {
			eco => 'C44f',
			# TRANSLATORS: C44f: 1. e4 e5 2. Nf3 Nc6 3. d3 Nf6 4. g3
			variation => N__('Open Game: Inverted Philidor, 4. g3'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4p3/4P3/3P1N2/PPP1BPPP/RNBQK2R b KQkq' => {
			eco => 'C44g',
			# TRANSLATORS: C44g: 1. e4 e5 2. Nf3 Nc6 3. Be2 Nf6 4. d3
			variation => N__('Open Game: Inverted Philidor, 4. Be2'),
			moves => {
				'd7d5' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2n2n2/3pp3/4P3/3P1N2/PPP1BPPP/RNBQK2R w KQkq' => {
			eco => 'C44g',
			# TRANSLATORS: C44g: 1. e4 e5 2. Nf3 Nc6 3. Be2 Nf6 4. d3 d5
			variation => N__('Open Game: Inverted Philidor, 4. Be2'),
			moves => {
				'b1d2' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2n2n2/3pp3/4P3/3P1N2/PPPNBPPP/R1BQK2R b KQkq' => {
			eco => 'C44h',
			# TRANSLATORS: C44h: 1. e4 e5 2. Nf3 Nc6 3. Be2 Nf6 4. d3 d5 5. Nbd2
			variation => N__('Open Game: Inverted Hanham'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4p3/4P3/2P2N2/PP1P1PPP/RNBQKB1R b KQkq' => {
			eco => 'C44i',
			# TRANSLATORS: C44i: 1. e4 e5 2. Nf3 Nc6 3. c3
			variation => N__('Ponziani Opening'),
			moves => {
				'd7d5' => 1,
				'f7f5' => 1,
				'f8e7' => 1,
				'g8e7' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqk1nr/ppppbppp/2n5/4p3/4P3/2P2N2/PP1P1PPP/RNBQKB1R w KQkq' => {
			eco => 'C44i',
			# TRANSLATORS: C44i: 1. e4 e5 2. Nf3 Nc6 3. c3 Be7
			variation => N__('Ponziani: Romanishin Variation'),
			moves => {
			},
		},
		'r1bqkb1r/ppppnppp/2n5/4p3/4P3/2P2N2/PP1P1PPP/RNBQKB1R w KQkq' => {
			eco => 'C44i',
			# TRANSLATORS: C44i: 1. e4 e5 2. Nf3 Nc6 3. c3 Nge7
			variation => N__('Ponziani: Reti Variation'),
			moves => {
			},
		},
		'r1bqkbnr/pppp2pp/2n5/4pp2/4P3/2P2N2/PP1P1PPP/RNBQKB1R w KQkq' => {
			eco => 'C44j',
			# TRANSLATORS: C44j: 1. e4 e5 2. Nf3 Nc6 3. c3 f5
			variation => N__('Ponziani Countergambit'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bqkbnr/pppp2pp/2n5/4pp2/3PP3/2P2N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'C44j',
			# TRANSLATORS: C44j: 1. e4 e5 2. Nf3 Nc6 3. c3 f5 4. d4
			variation => N__('Ponziani Countergambit'),
			moves => {
				'd7d6' => 1,
			},
		},
		'r1bqkbnr/ppp3pp/2np4/4pp2/3PP3/2P2N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'C44j',
			# TRANSLATORS: C44j: 1. e4 e5 2. Nf3 Nc6 3. c3 f5 4. d4 d6
			variation => N__('Ponziani Countergambit'),
			moves => {
				'd4d5' => 1,
			},
		},
		'r1bqkbnr/ppp3pp/2np4/3Ppp2/4P3/2P2N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'C44j',
			# TRANSLATORS: C44j: 1. e4 e5 2. Nf3 Nc6 3. c3 f5 4. d4 d6 5. d5
			variation => N__('Ponziani Countergambit, Schmidt Attack'),
			moves => {
				'f5e4' => 1,
			},
		},
		'r1bqkbnr/ppp3pp/2np4/3Pp3/4p3/2P2N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'C44j',
			# TRANSLATORS: C44j: 1. e4 e5 2. Nf3 Nc6 3. c3 f5 4. d4 d6 5. d5 fxe4
			variation => N__('Ponziani Countergambit, Schmidt Attack'),
			moves => {
				'f3g5' => 1,
			},
		},
		'r1bqkbnr/ppp3pp/2np4/3Pp1N1/4p3/2P5/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'C44j',
			# TRANSLATORS: C44j: 1. e4 e5 2. Nf3 Nc6 3. c3 f5 4. d4 d6 5. d5 fxe4 6. Ng5
			variation => N__('Ponziani Countergambit, Schmidt Attack'),
			moves => {
				'c6b8' => 1,
			},
		},
		'rnbqkbnr/ppp3pp/3p4/3Pp1N1/4p3/2P5/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'C44j',
			# TRANSLATORS: C44j: 1. e4 e5 2. Nf3 Nc6 3. c3 f5 4. d4 d6 5. d5 fxe4 6. Ng5 Nb8
			variation => N__('Ponziani Countergambit, Schmidt Attack'),
			moves => {
				'g5e4' => 1,
			},
		},
		'rnbqkbnr/ppp3pp/3p4/3Pp3/4N3/2P5/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'C44j',
			# TRANSLATORS: C44j: 1. e4 e5 2. Nf3 Nc6 3. c3 f5 4. d4 d6 5. d5 fxe4 6. Ng5 Nb8 7. Nxe4
			variation => N__('Ponziani Countergambit, Schmidt Attack'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/ppp3pp/3p1n2/3Pp3/4N3/2P5/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'C44j',
			# TRANSLATORS: C44j: 1. e4 e5 2. Nf3 Nc6 3. c3 f5 4. d4 d6 5. d5 fxe4 6. Ng5 Nb8 7. Nxe4 Nf6
			variation => N__('Ponziani Countergambit, Schmidt Attack'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rnbqkb1r/ppp3pp/3p1n2/3Pp3/4N3/2PB4/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'C44j',
			# TRANSLATORS: C44j: 1. e4 e5 2. Nf3 Nc6 3. c3 f5 4. d4 d6 5. d5 fxe4 6. Ng5 Nb8 7. Nxe4 Nf6 8. Bd3
			variation => N__('Ponziani Countergambit, Schmidt Attack'),
			moves => {
				'f8e7' => 1,
			},
		},
		'rnbqk2r/ppp1b1pp/3p1n2/3Pp3/4N3/2PB4/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'C44j',
			# TRANSLATORS: C44j: 1. e4 e5 2. Nf3 Nc6 3. c3 f5 4. d4 d6 5. d5 fxe4 6. Ng5 Nb8 7. Nxe4 Nf6 8. Bd3 Be7
			variation => N__('Ponziani Countergambit, Cordel Variation'),
			moves => {
			},
		},
		'r1bqkbnr/ppp2ppp/2n5/3pp3/4P3/2P2N2/PP1P1PPP/RNBQKB1R w KQkq' => {
			eco => 'C44k',
			# TRANSLATORS: C44k: 1. e4 e5 2. Nf3 Nc6 3. c3 d5
			variation => N__('Ponziani: 3... d5'),
			moves => {
				'd1a4' => 1,
			},
		},
		'r1bqkbnr/ppp2ppp/2n5/3pp3/Q3P3/2P2N2/PP1P1PPP/RNB1KB1R b KQkq' => {
			eco => 'C44l',
			# TRANSLATORS: C44l: 1. e4 e5 2. Nf3 Nc6 3. c3 d5 4. Qa4
			variation => N__('Ponziani: 3... d5 4. Qa4'),
			moves => {
				'c8d7' => 1,
				'f7f6' => 1,
				'g8f6' => 1,
			},
		},
		'r2qkbnr/pppb1ppp/2n5/3pp3/Q3P3/2P2N2/PP1P1PPP/RNB1KB1R w KQkq' => {
			eco => 'C44l',
			# TRANSLATORS: C44l: 1. e4 e5 2. Nf3 Nc6 3. c3 d5 4. Qa4 Bd7
			variation => N__('Ponziani: Caro Variation'),
			moves => {
			},
		},
		'r1bqkb1r/ppp2ppp/2n2n2/3pp3/Q3P3/2P2N2/PP1P1PPP/RNB1KB1R w KQkq' => {
			eco => 'C44l',
			# TRANSLATORS: C44l: 1. e4 e5 2. Nf3 Nc6 3. c3 d5 4. Qa4 Nf6
			variation => N__('Ponziani: Leonhardt Variation'),
			moves => {
			},
		},
		'r1bqkbnr/ppp3pp/2n2p2/3pp3/Q3P3/2P2N2/PP1P1PPP/RNB1KB1R w KQkq' => {
			eco => 'C44m',
			# TRANSLATORS: C44m: 1. e4 e5 2. Nf3 Nc6 3. c3 d5 4. Qa4 f6
			variation => N__('Ponziani: Steinitz Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4p3/4P3/2P2N2/PP1P1PPP/RNBQKB1R w KQkq' => {
			eco => 'C44n',
			# TRANSLATORS: C44n: 1. e4 e5 2. Nf3 Nc6 3. c3 Nf6
			variation => N__('Ponziani: 3... Nf6'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4p3/3PP3/2P2N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'C44n',
			# TRANSLATORS: C44n: 1. e4 e5 2. Nf3 Nc6 3. c3 Nf6 4. d4
			variation => N__('Ponziani: 3... Nf6'),
			moves => {
				'e5d4' => 1,
				'f6e4' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/8/3pP3/2P2N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'C44o',
			# TRANSLATORS: C44o: 1. e4 e5 2. Nf3 Nc6 3. c3 Nf6 4. d4 exd4
			variation => N__('Ponziani: 3... Nf6 4. d4 exd4'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n5/4p3/3Pn3/2P2N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'C44p',
			# TRANSLATORS: C44p: 1. e4 e5 2. Nf3 Nc6 3. c3 Nf6 4. d4 Nxe4
			variation => N__('Ponziani: 3... Nf6 4. d4 Nxe4'),
			moves => {
				'd4d5' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n5/3Pp3/4n3/2P2N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'C44p',
			# TRANSLATORS: C44p: 1. e4 e5 2. Nf3 Nc6 3. c3 Nf6 4. d4 Nxe4 5. d5
			variation => N__('Ponziani: 3... Nf6 4. d4 Nxe4'),
			moves => {
				'c6e7' => 1,
				'f8c5' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n5/2bPp3/4n3/2P2N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'C44p',
			# TRANSLATORS: C44p: 1. e4 e5 2. Nf3 Nc6 3. c3 Nf6 4. d4 Nxe4 5. d5 Bc5
			variation => N__('Ponziani: Fraser Defence'),
			moves => {
			},
		},
		'r1bqkb1r/ppppnppp/8/3Pp3/4n3/2P2N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'C44q',
			# TRANSLATORS: C44q: 1. e4 e5 2. Nf3 Nc6 3. c3 Nf6 4. d4 Nxe4 5. d5 Ne7
			variation => N__('Ponziani: 3... Nf6 4. d4 Nxe4 5. d5 Ne7'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4p3/3PP3/5N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'C44r',
			# TRANSLATORS: C44r: 1. e4 e5 2. Nf3 Nc6 3. d4
			variation => N__('Scotch Opening'),
			moves => {
				'c6d4' => 1,
				'd7d6' => 1,
				'e5d4' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/8/4p3/3nP3/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C44r',
			# TRANSLATORS: C44r: 1. e4 e5 2. Nf3 Nc6 3. d4 Nxd4
			variation => N__('Scotch: Lolli Variation'),
			moves => {
				'f3e5' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/8/4N3/3nP3/8/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'C44r',
			# TRANSLATORS: C44r: 1. e4 e5 2. Nf3 Nc6 3. d4 Nxd4 4. Nxe5
			variation => N__('Scotch: Lolli Variation'),
			moves => {
				'd4e6' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/4n3/4N3/4P3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C44r',
			# TRANSLATORS: C44r: 1. e4 e5 2. Nf3 Nc6 3. d4 Nxd4 4. Nxe5 Ne6
			variation => N__('Scotch: Lolli Variation'),
			moves => {
				'f1c4' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/4n3/4N3/2B1P3/8/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C44r',
			# TRANSLATORS: C44r: 1. e4 e5 2. Nf3 Nc6 3. d4 Nxd4 4. Nxe5 Ne6 5. Bc4
			variation => N__('Scotch: Lolli Variation'),
			moves => {
				'c7c6' => 1,
			},
		},
		'r1bqkbnr/pp1p1ppp/2p1n3/4N3/2B1P3/8/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C44r',
			# TRANSLATORS: C44r: 1. e4 e5 2. Nf3 Nc6 3. d4 Nxd4 4. Nxe5 Ne6 5. Bc4 c6
			variation => N__('Scotch: Lolli Variation'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqkbnr/pp1p1ppp/2p1n3/4N3/2B1P3/8/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C44r',
			# TRANSLATORS: C44r: 1. e4 e5 2. Nf3 Nc6 3. d4 Nxd4 4. Nxe5 Ne6 5. Bc4 c6 6. O-O
			variation => N__('Scotch: Lolli Variation'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r1bqkb1r/pp1p1ppp/2p1nn2/4N3/2B1P3/8/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C44r',
			# TRANSLATORS: C44r: 1. e4 e5 2. Nf3 Nc6 3. d4 Nxd4 4. Nxe5 Ne6 5. Bc4 c6 6. O-O Nf6
			variation => N__('Scotch: Lolli Variation'),
			moves => {
				'e5f7' => 1,
			},
		},
		'r1bqkb1r/pp1p1Npp/2p1nn2/8/2B1P3/8/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C44r',
			# TRANSLATORS: C44r: 1. e4 e5 2. Nf3 Nc6 3. d4 Nxd4 4. Nxe5 Ne6 5. Bc4 c6 6. O-O Nf6 7. Nxf7
			variation => N__('Scotch: Cochrane Variation'),
			moves => {
			},
		},
		'r1bqkbnr/ppp2ppp/2np4/4p3/3PP3/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C44s',
			# TRANSLATORS: C44s: 1. e4 e5 2. Nf3 Nc6 3. d4 d6
			variation => N__('Scotch: 3... d6'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/8/3pP3/5N2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C44t',
			# TRANSLATORS: C44t: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4
			variation => N__('Scotch: 3...exd4'),
			moves => {
				'c2c3' => 1,
				'f1b5' => 1,
				'f1c4' => 1,
				'f3d4' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/8/3pP3/2P2N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'C44t',
			# TRANSLATORS: C44t: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. c3
			variation => N__('Scotch: Goring Gambit'),
			moves => {
				'd4c3' => 1,
				'd4d3' => 1,
				'd7d5' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/1B6/3pP3/5N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C44t',
			# TRANSLATORS: C44t: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Bb5
			variation => N__('Scotch: Relfsson Gambit'),
			moves => {
			},
		},
		'r1bqkbnr/ppp2ppp/2n5/3p4/3pP3/2P2N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'C44u',
			# TRANSLATORS: C44u: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. c3 d5
			variation => N__('Scotch: Goring Gambit, 4... d5'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/8/4P3/2Pp1N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'C44v',
			# TRANSLATORS: C44v: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. c3 d3
			variation => N__('Scotch: Goring Gambit, 4... d3'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/8/4P3/2p2N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'C44w',
			# TRANSLATORS: C44w: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. c3 dxc3
			variation => N__('Scotch: Goring Gambit, 4...dxc3'),
			moves => {
				'b1c3' => 1,
				'f1c4' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/8/4P3/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'C44w',
			# TRANSLATORS: C44w: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. c3 dxc3 5. Nxc3
			variation => N__('Scotch: Goring Gambit, 4...dxc3 5.Nxc3'),
			moves => {
				'f8b4' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/8/1b2P3/2N2N2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'C44w',
			# TRANSLATORS: C44w: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. c3 dxc3 5. Nxc3 Bb4
			variation => N__('Scotch: Goring Gambit, 4...dxc3 5.Nxc3 Bb4'),
			moves => {
				'f1c4' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/8/1bB1P3/2N2N2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'C44w',
			# TRANSLATORS: C44w: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. c3 dxc3 5. Nxc3 Bb4 6. Bc4
			variation => N__('Scotch: Goring Gambit, 4...dxc3 5.Nxc3 Bb4'),
			moves => {
				'd7d6' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqk1nr/ppp2ppp/2np4/8/1bB1P3/2N2N2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'C44w',
			# TRANSLATORS: C44w: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. c3 dxc3 5. Nxc3 Bb4 6. Bc4 d6
			variation => N__('Scotch: Goring Gambit, 4...dxc3 5.Nxc3 Bb4 6. Bc4 d6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqk1nr/ppp2ppp/2np4/8/1bB1P3/2N2N2/PP3PPP/R1BQ1RK1 b kq' => {
			eco => 'C44w',
			# TRANSLATORS: C44w: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. c3 dxc3 5. Nxc3 Bb4 6. Bc4 d6 7. O-O
			variation => N__('Scotch: Goring Gambit, 4...dxc3 5.Nxc3 Bb4 6. Bc4 d6 7.O-O'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/8/1bB1P3/2N2N2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'C44w',
			# TRANSLATORS: C44w: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. c3 dxc3 5. Nxc3 Bb4 6. Bc4 Nf6
			variation => N__('Scotch: Goring Gambit, Bardeleben Variation'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/8/2B1P3/2p2N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'C44w',
			# TRANSLATORS: C44w: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. c3 dxc3 5. Bc4
			variation => N__('Scotch: Goring Gambit, 4...dxc3 5. Bc4'),
			moves => {
				'c3b2' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/8/2B1P3/5N2/Pp3PPP/RNBQK2R w KQkq' => {
			eco => 'C44w',
			# TRANSLATORS: C44w: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. c3 dxc3 5. Bc4 cxb2
			variation => N__('Scotch: Goring Gambit, 4...dxc3 5. Bc4'),
			moves => {
				'c1b2' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/8/2B1P3/5N2/PB3PPP/RN1QK2R b KQkq' => {
			eco => 'C44w',
			# TRANSLATORS: C44w: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. c3 dxc3 5. Bc4 cxb2 6. Bxb2
			variation => N__('Scotch: Goring Gambit, 4...dxc3 5. Bc4 cxb2 6.Bxb2'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/8/2BpP3/5N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C44x',
			# TRANSLATORS: C44x: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Bc4
			variation => N__('Scotch Gambit'),
			moves => {
				'f8b4' => 1,
				'f8c5' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/8/1bBpP3/5N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C44x',
			# TRANSLATORS: C44x: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Bc4 Bb4+
			variation => N__('Scotch Gambit: London Defence'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/2b5/2BpP3/5N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C44y',
			# TRANSLATORS: C44y: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Bc4 Bc5
			variation => N__('Scotch Gambit: 4... Bc5'),
			moves => {
				'c2c3' => 1,
				'e1g1' => 1,
				'f3g5' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/2b5/2BpP3/5N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C44y',
			# TRANSLATORS: C44y: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Bc4 Bc5 5. O-O
			variation => N__('Scotch Gambit: 5.O-O'),
			moves => {
				'd7d6' => 1,
			},
		},
		'r1bqk1nr/ppp2ppp/2np4/2b5/2BpP3/5N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C44y',
			# TRANSLATORS: C44y: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Bc4 Bc5 5. O-O d6
			variation => N__('Scotch Gambit: 5.O-O'),
			moves => {
				'c2c3' => 1,
			},
		},
		'r1bqk1nr/ppp2ppp/2np4/2b5/2BpP3/2P2N2/PP3PPP/RNBQ1RK1 b kq' => {
			eco => 'C44y',
			# TRANSLATORS: C44y: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Bc4 Bc5 5. O-O d6 6. c3
			variation => N__('Scotch Gambit: 5.O-O'),
			moves => {
				'c8g4' => 1,
			},
		},
		'r2qk1nr/ppp2ppp/2np4/2b5/2BpP1b1/2P2N2/PP3PPP/RNBQ1RK1 w kq' => {
			eco => 'C44y',
			# TRANSLATORS: C44y: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Bc4 Bc5 5. O-O d6 6. c3 Bg4
			variation => N__('Scotch Gambit: Anderssen (Paulsen) Counterattack'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/2b3N1/2BpP3/8/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C44y',
			# TRANSLATORS: C44y: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Bc4 Bc5 5. Ng5
			variation => N__('Scotch Gambit: 5. Ng5'),
			moves => {
				'g8h6' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n4n/2b3N1/2BpP3/8/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C44y',
			# TRANSLATORS: C44y: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Bc4 Bc5 5. Ng5 Nh6
			variation => N__('Scotch Gambit: 5. Ng5'),
			moves => {
				'd1h5' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n4n/2b3NQ/2BpP3/8/PPP2PPP/RNB1K2R b KQkq' => {
			eco => 'C44y',
			# TRANSLATORS: C44y: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Bc4 Bc5 5. Ng5 Nh6 6. Qh5
			variation => N__('Scotch Gambit: Vitzhum Attack'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/2b5/2BpP3/2P2N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'C44z',
			# TRANSLATORS: C44z: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Bc4 Bc5 5. c3
			variation => N__('Scotch Gambit: 5. c3'),
			moves => {
				'd4d3' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/2b5/2B1P3/2Pp1N2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'C44z',
			# TRANSLATORS: C44z: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Bc4 Bc5 5. c3 d3
			variation => N__('Scotch Gambit: 5. c3 d3'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/8/3NP3/8/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'C45a',
			# TRANSLATORS: C45a: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4
			variation => N__('Scotch: 4.Nxd4'),
			moves => {
				'c6d4' => 1,
				'd8f6' => 1,
				'd8h4' => 1,
				'f8b4' => 1,
				'f8c5' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/8/8/3nP3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C45b',
			# TRANSLATORS: C45b: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Nxd4
			variation => N__('Scotch: 4.Nxd4 Nxd4'),
			moves => {
				'd1d4' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/8/8/3QP3/8/PPP2PPP/RNB1KB1R b KQkq' => {
			eco => 'C45b',
			# TRANSLATORS: C45b: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Nxd4 5. Qxd4
			variation => N__('Scotch: 4.Nxd4 Nxd4'),
			moves => {
				'd7d6' => 1,
			},
		},
		'r1bqkbnr/ppp2ppp/3p4/8/3QP3/8/PPP2PPP/RNB1KB1R w KQkq' => {
			eco => 'C45b',
			# TRANSLATORS: C45b: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Nxd4 5. Qxd4 d6
			variation => N__('Scotch: 4.Nxd4 Nxd4'),
			moves => {
				'f1d3' => 1,
			},
		},
		'r1bqkbnr/ppp2ppp/3p4/8/3QP3/3B4/PPP2PPP/RNB1K2R b KQkq' => {
			eco => 'C45b',
			# TRANSLATORS: C45b: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Nxd4 5. Qxd4 d6 6. Bd3
			variation => N__('Scotch: Ghulam Kassim Variation'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/8/1b1NP3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C45c',
			# TRANSLATORS: C45c: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Bb4+
			variation => N__('Scotch: 4.Nxd4 Bb4+'),
			moves => {
			},
		},
		'r1b1kbnr/pppp1ppp/2n2q2/8/3NP3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C45d',
			# TRANSLATORS: C45d: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Qf6
			variation => N__('Scotch: 4.Nxd4 Qf6'),
			moves => {
			},
		},
		'r1b1kbnr/pppp1ppp/2n5/8/3NP2q/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C45e',
			# TRANSLATORS: C45e: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Qh4
			variation => N__('Scotch: Steinitz Variation'),
			moves => {
				'b1c3' => 1,
				'd1d3' => 1,
				'd4b5' => 1,
				'd4f3' => 1,
			},
		},
		'r1b1kbnr/pppp1ppp/2n5/8/3NP2q/3Q4/PPP2PPP/RNB1KB1R b KQkq' => {
			eco => 'C45e',
			# TRANSLATORS: C45e: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Qh4 5. Qd3
			variation => N__('Scotch: Steinitz, 5. Qd3'),
			moves => {
			},
		},
		'r1b1kbnr/pppp1ppp/2n5/8/4P2q/5N2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'C45e',
			# TRANSLATORS: C45e: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Qh4 5. Nf3
			variation => N__('Scotch: Steinitz, Fraser Attack'),
			moves => {
			},
		},
		'r1b1kbnr/pppp1ppp/2n5/8/3NP2q/2N5/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'C45f',
			# TRANSLATORS: C45f: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Qh4 5. Nc3
			variation => N__('Scotch: Steinitz, 5. Nc3'),
			moves => {
			},
		},
		'r1b1kbnr/pppp1ppp/2n5/1N6/4P2q/8/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'C45g',
			# TRANSLATORS: C45g: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Qh4 5. Nb5
			variation => N__('Scotch: Steinitz, 5. Nb5'),
			moves => {
				'f8b4' => 1,
				'f8c5' => 1,
				'h4e4' => 1,
			},
		},
		'r1b1k1nr/pppp1ppp/2n5/1N6/1b2P2q/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C45g',
			# TRANSLATORS: C45g: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Qh4 5. Nb5 Bb4+
			variation => N__('Scotch: Steinitz, 5. Nb5 Bb4+'),
			moves => {
				'b1d2' => 1,
				'c1d2' => 1,
			},
		},
		'r1b1k1nr/pppp1ppp/2n5/1N6/1b2P2q/8/PPPN1PPP/R1BQKB1R b KQkq' => {
			eco => 'C45g',
			# TRANSLATORS: C45g: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Qh4 5. Nb5 Bb4+ 6. Nd2
			variation => N__('Scotch: Steinitz, 5. Nb5 Bb4+'),
			moves => {
				'h4e4' => 1,
			},
		},
		'r1b1k1nr/pppp1ppp/2n5/1N6/1b2q3/8/PPPN1PPP/R1BQKB1R w KQkq' => {
			eco => 'C45g',
			# TRANSLATORS: C45g: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Qh4 5. Nb5 Bb4+ 6. Nd2 Qxe4+
			variation => N__('Scotch: Steinitz, 5. Nb5 Bb4+'),
			moves => {
				'f1e2' => 1,
			},
		},
		'r1b1k1nr/pppp1ppp/2n5/1N6/1b2q3/8/PPPNBPPP/R1BQK2R b KQkq' => {
			eco => 'C45g',
			# TRANSLATORS: C45g: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Qh4 5. Nb5 Bb4+ 6. Nd2 Qxe4+ 7. Be2
			variation => N__('Scotch: Steinitz, 5. Nb5 Bb4+'),
			moves => {
				'e4g2' => 1,
			},
		},
		'r1b1k1nr/pppp1ppp/2n5/1N6/1b6/8/PPPNBPqP/R1BQK2R w KQkq' => {
			eco => 'C45g',
			# TRANSLATORS: C45g: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Qh4 5. Nb5 Bb4+ 6. Nd2 Qxe4+ 7. Be2 Qxg2
			variation => N__('Scotch: Steinitz, 5. Nb5 Bb4+'),
			moves => {
				'e2f3' => 1,
			},
		},
		'r1b1k1nr/pppp1ppp/2n5/1N6/1b6/5B2/PPPN1PqP/R1BQK2R b KQkq' => {
			eco => 'C45g',
			# TRANSLATORS: C45g: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Qh4 5. Nb5 Bb4+ 6. Nd2 Qxe4+ 7. Be2 Qxg2 8. Bf3
			variation => N__('Scotch: Steinitz, 5. Nb5 Bb4+'),
			moves => {
				'g2h3' => 1,
			},
		},
		'r1b1k1nr/pppp1ppp/2n5/1N6/1b6/5B1q/PPPN1P1P/R1BQK2R w KQkq' => {
			eco => 'C45g',
			# TRANSLATORS: C45g: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Qh4 5. Nb5 Bb4+ 6. Nd2 Qxe4+ 7. Be2 Qxg2 8. Bf3 Qh3
			variation => N__('Scotch: Steinitz, 5. Nb5 Bb4+'),
			moves => {
				'b5c7' => 1,
			},
		},
		'r1b1k1nr/ppNp1ppp/2n5/8/1b6/5B1q/PPPN1P1P/R1BQK2R b KQkq' => {
			eco => 'C45g',
			# TRANSLATORS: C45g: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Qh4 5. Nb5 Bb4+ 6. Nd2 Qxe4+ 7. Be2 Qxg2 8. Bf3 Qh3 9. Nxc7+
			variation => N__('Scotch: Steinitz, 5. Nb5 Bb4+'),
			moves => {
				'e8d8' => 1,
			},
		},
		'r1bk2nr/ppNp1ppp/2n5/8/1b6/5B1q/PPPN1P1P/R1BQK2R w KQ' => {
			eco => 'C45g',
			# TRANSLATORS: C45g: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Qh4 5. Nb5 Bb4+ 6. Nd2 Qxe4+ 7. Be2 Qxg2 8. Bf3 Qh3 9. Nxc7+ Kd8
			variation => N__('Scotch: Steinitz, 5. Nb5 Bb4+'),
			moves => {
				'c7a8' => 1,
			},
		},
		'N1bk2nr/pp1p1ppp/2n5/8/1b6/5B1q/PPPN1P1P/R1BQK2R b KQ' => {
			eco => 'C45g',
			# TRANSLATORS: C45g: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Qh4 5. Nb5 Bb4+ 6. Nd2 Qxe4+ 7. Be2 Qxg2 8. Bf3 Qh3 9. Nxc7+ Kd8 10. Nxa8
			variation => N__('Scotch: Steinitz, 5. Nb5 Bb4+'),
			moves => {
				'g8f6' => 1,
			},
		},
		'N1bk3r/pp1p1ppp/2n2n2/8/1b6/5B1q/PPPN1P1P/R1BQK2R w KQ' => {
			eco => 'C45g',
			# TRANSLATORS: C45g: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Qh4 5. Nb5 Bb4+ 6. Nd2 Qxe4+ 7. Be2 Qxg2 8. Bf3 Qh3 9. Nxc7+ Kd8 10. Nxa8 Nf6
			variation => N__('Scotch: Steinitz, 5. Nb5 Bb4+'),
			moves => {
				'a2a3' => 1,
			},
		},
		'N1bk3r/pp1p1ppp/2n2n2/8/1b6/P4B1q/1PPN1P1P/R1BQK2R b KQ' => {
			eco => 'C45g',
			# TRANSLATORS: C45g: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Qh4 5. Nb5 Bb4+ 6. Nd2 Qxe4+ 7. Be2 Qxg2 8. Bf3 Qh3 9. Nxc7+ Kd8 10. Nxa8 Nf6 11. a3
			variation => N__('Scotch: Steinitz, Berger Variation'),
			moves => {
			},
		},
		'r1b1k1nr/pppp1ppp/2n5/1N6/1b2P2q/8/PPPB1PPP/RN1QKB1R b KQkq' => {
			eco => 'C45g',
			# TRANSLATORS: C45g: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Qh4 5. Nb5 Bb4+ 6. Bd2
			variation => N__('Scotch: Steinitz, 5. Nb5 Bb4+ 6. Bd2'),
			moves => {
				'h4e4' => 1,
			},
		},
		'r1b1k1nr/pppp1ppp/2n5/1N6/1b2q3/8/PPPB1PPP/RN1QKB1R w KQkq' => {
			eco => 'C45g',
			# TRANSLATORS: C45g: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Qh4 5. Nb5 Bb4+ 6. Bd2 Qxe4+
			variation => N__('Scotch: Steinitz, 5. Nb5 Bb4+ 6. Bd2'),
			moves => {
				'f1e2' => 1,
			},
		},
		'r1b1k1nr/pppp1ppp/2n5/1N6/1b2q3/8/PPPBBPPP/RN1QK2R b KQkq' => {
			eco => 'C45g',
			# TRANSLATORS: C45g: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Qh4 5. Nb5 Bb4+ 6. Bd2 Qxe4+ 7. Be2
			variation => N__('Scotch: Steinitz, 5. Nb5 Bb4+ 6. Bd2'),
			moves => {
				'e8d8' => 1,
			},
		},
		'r1bk2nr/pppp1ppp/2n5/1N6/1b2q3/8/PPPBBPPP/RN1QK2R w KQ' => {
			eco => 'C45g',
			# TRANSLATORS: C45g: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Qh4 5. Nb5 Bb4+ 6. Bd2 Qxe4+ 7. Be2 Kd8
			variation => N__('Scotch: Steinitz, 5. Nb5 Bb4+ 6. Bd2'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bk2nr/pppp1ppp/2n5/1N6/1b2q3/8/PPPBBPPP/RN1Q1RK1 b -' => {
			eco => 'C45g',
			# TRANSLATORS: C45g: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Qh4 5. Nb5 Bb4+ 6. Bd2 Qxe4+ 7. Be2 Kd8 8. O-O
			variation => N__('Scotch: Steinitz, 5. Nb5 Bb4+ 6. Bd2'),
			moves => {
				'b4d2' => 1,
			},
		},
		'r1bk2nr/pppp1ppp/2n5/1N6/4q3/8/PPPbBPPP/RN1Q1RK1 w -' => {
			eco => 'C45g',
			# TRANSLATORS: C45g: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Qh4 5. Nb5 Bb4+ 6. Bd2 Qxe4+ 7. Be2 Kd8 8. O-O Bxd2
			variation => N__('Scotch: Steinitz, 5. Nb5 Bb4+ 6. Bd2'),
			moves => {
				'b1d2' => 1,
			},
		},
		'r1bk2nr/pppp1ppp/2n5/1N6/4q3/8/PPPNBPPP/R2Q1RK1 b -' => {
			eco => 'C45g',
			# TRANSLATORS: C45g: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Qh4 5. Nb5 Bb4+ 6. Bd2 Qxe4+ 7. Be2 Kd8 8. O-O Bxd2 9. Nxd2
			variation => N__('Scotch: Steinitz, 5. Nb5 Bb4+ 6. Bd2'),
			moves => {
				'e4g6' => 1,
			},
		},
		'r1bk2nr/pppp1ppp/2n3q1/1N6/8/8/PPPNBPPP/R2Q1RK1 w -' => {
			eco => 'C45g',
			# TRANSLATORS: C45g: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Qh4 5. Nb5 Bb4+ 6. Bd2 Qxe4+ 7. Be2 Kd8 8. O-O Bxd2 9. Nxd2 Qg6
			variation => N__('Scotch: Steinitz, Rosenthal Variation'),
			moves => {
			},
		},
		'r1b1k1nr/pppp1ppp/2n5/1Nb5/4P2q/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C45g',
			# TRANSLATORS: C45g: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Qh4 5. Nb5 Bc5
			variation => N__('Scotch: Steinitz, 5. Nb5 Bc5'),
			moves => {
				'd1f3' => 1,
			},
		},
		'r1b1k1nr/pppp1ppp/2n5/1Nb5/4P2q/5Q2/PPP2PPP/RNB1KB1R b KQkq' => {
			eco => 'C45g',
			# TRANSLATORS: C45g: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Qh4 5. Nb5 Bc5 6. Qf3
			variation => N__('Scotch: Steinitz, 5. Nb5 Bc5 6. Qf3'),
			moves => {
			},
		},
		'r1b1kbnr/pppp1ppp/2n5/1N6/4q3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C45g',
			# TRANSLATORS: C45g: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Qh4 5. Nb5 Qxe4+
			variation => N__('Scotch: Steinitz, 5. Nb5 Qxe4+'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/8/3NP3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C45h',
			# TRANSLATORS: C45h: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Nf6
			variation => N__('Scotch: 4.Nxd4 Nf6'),
			moves => {
				'd4c6' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2N2n2/8/4P3/8/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'C45h',
			# TRANSLATORS: C45h: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Nf6 5. Nxc6
			variation => N__('Scotch: 4.Nxd4 Nf6 5.Nxc6'),
			moves => {
				'b7c6' => 1,
			},
		},
		'r1bqkb1r/p1pp1ppp/2p2n2/8/4P3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C45h',
			# TRANSLATORS: C45h: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Nf6 5. Nxc6 bxc6
			variation => N__('Scotch: 4.Nxd4 Nf6 5.Nxc6'),
			moves => {
				'b1d2' => 1,
				'e4e5' => 1,
				'f1d3' => 1,
			},
		},
		'r1bqkb1r/p1pp1ppp/2p2n2/8/4P3/8/PPPN1PPP/R1BQKB1R b KQkq' => {
			eco => 'C45h',
			# TRANSLATORS: C45h: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Nf6 5. Nxc6 bxc6 6. Nd2
			variation => N__('Scotch: Tartakower Variation'),
			moves => {
			},
		},
		'r1bqkb1r/p1pp1ppp/2p2n2/8/4P3/3B4/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C45i',
			# TRANSLATORS: C45i: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Nf6 5. Nxc6 bxc6 6. Bd3
			variation => N__('Scotch: 4.Nxd4 Nf6 5.Nxc6 bxc6 6. Bd3'),
			moves => {
			},
		},
		'r1bqkb1r/p1pp1ppp/2p2n2/4P3/8/8/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'C45j',
			# TRANSLATORS: C45j: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Nf6 5. Nxc6 bxc6 6. e5
			variation => N__('Scotch: Mieses Variation'),
			moves => {
				'd8e7' => 1,
			},
		},
		'r1b1kb1r/p1ppqppp/2p2n2/4P3/8/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C45j',
			# TRANSLATORS: C45j: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Nf6 5. Nxc6 bxc6 6. e5 Qe7
			variation => N__('Scotch: Mieses, 6... Qe7'),
			moves => {
				'd1e2' => 1,
			},
		},
		'r1b1kb1r/p1ppqppp/2p2n2/4P3/8/8/PPP1QPPP/RNB1KB1R b KQkq' => {
			eco => 'C45j',
			# TRANSLATORS: C45j: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Nf6 5. Nxc6 bxc6 6. e5 Qe7 7. Qe2
			variation => N__('Scotch: Mieses, 6... Qe7 7. Qe2'),
			moves => {
				'f6d5' => 1,
			},
		},
		'r1b1kb1r/p1ppqppp/2p5/3nP3/8/8/PPP1QPPP/RNB1KB1R w KQkq' => {
			eco => 'C45j',
			# TRANSLATORS: C45j: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Nf6 5. Nxc6 bxc6 6. e5 Qe7 7. Qe2 Nd5
			variation => N__('Scotch: Mieses, 6... Qe7 7. Qe2'),
			moves => {
				'c2c4' => 1,
			},
		},
		'r1b1kb1r/p1ppqppp/2p5/3nP3/2P5/8/PP2QPPP/RNB1KB1R b KQkq' => {
			eco => 'C45k',
			# TRANSLATORS: C45k: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Nf6 5. Nxc6 bxc6 6. e5 Qe7 7. Qe2 Nd5 8. c4
			variation => N__('Scotch: Mieses, 8. c4'),
			moves => {
				'c8a6' => 1,
			},
		},
		'r3kb1r/p1ppqppp/b1p5/3nP3/2P5/8/PP2QPPP/RNB1KB1R w KQkq' => {
			eco => 'C45l',
			# TRANSLATORS: C45l: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Nf6 5. Nxc6 bxc6 6. e5 Qe7 7. Qe2 Nd5 8. c4 Ba6
			variation => N__('Scotch: Mieses, 8. c4 Ba6'),
			moves => {
				'b2b3' => 1,
			},
		},
		'r3kb1r/p1ppqppp/b1p5/3nP3/2P5/1P6/P3QPPP/RNB1KB1R b KQkq' => {
			eco => 'C45m',
			# TRANSLATORS: C45m: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Nf6 5. Nxc6 bxc6 6. e5 Qe7 7. Qe2 Nd5 8. c4 Ba6 9. b3
			variation => N__('Scotch: Mieses, 8. c4 Ba6 9. b3'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/2b5/3NP3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C45n',
			# TRANSLATORS: C45n: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Bc5
			variation => N__('Scotch: 4.Nxd4 Bc5'),
			moves => {
				'c1e3' => 1,
				'd4b3' => 1,
				'd4c6' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/2b5/4P3/1N6/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'C45o',
			# TRANSLATORS: C45o: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Bc5 5. Nb3
			variation => N__('Scotch: 4.Nxd4 Bc5 5. Nb3'),
			moves => {
				'c5b4' => 1,
				'c5b6' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/8/1b2P3/1N6/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C45o',
			# TRANSLATORS: C45o: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Bc5 5. Nb3 Bb4+
			variation => N__('Scotch: Romanishin Variation'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/1bn5/8/4P3/1N6/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C45p',
			# TRANSLATORS: C45p: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Bc5 5. Nb3 Bb6
			variation => N__('Scotch: 4.Nxd4 Bc5 5. Nb3 Bb6'),
			moves => {
				'a2a4' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/1bn5/8/P3P3/1N6/1PP2PPP/RNBQKB1R b KQkq' => {
			eco => 'C45p',
			# TRANSLATORS: C45p: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Bc5 5. Nb3 Bb6 6. a4
			variation => N__('Scotch: 4.Nxd4 Bc5 5. Nb3 Bb6 6. a4'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r1bqk1nr/1ppp1ppp/pbn5/8/P3P3/1N6/1PP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C45q',
			# TRANSLATORS: C45q: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Bc5 5. Nb3 Bb6 6. a4 a6
			variation => N__('Scotch: 4.Nxd4 Bc5 5. Nb3 Bb6 6. a4 a6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r1bqk1nr/1ppp1ppp/pbn5/8/P3P3/1NN5/1PP2PPP/R1BQKB1R b KQkq' => {
			eco => 'C45q',
			# TRANSLATORS: C45q: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Bc5 5. Nb3 Bb6 6. a4 a6 7. Nc3
			variation => N__('Scotch: 4.Nxd4 Bc5 5. Nb3 Bb6 6. a4 a6 7. Nc3'),
			moves => {
				'd8f6' => 1,
				'g8f6' => 1,
			},
		},
		'r1b1k1nr/1ppp1ppp/pbn2q2/8/P3P3/1NN5/1PP2PPP/R1BQKB1R w KQkq' => {
			eco => 'C45q',
			# TRANSLATORS: C45q: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Bc5 5. Nb3 Bb6 6. a4 a6 7. Nc3 Qf6
			variation => N__('Scotch: 4.Nxd4 Bc5 5. Nb3 Bb6 6. a4 a6 7. Nc3 Qf6'),
			moves => {
			},
		},
		'r1bqk2r/1ppp1ppp/pbn2n2/8/P3P3/1NN5/1PP2PPP/R1BQKB1R w KQkq' => {
			eco => 'C45q',
			# TRANSLATORS: C45q: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Bc5 5. Nb3 Bb6 6. a4 a6 7. Nc3 Nf6
			variation => N__('Scotch: Geller Variation'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/2N5/2b5/4P3/8/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'C45r',
			# TRANSLATORS: C45r: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Bc5 5. Nxc6
			variation => N__('Scotch: 4.Nxd4 Bc5 5.Nxc6'),
			moves => {
				'd8f6' => 1,
			},
		},
		'r1b1k1nr/pppp1ppp/2N2q2/2b5/4P3/8/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'C45r',
			# TRANSLATORS: C45r: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Bc5 5. Nxc6 Qf6
			variation => N__('Scotch: 4.Nxd4 Bc5 5.Nxc6'),
			moves => {
				'd1d2' => 1,
			},
		},
		'r1b1k1nr/pppp1ppp/2N2q2/2b5/4P3/8/PPPQ1PPP/RNB1KB1R b KQkq' => {
			eco => 'C45s',
			# TRANSLATORS: C45s: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Bc5 5. Nxc6 Qf6 6. Qd2
			variation => N__('Scotch: 4.Nxd4 Bc5 5.Nxc6 Qf6 6. Qd2'),
			moves => {
				'd7c6' => 1,
			},
		},
		'r1b1k1nr/ppp2ppp/2p2q2/2b5/4P3/8/PPPQ1PPP/RNB1KB1R w KQkq' => {
			eco => 'C45s',
			# TRANSLATORS: C45s: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Bc5 5. Nxc6 Qf6 6. Qd2 dxc6
			variation => N__('Scotch: 4.Nxd4 Bc5 5.Nxc6 Qf6 6. Qd2'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r1b1k1nr/ppp2ppp/2p2q2/2b5/4P3/2N5/PPPQ1PPP/R1B1KB1R b KQkq' => {
			eco => 'C45t',
			# TRANSLATORS: C45t: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Bc5 5. Nxc6 Qf6 6. Qd2 dxc6 7. Nc3
			variation => N__('Scotch: 4.Nxd4 Bc5 5.Nxc6 Qf6 6. Qd2 dxc6 7. Nc3'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/2b5/3NP3/4B3/PPP2PPP/RN1QKB1R b KQkq' => {
			eco => 'C45u',
			# TRANSLATORS: C45u: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Bc5 5. Be3
			variation => N__('Scotch: 4.Nxd4 Bc5 5. Be3'),
			moves => {
				'd8f6' => 1,
			},
		},
		'r1b1k1nr/pppp1ppp/2n2q2/2b5/3NP3/4B3/PPP2PPP/RN1QKB1R w KQkq' => {
			eco => 'C45u',
			# TRANSLATORS: C45u: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Bc5 5. Be3 Qf6
			variation => N__('Scotch: 4.Nxd4 Bc5 5. Be3'),
			moves => {
				'c2c3' => 1,
				'd4b5' => 1,
			},
		},
		'r1b1k1nr/pppp1ppp/2n2q2/2b5/3NP3/2P1B3/PP3PPP/RN1QKB1R b KQkq' => {
			eco => 'C45v',
			# TRANSLATORS: C45v: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Bc5 5. Be3 Qf6 6. c3
			variation => N__('Scotch: 4.Nxd4 Bc5 5. Be3 Qf6 6. c3'),
			moves => {
				'g8e7' => 1,
			},
		},
		'r1b1k1nr/pppp1ppp/2n2q2/1Nb5/4P3/4B3/PPP2PPP/RN1QKB1R b KQkq' => {
			eco => 'C45v',
			# TRANSLATORS: C45v: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Bc5 5. Be3 Qf6 6. Nb5
			variation => N__('Scotch: Blumenfeld Attack'),
			moves => {
			},
		},
		'r1b1k2r/ppppnppp/2n2q2/2b5/3NP3/2P1B3/PP3PPP/RN1QKB1R w KQkq' => {
			eco => 'C45w',
			# TRANSLATORS: C45w: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Bc5 5. Be3 Qf6 6. c3 Nge7
			variation => N__('Scotch: 4.Nxd4 Bc5 5. Be3 Qf6 6. c3 Nge7'),
			moves => {
				'd1d2' => 1,
				'd4c2' => 1,
				'f1b5' => 1,
				'f1c4' => 1,
			},
		},
		'r1b1k2r/ppppnppp/2n2q2/2b5/3NP3/2P1B3/PP1Q1PPP/RN2KB1R b KQkq' => {
			eco => 'C45w',
			# TRANSLATORS: C45w: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Bc5 5. Be3 Qf6 6. c3 Nge7 7. Qd2
			variation => N__('Scotch: Blackburne Attack'),
			moves => {
			},
		},
		'r1b1k2r/ppppnppp/2n2q2/2b5/4P3/2P1B3/PPN2PPP/RN1QKB1R b KQkq' => {
			eco => 'C45w',
			# TRANSLATORS: C45w: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Bc5 5. Be3 Qf6 6. c3 Nge7 7. Nc2
			variation => N__('Scotch: Meitner Variation'),
			moves => {
			},
		},
		'r1b1k2r/ppppnppp/2n2q2/1Bb5/3NP3/2P1B3/PP3PPP/RN1QK2R b KQkq' => {
			eco => 'C45w',
			# TRANSLATORS: C45w: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Bc5 5. Be3 Qf6 6. c3 Nge7 7. Bb5
			variation => N__('Scotch: Paulsen Attack'),
			moves => {
				'c6d8' => 1,
			},
		},
		'r1bnk2r/ppppnppp/5q2/1Bb5/3NP3/2P1B3/PP3PPP/RN1QK2R w KQkq' => {
			eco => 'C45w',
			# TRANSLATORS: C45w: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Bc5 5. Be3 Qf6 6. c3 Nge7 7. Bb5 Nd8
			variation => N__('Scotch: Paulsen, Gunsberg Defence'),
			moves => {
			},
		},
		'r1b1k2r/ppppnppp/2n2q2/2b5/2BNP3/2P1B3/PP3PPP/RN1QK2R b KQkq' => {
			eco => 'C45x',
			# TRANSLATORS: C45x: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Bc5 5. Be3 Qf6 6. c3 Nge7 7. Bc4
			variation => N__('Scotch: 4.Nxd4 Bc5 5. Be3 Qf6 6. c3 Nge7 7. Bc4'),
			moves => {
				'c6e5' => 1,
			},
		},
		'r1b1k2r/ppppnppp/5q2/2b1n3/2BNP3/2P1B3/PP3PPP/RN1QK2R w KQkq' => {
			eco => 'C45y',
			# TRANSLATORS: C45y: 1. e4 e5 2. Nf3 Nc6 3. d4 exd4 4. Nxd4 Bc5 5. Be3 Qf6 6. c3 Nge7 7. Bc4 Ne5
			variation => N__('Scotch: 4.Nxd4 Bc5 5. Be3 Qf6 6. c3 Nge7 7. Bc4 Ne5'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4p3/4P3/2N2N2/PPPP1PPP/R1BQKB1R b KQkq' => {
			eco => 'C46a',
			# TRANSLATORS: C46a: 1. e4 e5 2. Nf3 Nc6 3. Nc3
			variation => N__('Three Knights Game'),
			moves => {
				'd7d6' => 1,
				'f7f5' => 1,
				'f8b4' => 1,
				'f8c5' => 1,
				'g7g6' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkbnr/pppp2pp/2n5/4pp2/4P3/2N2N2/PPPP1PPP/R1BQKB1R w KQkq' => {
			eco => 'C46b',
			# TRANSLATORS: C46b: 1. e4 e5 2. Nf3 Nc6 3. Nc3 f5
			variation => N__('Three Knights: Winawer Defence'),
			moves => {
			},
		},
		'r1bqkbnr/ppp2ppp/2np4/4p3/4P3/2N2N2/PPPP1PPP/R1BQKB1R w KQkq' => {
			eco => 'C46c',
			# TRANSLATORS: C46c: 1. e4 e5 2. Nf3 Nc6 3. Nc3 d6
			variation => N__('Three Knights: 3... d6'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bqkbnr/ppp2ppp/2np4/4p3/3PP3/2N2N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'C46d',
			# TRANSLATORS: C46d: 1. e4 e5 2. Nf3 Nc6 3. Nc3 d6 4. d4
			variation => N__('Three Knights: 3... d6 4. d4'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/2b1p3/4P3/2N2N2/PPPP1PPP/R1BQKB1R w KQkq' => {
			eco => 'C46e',
			# TRANSLATORS: C46e: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Bc5
			variation => N__('Three Knights: 3... Bc5'),
			moves => {
				'f1b5' => 1,
				'f3e5' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/1Bb1p3/4P3/2N2N2/PPPP1PPP/R1BQK2R b KQkq' => {
			eco => 'C46e',
			# TRANSLATORS: C46e: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Bc5 4. Bb5
			variation => N__('Three Knights: 3... Bc5 4. Bb5'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/2b1N3/4P3/2N5/PPPP1PPP/R1BQKB1R b KQkq' => {
			eco => 'C46f',
			# TRANSLATORS: C46f: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Bc5 4. Nxe5
			variation => N__('Three Knights: 3... Bc5 4.Nxe5'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/4p3/1b2P3/2N2N2/PPPP1PPP/R1BQKB1R w KQkq' => {
			eco => 'C46g',
			# TRANSLATORS: C46g: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Bb4
			variation => N__('Three Knights: 3... Bb4'),
			moves => {
				'c3d5' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/3Np3/1b2P3/5N2/PPPP1PPP/R1BQKB1R b KQkq' => {
			eco => 'C46h',
			# TRANSLATORS: C46h: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Bb4 4. Nd5
			variation => N__('Three Knights: 3... Bb4 4. Nd5'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/3Np3/1b2P3/5N2/PPPP1PPP/R1BQKB1R w KQkq' => {
			eco => 'C46h',
			# TRANSLATORS: C46h: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Bb4 4. Nd5 Nf6
			variation => N__('Three Knights: Schlechter Variation'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1p1p/2n3p1/4p3/4P3/2N2N2/PPPP1PPP/R1BQKB1R w KQkq' => {
			eco => 'C46i',
			# TRANSLATORS: C46i: 1. e4 e5 2. Nf3 Nc6 3. Nc3 g6
			variation => N__('Three Knights: Steinitz Variation'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bqkbnr/pppp1p1p/2n3p1/4p3/3PP3/2N2N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'C46j',
			# TRANSLATORS: C46j: 1. e4 e5 2. Nf3 Nc6 3. Nc3 g6 4. d4
			variation => N__('Three Knights: Steinitz, 4. d4'),
			moves => {
				'e5d4' => 1,
			},
		},
		'r1bqkbnr/pppp1p1p/2n3p1/8/3pP3/2N2N2/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'C46j',
			# TRANSLATORS: C46j: 1. e4 e5 2. Nf3 Nc6 3. Nc3 g6 4. d4 exd4
			variation => N__('Three Knights: Steinitz, 4. d4'),
			moves => {
				'c3d5' => 1,
				'f3d4' => 1,
			},
		},
		'r1bqkbnr/pppp1p1p/2n3p1/3N4/3pP3/5N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'C46k',
			# TRANSLATORS: C46k: 1. e4 e5 2. Nf3 Nc6 3. Nc3 g6 4. d4 exd4 5. Nd5
			variation => N__('Three Knights: Steinitz, Rosenthal Variation'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1p1p/2n3p1/8/3NP3/2N5/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'C46l',
			# TRANSLATORS: C46l: 1. e4 e5 2. Nf3 Nc6 3. Nc3 g6 4. d4 exd4 5. Nxd4
			variation => N__('Three Knights: Steinitz, 4. d4 exd4 5.Nxd4'),
			moves => {
				'f8g7' => 1,
			},
		},
		'r1bqk1nr/pppp1pbp/2n3p1/8/3NP3/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'C46l',
			# TRANSLATORS: C46l: 1. e4 e5 2. Nf3 Nc6 3. Nc3 g6 4. d4 exd4 5. Nxd4 Bg7
			variation => N__('Three Knights: Steinitz, 4. d4 exd4 5.Nxd4 Bg7'),
			moves => {
				'c1e3' => 1,
			},
		},
		'r1bqk1nr/pppp1pbp/2n3p1/8/3NP3/2N1B3/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'C46l',
			# TRANSLATORS: C46l: 1. e4 e5 2. Nf3 Nc6 3. Nc3 g6 4. d4 exd4 5. Nxd4 Bg7 6. Be3
			variation => N__('Three Knights: Steinitz, 4. d4 exd4 5.Nxd4 Bg7 6. Be3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r1bqk2r/pppp1pbp/2n2np1/8/3NP3/2N1B3/PPP2PPP/R2QKB1R w KQkq' => {
			eco => 'C46m',
			# TRANSLATORS: C46m: 1. e4 e5 2. Nf3 Nc6 3. Nc3 g6 4. d4 exd4 5. Nxd4 Bg7 6. Be3 Nf6
			variation => N__('Three Knights: Steinitz, 4. d4 exd4 5.Nxd4 Bg7 6. Be3 Nf6'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4p3/4P3/2N2N2/PPPP1PPP/R1BQKB1R w KQkq' => {
			eco => 'C47a',
			# TRANSLATORS: C47a: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6
			variation => N__('Four Knights Game'),
			moves => {
				'a2a3' => 1,
				'd2d4' => 1,
				'f1b5' => 1,
				'f1c4' => 1,
				'f1e2' => 1,
				'f3e5' => 1,
				'g2g3' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4N3/4P3/2N5/PPPP1PPP/R1BQKB1R b KQkq' => {
			eco => 'C47a',
			# TRANSLATORS: C47a: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Nxe5
			variation => N__('Four Knights: Halloween Gambit'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4p3/4P3/P1N2N2/1PPP1PPP/R1BQKB1R b KQkq' => {
			eco => 'C47b',
			# TRANSLATORS: C47b: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. a3
			variation => N__('Four Knights: Gunsberg Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4p3/4P3/2N2N2/PPPPBPPP/R1BQK2R b KQkq' => {
			eco => 'C47c',
			# TRANSLATORS: C47c: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Be2
			variation => N__('Four Knights: Van der Wiel Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4p3/2B1P3/2N2N2/PPPP1PPP/R1BQK2R b KQkq' => {
			eco => 'C47d',
			# TRANSLATORS: C47d: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bc4
			variation => N__('Four Knights: Italian Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4p3/4P3/2N2NP1/PPPP1P1P/R1BQKB1R b KQkq' => {
			eco => 'C47e',
			# TRANSLATORS: C47e: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. g3
			variation => N__('Four Knights: Glek Variation'),
			moves => {
				'd7d5' => 1,
				'f8c5' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2n2n2/3pp3/4P3/2N2NP1/PPPP1P1P/R1BQKB1R w KQkq' => {
			eco => 'C47f',
			# TRANSLATORS: C47f: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. g3 d5
			variation => N__('Four Knights: Glek, 4... d5'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/2b1p3/4P3/2N2NP1/PPPP1P1P/R1BQKB1R w KQkq' => {
			eco => 'C47g',
			# TRANSLATORS: C47g: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. g3 Bc5
			variation => N__('Four Knights: Glek, 4... Bc5'),
			moves => {
				'f1g2' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/2b1p3/4P3/2N2NP1/PPPP1PBP/R1BQK2R b KQkq' => {
			eco => 'C47g',
			# TRANSLATORS: C47g: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. g3 Bc5 5. Bg2
			variation => N__('Four Knights: Glek, 4... Bc5'),
			moves => {
				'd7d6' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2np1n2/2b1p3/4P3/2N2NP1/PPPP1PBP/R1BQK2R w KQkq' => {
			eco => 'C47g',
			# TRANSLATORS: C47g: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. g3 Bc5 5. Bg2 d6
			variation => N__('Four Knights: Glek, 4... Bc5'),
			moves => {
				'd2d3' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2np1n2/2b1p3/4P3/2NP1NP1/PPP2PBP/R1BQK2R b KQkq' => {
			eco => 'C47g',
			# TRANSLATORS: C47g: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. g3 Bc5 5. Bg2 d6 6. d3
			variation => N__('Four Knights: Glek, 4... Bc5'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r1bqk2r/1pp2ppp/p1np1n2/2b1p3/4P3/2NP1NP1/PPP2PBP/R1BQK2R w KQkq' => {
			eco => 'C47h',
			# TRANSLATORS: C47h: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. g3 Bc5 5. Bg2 d6 6. d3 a6
			variation => N__('Four Knights: Glek, Main Line'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4p3/3PP3/2N2N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'C47i',
			# TRANSLATORS: C47i: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. d4
			variation => N__('Four Knights: Scotch Variation'),
			moves => {
				'd7d6' => 1,
				'e5d4' => 1,
				'f8b4' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2np1n2/4p3/3PP3/2N2N2/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'C47i',
			# TRANSLATORS: C47i: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. d4 d6
			variation => N__('Four Knights: Scotch, 4... d6'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/4p3/1b1PP3/2N2N2/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'C47j',
			# TRANSLATORS: C47j: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. d4 Bb4
			variation => N__('Four Knights: Scotch, Bogoljubow'),
			moves => {
				'd4d5' => 1,
				'f3e5' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/3Pp3/1b2P3/2N2N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'C47j',
			# TRANSLATORS: C47j: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. d4 Bb4 5. d5
			variation => N__('Four Knights: Scotch, Bogoljubow, 5. d5'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/4N3/1b1PP3/2N5/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'C47k',
			# TRANSLATORS: C47k: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. d4 Bb4 5. Nxe5
			variation => N__('Four Knights: Scotch, Krause Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/8/3pP3/2N2N2/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'C47l',
			# TRANSLATORS: C47l: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. d4 exd4
			variation => N__('Four Knights: Scotch, 4...exd4'),
			moves => {
				'c3d5' => 1,
				'f3d4' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/3N4/3pP3/5N2/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'C47l',
			# TRANSLATORS: C47l: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. d4 exd4 5. Nd5
			variation => N__('Four Knights: Belgrade Gambit'),
			moves => {
				'c6b4' => 1,
				'f6d5' => 1,
				'f6e4' => 1,
				'f8e7' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/5n2/3N4/1n1pP3/5N2/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'C47l',
			# TRANSLATORS: C47l: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. d4 exd4 5. Nd5 Nb4
			variation => N__('Four Knights: Belgrade Gambit, 5... Nb4'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n5/3n4/3pP3/5N2/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'C47l',
			# TRANSLATORS: C47l: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. d4 exd4 5. Nd5 Nxd5
			variation => N__('Four Knights: Belgrade Gambit, 5...Nxd5'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n5/3N4/3pn3/5N2/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'C47m',
			# TRANSLATORS: C47m: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. d4 exd4 5. Nd5 Nxe4
			variation => N__('Four Knights: Belgrade Gambit, 5...Nxe4'),
			moves => {
				'd1e2' => 1,
				'f1c4' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n5/3N4/3pn3/5N2/PPP1QPPP/R1B1KB1R b KQkq' => {
			eco => 'C47m',
			# TRANSLATORS: C47m: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. d4 exd4 5. Nd5 Nxe4 6. Qe2
			variation => N__('Four Knights: Belgrade Gambit, 5...Nxe4 6. Qe2 (Old Line)'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n5/3N4/2Bpn3/5N2/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'C47m',
			# TRANSLATORS: C47m: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. d4 exd4 5. Nd5 Nxe4 6. Bc4
			variation => N__('Four Knights: Belgrade Gambit, 5...Nxe4 6. Bc4 (Modern Line)'),
			moves => {
			},
		},
		'r1bqk2r/ppppbppp/2n2n2/3N4/3pP3/5N2/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'C47n',
			# TRANSLATORS: C47n: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. d4 exd4 5. Nd5 Be7
			variation => N__('Four Knights: Belgrade Gambit, 5... Be7'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/8/3NP3/2N5/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'C47o',
			# TRANSLATORS: C47o: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. d4 exd4 5. Nxd4
			variation => N__('Four Knights: Scotch, 4...exd4 5.Nxd4'),
			moves => {
				'd7d6' => 1,
				'f8b4' => 1,
				'f8c5' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2np1n2/8/3NP3/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'C47p',
			# TRANSLATORS: C47p: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. d4 exd4 5. Nxd4 d6
			variation => N__('Four Knights: Scotch, 4...exd4 5.Nxd4 d6'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/2b5/3NP3/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'C47q',
			# TRANSLATORS: C47q: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. d4 exd4 5. Nxd4 Bc5
			variation => N__('Four Knights: Scotch, 4...exd4 5.Nxd4 Bc5'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/8/1b1NP3/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'C47r',
			# TRANSLATORS: C47r: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. d4 exd4 5. Nxd4 Bb4
			variation => N__('Four Knights: Scotch, 4...exd4 5.Nxd4 Bb4'),
			moves => {
				'd4c6' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2N2n2/8/1b2P3/2N5/PPP2PPP/R1BQKB1R b KQkq' => {
			eco => 'C47r',
			# TRANSLATORS: C47r: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. d4 exd4 5. Nxd4 Bb4 6. Nxc6
			variation => N__('Four Knights: Scotch, 4...exd4 5.Nxd4 Bb4'),
			moves => {
				'b7c6' => 1,
			},
		},
		'r1bqk2r/p1pp1ppp/2p2n2/8/1b2P3/2N5/PPP2PPP/R1BQKB1R w KQkq' => {
			eco => 'C47s',
			# TRANSLATORS: C47s: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. d4 exd4 5. Nxd4 Bb4 6. Nxc6 bxc6
			variation => N__('Four Knights: Scotch, 4...exd4 5.Nxd4 Bb4 6.Nxc6 bxc6'),
			moves => {
				'f1d3' => 1,
			},
		},
		'r1bqk2r/p1pp1ppp/2p2n2/8/1b2P3/2NB4/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'C47s',
			# TRANSLATORS: C47s: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. d4 exd4 5. Nxd4 Bb4 6. Nxc6 bxc6 7. Bd3
			variation => N__('Four Knights: Scotch, Main Line'),
			moves => {
				'd7d5' => 1,
			},
		},
		'r1bqk2r/p1p2ppp/2p2n2/3p4/1b2P3/2NB4/PPP2PPP/R1BQK2R w KQkq' => {
			eco => 'C47t',
			# TRANSLATORS: C47t: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. d4 exd4 5. Nxd4 Bb4 6. Nxc6 bxc6 7. Bd3 d5
			variation => N__('Four Knights: Scotch, Main Line, 7... d5'),
			moves => {
				'e4d5' => 1,
			},
		},
		'r1bqk2r/p1p2ppp/2p2n2/3P4/1b6/2NB4/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'C47t',
			# TRANSLATORS: C47t: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. d4 exd4 5. Nxd4 Bb4 6. Nxc6 bxc6 7. Bd3 d5 8. exd5
			variation => N__('Four Knights: Scotch, Main Line, 7... d5'),
			moves => {
				'c6d5' => 1,
			},
		},
		'r1bqk2r/p1p2ppp/5n2/3p4/1b6/2NB4/PPP2PPP/R1BQK2R w KQkq' => {
			eco => 'C47t',
			# TRANSLATORS: C47t: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. d4 exd4 5. Nxd4 Bb4 6. Nxc6 bxc6 7. Bd3 d5 8. exd5 cxd5
			variation => N__('Four Knights: Scotch, Main Line, 7... d5 8.exd5 cxd5'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqk2r/p1p2ppp/5n2/3p4/1b6/2NB4/PPP2PPP/R1BQ1RK1 b kq' => {
			eco => 'C47t',
			# TRANSLATORS: C47t: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. d4 exd4 5. Nxd4 Bb4 6. Nxc6 bxc6 7. Bd3 d5 8. exd5 cxd5 9. O-O
			variation => N__('Four Knights: Scotch, Main Line, 7... d5 8.exd5 cxd5'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/p1p2ppp/5n2/3p4/1b6/2NB4/PPP2PPP/R1BQ1RK1 w -' => {
			eco => 'C47u',
			# TRANSLATORS: C47u: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. d4 exd4 5. Nxd4 Bb4 6. Nxc6 bxc6 7. Bd3 d5 8. exd5 cxd5 9. O-O O-O
			variation => N__('Four Knights: Scotch, Main Line, 8.exd5 cxd5 9.O-O O-O'),
			moves => {
				'c1g5' => 1,
			},
		},
		'r1bq1rk1/p1p2ppp/5n2/3p2B1/1b6/2NB4/PPP2PPP/R2Q1RK1 b -' => {
			eco => 'C47u',
			# TRANSLATORS: C47u: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. d4 exd4 5. Nxd4 Bb4 6. Nxc6 bxc6 7. Bd3 d5 8. exd5 cxd5 9. O-O O-O 10. Bg5
			variation => N__('Four Knights: Scotch, Main Line, 8.exd5 cxd5 9.O-O O-O'),
			moves => {
				'c7c6' => 1,
			},
		},
		'r1bq1rk1/p4ppp/2p2n2/3p2B1/1b6/2NB4/PPP2PPP/R2Q1RK1 w -' => {
			eco => 'C47v',
			# TRANSLATORS: C47v: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. d4 exd4 5. Nxd4 Bb4 6. Nxc6 bxc6 7. Bd3 d5 8. exd5 cxd5 9. O-O O-O 10. Bg5 c6
			variation => N__('Four Knights: Scotch, Main Line, 9.O-O O-O 10. Bg5 c6'),
			moves => {
				'c3a4' => 1,
				'd1f3' => 1,
			},
		},
		'r1bq1rk1/p4ppp/2p2n2/3p2B1/Nb6/3B4/PPP2PPP/R2Q1RK1 b -' => {
			eco => 'C47w',
			# TRANSLATORS: C47w: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. d4 exd4 5. Nxd4 Bb4 6. Nxc6 bxc6 7. Bd3 d5 8. exd5 cxd5 9. O-O O-O 10. Bg5 c6 11. Na4
			variation => N__('Four Knights: Scotch, Main Line, 10. Bg5 c6 11. Na4'),
			moves => {
			},
		},
		'r1bq1rk1/p4ppp/2p2n2/3p2B1/1b6/2NB1Q2/PPP2PPP/R4RK1 b -' => {
			eco => 'C47x',
			# TRANSLATORS: C47x: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. d4 exd4 5. Nxd4 Bb4 6. Nxc6 bxc6 7. Bd3 d5 8. exd5 cxd5 9. O-O O-O 10. Bg5 c6 11. Qf3
			variation => N__('Four Knights: Scotch, Main Line, 10. Bg5 c6 11. Qf3'),
			moves => {
				'b4e7' => 1,
			},
		},
		'r1bq1rk1/p3bppp/2p2n2/3p2B1/8/2NB1Q2/PPP2PPP/R4RK1 w -' => {
			eco => 'C47y',
			# TRANSLATORS: C47y: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. d4 exd4 5. Nxd4 Bb4 6. Nxc6 bxc6 7. Bd3 d5 8. exd5 cxd5 9. O-O O-O 10. Bg5 c6 11. Qf3 Be7
			variation => N__('Four Knights: Scotch, Main Line, 10. Bg5 c6 11. Qf3 Be7'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/1B2p3/4P3/2N2N2/PPPP1PPP/R1BQK2R b KQkq' => {
			eco => 'C48a',
			# TRANSLATORS: C48a: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5
			variation => N__('Four Knights: Spanish Variation'),
			moves => {
				'a7a6' => 1,
				'c6d4' => 1,
				'd7d6' => 1,
				'f8b4' => 1,
				'f8c5' => 1,
			},
		},
		'r1bqkb1r/1ppp1ppp/p1n2n2/1B2p3/4P3/2N2N2/PPPP1PPP/R1BQK2R w KQkq' => {
			eco => 'C48a',
			# TRANSLATORS: C48a: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 a6
			variation => N__('Four Knights: Spanish Variation'),
			moves => {
				'b5c6' => 1,
			},
		},
		'r1bqkb1r/1ppp1ppp/p1B2n2/4p3/4P3/2N2N2/PPPP1PPP/R1BQK2R b KQkq' => {
			eco => 'C48a',
			# TRANSLATORS: C48a: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 a6 5. Bxc6
			variation => N__('Four Knights: Spanish, Ranken Variation'),
			moves => {
				'd7c6' => 1,
			},
		},
		'r1bqkb1r/1pp2ppp/p1p2n2/4p3/4P3/2N2N2/PPPP1PPP/R1BQK2R w KQkq' => {
			eco => 'C48a',
			# TRANSLATORS: C48a: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 a6 5. Bxc6 dxc6
			variation => N__('Four Knights: Spanish, Ranken Variation'),
			moves => {
				'f3e5' => 1,
			},
		},
		'r1bqkb1r/1pp2ppp/p1p2n2/4N3/4P3/2N5/PPPP1PPP/R1BQK2R b KQkq' => {
			eco => 'C48a',
			# TRANSLATORS: C48a: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 a6 5. Bxc6 dxc6 6. Nxe5
			variation => N__('Four Knights: Spanish, Ranken Variation'),
			moves => {
				'f6e4' => 1,
			},
		},
		'r1bqkb1r/1pp2ppp/p1p5/4N3/4n3/2N5/PPPP1PPP/R1BQK2R w KQkq' => {
			eco => 'C48a',
			# TRANSLATORS: C48a: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 a6 5. Bxc6 dxc6 6. Nxe5 Nxe4
			variation => N__('Four Knights: Spanish, Ranken Variation'),
			moves => {
				'c3e4' => 1,
			},
		},
		'r1bqkb1r/1pp2ppp/p1p5/4N3/4N3/8/PPPP1PPP/R1BQK2R b KQkq' => {
			eco => 'C48a',
			# TRANSLATORS: C48a: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 a6 5. Bxc6 dxc6 6. Nxe5 Nxe4 7. Nxe4
			variation => N__('Four Knights: Spanish, Ranken Variation'),
			moves => {
				'd8d4' => 1,
			},
		},
		'r1b1kb1r/1pp2ppp/p1p5/4N3/3qN3/8/PPPP1PPP/R1BQK2R w KQkq' => {
			eco => 'C48a',
			# TRANSLATORS: C48a: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 a6 5. Bxc6 dxc6 6. Nxe5 Nxe4 7. Nxe4 Qd4
			variation => N__('Four Knights: Spanish, Ranken Variation'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1b1kb1r/1pp2ppp/p1p5/4N3/3qN3/8/PPPP1PPP/R1BQ1RK1 b kq' => {
			eco => 'C48a',
			# TRANSLATORS: C48a: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 a6 5. Bxc6 dxc6 6. Nxe5 Nxe4 7. Nxe4 Qd4 8. O-O
			variation => N__('Four Knights: Spanish, Ranken Variation'),
			moves => {
				'd4e5' => 1,
			},
		},
		'r1b1kb1r/1pp2ppp/p1p5/4q3/4N3/8/PPPP1PPP/R1BQ1RK1 w kq' => {
			eco => 'C48a',
			# TRANSLATORS: C48a: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 a6 5. Bxc6 dxc6 6. Nxe5 Nxe4 7. Nxe4 Qd4 8. O-O Qxe5
			variation => N__('Four Knights: Spanish, Ranken Variation'),
			moves => {
				'f1e1' => 1,
			},
		},
		'r1b1kb1r/1pp2ppp/p1p5/4q3/4N3/8/PPPP1PPP/R1BQR1K1 b kq' => {
			eco => 'C48a',
			# TRANSLATORS: C48a: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 a6 5. Bxc6 dxc6 6. Nxe5 Nxe4 7. Nxe4 Qd4 8. O-O Qxe5 9. Re1
			variation => N__('Four Knights: Spanish, Ranken Variation'),
			moves => {
				'c8e6' => 1,
			},
		},
		'r3kb1r/1pp2ppp/p1p1b3/4q3/4N3/8/PPPP1PPP/R1BQR1K1 w kq' => {
			eco => 'C48a',
			# TRANSLATORS: C48a: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 a6 5. Bxc6 dxc6 6. Nxe5 Nxe4 7. Nxe4 Qd4 8. O-O Qxe5 9. Re1 Be6
			variation => N__('Four Knights: Spanish, Ranken Variation'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r3kb1r/1pp2ppp/p1p1b3/4q3/3PN3/8/PPP2PPP/R1BQR1K1 b kq' => {
			eco => 'C48a',
			# TRANSLATORS: C48a: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 a6 5. Bxc6 dxc6 6. Nxe5 Nxe4 7. Nxe4 Qd4 8. O-O Qxe5 9. Re1 Be6 10. d4
			variation => N__('Four Knights: Spanish, Ranken Variation'),
			moves => {
				'e5d5' => 1,
			},
		},
		'r3kb1r/1pp2ppp/p1p1b3/3q4/3PN3/8/PPP2PPP/R1BQR1K1 w kq' => {
			eco => 'C48a',
			# TRANSLATORS: C48a: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 a6 5. Bxc6 dxc6 6. Nxe5 Nxe4 7. Nxe4 Qd4 8. O-O Qxe5 9. Re1 Be6 10. d4 Qd5
			variation => N__('Four Knights: Spanish, Spielmann Variation'),
			moves => {
			},
		},
		'r1bqkb1r/ppp2ppp/2np1n2/1B2p3/4P3/2N2N2/PPPP1PPP/R1BQK2R w KQkq' => {
			eco => 'C48b',
			# TRANSLATORS: C48b: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 d6
			variation => N__('Four Knights: Spanish, 4... d6'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2np1n2/1B2p3/3PP3/2N2N2/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'C48c',
			# TRANSLATORS: C48c: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 d6 5. d4
			variation => N__('Four Knights: Spanish, 4... d6 5. d4'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/1Bb1p3/4P3/2N2N2/PPPP1PPP/R1BQK2R w KQkq' => {
			eco => 'C48d',
			# TRANSLATORS: C48d: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bc5
			variation => N__('Four Knights: Spanish, Classical Defence'),
			moves => {
				'e1g1' => 1,
				'f3e5' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/1Bb1N3/4P3/2N5/PPPP1PPP/R1BQK2R b KQkq' => {
			eco => 'C48e',
			# TRANSLATORS: C48e: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bc5 5. Nxe5
			variation => N__('Four Knights: Spanish, Classical Defence, 5.Nxe5'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/1Bb1p3/4P3/2N2N2/PPPP1PPP/R1BQ1RK1 b kq' => {
			eco => 'C48f',
			# TRANSLATORS: C48f: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bc5 5. O-O
			variation => N__('Four Knights: Spanish, Classical Defence, 5.O-O'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pppp1ppp/2n2n2/1Bb1p3/4P3/2N2N2/PPPP1PPP/R1BQ1RK1 w -' => {
			eco => 'C48f',
			# TRANSLATORS: C48f: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bc5 5. O-O O-O
			variation => N__('Four Knights: Spanish, Classical Defence, 5.O-O'),
			moves => {
				'f3e5' => 1,
			},
		},
		'r1bq1rk1/pppp1ppp/2n2n2/1Bb1N3/4P3/2N5/PPPP1PPP/R1BQ1RK1 b -' => {
			eco => 'C48f',
			# TRANSLATORS: C48f: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bc5 5. O-O O-O 6. Nxe5
			variation => N__('Four Knights: Spanish, Classical Defence, 5.O-O'),
			moves => {
				'c6d4' => 1,
				'c6e5' => 1,
			},
		},
		'r1bq1rk1/pppp1ppp/5n2/1Bb1N3/3nP3/2N5/PPPP1PPP/R1BQ1RK1 w -' => {
			eco => 'C48f',
			# TRANSLATORS: C48f: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bc5 5. O-O O-O 6. Nxe5 Nd4
			variation => N__('Four Knights: Spanish, Classical, Marshall Variation'),
			moves => {
			},
		},
		'r1bq1rk1/pppp1ppp/5n2/1Bb1n3/4P3/2N5/PPPP1PPP/R1BQ1RK1 w -' => {
			eco => 'C48f',
			# TRANSLATORS: C48f: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bc5 5. O-O O-O 6. Nxe5 Nxe5
			variation => N__('Four Knights: Spanish, Classical Defence, 5.O-O'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bq1rk1/pppp1ppp/5n2/1Bb1n3/3PP3/2N5/PPP2PPP/R1BQ1RK1 b -' => {
			eco => 'C48f',
			# TRANSLATORS: C48f: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bc5 5. O-O O-O 6. Nxe5 Nxe5 7. d4
			variation => N__('Four Knights: Spanish, Classical Defence, 5.O-O'),
			moves => {
				'c5d6' => 1,
			},
		},
		'r1bq1rk1/pppp1ppp/3b1n2/1B2n3/3PP3/2N5/PPP2PPP/R1BQ1RK1 w -' => {
			eco => 'C48f',
			# TRANSLATORS: C48f: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bc5 5. O-O O-O 6. Nxe5 Nxe5 7. d4 Bd6
			variation => N__('Four Knights: Spanish, Classical Defence, 5.O-O'),
			moves => {
				'f2f4' => 1,
			},
		},
		'r1bq1rk1/pppp1ppp/3b1n2/1B2n3/3PPP2/2N5/PPP3PP/R1BQ1RK1 b -' => {
			eco => 'C48f',
			# TRANSLATORS: C48f: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bc5 5. O-O O-O 6. Nxe5 Nxe5 7. d4 Bd6 8. f4
			variation => N__('Four Knights: Spanish, Classical Defence, 5.O-O'),
			moves => {
				'e5c6' => 1,
			},
		},
		'r1bq1rk1/pppp1ppp/2nb1n2/1B6/3PPP2/2N5/PPP3PP/R1BQ1RK1 w -' => {
			eco => 'C48f',
			# TRANSLATORS: C48f: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bc5 5. O-O O-O 6. Nxe5 Nxe5 7. d4 Bd6 8. f4 Nc6
			variation => N__('Four Knights: Spanish, Classical Defence, 5.O-O'),
			moves => {
				'e4e5' => 1,
			},
		},
		'r1bq1rk1/pppp1ppp/2nb1n2/1B2P3/3P1P2/2N5/PPP3PP/R1BQ1RK1 b -' => {
			eco => 'C48f',
			# TRANSLATORS: C48f: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bc5 5. O-O O-O 6. Nxe5 Nxe5 7. d4 Bd6 8. f4 Nc6 9. e5
			variation => N__('Four Knights: Spanish, Classical Defence, 5.O-O'),
			moves => {
				'd6b4' => 1,
			},
		},
		'r1bq1rk1/pppp1ppp/2n2n2/1B2P3/1b1P1P2/2N5/PPP3PP/R1BQ1RK1 w -' => {
			eco => 'C48f',
			# TRANSLATORS: C48f: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bc5 5. O-O O-O 6. Nxe5 Nxe5 7. d4 Bd6 8. f4 Nc6 9. e5 Bb4
			variation => N__('Four Knights: Spanish, Classical, Bardeleben Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/5n2/1B2p3/3nP3/2N2N2/PPPP1PPP/R1BQK2R w KQkq' => {
			eco => 'C48g',
			# TRANSLATORS: C48g: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Nd4
			variation => N__('Four Knights: Rubinstein Countergambit'),
			moves => {
				'b5a4' => 1,
				'b5c4' => 1,
				'b5e2' => 1,
				'e1g1' => 1,
				'f3d4' => 1,
				'f3e5' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/5n2/4p3/3nP3/2N2N2/PPPPBPPP/R1BQK2R b KQkq' => {
			eco => 'C48g',
			# TRANSLATORS: C48g: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Nd4 5. Be2
			variation => N__('Four Knights: Rubinstein, 5. Be2'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/5n2/1B2N3/3nP3/2N5/PPPP1PPP/R1BQK2R b KQkq' => {
			eco => 'C48h',
			# TRANSLATORS: C48h: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Nd4 5. Nxe5
			variation => N__('Four Knights: Rubinstein, 5.Nxe5'),
			moves => {
				'd8e7' => 1,
			},
		},
		'r1b1kb1r/ppppqppp/5n2/1B2N3/3nP3/2N5/PPPP1PPP/R1BQK2R w KQkq' => {
			eco => 'C48h',
			# TRANSLATORS: C48h: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Nd4 5. Nxe5 Qe7
			variation => N__('Four Knights: Rubinstein, 5.Nxe5'),
			moves => {
				'f2f4' => 1,
			},
		},
		'r1b1kb1r/ppppqppp/5n2/1B2N3/3nPP2/2N5/PPPP2PP/R1BQK2R b KQkq' => {
			eco => 'C48h',
			# TRANSLATORS: C48h: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Nd4 5. Nxe5 Qe7 6. f4
			variation => N__('Four Knights: Rubinstein, Bogoljubow Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/5n2/1B2p3/3nP3/2N2N2/PPPP1PPP/R1BQ1RK1 b kq' => {
			eco => 'C48i',
			# TRANSLATORS: C48i: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Nd4 5. O-O
			variation => N__('Four Knights: Rubinstein, Henneberger Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/5n2/4p3/2BnP3/2N2N2/PPPP1PPP/R1BQK2R b KQkq' => {
			eco => 'C48j',
			# TRANSLATORS: C48j: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Nd4 5. Bc4
			variation => N__('Four Knights: Rubinstein, 5. Bc4'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/5n2/1B2p3/3NP3/2N5/PPPP1PPP/R1BQK2R b KQkq' => {
			eco => 'C48k',
			# TRANSLATORS: C48k: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Nd4 5. Nxd4
			variation => N__('Four Knights: Rubinstein, Exchange Variation'),
			moves => {
				'e5d4' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/5n2/1B6/3pP3/2N5/PPPP1PPP/R1BQK2R w KQkq' => {
			eco => 'C48k',
			# TRANSLATORS: C48k: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Nd4 5. Nxd4 exd4
			variation => N__('Four Knights: Rubinstein, Exchange Variation'),
			moves => {
				'e4e5' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/5n2/1B2P3/3p4/2N5/PPPP1PPP/R1BQK2R b KQkq' => {
			eco => 'C48k',
			# TRANSLATORS: C48k: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Nd4 5. Nxd4 exd4 6. e5
			variation => N__('Four Knights: Rubinstein, Exchange Variation'),
			moves => {
				'd4c3' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/5n2/1B2P3/8/2p5/PPPP1PPP/R1BQK2R w KQkq' => {
			eco => 'C48k',
			# TRANSLATORS: C48k: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Nd4 5. Nxd4 exd4 6. e5 dxc3
			variation => N__('Four Knights: Rubinstein, Exchange Variation'),
			moves => {
				'e5f6' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/5P2/1B6/8/2p5/PPPP1PPP/R1BQK2R b KQkq' => {
			eco => 'C48k',
			# TRANSLATORS: C48k: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Nd4 5. Nxd4 exd4 6. e5 dxc3 7. exf6
			variation => N__('Four Knights: Rubinstein, Exchange Variation'),
			moves => {
				'd8f6' => 1,
			},
		},
		'r1b1kb1r/pppp1ppp/5q2/1B6/8/2p5/PPPP1PPP/R1BQK2R w KQkq' => {
			eco => 'C48k',
			# TRANSLATORS: C48k: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Nd4 5. Nxd4 exd4 6. e5 dxc3 7. exf6 Qxf6
			variation => N__('Four Knights: Rubinstein, Exchange Variation'),
			moves => {
				'd2c3' => 1,
			},
		},
		'r1b1kb1r/pppp1ppp/5q2/1B6/8/2P5/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'C48k',
			# TRANSLATORS: C48k: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Nd4 5. Nxd4 exd4 6. e5 dxc3 7. exf6 Qxf6 8. dxc3
			variation => N__('Four Knights: Rubinstein, Exchange Variation'),
			moves => {
				'f6e5' => 1,
				'f8c5' => 1,
			},
		},
		'r1b1k2r/pppp1ppp/5q2/1Bb5/8/2P5/PPP2PPP/R1BQK2R w KQkq' => {
			eco => 'C48l',
			# TRANSLATORS: C48l: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Nd4 5. Nxd4 exd4 6. e5 dxc3 7. exf6 Qxf6 8. dxc3 Bc5
			variation => N__('Four Knights: Rubinstein, Exchange Variation, 8... Bc5'),
			moves => {
			},
		},
		'r1b1kb1r/pppp1ppp/8/1B2q3/8/2P5/PPP2PPP/R1BQK2R w KQkq' => {
			eco => 'C48m',
			# TRANSLATORS: C48m: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Nd4 5. Nxd4 exd4 6. e5 dxc3 7. exf6 Qxf6 8. dxc3 Qe5+
			variation => N__('Four Knights: Rubinstein, Exchange Variation, 8... Qe5+'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/5n2/4p3/B2nP3/2N2N2/PPPP1PPP/R1BQK2R b KQkq' => {
			eco => 'C48n',
			# TRANSLATORS: C48n: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Nd4 5. Ba4
			variation => N__('Four Knights: Rubinstein, 5. Ba4'),
			moves => {
				'c7c6' => 1,
				'd4f3' => 1,
				'f8c5' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/5n2/4p3/B3P3/2N2n2/PPPP1PPP/R1BQK2R w KQkq' => {
			eco => 'C48n',
			# TRANSLATORS: C48n: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Nd4 5. Ba4 Nxf3+
			variation => N__('Four Knights: Rubinstein, 5. Ba4 Nxf3+'),
			moves => {
			},
		},
		'r1bqkb1r/pp1p1ppp/2p2n2/4p3/B2nP3/2N2N2/PPPP1PPP/R1BQK2R w KQkq' => {
			eco => 'C48o',
			# TRANSLATORS: C48o: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Nd4 5. Ba4 c6
			variation => N__('Four Knights: Rubinstein, 5. Ba4 c6'),
			moves => {
				'f3e5' => 1,
			},
		},
		'r1bqkb1r/pp1p1ppp/2p2n2/4N3/B2nP3/2N5/PPPP1PPP/R1BQK2R b KQkq' => {
			eco => 'C48p',
			# TRANSLATORS: C48p: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Nd4 5. Ba4 c6 6. Nxe5
			variation => N__('Four Knights: Rubinstein, 5. Ba4 c6 6.Nxe5'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/5n2/2b1p3/B2nP3/2N2N2/PPPP1PPP/R1BQK2R w KQkq' => {
			eco => 'C48q',
			# TRANSLATORS: C48q: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Nd4 5. Ba4 Bc5
			variation => N__('Four Knights: Rubinstein, 5. Ba4 Bc5'),
			moves => {
				'f3e5' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/5n2/2b1N3/B2nP3/2N5/PPPP1PPP/R1BQK2R b KQkq' => {
			eco => 'C48r',
			# TRANSLATORS: C48r: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Nd4 5. Ba4 Bc5 6. Nxe5
			variation => N__('Four Knights: Rubinstein, 5. Ba4 Bc5 6.Nxe5'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/1B2p3/1b2P3/2N2N2/PPPP1PPP/R1BQK2R w KQkq' => {
			eco => 'C49a',
			# TRANSLATORS: C49a: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4
			variation => N__('Four Knights: 4. Bb5 Bb4'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/1B2p3/1b2P3/2N2N2/PPPP1PPP/R1BQ1RK1 b kq' => {
			eco => 'C49b',
			# TRANSLATORS: C49b: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O
			variation => N__('Four Knights: 4. Bb5 Bb4 5.O-O'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pppp1ppp/2n2n2/1B2p3/1b2P3/2N2N2/PPPP1PPP/R1BQ1RK1 w -' => {
			eco => 'C49c',
			# TRANSLATORS: C49c: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O O-O
			variation => N__('Four Knights: 4. Bb5 Bb4 5.O-O O-O'),
			moves => {
				'b5c6' => 1,
				'c3d5' => 1,
				'd2d3' => 1,
			},
		},
		'r1bq1rk1/pppp1ppp/2n2n2/1B1Np3/1b2P3/5N2/PPPP1PPP/R1BQ1RK1 b -' => {
			eco => 'C49c',
			# TRANSLATORS: C49c: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O O-O 6. Nd5
			variation => N__('Four Knights: 4. Bb5 Bb4 5.O-O O-O'),
			moves => {
				'f6d5' => 1,
			},
		},
		'r1bq1rk1/pppp1ppp/2n5/1B1np3/1b2P3/5N2/PPPP1PPP/R1BQ1RK1 w -' => {
			eco => 'C49c',
			# TRANSLATORS: C49c: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O O-O 6. Nd5 Nxd5
			variation => N__('Four Knights: 4. Bb5 Bb4 5.O-O O-O'),
			moves => {
				'e4d5' => 1,
			},
		},
		'r1bq1rk1/pppp1ppp/2n5/1B1Pp3/1b6/5N2/PPPP1PPP/R1BQ1RK1 b -' => {
			eco => 'C49c',
			# TRANSLATORS: C49c: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O O-O 6. Nd5 Nxd5 7. exd5
			variation => N__('Four Knights: 4. Bb5 Bb4 5.O-O O-O'),
			moves => {
				'e5e4' => 1,
			},
		},
		'r1bq1rk1/pppp1ppp/2n5/1B1P4/1b2p3/5N2/PPPP1PPP/R1BQ1RK1 w -' => {
			eco => 'C49c',
			# TRANSLATORS: C49c: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O O-O 6. Nd5 Nxd5 7. exd5 e4
			variation => N__('Four Knights: Gunsberg Variation'),
			moves => {
			},
		},
		'r1bq1rk1/pppp1ppp/2B2n2/4p3/1b2P3/2N2N2/PPPP1PPP/R1BQ1RK1 b -' => {
			eco => 'C49d',
			# TRANSLATORS: C49d: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O O-O 6. Bxc6
			variation => N__('Four Knights: Nimzowitsch (Paulsen) Variation'),
			moves => {
			},
		},
		'r1bq1rk1/pppp1ppp/2n2n2/1B2p3/1b2P3/2NP1N2/PPP2PPP/R1BQ1RK1 b -' => {
			eco => 'C49e',
			# TRANSLATORS: C49e: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O O-O 6. d3
			variation => N__('Four Knights: Double Bishops, 6. d3'),
			moves => {
				'b4c3' => 1,
				'd7d6' => 1,
			},
		},
		'r1bq1rk1/pppp1ppp/2n2n2/1B2p3/4P3/2bP1N2/PPP2PPP/R1BQ1RK1 w -' => {
			eco => 'C49f',
			# TRANSLATORS: C49f: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O O-O 6. d3 Bxc3
			variation => N__('Four Knights: Double Bishops, 6. d3 Bxc3'),
			moves => {
				'b2c3' => 1,
			},
		},
		'r1bq1rk1/pppp1ppp/2n2n2/1B2p3/4P3/2PP1N2/P1P2PPP/R1BQ1RK1 b -' => {
			eco => 'C49f',
			# TRANSLATORS: C49f: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O O-O 6. d3 Bxc3 7. bxc3
			variation => N__('Four Knights: Double Bishops, 6. d3 Bxc3'),
			moves => {
				'd7d5' => 1,
				'd7d6' => 1,
			},
		},
		'r1bq1rk1/ppp2ppp/2n2n2/1B1pp3/4P3/2PP1N2/P1P2PPP/R1BQ1RK1 w -' => {
			eco => 'C49f',
			# TRANSLATORS: C49f: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O O-O 6. d3 Bxc3 7. bxc3 d5
			variation => N__('Four Knights: Svenonius Variation'),
			moves => {
			},
		},
		'r1bq1rk1/ppp2ppp/2np1n2/1B2p3/4P3/2PP1N2/P1P2PPP/R1BQ1RK1 w -' => {
			eco => 'C49f',
			# TRANSLATORS: C49f: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O O-O 6. d3 Bxc3 7. bxc3 d6
			variation => N__('Four Knights: Double Bishops, 6. d3 Bxc3'),
			moves => {
				'f1e1' => 1,
			},
		},
		'r1bq1rk1/ppp2ppp/2np1n2/1B2p3/4P3/2PP1N2/P1P2PPP/R1BQR1K1 b -' => {
			eco => 'C49f',
			# TRANSLATORS: C49f: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O O-O 6. d3 Bxc3 7. bxc3 d6 8. Re1
			variation => N__('Four Knights: Janowski Variation'),
			moves => {
			},
		},
		'r1bq1rk1/ppp2ppp/2np1n2/1B2p3/1b2P3/2NP1N2/PPP2PPP/R1BQ1RK1 w -' => {
			eco => 'C49g',
			# TRANSLATORS: C49g: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O O-O 6. d3 d6
			variation => N__('Four Knights: Symmetrical Variation'),
			moves => {
				'c1g5' => 1,
				'c3e2' => 1,
			},
		},
		'r1bq1rk1/ppp2ppp/2np1n2/1B2p3/1b2P3/3P1N2/PPP1NPPP/R1BQ1RK1 b -' => {
			eco => 'C49h',
			# TRANSLATORS: C49h: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O O-O 6. d3 d6 7. Ne2
			variation => N__('Four Knights: Symmetrical, Maroczy System'),
			moves => {
			},
		},
		'r1bq1rk1/ppp2ppp/2np1n2/1B2p1B1/1b2P3/2NP1N2/PPP2PPP/R2Q1RK1 b -' => {
			eco => 'C49i',
			# TRANSLATORS: C49i: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O O-O 6. d3 d6 7. Bg5
			variation => N__('Four Knights: Symmetrical, 7. Bg5'),
			moves => {
				'b4c3' => 1,
				'c6e7' => 1,
				'c8e6' => 1,
			},
		},
		'r2q1rk1/ppp2ppp/2npbn2/1B2p1B1/1b2P3/2NP1N2/PPP2PPP/R2Q1RK1 w -' => {
			eco => 'C49j',
			# TRANSLATORS: C49j: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O O-O 6. d3 d6 7. Bg5 Be6
			variation => N__('Four Knights: Symmetrical, Tarrasch Variation'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1nppp/3p1n2/1B2p1B1/1b2P3/2NP1N2/PPP2PPP/R2Q1RK1 w -' => {
			eco => 'C49k',
			# TRANSLATORS: C49k: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O O-O 6. d3 d6 7. Bg5 Ne7
			variation => N__('Four Knights: Symmetrical, Pillsbury Variation'),
			moves => {
				'f3h4' => 1,
			},
		},
		'r1bq1rk1/ppp1nppp/3p1n2/1B2p1B1/1b2P2N/2NP4/PPP2PPP/R2Q1RK1 b -' => {
			eco => 'C49k',
			# TRANSLATORS: C49k: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O O-O 6. d3 d6 7. Bg5 Ne7 8. Nh4
			variation => N__('Four Knights: Symmetrical, Pillsbury Variation'),
			moves => {
				'c7c6' => 1,
			},
		},
		'r1bq1rk1/pp2nppp/2pp1n2/1B2p1B1/1b2P2N/2NP4/PPP2PPP/R2Q1RK1 w -' => {
			eco => 'C49k',
			# TRANSLATORS: C49k: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O O-O 6. d3 d6 7. Bg5 Ne7 8. Nh4 c6
			variation => N__('Four Knights: Symmetrical, Pillsbury Variation'),
			moves => {
				'b5c4' => 1,
			},
		},
		'r1bq1rk1/pp2nppp/2pp1n2/4p1B1/1bB1P2N/2NP4/PPP2PPP/R2Q1RK1 b -' => {
			eco => 'C49k',
			# TRANSLATORS: C49k: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O O-O 6. d3 d6 7. Bg5 Ne7 8. Nh4 c6 9. Bc4
			variation => N__('Four Knights: Symmetrical, Pillsbury Variation'),
			moves => {
				'd6d5' => 1,
			},
		},
		'r1bq1rk1/pp2nppp/2p2n2/3pp1B1/1bB1P2N/2NP4/PPP2PPP/R2Q1RK1 w -' => {
			eco => 'C49k',
			# TRANSLATORS: C49k: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O O-O 6. d3 d6 7. Bg5 Ne7 8. Nh4 c6 9. Bc4 d5
			variation => N__('Four Knights: Symmetrical, Pillsbury Variation'),
			moves => {
				'c4b3' => 1,
			},
		},
		'r1bq1rk1/pp2nppp/2p2n2/3pp1B1/1b2P2N/1BNP4/PPP2PPP/R2Q1RK1 b -' => {
			eco => 'C49k',
			# TRANSLATORS: C49k: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O O-O 6. d3 d6 7. Bg5 Ne7 8. Nh4 c6 9. Bc4 d5 10. Bb3
			variation => N__('Four Knights: Symmetrical, Pillsbury Variation'),
			moves => {
				'd8d6' => 1,
			},
		},
		'r1b2rk1/pp2nppp/2pq1n2/3pp1B1/1b2P2N/1BNP4/PPP2PPP/R2Q1RK1 w -' => {
			eco => 'C49k',
			# TRANSLATORS: C49k: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O O-O 6. d3 d6 7. Bg5 Ne7 8. Nh4 c6 9. Bc4 d5 10. Bb3 Qd6
			variation => N__('Four Knights: Symmetrical, Blake Variation'),
			moves => {
			},
		},
		'r1bq1rk1/ppp2ppp/2np1n2/1B2p1B1/4P3/2bP1N2/PPP2PPP/R2Q1RK1 w -' => {
			eco => 'C49l',
			# TRANSLATORS: C49l: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O O-O 6. d3 d6 7. Bg5 Bxc3
			variation => N__('Four Knights: Symmetrical, 7. Bg5 Bxc3'),
			moves => {
				'b2c3' => 1,
			},
		},
		'r1bq1rk1/ppp2ppp/2np1n2/1B2p1B1/4P3/2PP1N2/P1P2PPP/R2Q1RK1 b -' => {
			eco => 'C49l',
			# TRANSLATORS: C49l: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O O-O 6. d3 d6 7. Bg5 Bxc3 8. bxc3
			variation => N__('Four Knights: Symmetrical, 7. Bg5 Bxc3'),
			moves => {
				'd8e7' => 1,
				'h7h6' => 1,
			},
		},
		'r1bq1rk1/ppp2pp1/2np1n1p/1B2p1B1/4P3/2PP1N2/P1P2PPP/R2Q1RK1 w -' => {
			eco => 'C49m',
			# TRANSLATORS: C49m: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O O-O 6. d3 d6 7. Bg5 Bxc3 8. bxc3 h6
			variation => N__('Four Knights: Symmetrical, 7. Bg5 Bxc3 8.bxc3 h6'),
			moves => {
			},
		},
		'r1b2rk1/ppp1qppp/2np1n2/1B2p1B1/4P3/2PP1N2/P1P2PPP/R2Q1RK1 w -' => {
			eco => 'C49n',
			# TRANSLATORS: C49n: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O O-O 6. d3 d6 7. Bg5 Bxc3 8. bxc3 Qe7
			variation => N__('Four Knights: Symmetrical, Metger unpin'),
			moves => {
				'f1e1' => 1,
			},
		},
		'r1b2rk1/ppp1qppp/2np1n2/1B2p1B1/4P3/2PP1N2/P1P2PPP/R2QR1K1 b -' => {
			eco => 'C49n',
			# TRANSLATORS: C49n: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O O-O 6. d3 d6 7. Bg5 Bxc3 8. bxc3 Qe7 9. Re1
			variation => N__('Four Knights: Symmetrical, Metger unpin'),
			moves => {
				'c6d8' => 1,
			},
		},
		'r1bn1rk1/ppp1qppp/3p1n2/1B2p1B1/4P3/2PP1N2/P1P2PPP/R2QR1K1 w -' => {
			eco => 'C49n',
			# TRANSLATORS: C49n: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O O-O 6. d3 d6 7. Bg5 Bxc3 8. bxc3 Qe7 9. Re1 Nd8
			variation => N__('Four Knights: Symmetrical, Metger unpin'),
			moves => {
				'd3d4' => 1,
			},
		},
		'r1bn1rk1/ppp1qppp/3p1n2/1B2p1B1/3PP3/2P2N2/P1P2PPP/R2QR1K1 b -' => {
			eco => 'C49n',
			# TRANSLATORS: C49n: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O O-O 6. d3 d6 7. Bg5 Bxc3 8. bxc3 Qe7 9. Re1 Nd8 10. d4
			variation => N__('Four Knights: Symmetrical, Metger, 10. d4'),
			moves => {
				'c8g4' => 1,
				'd8e6' => 1,
			},
		},
		'r2n1rk1/ppp1qppp/3p1n2/1B2p1B1/3PP1b1/2P2N2/P1P2PPP/R2QR1K1 w -' => {
			eco => 'C49o',
			# TRANSLATORS: C49o: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O O-O 6. d3 d6 7. Bg5 Bxc3 8. bxc3 Qe7 9. Re1 Nd8 10. d4 Bg4
			variation => N__('Four Knights: Symmetrical, Metger, Capablanca Variation'),
			moves => {
			},
		},
		'r1b2rk1/ppp1qppp/3pnn2/1B2p1B1/3PP3/2P2N2/P1P2PPP/R2QR1K1 w -' => {
			eco => 'C49p',
			# TRANSLATORS: C49p: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O O-O 6. d3 d6 7. Bg5 Bxc3 8. bxc3 Qe7 9. Re1 Nd8 10. d4 Ne6
			variation => N__('Four Knights: Symmetrical, Metger, 10. d4 Ne6'),
			moves => {
				'g5c1' => 1,
			},
		},
		'r1b2rk1/ppp1qppp/3pnn2/1B2p3/3PP3/2P2N2/P1P2PPP/R1BQR1K1 b -' => {
			eco => 'C49p',
			# TRANSLATORS: C49p: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O O-O 6. d3 d6 7. Bg5 Bxc3 8. bxc3 Qe7 9. Re1 Nd8 10. d4 Ne6 11. Bc1
			variation => N__('Four Knights: Symmetrical, Metger, 10. d4 Ne6'),
			moves => {
				'c7c5' => 1,
				'f8d8' => 1,
			},
		},
		'r1br2k1/ppp1qppp/3pnn2/1B2p3/3PP3/2P2N2/P1P2PPP/R1BQR1K1 w -' => {
			eco => 'C49q',
			# TRANSLATORS: C49q: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O O-O 6. d3 d6 7. Bg5 Bxc3 8. bxc3 Qe7 9. Re1 Nd8 10. d4 Ne6 11. Bc1 Rd8
			variation => N__('Four Knights: Symmetrical, Metger, 10. d4 Ne6 11. Bc1 Rd8'),
			moves => {
			},
		},
		'r1b2rk1/pp2qppp/3pnn2/1Bp1p3/3PP3/2P2N2/P1P2PPP/R1BQR1K1 w -' => {
			eco => 'C49r',
			# TRANSLATORS: C49r: 1. e4 e5 2. Nf3 Nc6 3. Nc3 Nf6 4. Bb5 Bb4 5. O-O O-O 6. d3 d6 7. Bg5 Bxc3 8. bxc3 Qe7 9. Re1 Nd8 10. d4 Ne6 11. Bc1 c5
			variation => N__('Four Knights: Symmetrical, Metger, 10. d4 Ne6 11. Bc1 c5'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4p3/2B1P3/5N2/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'C50a',
			# TRANSLATORS: C50a: 1. e4 e5 2. Nf3 Nc6 3. Bc4
			variation => N__('Italian Game'),
			moves => {
				'c6d4' => 1,
				'd7d6' => 1,
				'f7f5' => 1,
				'f8c5' => 1,
				'f8e7' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkbnr/pppp2pp/2n5/4pp2/2B1P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C50b',
			# TRANSLATORS: C50b: 1. e4 e5 2. Nf3 Nc6 3. Bc4 f5
			variation => N__('Italian: Rousseau Gambit'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/8/4p3/2BnP3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C50c',
			# TRANSLATORS: C50c: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nd4
			variation => N__('Italian: Blackburne-Shilling Gambit'),
			moves => {
			},
		},
		'r1bqkbnr/ppp2ppp/2np4/4p3/2B1P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C50d',
			# TRANSLATORS: C50d: 1. e4 e5 2. Nf3 Nc6 3. Bc4 d6
			variation => N__('Italian: 3... d6'),
			moves => {
			},
		},
		'r1bqk1nr/ppppbppp/2n5/4p3/2B1P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C50e',
			# TRANSLATORS: C50e: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Be7
			variation => N__('Italian: Hungarian Defence'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bqk1nr/ppppbppp/2n5/4p3/2BPP3/5N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C50e',
			# TRANSLATORS: C50e: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Be7 4. d4
			variation => N__('Italian: Hungarian Defence'),
			moves => {
				'd7d6' => 1,
				'e5d4' => 1,
			},
		},
		'r1bqk1nr/ppppbppp/2n5/8/2BpP3/5N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C50f',
			# TRANSLATORS: C50f: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Be7 4. d4 exd4
			variation => N__('Italian: Hungarian Defence, 4. d4 exd4'),
			moves => {
				'c2c3' => 1,
			},
		},
		'r1bqk1nr/ppppbppp/2n5/8/2BpP3/2P2N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'C50f',
			# TRANSLATORS: C50f: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Be7 4. d4 exd4 5. c3
			variation => N__('Italian: Hungarian Defence, 4. d4 exd4'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r1bqk2r/ppppbppp/2n2n2/8/2BpP3/2P2N2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'C50f',
			# TRANSLATORS: C50f: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Be7 4. d4 exd4 5. c3 Nf6
			variation => N__('Italian: Hungarian Defence, 4. d4 exd4'),
			moves => {
				'e4e5' => 1,
			},
		},
		'r1bqk2r/ppppbppp/2n2n2/4P3/2Bp4/2P2N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'C50f',
			# TRANSLATORS: C50f: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Be7 4. d4 exd4 5. c3 Nf6 6. e5
			variation => N__('Italian: Hungarian Defence, 4. d4 exd4'),
			moves => {
				'f6e4' => 1,
			},
		},
		'r1bqk2r/ppppbppp/2n5/4P3/2Bpn3/2P2N2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'C50f',
			# TRANSLATORS: C50f: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Be7 4. d4 exd4 5. c3 Nf6 6. e5 Ne4
			variation => N__('Italian: Hungarian Defence, Tartakower Variation'),
			moves => {
			},
		},
		'r1bqk1nr/ppp1bppp/2np4/4p3/2BPP3/5N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C50g',
			# TRANSLATORS: C50g: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Be7 4. d4 d6
			variation => N__('Italian: Hungarian Defence, 4. d4 d6'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/2b1p3/2B1P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C50h',
			# TRANSLATORS: C50h: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5
			variation => N__('Giuoco Piano'),
			moves => {
				'b1c3' => 1,
				'b2b4' => 1,
				'c2c3' => 1,
				'c4f7' => 1,
				'd2d3' => 1,
				'd2d4' => 1,
				'e1g1' => 1,
			},
		},
		'r1bqk1nr/pppp1Bpp/2n5/2b1p3/4P3/5N2/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'C50h',
			# TRANSLATORS: C50h: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. Bxf7+
			variation => N__('Giuoco Piano: Jerome Gambit'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/2b1p3/2BPP3/5N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C50h',
			# TRANSLATORS: C50h: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. d4
			variation => N__('Giuoco Piano: Rosentreter Gambit'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/2b1p3/2B1P3/2N2N2/PPPP1PPP/R1BQK2R b KQkq' => {
			eco => 'C50i',
			# TRANSLATORS: C50i: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. Nc3
			variation => N__('Giuoco Piano: Three Knights Variation'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/2b1p3/2B1P3/2N2N2/PPPP1PPP/R1BQK2R w KQkq' => {
			eco => 'C50j',
			# TRANSLATORS: C50j: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. Nc3 Nf6
			variation => N__('Giuoco Piano: Four Knights Variation'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/2b1p3/2B1P3/5N2/PPPP1PPP/RNBQ1RK1 b kq' => {
			eco => 'C50k',
			# TRANSLATORS: C50k: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. O-O
			variation => N__('Giuoco Piano: 4.O-O'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/2b1p3/2B1P3/5N2/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C50l',
			# TRANSLATORS: C50l: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. O-O Bc5
			variation => N__('Giuoco Piano: 4.O-O Nf6'),
			moves => {
				'b1c3' => 1,
				'd2d4' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/2b1p3/2B1P3/2N2N2/PPPP1PPP/R1BQ1RK1 b kq' => {
			eco => 'C50m',
			# TRANSLATORS: C50m: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. O-O Nf6 5. Nc3
			variation => N__('Giuoco Piano: 4.O-O Nf6 5. Nc3'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/2b1p3/2B1P3/3P1N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C50n',
			# TRANSLATORS: C50n: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. d3
			variation => N__('Giuoco Pianissimo: 4. d3'),
			moves => {
				'f7f5' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqk1nr/pppp2pp/2n5/2b1pp2/2B1P3/3P1N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C50n',
			# TRANSLATORS: C50n: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. d3 f5
			variation => N__('Giuoco Pianissimo: Lucchini Gambit'),
			moves => {
				'f3g5' => 1,
			},
		},
		'r1bqk1nr/pppp2pp/2n5/2b1ppN1/2B1P3/3P4/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C50n',
			# TRANSLATORS: C50n: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. d3 f5 5. Ng5
			variation => N__('Giuoco Pianissimo: Lucchini Gambit'),
			moves => {
				'f5f4' => 1,
			},
		},
		'r1bqk1nr/pppp2pp/2n5/2b1p1N1/2B1Pp2/3P4/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C50n',
			# TRANSLATORS: C50n: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. d3 f5 5. Ng5 f4
			variation => N__('Giuoco Pianissimo: Dubois Variation'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/2b1p3/2B1P3/3P1N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C50o',
			# TRANSLATORS: C50o: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. d3 Nf6
			variation => N__('Giuoco Pianissimo: 4. d3 Nf6'),
			moves => {
				'b1c3' => 1,
				'e1g1' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/2b1p3/2B1P3/3P1N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C50p',
			# TRANSLATORS: C50p: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. d3 Nf6 5. O-O
			variation => N__('Giuoco Pianissimo: 4. d3 Nf6 5.O-O'),
			moves => {
				'd7d6' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2np1n2/2b1p3/2B1P3/3P1N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C50q',
			# TRANSLATORS: C50q: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. d3 Nf6 5. O-O d6
			variation => N__('Giuoco Pianissimo: 4. d3 Nf6 5.O-O d6'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/2b1p3/2B1P3/2NP1N2/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'C50r',
			# TRANSLATORS: C50r: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. d3 Nf6 5. Nc3
			variation => N__('Giuoco Pianissimo: Italian Four Knights'),
			moves => {
				'd7d6' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2np1n2/2b1p3/2B1P3/2NP1N2/PPP2PPP/R1BQK2R w KQkq' => {
			eco => 'C50s',
			# TRANSLATORS: C50s: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. d3 Nf6 5. Nc3 d6
			variation => N__('Giuoco Pianissimo: Italian Four Knights, 5... d6'),
			moves => {
				'c1e3' => 1,
				'c1g5' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2np1n2/2b1p3/2B1P3/2NPBN2/PPP2PPP/R2QK2R b KQkq' => {
			eco => 'C50t',
			# TRANSLATORS: C50t: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. d3 Nf6 5. Nc3 d6 6. Be3
			variation => N__('Giuoco Pianissimo: Italian Four Knights, 5... d6 6. Be3'),
			moves => {
			},
		},
		'r1bqk2r/ppp2ppp/2np1n2/2b1p1B1/2B1P3/2NP1N2/PPP2PPP/R2QK2R b KQkq' => {
			eco => 'C50u',
			# TRANSLATORS: C50u: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. d3 Nf6 5. Nc3 d6 6. Bg5
			variation => N__('Giuoco Pianissimo: Canal Variation'),
			moves => {
				'h7h6' => 1,
			},
		},
		'r1bqk2r/ppp2pp1/2np1n1p/2b1p1B1/2B1P3/2NP1N2/PPP2PPP/R2QK2R w KQkq' => {
			eco => 'C50v',
			# TRANSLATORS: C50v: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. d3 Nf6 5. Nc3 d6 6. Bg5 h6
			variation => N__('Giuoco Pianissimo: Canal, 6... h6'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/2b1p3/1PB1P3/5N2/P1PP1PPP/RNBQK2R b KQkq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4
			variation => N__('Evans Gambit'),
			moves => {
				'c5b4' => 1,
				'c5b6' => 1,
				'c5e7' => 1,
				'd7d5' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/4p3/1bB1P3/5N2/P1PP1PPP/RNBQK2R w KQkq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4
			variation => N__('Evans Gambit Accepted'),
			moves => {
				'c2c3' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/4p3/1bB1P3/2P2N2/P2P1PPP/RNBQK2R b KQkq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3
			variation => N__('Evans Gambit Accepted, 5. c3'),
			moves => {
				'b4a5' => 1,
				'b4c5' => 1,
				'b4d6' => 1,
				'b4e7' => 1,
				'b4f8' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/2b1p3/2B1P3/2P2N2/P2P1PPP/RNBQK2R w KQkq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Bc5
			variation => N__('Evans Gambit Accepted, 5. c3'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/2b1p3/2BPP3/2P2N2/P4PPP/RNBQK2R b KQkq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Bc5 6. d4
			variation => N__('Evans Gambit Accepted, 5. c3'),
			moves => {
				'e5d4' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/2b5/2BpP3/2P2N2/P4PPP/RNBQK2R w KQkq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Bc5 6. d4 exd4
			variation => N__('Evans Gambit Accepted, 5. c3'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/2b5/2BpP3/2P2N2/P4PPP/RNBQ1RK1 b kq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Bc5 6. d4 exd4 7. O-O
			variation => N__('Evans Gambit Accepted, 5. c3'),
			moves => {
				'd7d6' => 1,
			},
		},
		'r1bqk1nr/ppp2ppp/2np4/2b5/2BpP3/2P2N2/P4PPP/RNBQ1RK1 w kq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Bc5 6. d4 exd4 7. O-O d6
			variation => N__('Evans Gambit Accepted, 5. c3'),
			moves => {
				'c3d4' => 1,
			},
		},
		'r1bqk1nr/ppp2ppp/2np4/2b5/2BPP3/5N2/P4PPP/RNBQ1RK1 b kq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Bc5 6. d4 exd4 7. O-O d6 8. cxd4
			variation => N__('Evans Gambit Accepted, 5. c3'),
			moves => {
				'c5b6' => 1,
			},
		},
		'r1bqk1nr/ppp2ppp/1bnp4/8/2BPP3/5N2/P4PPP/RNBQ1RK1 w kq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Bc5 6. d4 exd4 7. O-O d6 8. cxd4 Bb6
			variation => N__('Evans Gambit: Normal Variation'),
			moves => {
				'b1c3' => 1,
				'd4d5' => 1,
			},
		},
		'r1bqk1nr/ppp2ppp/1bnp4/8/2BPP3/2N2N2/P4PPP/R1BQ1RK1 b kq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Bc5 6. d4 exd4 7. O-O d6 8. cxd4 Bb6 9. Nc3
			variation => N__('Evans Gambit: Morphy Attack'),
			moves => {
				'c6a5' => 1,
				'c8g4' => 1,
			},
		},
		'r1bqk1nr/ppp2ppp/1b1p4/n7/2BPP3/2N2N2/P4PPP/R1BQ1RK1 w kq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Bc5 6. d4 exd4 7. O-O d6 8. cxd4 Bb6 9. Nc3 Na5
			variation => N__('Evans Gambit: Morphy Attack'),
			moves => {
				'c1g5' => 1,
			},
		},
		'r1bqk1nr/ppp2ppp/1b1p4/n5B1/2BPP3/2N2N2/P4PPP/R2Q1RK1 b kq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Bc5 6. d4 exd4 7. O-O d6 8. cxd4 Bb6 9. Nc3 Na5 10. Bg5
			variation => N__('Evans Gambit: Göring Attack'),
			moves => {
				'f7f6' => 1,
			},
		},
		'r1bqk1nr/ppp3pp/1b1p1p2/n5B1/2BPP3/2N2N2/P4PPP/R2Q1RK1 w kq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Bc5 6. d4 exd4 7. O-O d6 8. cxd4 Bb6 9. Nc3 Na5 10. Bg5 f6
			variation => N__('Evans Gambit: Göring Attack'),
			moves => {
				'g5e3' => 1,
			},
		},
		'r1bqk1nr/ppp3pp/1b1p1p2/n7/2BPP3/2N1BN2/P4PPP/R2Q1RK1 b kq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Bc5 6. d4 exd4 7. O-O d6 8. cxd4 Bb6 9. Nc3 Na5 10. Bg5 f6 11. Be3
			variation => N__('Evans Gambit: Steinitz Variation'),
			moves => {
			},
		},
		'r2qk1nr/ppp2ppp/1bnp4/8/2BPP1b1/2N2N2/P4PPP/R1BQ1RK1 w kq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Bc5 6. d4 exd4 7. O-O d6 8. cxd4 Bb6 9. Nc3 Bg4
			variation => N__('Evans Gambit: Normal Variation'),
			moves => {
				'd1a4' => 1,
			},
		},
		'r2qk1nr/ppp2ppp/1bnp4/8/Q1BPP1b1/2N2N2/P4PPP/R1B2RK1 b kq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Bc5 6. d4 exd4 7. O-O d6 8. cxd4 Bb6 9. Nc3 Bg4 10. Qa4
			variation => N__('Evans Gambit: Fraser Attack'),
			moves => {
				'g4d7' => 1,
			},
		},
		'r2qk1nr/pppb1ppp/1bnp4/8/Q1BPP3/2N2N2/P4PPP/R1B2RK1 w kq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Bc5 6. d4 exd4 7. O-O d6 8. cxd4 Bb6 9. Nc3 Bg4 10. Qa4 Bd7
			variation => N__('Evans Gambit: Fraser Attack'),
			moves => {
				'a4b3' => 1,
			},
		},
		'r2qk1nr/pppb1ppp/1bnp4/8/2BPP3/1QN2N2/P4PPP/R1B2RK1 b kq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Bc5 6. d4 exd4 7. O-O d6 8. cxd4 Bb6 9. Nc3 Bg4 10. Qa4 Bd7 11. Qb3
			variation => N__('Evans Gambit: Fraser Attack'),
			moves => {
				'c6a5' => 1,
			},
		},
		'r2qk1nr/pppb1ppp/1b1p4/n7/2BPP3/1QN2N2/P4PPP/R1B2RK1 w kq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Bc5 6. d4 exd4 7. O-O d6 8. cxd4 Bb6 9. Nc3 Bg4 10. Qa4 Bd7 11. Qb3 Na5
			variation => N__('Evans Gambit: Fraser Attack'),
			moves => {
				'c4f7' => 1,
			},
		},
		'r2qk1nr/pppb1Bpp/1b1p4/n7/3PP3/1QN2N2/P4PPP/R1B2RK1 b kq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Bc5 6. d4 exd4 7. O-O d6 8. cxd4 Bb6 9. Nc3 Bg4 10. Qa4 Bd7 11. Qb3 Na5 12. Bxf7+
			variation => N__('Evans Gambit: Fraser Attack'),
			moves => {
				'e8f8' => 1,
			},
		},
		'r2q1knr/pppb1Bpp/1b1p4/n7/3PP3/1QN2N2/P4PPP/R1B2RK1 w -' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Bc5 6. d4 exd4 7. O-O d6 8. cxd4 Bb6 9. Nc3 Bg4 10. Qa4 Bd7 11. Qb3 Na5 12. Bxf7+ Kf8
			variation => N__('Evans Gambit: Fraser Attack'),
			moves => {
				'b3c2' => 1,
			},
		},
		'r2q1knr/pppb1Bpp/1b1p4/n7/3PP3/2N2N2/P1Q2PPP/R1B2RK1 b -' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Bc5 6. d4 exd4 7. O-O d6 8. cxd4 Bb6 9. Nc3 Bg4 10. Qa4 Bd7 11. Qb3 Na5 12. Bxf7+ Kf8 13. Qc2
			variation => N__('Evans Gambit: Fraser-Mortimer Attack'),
			moves => {
			},
		},
		'r1bqk1nr/ppp2ppp/1bnp4/3P4/2B1P3/5N2/P4PPP/RNBQ1RK1 b kq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Bc5 6. d4 exd4 7. O-O d6 8. cxd4 Bb6 9. d5
			variation => N__('Evans Gambit: Anderssen Variation'),
			moves => {
				'c6a5' => 1,
			},
		},
		'r1bqk1nr/ppp2ppp/1b1p4/n2P4/2B1P3/5N2/P4PPP/RNBQ1RK1 w kq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Bc5 6. d4 exd4 7. O-O d6 8. cxd4 Bb6 9. d5 Na5
			variation => N__('Evans Gambit: Anderssen Variation'),
			moves => {
				'c1b2' => 1,
			},
		},
		'r1bqk1nr/ppp2ppp/1b1p4/n2P4/2B1P3/5N2/PB3PPP/RN1Q1RK1 b kq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Bc5 6. d4 exd4 7. O-O d6 8. cxd4 Bb6 9. d5 Na5 10. Bb2
			variation => N__('Evans Gambit: Ulvestad Variation'),
			moves => {
				'g8e7' => 1,
			},
		},
		'r1bqk2r/ppp1nppp/1b1p4/n2P4/2B1P3/5N2/PB3PPP/RN1Q1RK1 w kq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Bc5 6. d4 exd4 7. O-O d6 8. cxd4 Bb6 9. d5 Na5 10. Bb2 Ne7
			variation => N__('Evans Gambit: Paulsen Variation'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/2nb4/4p3/2B1P3/2P2N2/P2P1PPP/RNBQK2R w KQkq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Bd6
			variation => N__('Evans Gambit: Stone-Ware Defence'),
			moves => {
			},
		},
		'r1bqk1nr/ppppbppp/2n5/4p3/2B1P3/2P2N2/P2P1PPP/RNBQK2R w KQkq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Be7
			variation => N__('Evans Gambit: Anderssen Variation'),
			moves => {
				'd1b3' => 1,
				'd2d4' => 1,
			},
		},
		'r1bqk1nr/ppppbppp/2n5/4p3/2B1P3/1QP2N2/P2P1PPP/RNB1K2R b KQkq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Be7 6. Qb3
			variation => N__('Evans Gambit: Anderssen, 6. Qb3'),
			moves => {
			},
		},
		'r1bqk1nr/ppppbppp/2n5/4p3/2BPP3/2P2N2/P4PPP/RNBQK2R b KQkq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Be7 6. d4
			variation => N__('Evans Gambit: Anderssen, 6. d4'),
			moves => {
				'c6a5' => 1,
			},
		},
		'r1bqk1nr/ppppbppp/8/n3p3/2BPP3/2P2N2/P4PPP/RNBQK2R w KQkq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Be7 6. d4 Na5
			variation => N__('Evans Gambit: Cordel Variation'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/4p3/2B1P3/2P2N2/P2P1PPP/RNBQK2R w KQkq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Bf8
			variation => N__('Evans Gambit: Mayet Defence'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/1bn5/4p3/1PB1P3/5N2/P1PP1PPP/RNBQK2R w KQkq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bb6
			variation => N__('Evans Gambit Declined'),
			moves => {
				'a2a4' => 1,
				'b4b5' => 1,
				'c1b2' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/1bn5/4p3/PPB1P3/5N2/2PP1PPP/RNBQK2R b KQkq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bb6 5. a4
			variation => N__('Evans Gambit Declined, 5. a4'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r1bqk1nr/1ppp1ppp/pbn5/4p3/PPB1P3/5N2/2PP1PPP/RNBQK2R w KQkq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bb6 5. a4 a6
			variation => N__('Evans Gambit Declined, 5. a4'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r1bqk1nr/1ppp1ppp/pbn5/4p3/PPB1P3/2N2N2/2PP1PPP/R1BQK2R b KQkq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bb6 5. a4 a6 6. Nc3
			variation => N__('Evans Gambit Declined, Showalter Variation'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/1bn5/1P2p3/2B1P3/5N2/P1PP1PPP/RNBQK2R b KQkq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bb6 5. b5
			variation => N__('Evans Gambit Declined, 5. b5'),
			moves => {
				'c6a5' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/1b6/nP2p3/2B1P3/5N2/P1PP1PPP/RNBQK2R w KQkq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bb6 5. b5 Na5
			variation => N__('Evans Gambit Declined, 5. b5'),
			moves => {
				'f3e5' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/1b6/nP2N3/2B1P3/8/P1PP1PPP/RNBQK2R b KQkq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bb6 5. b5 Na5 6. Nxe5
			variation => N__('Evans Gambit Declined, 5. b5'),
			moves => {
				'd8g5' => 1,
				'g8h6' => 1,
			},
		},
		'r1b1k1nr/pppp1ppp/1b6/nP2N1q1/2B1P3/8/P1PP1PPP/RNBQK2R w KQkq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bb6 5. b5 Na5 6. Nxe5 Qg5
			variation => N__('Evans Gambit Declined, Hirschbach Variation'),
			moves => {
				'c4f7' => 1,
				'd1f3' => 1,
			},
		},
		'r1b1k1nr/pppp1Bpp/1b6/nP2N1q1/4P3/8/P1PP1PPP/RNBQK2R b KQkq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bb6 5. b5 Na5 6. Nxe5 Qg5 7. Bxf7+
			variation => N__('Evans Gambit Declined, Hirschbach Variation'),
			moves => {
				'e8e7' => 1,
			},
		},
		'r1b3nr/ppppkBpp/1b6/nP2N1q1/4P3/8/P1PP1PPP/RNBQK2R w KQ' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bb6 5. b5 Na5 6. Nxe5 Qg5 7. Bxf7+ Ke7
			variation => N__('Evans Gambit Declined, Hirschbach Variation'),
			moves => {
				'd1h5' => 1,
			},
		},
		'r1b3nr/ppppkBpp/1b6/nP2N1qQ/4P3/8/P1PP1PPP/RNB1K2R b KQ' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bb6 5. b5 Na5 6. Nxe5 Qg5 7. Bxf7+ Ke7 8. Qh5
			variation => N__('Evans Gambit Declined, Vasquez Variation'),
			moves => {
			},
		},
		'r1b1k1nr/pppp1ppp/1b6/nP2N1q1/2B1P3/5Q2/P1PP1PPP/RNB1K2R b KQkq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bb6 5. b5 Na5 6. Nxe5 Qg5 7. Qf3
			variation => N__('Evans Gambit Declined, Hirschbach Variation'),
			moves => {
				'g5e5' => 1,
			},
		},
		'r1b1k1nr/pppp1ppp/1b6/nP2q3/2B1P3/5Q2/P1PP1PPP/RNB1K2R w KQkq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bb6 5. b5 Na5 6. Nxe5 Qg5 7. Qf3 Qxe5
			variation => N__('Evans Gambit Declined, Hirschbach Variation'),
			moves => {
				'f3f7' => 1,
			},
		},
		'r1b1k1nr/pppp1Qpp/1b6/nP2q3/2B1P3/8/P1PP1PPP/RNB1K2R b KQkq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bb6 5. b5 Na5 6. Nxe5 Qg5 7. Qf3 Qxe5 8. Qxf7+
			variation => N__('Evans Gambit Declined, Hirschbach Variation'),
			moves => {
				'e8d8' => 1,
			},
		},
		'r1bk2nr/pppp1Qpp/1b6/nP2q3/2B1P3/8/P1PP1PPP/RNB1K2R w KQ' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bb6 5. b5 Na5 6. Nxe5 Qg5 7. Qf3 Qxe5 8. Qxf7+ Kd8
			variation => N__('Evans Gambit Declined, Hirschbach Variation'),
			moves => {
				'c1b2' => 1,
			},
		},
		'r1bk2nr/pppp1Qpp/1b6/nP2q3/2B1P3/8/PBPP1PPP/RN2K2R b KQ' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bb6 5. b5 Na5 6. Nxe5 Qg5 7. Qf3 Qxe5 8. Qxf7+ Kd8 9. Bb2
			variation => N__('Evans Gambit Declined, Hicken Variation'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/1b5n/nP2N3/2B1P3/8/P1PP1PPP/RNBQK2R w KQkq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bb6 5. b5 Na5 6. Nxe5 Nh6
			variation => N__('Evans Gambit Declined, Lange Variation'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/1b5n/nP2N3/2BPP3/8/P1P2PPP/RNBQK2R b KQkq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bb6 5. b5 Na5 6. Nxe5 Nh6 7. d4
			variation => N__('Evans Gambit Declined, Lange Variation'),
			moves => {
				'd7d6' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/1b1p3n/nP2N3/2BPP3/8/P1P2PPP/RNBQK2R w KQkq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bb6 5. b5 Na5 6. Nxe5 Nh6 7. d4 d6
			variation => N__('Evans Gambit Declined, Lange Variation'),
			moves => {
				'c1h6' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/1b1p3B/nP2N3/2BPP3/8/P1P2PPP/RN1QK2R b KQkq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bb6 5. b5 Na5 6. Nxe5 Nh6 7. d4 d6 8. Bxh6
			variation => N__('Evans Gambit Declined, Lange Variation'),
			moves => {
				'd6e5' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/1b5B/nP2p3/2BPP3/8/P1P2PPP/RN1QK2R w KQkq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bb6 5. b5 Na5 6. Nxe5 Nh6 7. d4 d6 8. Bxh6 dxe5
			variation => N__('Evans Gambit Declined, Lange Variation'),
			moves => {
				'h6g7' => 1,
			},
		},
		'r1bqk2r/ppp2pBp/1b6/nP2p3/2BPP3/8/P1P2PPP/RN1QK2R b KQkq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bb6 5. b5 Na5 6. Nxe5 Nh6 7. d4 d6 8. Bxh6 dxe5 9. Bxg7
			variation => N__('Evans Gambit Declined, Lange Variation'),
			moves => {
				'h8g8' => 1,
			},
		},
		'r1bqk1r1/ppp2pBp/1b6/nP2p3/2BPP3/8/P1P2PPP/RN1QK2R w KQq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bb6 5. b5 Na5 6. Nxe5 Nh6 7. d4 d6 8. Bxh6 dxe5 9. Bxg7 Rg8
			variation => N__('Evans Gambit Declined, Lange Variation'),
			moves => {
				'c4f7' => 1,
			},
		},
		'r1bqk1r1/ppp2BBp/1b6/nP2p3/3PP3/8/P1P2PPP/RN1QK2R b KQq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bb6 5. b5 Na5 6. Nxe5 Nh6 7. d4 d6 8. Bxh6 dxe5 9. Bxg7 Rg8 10. Bxf7+
			variation => N__('Evans Gambit Declined, Lange Variation'),
			moves => {
				'e8f7' => 1,
			},
		},
		'r1bq2r1/ppp2kBp/1b6/nP2p3/3PP3/8/P1P2PPP/RN1QK2R w KQ' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bb6 5. b5 Na5 6. Nxe5 Nh6 7. d4 d6 8. Bxh6 dxe5 9. Bxg7 Rg8 10. Bxf7+ Kxf7
			variation => N__('Evans Gambit Declined, Lange Variation'),
			moves => {
				'g7e5' => 1,
			},
		},
		'r1bq2r1/ppp2k1p/1b6/nP2B3/3PP3/8/P1P2PPP/RN1QK2R b KQ' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bb6 5. b5 Na5 6. Nxe5 Nh6 7. d4 d6 8. Bxh6 dxe5 9. Bxg7 Rg8 10. Bxf7+ Kxf7 11. Bxe5
			variation => N__('Evans Gambit Declined, Lange Variation'),
			moves => {
				'd8g5' => 1,
			},
		},
		'r1b3r1/ppp2k1p/1b6/nP2B1q1/3PP3/8/P1P2PPP/RN1QK2R w KQ' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bb6 5. b5 Na5 6. Nxe5 Nh6 7. d4 d6 8. Bxh6 dxe5 9. Bxg7 Rg8 10. Bxf7+ Kxf7 11. Bxe5 Qg5
			variation => N__('Evans Gambit Declined, Lange Variation'),
			moves => {
				'b1d2' => 1,
			},
		},
		'r1b3r1/ppp2k1p/1b6/nP2B1q1/3PP3/8/P1PN1PPP/R2QK2R b KQ' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bb6 5. b5 Na5 6. Nxe5 Nh6 7. d4 d6 8. Bxh6 dxe5 9. Bxg7 Rg8 10. Bxf7+ Kxf7 11. Bxe5 Qg5 12. Nd2
			variation => N__('Evans Gambit Declined, Pavlov Variation'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/1bn5/4p3/1PB1P3/5N2/PBPP1PPP/RN1QK2R b KQkq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bb6 5. Bb2
			variation => N__('Evans Gambit Declined, Cordel Variation'),
			moves => {
			},
		},
		'r1bqk1nr/ppppbppp/2n5/4p3/1PB1P3/5N2/P1PP1PPP/RNBQK2R w KQkq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Be7
			variation => N__('Evans Gambit Declined: 4... Be7'),
			moves => {
			},
		},
		'r1bqk1nr/ppp2ppp/2n5/2bpp3/1PB1P3/5N2/P1PP1PPP/RNBQK2R w KQkq' => {
			eco => 'C51',
			# TRANSLATORS: C51: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 d5
			variation => N__('Evans Gambit: Hein Countergambit'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/b3p3/2B1P3/2P2N2/P2P1PPP/RNBQK2R w KQkq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5
			variation => N__('Evans Gambit: 5... Ba5'),
			moves => {
				'd1b3' => 1,
				'd2d4' => 1,
				'e1g1' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/b3p3/2B1P3/1QP2N2/P2P1PPP/RNB1K2R b KQkq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. Qb3
			variation => N__('Evans Gambit: 5... Ba5 6. Qb3'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/b3p3/2BPP3/2P2N2/P4PPP/RNBQK2R b KQkq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. d4
			variation => N__('Evans Gambit: 5... Ba5 6. d4'),
			moves => {
				'b7b5' => 1,
				'd7d6' => 1,
				'e5d4' => 1,
			},
		},
		'r1bqk1nr/p1pp1ppp/2n5/bp2p3/2BPP3/2P2N2/P4PPP/RNBQK2R w KQkq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. d4 b5
			variation => N__('Evans Gambit: Leonhardt Variation'),
			moves => {
			},
		},
		'r1bqk1nr/ppp2ppp/2np4/b3p3/2BPP3/2P2N2/P4PPP/RNBQK2R w KQkq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. d4 d6
			variation => N__('Evans Gambit: 5... Ba5 6. d4 d6'),
			moves => {
				'c1g5' => 1,
				'd1b3' => 1,
			},
		},
		'r1bqk1nr/ppp2ppp/2np4/b3p1B1/2BPP3/2P2N2/P4PPP/RN1QK2R b KQkq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. d4 d6 7. Bg5
			variation => N__('Evans Gambit: Sokolsky Variation'),
			moves => {
			},
		},
		'r1bqk1nr/ppp2ppp/2np4/b3p3/2BPP3/1QP2N2/P4PPP/RNB1K2R b KQkq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. d4 d6 7. Qb3
			variation => N__('Evans Gambit: Tartakower Attack'),
			moves => {
				'd8d7' => 1,
			},
		},
		'r1b1k1nr/pppq1ppp/2np4/b3p3/2BPP3/1QP2N2/P4PPP/RNB1K2R w KQkq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. d4 d6 7. Qb3 Qd7
			variation => N__('Evans Gambit: Tartakower Attack, 7... Qd7'),
			moves => {
				'd4e5' => 1,
			},
		},
		'r1b1k1nr/pppq1ppp/2np4/b3P3/2B1P3/1QP2N2/P4PPP/RNB1K2R b KQkq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. d4 d6 7. Qb3 Qd7 8. dxe5
			variation => N__('Evans Gambit: Tartakower Attack, 7... Qd7'),
			moves => {
				'a5b6' => 1,
				'd6e5' => 1,
			},
		},
		'r1b1k1nr/pppq1ppp/1bnp4/4P3/2B1P3/1QP2N2/P4PPP/RNB1K2R w KQkq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. d4 d6 7. Qb3 Qd7 8. dxe5 Bb6
			variation => N__('Evans Gambit: Tartakower Attack, 8.dxe5 Bb6'),
			moves => {
			},
		},
		'r1b1k1nr/pppq1ppp/2n5/b3p3/2B1P3/1QP2N2/P4PPP/RNB1K2R w KQkq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. d4 d6 7. Qb3 Qd7 8. dxe5 dxe5
			variation => N__('Evans Gambit: Tartakower Attack, 8.dxe5 dxe5'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1b1k1nr/pppq1ppp/2n5/b3p3/2B1P3/1QP2N2/P4PPP/RNB2RK1 b kq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. d4 d6 7. Qb3 Qd7 8. dxe5 dxe5 9. O-O
			variation => N__('Evans Gambit: Tartakower Attack, 8.dxe5 dxe5'),
			moves => {
				'a5b6' => 1,
			},
		},
		'r1b1k1nr/pppq1ppp/1bn5/4p3/2B1P3/1QP2N2/P4PPP/RNB2RK1 w kq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. d4 d6 7. Qb3 Qd7 8. dxe5 dxe5 9. O-O Bb6
			variation => N__('Evans Gambit: Tartakower Attack, 8.dxe5 dxe5'),
			moves => {
				'c1a3' => 1,
			},
		},
		'r1b1k1nr/pppq1ppp/1bn5/4p3/2B1P3/BQP2N2/P4PPP/RN3RK1 b kq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. d4 d6 7. Qb3 Qd7 8. dxe5 dxe5 9. O-O Bb6 10. Ba3
			variation => N__('Evans Gambit: Tartakower Attack, 8.dxe5 dxe5'),
			moves => {
				'c6a5' => 1,
			},
		},
		'r1b1k1nr/pppq1ppp/1b6/n3p3/2B1P3/BQP2N2/P4PPP/RN3RK1 w kq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. d4 d6 7. Qb3 Qd7 8. dxe5 dxe5 9. O-O Bb6 10. Ba3 Na5
			variation => N__('Evans Gambit: Tartakower Attack, 8.dxe5 dxe5'),
			moves => {
				'f3e5' => 1,
			},
		},
		'r1b1k1nr/pppq1ppp/1b6/n3N3/2B1P3/BQP5/P4PPP/RN3RK1 b kq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. d4 d6 7. Qb3 Qd7 8. dxe5 dxe5 9. O-O Bb6 10. Ba3 Na5 11. Nxe5
			variation => N__('Evans Gambit: Tartakower, Levenfish Variation'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/b7/2BpP3/2P2N2/P4PPP/RNBQK2R w KQkq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. d4 exd4
			variation => N__('Evans Gambit: 5... Ba5 6. d4 exd4'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/b7/2BpP3/2P2N2/P4PPP/RNBQ1RK1 b kq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. d4 exd4 7. O-O
			variation => N__('Evans Gambit: 5... Ba5 6. d4 exd4'),
			moves => {
				'd4c3' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/b7/2B1P3/2p2N2/P4PPP/RNBQ1RK1 w kq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. d4 exd4 7. O-O dxc3
			variation => N__('Evans Gambit: Compromised Defence'),
			moves => {
				'd1b3' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/b7/2B1P3/1Qp2N2/P4PPP/RNB2RK1 b kq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. d4 exd4 7. O-O dxc3 8. Qb3
			variation => N__('Evans Gambit: Compromised Defence'),
			moves => {
				'd8f6' => 1,
			},
		},
		'r1b1k1nr/pppp1ppp/2n2q2/b7/2B1P3/1Qp2N2/P4PPP/RNB2RK1 w kq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. d4 exd4 7. O-O dxc3 8. Qb3 Qf6
			variation => N__('Evans Gambit: Compromised Defence'),
			moves => {
				'e4e5' => 1,
			},
		},
		'r1b1k1nr/pppp1ppp/2n2q2/b3P3/2B5/1Qp2N2/P4PPP/RNB2RK1 b kq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. d4 exd4 7. O-O dxc3 8. Qb3 Qf6 9. e5
			variation => N__('Evans Gambit: Compromised Defence'),
			moves => {
				'f6g6' => 1,
			},
		},
		'r1b1k1nr/pppp1ppp/2n3q1/b3P3/2B5/1Qp2N2/P4PPP/RNB2RK1 w kq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. d4 exd4 7. O-O dxc3 8. Qb3 Qf6 9. e5 Qg6
			variation => N__('Evans Gambit: Compromised Defence'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r1b1k1nr/pppp1ppp/2n3q1/b3P3/2B5/1QN2N2/P4PPP/R1B2RK1 b kq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. d4 exd4 7. O-O dxc3 8. Qb3 Qf6 9. e5 Qg6 10. Nxc3
			variation => N__('Evans Gambit: Compromised Defence'),
			moves => {
				'g8e7' => 1,
			},
		},
		'r1b1k2r/ppppnppp/2n3q1/b3P3/2B5/1QN2N2/P4PPP/R1B2RK1 w kq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. d4 exd4 7. O-O dxc3 8. Qb3 Qf6 9. e5 Qg6 10. Nxc3 Nge7
			variation => N__('Evans Gambit: Compromised Defence'),
			moves => {
				'c1a3' => 1,
				'f1d1' => 1,
			},
		},
		'r1b1k2r/ppppnppp/2n3q1/b3P3/2B5/BQN2N2/P4PPP/R4RK1 b kq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. d4 exd4 7. O-O dxc3 8. Qb3 Qf6 9. e5 Qg6 10. Nxc3 Nge7 11. Ba3
			variation => N__('Evans Gambit: Compromised Defence, Paulsen Variation'),
			moves => {
			},
		},
		'r1b1k2r/ppppnppp/2n3q1/b3P3/2B5/1QN2N2/P4PPP/R1BR2K1 b kq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. d4 exd4 7. O-O dxc3 8. Qb3 Qf6 9. e5 Qg6 10. Nxc3 Nge7 11. Rd1
			variation => N__('Evans Gambit: Compromised Defence, Potter Variation'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/b3p3/2B1P3/2P2N2/P2P1PPP/RNBQ1RK1 b kq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. O-O
			variation => N__('Evans Gambit: 5... Ba5 6.O-O'),
			moves => {
				'd7d6' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqk1nr/ppp2ppp/2np4/b3p3/2B1P3/2P2N2/P2P1PPP/RNBQ1RK1 w kq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. O-O d6
			variation => N__('Evans Gambit: 5... Ba5 6.O-O d6'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bqk1nr/ppp2ppp/2np4/b3p3/2BPP3/2P2N2/P4PPP/RNBQ1RK1 b kq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. O-O d6 7. d4
			variation => N__('Evans Gambit: 5... Ba5 6.O-O d6 7. d4'),
			moves => {
				'a5b6' => 1,
				'c8d7' => 1,
				'c8g4' => 1,
				'e5d4' => 1,
			},
		},
		'r1bqk1nr/ppp2ppp/1bnp4/4p3/2BPP3/2P2N2/P4PPP/RNBQ1RK1 w kq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. O-O d6 7. d4 Bb6
			variation => N__('Evans Gambit: Lasker\'s Defence'),
			moves => {
			},
		},
		'r2qk1nr/pppb1ppp/2np4/b3p3/2BPP3/2P2N2/P4PPP/RNBQ1RK1 w kq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. O-O d6 7. d4 Bd7
			variation => N__('Evans Gambit: Sanders-Alapin Variation'),
			moves => {
			},
		},
		'r2qk1nr/ppp2ppp/2np4/b3p3/2BPP1b1/2P2N2/P4PPP/RNBQ1RK1 w kq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. O-O d6 7. d4 Bg4
			variation => N__('Evans Gambit: Alapin-Steinitz Variation'),
			moves => {
			},
		},
		'r1bqk1nr/ppp2ppp/2np4/b7/2BpP3/2P2N2/P4PPP/RNBQ1RK1 w kq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. O-O d6 7. d4 exd4
			variation => N__('Evans Gambit: 5... Ba5 6.O-O d6 7. d4'),
			moves => {
				'd1b3' => 1,
			},
		},
		'r1bqk1nr/ppp2ppp/2np4/b7/2BpP3/1QP2N2/P4PPP/RNB2RK1 b kq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. O-O d6 7. d4 exd4 8. Qb3
			variation => N__('Evans Gambit: Waller Attack'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/b3p3/2B1P3/2P2N2/P2P1PPP/RNBQ1RK1 w kq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. O-O Nf6
			variation => N__('Evans Gambit: 5... Ba5 6.O-O Nf6'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/b3p3/2BPP3/2P2N2/P4PPP/RNBQ1RK1 b kq' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. O-O Nf6 7. d4
			variation => N__('Evans Gambit: 5... Ba5 6.O-O Nf6'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pppp1ppp/2n2n2/b3p3/2BPP3/2P2N2/P4PPP/RNBQ1RK1 w -' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. O-O Nf6 7. d4 O-O
			variation => N__('Evans Gambit: 5... Ba5 6.O-O Nf6'),
			moves => {
				'f3e5' => 1,
			},
		},
		'r1bq1rk1/pppp1ppp/2n2n2/b3N3/2BPP3/2P5/P4PPP/RNBQ1RK1 b -' => {
			eco => 'C52',
			# TRANSLATORS: C52: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. b4 Bxb4 5. c3 Ba5 6. O-O Nf6 7. d4 O-O 8. Nxe5
			variation => N__('Evans Gambit: Richardson Attack'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/2b1p3/2B1P3/2P2N2/PP1P1PPP/RNBQK2R b KQkq' => {
			eco => 'C53',
			# TRANSLATORS: C53: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3
			variation => N__('Giuoco Piano: 4. c3'),
			moves => {
				'd7d6' => 1,
				'd8e7' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqk1nr/ppp2ppp/2np4/2b1p3/2B1P3/2P2N2/PP1P1PPP/RNBQK2R w KQkq' => {
			eco => 'C53',
			# TRANSLATORS: C53: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 d6
			variation => N__('Giuoco Piano: 4. c3'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bqk1nr/ppp2ppp/2np4/2b1p3/2BPP3/2P2N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'C53',
			# TRANSLATORS: C53: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 d6 5. d4
			variation => N__('Giuoco Piano: 4. c3'),
			moves => {
				'e5d4' => 1,
			},
		},
		'r1bqk1nr/ppp2ppp/2np4/2b5/2BpP3/2P2N2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'C53',
			# TRANSLATORS: C53: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 d6 5. d4 exd4
			variation => N__('Giuoco Piano: 4. c3'),
			moves => {
				'c3d4' => 1,
			},
		},
		'r1bqk1nr/ppp2ppp/2np4/2b5/2BPP3/5N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'C53',
			# TRANSLATORS: C53: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 d6 5. d4 exd4 6. cxd4
			variation => N__('Giuoco Piano: 4. c3'),
			moves => {
				'c5b6' => 1,
			},
		},
		'r1bqk1nr/ppp2ppp/1bnp4/8/2BPP3/5N2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'C53',
			# TRANSLATORS: C53: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 d6 5. d4 exd4 6. cxd4 Bb6
			variation => N__('Giuoco Piano: LaBourdonnais Variation'),
			moves => {
			},
		},
		'r1b1k1nr/ppppqppp/2n5/2b1p3/2B1P3/2P2N2/PP1P1PPP/RNBQK2R w KQkq' => {
			eco => 'C53',
			# TRANSLATORS: C53: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Qe7
			variation => N__('Giuoco Piano: Close Variation'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1b1k1nr/ppppqppp/2n5/2b1p3/2BPP3/2P2N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'C53',
			# TRANSLATORS: C53: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Qe7 5. d4
			variation => N__('Giuoco Piano: Close Variation'),
			moves => {
				'c5b6' => 1,
			},
		},
		'r1b1k1nr/ppppqppp/1bn5/4p3/2BPP3/2P2N2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'C53',
			# TRANSLATORS: C53: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Qe7 5. d4 Bb6
			variation => N__('Giuoco Piano: Centre-Holding Variation'),
			moves => {
				'c1g5' => 1,
				'd4d5' => 1,
				'e1g1' => 1,
			},
		},
		'r1b1k1nr/ppppqppp/1bn5/4p1B1/2BPP3/2P2N2/PP3PPP/RN1QK2R b KQkq' => {
			eco => 'C53',
			# TRANSLATORS: C53: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Qe7 5. d4 Bb6 6. Bg5
			variation => N__('Giuoco Piano: Mestel Variation'),
			moves => {
			},
		},
		'r1b1k1nr/ppppqppp/1bn5/3Pp3/2B1P3/2P2N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'C53',
			# TRANSLATORS: C53: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Qe7 5. d4 Bb6 6. d5
			variation => N__('Giuoco Piano: Centre-Holding Variation'),
			moves => {
				'c6b8' => 1,
			},
		},
		'rnb1k1nr/ppppqppp/1b6/3Pp3/2B1P3/2P2N2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'C53',
			# TRANSLATORS: C53: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Qe7 5. d4 Bb6 6. d5 Nb8
			variation => N__('Giuoco Piano: Centre-Holding Variation'),
			moves => {
				'd5d6' => 1,
			},
		},
		'rnb1k1nr/ppppqppp/1b1P4/4p3/2B1P3/2P2N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'C53',
			# TRANSLATORS: C53: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Qe7 5. d4 Bb6 6. d5 Nb8 7. d6
			variation => N__('Giuoco Piano: Eisinger Variation'),
			moves => {
			},
		},
		'r1b1k1nr/ppppqppp/1bn5/4p3/2BPP3/2P2N2/PP3PPP/RNBQ1RK1 b kq' => {
			eco => 'C53',
			# TRANSLATORS: C53: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Qe7 5. d4 Bb6 6. O-O
			variation => N__('Giuoco Piano: Centre-Holding Variation'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r1b1k2r/ppppqppp/1bn2n2/4p3/2BPP3/2P2N2/PP3PPP/RNBQ1RK1 w kq' => {
			eco => 'C53',
			# TRANSLATORS: C53: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Qe7 5. d4 Bb6 6. O-O Nf6
			variation => N__('Giuoco Piano: Centre-Holding Variation'),
			moves => {
				'a2a4' => 1,
			},
		},
		'r1b1k2r/ppppqppp/1bn2n2/4p3/P1BPP3/2P2N2/1P3PPP/RNBQ1RK1 b kq' => {
			eco => 'C53',
			# TRANSLATORS: C53: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Qe7 5. d4 Bb6 6. O-O Nf6 7. a4
			variation => N__('Giuoco Piano: Centre-Holding Variation'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r1b1k2r/1pppqppp/pbn2n2/4p3/P1BPP3/2P2N2/1P3PPP/RNBQ1RK1 w kq' => {
			eco => 'C53',
			# TRANSLATORS: C53: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Qe7 5. d4 Bb6 6. O-O Nf6 7. a4 a6
			variation => N__('Giuoco Piano: Centre-Holding Variation'),
			moves => {
				'f1e1' => 1,
			},
		},
		'r1b1k2r/1pppqppp/pbn2n2/4p3/P1BPP3/2P2N2/1P3PPP/RNBQR1K1 b kq' => {
			eco => 'C53',
			# TRANSLATORS: C53: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Qe7 5. d4 Bb6 6. O-O Nf6 7. a4 a6 8. Re1
			variation => N__('Giuoco Piano: Centre-Holding Variation'),
			moves => {
				'd7d6' => 1,
			},
		},
		'r1b1k2r/1pp1qppp/pbnp1n2/4p3/P1BPP3/2P2N2/1P3PPP/RNBQR1K1 w kq' => {
			eco => 'C53',
			# TRANSLATORS: C53: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Qe7 5. d4 Bb6 6. O-O Nf6 7. a4 a6 8. Re1 d6
			variation => N__('Giuoco Piano: Centre-Holding Variation'),
			moves => {
				'h2h3' => 1,
			},
		},
		'r1b1k2r/1pp1qppp/pbnp1n2/4p3/P1BPP3/2P2N1P/1P3PP1/RNBQR1K1 b kq' => {
			eco => 'C53',
			# TRANSLATORS: C53: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Qe7 5. d4 Bb6 6. O-O Nf6 7. a4 a6 8. Re1 d6 9. h3
			variation => N__('Giuoco Piano: Tarrasch Variation'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/2b1p3/2B1P3/2P2N2/PP1P1PPP/RNBQK2R w KQkq' => {
			eco => 'C54a',
			# TRANSLATORS: C54a: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6
			variation => N__('Giuoco Piano: 4. c3 Nf6'),
			moves => {
				'b2b4' => 1,
				'd2d3' => 1,
				'd2d4' => 1,
				'e1g1' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/2b1p3/2B1P3/2P2N2/PP1P1PPP/RNBQ1RK1 b kq' => {
			eco => 'C54b',
			# TRANSLATORS: C54b: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. O-O
			variation => N__('Giuoco Piano: Albin Gambit'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/2b1p3/1PB1P3/2P2N2/P2P1PPP/RNBQK2R b KQkq' => {
			eco => 'C54c',
			# TRANSLATORS: C54c: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. b4
			variation => N__('Giuoco Piano: Bird\'s Attack'),
			moves => {
				'c5b6' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/1bn2n2/4p3/1PB1P3/2P2N2/P2P1PPP/RNBQK2R w KQkq' => {
			eco => 'C54c',
			# TRANSLATORS: C54c: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. b4 Bb6
			variation => N__('Giuoco Piano: Bird\'s Attack'),
			moves => {
				'a2a4' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/1bn2n2/4p3/PPB1P3/2P2N2/3P1PPP/RNBQK2R b KQkq' => {
			eco => 'C54c',
			# TRANSLATORS: C54c: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. b4 Bb6 6. a4
			variation => N__('Giuoco Piano: Bird\'s Attack'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/2b1p3/2B1P3/2PP1N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'C54d',
			# TRANSLATORS: C54d: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d3
			variation => N__('Giuoco Pianissimo: 5. d3'),
			moves => {
				'a7a6' => 1,
				'd7d6' => 1,
			},
		},
		'r1bqk2r/1ppp1ppp/p1n2n2/2b1p3/2B1P3/2PP1N2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'C54e',
			# TRANSLATORS: C54e: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d3 a6
			variation => N__('Giuoco Pianissimo: 5. d3 a6'),
			moves => {
			},
		},
		'r1bqk2r/ppp2ppp/2np1n2/2b1p3/2B1P3/2PP1N2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'C54f',
			# TRANSLATORS: C54f: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d3 d6
			variation => N__('Giuoco Pianissimo: 5. d3 d6'),
			moves => {
				'b1d2' => 1,
				'e1g1' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2np1n2/2b1p3/2B1P3/2PP1N2/PP1N1PPP/R1BQK2R b KQkq' => {
			eco => 'C54g',
			# TRANSLATORS: C54g: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d3 d6 6. Nbd2
			variation => N__('Giuoco Pianissimo: 5. d3 d6 6.Nbd2'),
			moves => {
			},
		},
		'r1bqk2r/ppp2ppp/2np1n2/2b1p3/2B1P3/2PP1N2/PP3PPP/RNBQ1RK1 b kq' => {
			eco => 'C54h',
			# TRANSLATORS: C54h: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d3 d6 6. O-O
			variation => N__('Giuoco Pianissimo: 5. d3 d6 6.O-O'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/ppp2ppp/2np1n2/2b1p3/2B1P3/2PP1N2/PP3PPP/RNBQ1RK1 w -' => {
			eco => 'C54i',
			# TRANSLATORS: C54i: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d3 d6 6. O-O O-O
			variation => N__('Giuoco Pianissimo: 5. d3 d6 6.O-O O-O'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/2b1p3/2BPP3/2P2N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'C54j',
			# TRANSLATORS: C54j: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4
			variation => N__('Giuoco Piano: 5. d4'),
			moves => {
				'e5d4' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/2b5/2BpP3/2P2N2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'C54j',
			# TRANSLATORS: C54j: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4
			variation => N__('Giuoco Piano: 5. d4'),
			moves => {
				'c3d4' => 1,
				'e4e5' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/2b1P3/2Bp4/2P2N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'C54k',
			# TRANSLATORS: C54k: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. e5
			variation => N__('Giuoco Piano: 6. e5'),
			moves => {
				'd7d5' => 1,
				'f6e4' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2n2n2/2bpP3/2Bp4/2P2N2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'C54k',
			# TRANSLATORS: C54k: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. e5 d5
			variation => N__('Giuoco Piano: 6. e5 d5'),
			moves => {
				'c4b5' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2n2n2/1BbpP3/3p4/2P2N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'C54k',
			# TRANSLATORS: C54k: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. e5 d5 7. Bb5
			variation => N__('Giuoco Piano: 6. e5 d5'),
			moves => {
				'f6e4' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2n5/1BbpP3/3pn3/2P2N2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'C54k',
			# TRANSLATORS: C54k: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. e5 d5 7. Bb5 Ne4
			variation => N__('Giuoco Piano: 6. e5 d5'),
			moves => {
				'c3d4' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2n5/1BbpP3/3Pn3/5N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'C54k',
			# TRANSLATORS: C54k: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. e5 d5 7. Bb5 Ne4 8. cxd4
			variation => N__('Giuoco Piano: 6. e5 d5'),
			moves => {
				'c5b4' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2n5/1B1pP3/1b1Pn3/5N2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'C54k',
			# TRANSLATORS: C54k: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. e5 d5 7. Bb5 Ne4 8. cxd4 Bb4+
			variation => N__('Giuoco Piano: Anderssen Variation'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n5/2b1P3/2Bpn3/2P2N2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'C54k',
			# TRANSLATORS: C54k: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. e5 Ne4
			variation => N__('Giuoco Piano: 6. e5'),
			moves => {
				'c4d5' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n5/2bBP3/3pn3/2P2N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'C54k',
			# TRANSLATORS: C54k: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. e5 Ne4 7. Bd5
			variation => N__('Giuoco Piano: 6. e5'),
			moves => {
				'e4f2' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n5/2bBP3/3p4/2P2N2/PP3nPP/RNBQK2R w KQkq' => {
			eco => 'C54k',
			# TRANSLATORS: C54k: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. e5 Ne4 7. Bd5 Nxf2
			variation => N__('Giuoco Piano: 6. e5'),
			moves => {
				'e1f2' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n5/2bBP3/3p4/2P2N2/PP3KPP/RNBQ3R b kq' => {
			eco => 'C54k',
			# TRANSLATORS: C54k: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. e5 Ne4 7. Bd5 Nxf2 8. Kxf2
			variation => N__('Giuoco Piano: 6. e5'),
			moves => {
				'd4c3' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n5/2bBP3/8/2p2N2/PP3KPP/RNBQ3R w kq' => {
			eco => 'C54k',
			# TRANSLATORS: C54k: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. e5 Ne4 7. Bd5 Nxf2 8. Kxf2 dxc3+
			variation => N__('Giuoco Piano: 6. e5'),
			moves => {
				'f2g3' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n5/2bBP3/8/2p2NK1/PP4PP/RNBQ3R b kq' => {
			eco => 'C54k',
			# TRANSLATORS: C54k: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. e5 Ne4 7. Bd5 Nxf2 8. Kxf2 dxc3+ 9. Kg3
			variation => N__('Giuoco Piano: Ghulam Kassim Variation'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/2b5/2BPP3/5N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'C54l',
			# TRANSLATORS: C54l: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4
			variation => N__('Giuoco Piano: 6.cxd4'),
			moves => {
				'c5b4' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/8/1bBPP3/5N2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'C54l',
			# TRANSLATORS: C54l: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+
			variation => N__('Giuoco Piano: 6.cxd4 Bb4+'),
			moves => {
				'b1c3' => 1,
				'c1d2' => 1,
				'e1f1' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/8/1bBPP3/5N2/PP3PPP/RNBQ1K1R b kq' => {
			eco => 'C54l',
			# TRANSLATORS: C54l: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Kf1
			variation => N__('Giuoco Piano: Krakow Variation'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/8/1bBPP3/5N2/PP1B1PPP/RN1QK2R b KQkq' => {
			eco => 'C54m',
			# TRANSLATORS: C54m: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Bd2
			variation => N__('Giuoco Piano: 6.cxd4 Bb4+ 7. Bd2'),
			moves => {
				'f6e4' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n5/8/1bBPn3/5N2/PP1B1PPP/RN1QK2R w KQkq' => {
			eco => 'C54m',
			# TRANSLATORS: C54m: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Bd2 Nxe4
			variation => N__('Giuoco Piano: 6.cxd4 Bb4+ 7. Bd2'),
			moves => {
				'd2b4' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n5/8/1BBPn3/5N2/PP3PPP/RN1QK2R b KQkq' => {
			eco => 'C54m',
			# TRANSLATORS: C54m: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Bd2 Nxe4 8. Bxb4
			variation => N__('Giuoco Piano: 6.cxd4 Bb4+ 7. Bd2'),
			moves => {
				'c6b4' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/8/8/1nBPn3/5N2/PP3PPP/RN1QK2R w KQkq' => {
			eco => 'C54m',
			# TRANSLATORS: C54m: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Bd2 Nxe4 8. Bxb4 Nxb4
			variation => N__('Giuoco Piano: 6.cxd4 Bb4+ 7. Bd2'),
			moves => {
				'c4f7' => 1,
			},
		},
		'r1bqk2r/pppp1Bpp/8/8/1n1Pn3/5N2/PP3PPP/RN1QK2R b KQkq' => {
			eco => 'C54m',
			# TRANSLATORS: C54m: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Bd2 Nxe4 8. Bxb4 Nxb4 9. Bxf7+
			variation => N__('Giuoco Piano: 6.cxd4 Bb4+ 7. Bd2'),
			moves => {
				'e8f7' => 1,
			},
		},
		'r1bq3r/pppp1kpp/8/8/1n1Pn3/5N2/PP3PPP/RN1QK2R w KQ' => {
			eco => 'C54m',
			# TRANSLATORS: C54m: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Bd2 Nxe4 8. Bxb4 Nxb4 9. Bxf7+ Kxf7
			variation => N__('Giuoco Piano: 6.cxd4 Bb4+ 7. Bd2'),
			moves => {
				'd1b3' => 1,
			},
		},
		'r1bq3r/pppp1kpp/8/8/1n1Pn3/1Q3N2/PP3PPP/RN2K2R b KQ' => {
			eco => 'C54m',
			# TRANSLATORS: C54m: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Bd2 Nxe4 8. Bxb4 Nxb4 9. Bxf7+ Kxf7 10. Qb3+
			variation => N__('Giuoco Piano: 6.cxd4 Bb4+ 7. Bd2'),
			moves => {
				'd7d5' => 1,
			},
		},
		'r1bq3r/ppp2kpp/8/3p4/1n1Pn3/1Q3N2/PP3PPP/RN2K2R w KQ' => {
			eco => 'C54m',
			# TRANSLATORS: C54m: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Bd2 Nxe4 8. Bxb4 Nxb4 9. Bxf7+ Kxf7 10. Qb3+ d5
			variation => N__('Giuoco Piano: 6.cxd4 Bb4+ 7. Bd2'),
			moves => {
				'f3e5' => 1,
			},
		},
		'r1bq3r/ppp2kpp/8/3pN3/1n1Pn3/1Q6/PP3PPP/RN2K2R b KQ' => {
			eco => 'C54m',
			# TRANSLATORS: C54m: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Bd2 Nxe4 8. Bxb4 Nxb4 9. Bxf7+ Kxf7 10. Qb3+ d5 11. Ne5+
			variation => N__('Giuoco Piano: 6.cxd4 Bb4+ 7. Bd2'),
			moves => {
				'f7f6' => 1,
			},
		},
		'r1bq3r/ppp3pp/5k2/3pN3/1n1Pn3/1Q6/PP3PPP/RN2K2R w KQ' => {
			eco => 'C54m',
			# TRANSLATORS: C54m: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Bd2 Nxe4 8. Bxb4 Nxb4 9. Bxf7+ Kxf7 10. Qb3+ d5 11. Ne5+ Kf6
			variation => N__('Giuoco Piano: 6.cxd4 Bb4+ 7. Bd2'),
			moves => {
				'f2f3' => 1,
			},
		},
		'r1bq3r/ppp3pp/5k2/3pN3/1n1Pn3/1Q3P2/PP4PP/RN2K2R b KQ' => {
			eco => 'C54m',
			# TRANSLATORS: C54m: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Bd2 Nxe4 8. Bxb4 Nxb4 9. Bxf7+ Kxf7 10. Qb3+ d5 11. Ne5+ Kf6 12. f3
			variation => N__('Giuoco Piano: Krause Variation'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/8/1bBPP3/2N2N2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'C54n',
			# TRANSLATORS: C54n: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Nc3
			variation => N__('Giuoco Piano: Greco Attack'),
			moves => {
				'f6e4' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n5/8/1bBPn3/2N2N2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'C54n',
			# TRANSLATORS: C54n: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Nc3 Nxe4
			variation => N__('Giuoco Piano: Greco Attack'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n5/8/1bBPn3/2N2N2/PP3PPP/R1BQ1RK1 b kq' => {
			eco => 'C54n',
			# TRANSLATORS: C54n: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Nc3 Nxe4 8. O-O
			variation => N__('Giuoco Piano: Greco Attack'),
			moves => {
				'b4c3' => 1,
				'e4c3' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n5/8/1bBP4/2n2N2/PP3PPP/R1BQ1RK1 w kq' => {
			eco => 'C54n',
			# TRANSLATORS: C54n: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Nc3 Nxe4 8. O-O Nxc3
			variation => N__('Giuoco Piano: Greco Attack'),
			moves => {
				'b2c3' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n5/8/1bBP4/2P2N2/P4PPP/R1BQ1RK1 b kq' => {
			eco => 'C54n',
			# TRANSLATORS: C54n: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Nc3 Nxe4 8. O-O Nxc3 9. bxc3
			variation => N__('Giuoco Piano: Greco Attack'),
			moves => {
				'b4c3' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n5/8/2BP4/2b2N2/P4PPP/R1BQ1RK1 w kq' => {
			eco => 'C54n',
			# TRANSLATORS: C54n: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Nc3 Nxe4 8. O-O Nxc3 9. bxc3 Bxc3
			variation => N__('Giuoco Piano: Greco Attack'),
			moves => {
				'c1a3' => 1,
				'd1b3' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n5/8/2BP4/B1b2N2/P4PPP/R2Q1RK1 b kq' => {
			eco => 'C54n',
			# TRANSLATORS: C54n: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Nc3 Nxe4 8. O-O Nxc3 9. bxc3 Bxc3 10. Ba3
			variation => N__('Giuoco Piano: Aitken Variation'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n5/8/2BP4/1Qb2N2/P4PPP/R1B2RK1 b kq' => {
			eco => 'C54n',
			# TRANSLATORS: C54n: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Nc3 Nxe4 8. O-O Nxc3 9. bxc3 Bxc3 10. Qb3
			variation => N__('Giuoco Piano: Greco Attack'),
			moves => {
				'd7d5' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2n5/3p4/2BP4/1Qb2N2/P4PPP/R1B2RK1 w kq' => {
			eco => 'C54n',
			# TRANSLATORS: C54n: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Nc3 Nxe4 8. O-O Nxc3 9. bxc3 Bxc3 10. Qb3 d5
			variation => N__('Giuoco Piano: Bernstein Variation'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n5/8/2BPn3/2b2N2/PP3PPP/R1BQ1RK1 w kq' => {
			eco => 'C54o',
			# TRANSLATORS: C54o: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Nc3 Nxe4 8. O-O Bxc3
			variation => N__('Giuoco Piano: Greco Attack'),
			moves => {
				'b2c3' => 1,
				'd4d5' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n5/8/2BPn3/2P2N2/P4PPP/R1BQ1RK1 b kq' => {
			eco => 'C54o',
			# TRANSLATORS: C54o: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Nc3 Nxe4 8. O-O Bxc3 9. bxc3
			variation => N__('Giuoco Piano: Greco Attack'),
			moves => {
				'd7d5' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2n5/3p4/2BPn3/2P2N2/P4PPP/R1BQ1RK1 w kq' => {
			eco => 'C54o',
			# TRANSLATORS: C54o: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Nc3 Nxe4 8. O-O Bxc3 9. bxc3 d5
			variation => N__('Giuoco Piano: Greco Attack'),
			moves => {
				'c1a3' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2n5/3p4/2BPn3/B1P2N2/P4PPP/R2Q1RK1 b kq' => {
			eco => 'C54o',
			# TRANSLATORS: C54o: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Nc3 Nxe4 8. O-O Bxc3 9. bxc3 d5 10. Ba3
			variation => N__('Giuoco Piano: Steinitz Variation'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n5/3P4/2B1n3/2b2N2/PP3PPP/R1BQ1RK1 b kq' => {
			eco => 'C54o',
			# TRANSLATORS: C54o: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Nc3 Nxe4 8. O-O Bxc3 9. d5
			variation => N__('Giuoco Piano: Möller (Therkatz) Attack'),
			moves => {
				'c3f6' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2b2/3P4/2B1n3/5N2/PP3PPP/R1BQ1RK1 w kq' => {
			eco => 'C54o',
			# TRANSLATORS: C54o: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Nc3 Nxe4 8. O-O Bxc3 9. d5 Bf6
			variation => N__('Giuoco Piano: Möller (Therkatz) Attack'),
			moves => {
				'f1e1' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2b2/3P4/2B1n3/5N2/PP3PPP/R1BQR1K1 b kq' => {
			eco => 'C54o',
			# TRANSLATORS: C54o: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Nc3 Nxe4 8. O-O Bxc3 9. d5 Bf6 10. Re1
			variation => N__('Giuoco Piano: Möller (Therkatz) Attack'),
			moves => {
				'c6e7' => 1,
			},
		},
		'r1bqk2r/ppppnppp/5b2/3P4/2B1n3/5N2/PP3PPP/R1BQR1K1 w kq' => {
			eco => 'C54o',
			# TRANSLATORS: C54o: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Nc3 Nxe4 8. O-O Bxc3 9. d5 Bf6 10. Re1 Ne7
			variation => N__('Giuoco Piano: Möller (Therkatz) Attack'),
			moves => {
				'e1e4' => 1,
			},
		},
		'r1bqk2r/ppppnppp/5b2/3P4/2B1R3/5N2/PP3PPP/R1BQ2K1 b kq' => {
			eco => 'C54o',
			# TRANSLATORS: C54o: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Nc3 Nxe4 8. O-O Bxc3 9. d5 Bf6 10. Re1 Ne7 11. Rxe4
			variation => N__('Giuoco Piano: Möller (Therkatz) Attack'),
			moves => {
				'd7d6' => 1,
			},
		},
		'r1bqk2r/ppp1nppp/3p1b2/3P4/2B1R3/5N2/PP3PPP/R1BQ2K1 w kq' => {
			eco => 'C54o',
			# TRANSLATORS: C54o: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Nc3 Nxe4 8. O-O Bxc3 9. d5 Bf6 10. Re1 Ne7 11. Rxe4 d6
			variation => N__('Giuoco Piano: Möller (Therkatz) Attack'),
			moves => {
				'c1g5' => 1,
				'g2g4' => 1,
			},
		},
		'r1bqk2r/ppp1nppp/3p1b2/3P2B1/2B1R3/5N2/PP3PPP/R2Q2K1 b kq' => {
			eco => 'C54o',
			# TRANSLATORS: C54o: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Nc3 Nxe4 8. O-O Bxc3 9. d5 Bf6 10. Re1 Ne7 11. Rxe4 d6 12. Bg5
			variation => N__('Giuoco Piano: Möller (Therkatz) Attack'),
			moves => {
				'f6g5' => 1,
			},
		},
		'r1bqk2r/ppp1nppp/3p4/3P2b1/2B1R3/5N2/PP3PPP/R2Q2K1 w kq' => {
			eco => 'C54o',
			# TRANSLATORS: C54o: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Nc3 Nxe4 8. O-O Bxc3 9. d5 Bf6 10. Re1 Ne7 11. Rxe4 d6 12. Bg5 Bxg5
			variation => N__('Giuoco Piano: Möller (Therkatz) Attack'),
			moves => {
				'f3g5' => 1,
			},
		},
		'r1bqk2r/ppp1nppp/3p4/3P2N1/2B1R3/8/PP3PPP/R2Q2K1 b kq' => {
			eco => 'C54o',
			# TRANSLATORS: C54o: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Nc3 Nxe4 8. O-O Bxc3 9. d5 Bf6 10. Re1 Ne7 11. Rxe4 d6 12. Bg5 Bxg5 13. Nxg5
			variation => N__('Giuoco Piano: Möller (Therkatz) Attack'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/ppp1nppp/3p4/3P2N1/2B1R3/8/PP3PPP/R2Q2K1 w -' => {
			eco => 'C54o',
			# TRANSLATORS: C54o: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Nc3 Nxe4 8. O-O Bxc3 9. d5 Bf6 10. Re1 Ne7 11. Rxe4 d6 12. Bg5 Bxg5 13. Nxg5 O-O
			variation => N__('Giuoco Piano: Möller (Therkatz) Attack'),
			moves => {
				'g5h7' => 1,
			},
		},
		'r1bq1rk1/ppp1nppN/3p4/3P4/2B1R3/8/PP3PPP/R2Q2K1 b -' => {
			eco => 'C54o',
			# TRANSLATORS: C54o: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Nc3 Nxe4 8. O-O Bxc3 9. d5 Bf6 10. Re1 Ne7 11. Rxe4 d6 12. Bg5 Bxg5 13. Nxg5 O-O 14. Nxh7
			variation => N__('Giuoco Piano: Möller-Herzog Variation'),
			moves => {
			},
		},
		'r1bqk2r/ppp1nppp/3p1b2/3P4/2B1R1P1/5N2/PP3P1P/R1BQ2K1 b kq' => {
			eco => 'C54o',
			# TRANSLATORS: C54o: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Bc5 4. c3 Nf6 5. d4 exd4 6. cxd4 Bb4+ 7. Nc3 Nxe4 8. O-O Bxc3 9. d5 Bf6 10. Re1 Ne7 11. Rxe4 d6 12. g4
			variation => N__('Giuoco Piano: Möller, Bayonet Attack'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4p3/2B1P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C55a',
			# TRANSLATORS: C55a: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6
			variation => N__('Two Knights Defence'),
			moves => {
				'd2d3' => 1,
				'd2d4' => 1,
				'e1g1' => 1,
				'f3g5' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4p3/2B1P3/5N2/PPPP1PPP/RNBQ1RK1 b kq' => {
			eco => 'C55a',
			# TRANSLATORS: C55a: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. O-O
			variation => N__('Two Knights Defence'),
			moves => {
				'f8c5' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/2b1p3/2BPP3/5N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C55b',
			# TRANSLATORS: C55b: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. O-O Bc5 5. d4
			variation => N__('Two Knights: Deutz Gambit'),
			moves => {
				'c5d4' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/4p3/2BbP3/5N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C55b',
			# TRANSLATORS: C55b: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. O-O Bc5 5. d4 Bxd4
			variation => N__('Two Knights: Deutz Gambit'),
			moves => {
				'f3d4' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/4p3/2BNP3/8/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C55b',
			# TRANSLATORS: C55b: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. O-O Bc5 5. d4 Bxd4 6. Nxd4
			variation => N__('Two Knights: Deutz Gambit'),
			moves => {
				'c6d4' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/5n2/4p3/2BnP3/8/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C55b',
			# TRANSLATORS: C55b: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. O-O Bc5 5. d4 Bxd4 6. Nxd4 Nxd4
			variation => N__('Two Knights: Deutz Gambit'),
			moves => {
				'c1g5' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/5n2/4p1B1/2BnP3/8/PPP2PPP/RN1Q1RK1 b kq' => {
			eco => 'C55b',
			# TRANSLATORS: C55b: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. O-O Bc5 5. d4 Bxd4 6. Nxd4 Nxd4 7. Bg5
			variation => N__('Two Knights: Deutz Gambit'),
			moves => {
				'd7d6' => 1,
				'h7h6' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/3p1n2/4p1B1/2BnP3/8/PPP2PPP/RN1Q1RK1 w kq' => {
			eco => 'C55b',
			# TRANSLATORS: C55b: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. O-O Bc5 5. d4 Bxd4 6. Nxd4 Nxd4 7. Bg5 d6
			variation => N__('Two Knights: Deutz Gambit'),
			moves => {
				'f2f4' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/3p1n2/4p1B1/2BnPP2/8/PPP3PP/RN1Q1RK1 b kq' => {
			eco => 'C55b',
			# TRANSLATORS: C55b: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. O-O Bc5 5. d4 Bxd4 6. Nxd4 Nxd4 7. Bg5 d6 8. f4
			variation => N__('Two Knights: Deutz Gambit'),
			moves => {
				'd8e7' => 1,
			},
		},
		'r1b1k2r/ppp1qppp/3p1n2/4p1B1/2BnPP2/8/PPP3PP/RN1Q1RK1 w kq' => {
			eco => 'C55b',
			# TRANSLATORS: C55b: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. O-O Bc5 5. d4 Bxd4 6. Nxd4 Nxd4 7. Bg5 d6 8. f4 Qe7
			variation => N__('Two Knights: Deutz Gambit'),
			moves => {
				'f4e5' => 1,
			},
		},
		'r1b1k2r/ppp1qppp/3p1n2/4P1B1/2BnP3/8/PPP3PP/RN1Q1RK1 b kq' => {
			eco => 'C55b',
			# TRANSLATORS: C55b: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. O-O Bc5 5. d4 Bxd4 6. Nxd4 Nxd4 7. Bg5 d6 8. f4 Qe7 9. fxe5
			variation => N__('Two Knights: Deutz Gambit'),
			moves => {
				'd6e5' => 1,
			},
		},
		'r1b1k2r/ppp1qppp/5n2/4p1B1/2BnP3/8/PPP3PP/RN1Q1RK1 w kq' => {
			eco => 'C55b',
			# TRANSLATORS: C55b: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. O-O Bc5 5. d4 Bxd4 6. Nxd4 Nxd4 7. Bg5 d6 8. f4 Qe7 9. fxe5 dxe5
			variation => N__('Two Knights: Deutz Gambit'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r1b1k2r/ppp1qppp/5n2/4p1B1/2BnP3/2N5/PPP3PP/R2Q1RK1 b kq' => {
			eco => 'C55b',
			# TRANSLATORS: C55b: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. O-O Bc5 5. d4 Bxd4 6. Nxd4 Nxd4 7. Bg5 d6 8. f4 Qe7 9. fxe5 dxe5 10. Nc3
			variation => N__('Two Knights: 4.O-O Gambit, Holzhausen Attack'),
			moves => {
			},
		},
		'r1bqk2r/pppp1pp1/5n1p/4p1B1/2BnP3/8/PPP2PPP/RN1Q1RK1 w kq' => {
			eco => 'C55b',
			# TRANSLATORS: C55b: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. O-O Bc5 5. d4 Bxd4 6. Nxd4 Nxd4 7. Bg5 h6
			variation => N__('Two Knights: Deutz Gambit'),
			moves => {
				'g5h4' => 1,
			},
		},
		'r1bqk2r/pppp1pp1/5n1p/4p3/2BnP2B/8/PPP2PPP/RN1Q1RK1 b kq' => {
			eco => 'C55b',
			# TRANSLATORS: C55b: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. O-O Bc5 5. d4 Bxd4 6. Nxd4 Nxd4 7. Bg5 h6 8. Bh4
			variation => N__('Two Knights: Deutz Gambit'),
			moves => {
				'g7g5' => 1,
			},
		},
		'r1bqk2r/pppp1p2/5n1p/4p1p1/2BnP2B/8/PPP2PPP/RN1Q1RK1 w kq' => {
			eco => 'C55b',
			# TRANSLATORS: C55b: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. O-O Bc5 5. d4 Bxd4 6. Nxd4 Nxd4 7. Bg5 h6 8. Bh4 g5
			variation => N__('Two Knights: Deutz Gambit'),
			moves => {
				'f2f4' => 1,
			},
		},
		'r1bqk2r/pppp1p2/5n1p/4p1p1/2BnPP1B/8/PPP3PP/RN1Q1RK1 b kq' => {
			eco => 'C55b',
			# TRANSLATORS: C55b: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. O-O Bc5 5. d4 Bxd4 6. Nxd4 Nxd4 7. Bg5 h6 8. Bh4 g5 9. f4
			variation => N__('Two Knights: 4.O-O Gambit, Rosentreter Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4p3/2B1P3/3P1N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C55c',
			# TRANSLATORS: C55c: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d3
			variation => N__('Two Knights: 4. d3'),
			moves => {
				'f8e7' => 1,
				'h7h6' => 1,
			},
		},
		'r1bqkb1r/pppp1pp1/2n2n1p/4p3/2B1P3/3P1N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C55d',
			# TRANSLATORS: C55d: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d3 h6
			variation => N__('Two Knights: 4. d3 h6'),
			moves => {
			},
		},
		'r1bqk2r/ppppbppp/2n2n2/4p3/2B1P3/3P1N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C55e',
			# TRANSLATORS: C55e: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d3 Be7
			variation => N__('Two Knights: 4. d3 Be7'),
			moves => {
				'c2c3' => 1,
				'c4b3' => 1,
				'e1g1' => 1,
			},
		},
		'r1bqk2r/ppppbppp/2n2n2/4p3/4P3/1B1P1N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C55e',
			# TRANSLATORS: C55e: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d3 Be7 5. Bb3
			variation => N__('Two Knights: 4. d3 Be7'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/ppppbppp/2n2n2/4p3/4P3/1B1P1N2/PPP2PPP/RNBQK2R w KQ' => {
			eco => 'C55e',
			# TRANSLATORS: C55e: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d3 Be7 5. Bb3 O-O
			variation => N__('Two Knights: 4. d3 Be7 5. Bb3 O-O'),
			moves => {
			},
		},
		'r1bqk2r/ppppbppp/2n2n2/4p3/2B1P3/2PP1N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'C55f',
			# TRANSLATORS: C55f: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d3 Be7 5. c3
			variation => N__('Two Knights: 4. d3 Be7 5. c3'),
			moves => {
			},
		},
		'r1bqk2r/ppppbppp/2n2n2/4p3/2B1P3/3P1N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C55g',
			# TRANSLATORS: C55g: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d3 Be7 5. O-O
			variation => N__('Two Knights: 4. d3 Be7 5.O-O'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/ppppbppp/2n2n2/4p3/2B1P3/3P1N2/PPP2PPP/RNBQ1RK1 w -' => {
			eco => 'C55h',
			# TRANSLATORS: C55h: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d3 Be7 5. O-O O-O
			variation => N__('Two Knights: 4. d3 Be7 5.O-O O-O'),
			moves => {
				'c4b3' => 1,
				'f1e1' => 1,
			},
		},
		'r1bq1rk1/ppppbppp/2n2n2/4p3/4P3/1B1P1N2/PPP2PPP/RNBQ1RK1 b -' => {
			eco => 'C55i',
			# TRANSLATORS: C55i: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d3 Be7 5. O-O O-O 6. Bb3
			variation => N__('Two Knights: 4. d3 Be7 5.O-O O-O 6. Bb3'),
			moves => {
				'd7d6' => 1,
			},
		},
		'r1bq1rk1/ppp1bppp/2np1n2/4p3/4P3/1B1P1N2/PPP2PPP/RNBQ1RK1 w -' => {
			eco => 'C55i',
			# TRANSLATORS: C55i: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d3 Be7 5. O-O O-O 6. Bb3 d6
			variation => N__('Two Knights: 4. d3 Be7 5.O-O O-O 6. Bb3'),
			moves => {
				'c2c3' => 1,
			},
		},
		'r1bq1rk1/ppp1bppp/2np1n2/4p3/4P3/1BPP1N2/PP3PPP/RNBQ1RK1 b -' => {
			eco => 'C55j',
			# TRANSLATORS: C55j: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d3 Be7 5. O-O O-O 6. Bb3 d6 7. c3
			variation => N__('Two Knights: 4. d3 Be7 5.O-O O-O 6. Bb3 d6 7. c3'),
			moves => {
			},
		},
		'r1bq1rk1/ppppbppp/2n2n2/4p3/2B1P3/3P1N2/PPP2PPP/RNBQR1K1 b -' => {
			eco => 'C55k',
			# TRANSLATORS: C55k: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d3 Be7 5. O-O O-O 6. Re1
			variation => N__('Two Knights: 4. d3 Be7 5.O-O O-O 6. Re1'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4p3/2BPP3/5N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C55l',
			# TRANSLATORS: C55l: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4
			variation => N__('Two Knights: 4. d4'),
			moves => {
				'e5d4' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/8/2BpP3/5N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C55l',
			# TRANSLATORS: C55l: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4
			variation => N__('Two Knights: 4. d4 exd4'),
			moves => {
				'e1g1' => 1,
				'e4e5' => 1,
				'f3d4' => 1,
				'f3g5' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/8/2BNP3/8/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C55m',
			# TRANSLATORS: C55m: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. Nxd4
			variation => N__('Two Knights: 4. d4 exd4 5.Nxd4'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/6N1/2BpP3/8/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C55n',
			# TRANSLATORS: C55n: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. Ng5
			variation => N__('Two Knights: Perreux Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4P3/2Bp4/5N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C55o',
			# TRANSLATORS: C55o: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. e5
			variation => N__('Two Knights: Modern Variation'),
			moves => {
				'd7d5' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2n2n2/3pP3/2Bp4/5N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C55p',
			# TRANSLATORS: C55p: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. e5 d5
			variation => N__('Two Knights: Modern, 5. e5 d5'),
			moves => {
				'c4b5' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2n2n2/1B1pP3/3p4/5N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C55p',
			# TRANSLATORS: C55p: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. e5 d5 6. Bb5
			variation => N__('Two Knights: Modern, 5. e5 d5'),
			moves => {
				'f6e4' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2n5/1B1pP3/3pn3/5N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C55p',
			# TRANSLATORS: C55p: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. e5 d5 6. Bb5 Ne4
			variation => N__('Two Knights: Modern, 5. e5 d5'),
			moves => {
				'f3d4' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2n5/1B1pP3/3Nn3/8/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C55p',
			# TRANSLATORS: C55p: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. e5 d5 6. Bb5 Ne4 7. Nxd4
			variation => N__('Two Knights: Modern, 5. e5 d5'),
			moves => {
				'c8d7' => 1,
			},
		},
		'r2qkb1r/pppb1ppp/2n5/1B1pP3/3Nn3/8/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C55q',
			# TRANSLATORS: C55q: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. e5 d5 6. Bb5 Ne4 7. Nxd4 Bd7
			variation => N__('Two Knights: Modern, Main Line'),
			moves => {
				'b5c6' => 1,
			},
		},
		'r2qkb1r/pppb1ppp/2B5/3pP3/3Nn3/8/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C55q',
			# TRANSLATORS: C55q: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. e5 d5 6. Bb5 Ne4 7. Nxd4 Bd7 8. Bxc6
			variation => N__('Two Knights: Modern, Main Line'),
			moves => {
				'b7c6' => 1,
			},
		},
		'r2qkb1r/p1pb1ppp/2p5/3pP3/3Nn3/8/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C55q',
			# TRANSLATORS: C55q: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. e5 d5 6. Bb5 Ne4 7. Nxd4 Bd7 8. Bxc6 bxc6
			variation => N__('Two Knights: Modern, Main Line'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r2qkb1r/p1pb1ppp/2p5/3pP3/3Nn3/8/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C55q',
			# TRANSLATORS: C55q: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. e5 d5 6. Bb5 Ne4 7. Nxd4 Bd7 8. Bxc6 bxc6 9. O-O
			variation => N__('Two Knights: Modern, Main Line'),
			moves => {
				'f8c5' => 1,
			},
		},
		'r2qk2r/p1pb1ppp/2p5/2bpP3/3Nn3/8/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C55r',
			# TRANSLATORS: C55r: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. e5 d5 6. Bb5 Ne4 7. Nxd4 Bd7 8. Bxc6 bxc6 9. O-O Bc5
			variation => N__('Two Knights: Modern, Main Line, 8.Bxc6 bxc6 9.O-O Bc5'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/8/2BpP3/5N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C55s',
			# TRANSLATORS: C55s: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O
			variation => N__('Two Knights: 5.O-O'),
			moves => {
				'd7d6' => 1,
				'f6e4' => 1,
				'f8c5' => 1,
				'f8e7' => 1,
			},
		},
		'r1bqk2r/ppppbppp/2n2n2/8/2BpP3/5N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C55s',
			# TRANSLATORS: C55s: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Be7
			variation => N__('Two Knights: 5.O-O Be7'),
			moves => {
			},
		},
		'r1bqkb1r/ppp2ppp/2np1n2/8/2BpP3/5N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C55t',
			# TRANSLATORS: C55t: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O d6
			variation => N__('Two Knights: 5.O-O d6'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/2b5/2BpP3/5N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C55u',
			# TRANSLATORS: C55u: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Bc5
			variation => N__('Two Knights: Max Lange Attack'),
			moves => {
				'e4e5' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/2b1P3/2Bp4/5N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C55u',
			# TRANSLATORS: C55u: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Bc5 6. e5
			variation => N__('Two Knights: Max Lange Attack'),
			moves => {
				'd7d5' => 1,
				'f6g4' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n5/2b1P3/2Bp2n1/5N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C55v',
			# TRANSLATORS: C55v: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Bc5 6. e5 Ng4
			variation => N__('Two Knights: Max Lange, Steinitz Variation'),
			moves => {
				'c2c3' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n5/2b1P3/2Bp2n1/2P2N2/PP3PPP/RNBQ1RK1 b kq' => {
			eco => 'C55v',
			# TRANSLATORS: C55v: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Bc5 6. e5 Ng4 7. c3
			variation => N__('Two Knights: Max Lange, Krause Variation'),
			moves => {
			},
		},
		'r1bqk2r/ppp2ppp/2n2n2/2bpP3/2Bp4/5N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C55w',
			# TRANSLATORS: C55w: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Bc5 6. e5 d5
			variation => N__('Two Knights: Max Lange, 6. e5 d5'),
			moves => {
				'e5f6' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2n2P2/2bp4/2Bp4/5N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C55w',
			# TRANSLATORS: C55w: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Bc5 6. e5 d5 7. exf6
			variation => N__('Two Knights: Max Lange, 6. e5 d5'),
			moves => {
				'd5c4' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2n2P2/2b5/2pp4/5N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C55w',
			# TRANSLATORS: C55w: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Bc5 6. e5 d5 7. exf6 dxc4
			variation => N__('Two Knights: Max Lange, 6. e5 d5'),
			moves => {
				'f1e1' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2n2P2/2b5/2pp4/5N2/PPP2PPP/RNBQR1K1 b kq' => {
			eco => 'C55w',
			# TRANSLATORS: C55w: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Bc5 6. e5 d5 7. exf6 dxc4 8. Re1+
			variation => N__('Two Knights: Max Lange, 6. e5 d5'),
			moves => {
				'c8e6' => 1,
			},
		},
		'r2qk2r/ppp2ppp/2n1bP2/2b5/2pp4/5N2/PPP2PPP/RNBQR1K1 w kq' => {
			eco => 'C55w',
			# TRANSLATORS: C55w: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Bc5 6. e5 d5 7. exf6 dxc4 8. Re1+ Be6
			variation => N__('Two Knights: Max Lange, 6. e5 d5'),
			moves => {
				'f3g5' => 1,
				'f6g7' => 1,
			},
		},
		'r2qk2r/ppp2ppp/2n1bP2/2b3N1/2pp4/8/PPP2PPP/RNBQR1K1 b kq' => {
			eco => 'C55w',
			# TRANSLATORS: C55w: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Bc5 6. e5 d5 7. exf6 dxc4 8. Re1+ Be6 9. Ng5
			variation => N__('Two Knights: Max Lange, 6. e5 d5'),
			moves => {
				'd8d5' => 1,
				'g7g6' => 1,
			},
		},
		'r3k2r/ppp2ppp/2n1bP2/2bq2N1/2pp4/8/PPP2PPP/RNBQR1K1 w kq' => {
			eco => 'C55w',
			# TRANSLATORS: C55w: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Bc5 6. e5 d5 7. exf6 dxc4 8. Re1+ Be6 9. Ng5 Qd5
			variation => N__('Two Knights: Max Lange, 6. e5 d5'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r3k2r/ppp2ppp/2n1bP2/2bq2N1/2pp4/2N5/PPP2PPP/R1BQR1K1 b kq' => {
			eco => 'C55w',
			# TRANSLATORS: C55w: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Bc5 6. e5 d5 7. exf6 dxc4 8. Re1+ Be6 9. Ng5 Qd5 10. Nc3
			variation => N__('Two Knights: Max Lange, 6. e5 d5'),
			moves => {
				'd5f5' => 1,
			},
		},
		'r3k2r/ppp2ppp/2n1bP2/2b2qN1/2pp4/2N5/PPP2PPP/R1BQR1K1 w kq' => {
			eco => 'C55w',
			# TRANSLATORS: C55w: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Bc5 6. e5 d5 7. exf6 dxc4 8. Re1+ Be6 9. Ng5 Qd5 10. Nc3 Qf5
			variation => N__('Two Knights: Max Lange, 6. e5 d5'),
			moves => {
				'c3e4' => 1,
				'g2g4' => 1,
			},
		},
		'r3k2r/ppp2ppp/2n1bP2/2b2qN1/2pp2P1/2N5/PPP2P1P/R1BQR1K1 b kq' => {
			eco => 'C55w',
			# TRANSLATORS: C55w: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Bc5 6. e5 d5 7. exf6 dxc4 8. Re1+ Be6 9. Ng5 Qd5 10. Nc3 Qf5 11. g4
			variation => N__('Two Knights: Max Lange, 6. e5 d5'),
			moves => {
				'f5g6' => 1,
			},
		},
		'r3k2r/ppp2ppp/2n1bPq1/2b3N1/2pp2P1/2N5/PPP2P1P/R1BQR1K1 w kq' => {
			eco => 'C55w',
			# TRANSLATORS: C55w: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Bc5 6. e5 d5 7. exf6 dxc4 8. Re1+ Be6 9. Ng5 Qd5 10. Nc3 Qf5 11. g4 Qg6
			variation => N__('Two Knights: Max Lange, 6. e5 d5'),
			moves => {
				'c3e4' => 1,
			},
		},
		'r3k2r/ppp2ppp/2n1bPq1/2b3N1/2ppN1P1/8/PPP2P1P/R1BQR1K1 b kq' => {
			eco => 'C55w',
			# TRANSLATORS: C55w: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Bc5 6. e5 d5 7. exf6 dxc4 8. Re1+ Be6 9. Ng5 Qd5 10. Nc3 Qf5 11. g4 Qg6 12. Nce4
			variation => N__('Two Knights: Max Lange, 6. e5 d5'),
			moves => {
				'c5b6' => 1,
			},
		},
		'r3k2r/ppp2ppp/1bn1bPq1/6N1/2ppN1P1/8/PPP2P1P/R1BQR1K1 w kq' => {
			eco => 'C55w',
			# TRANSLATORS: C55w: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Bc5 6. e5 d5 7. exf6 dxc4 8. Re1+ Be6 9. Ng5 Qd5 10. Nc3 Qf5 11. g4 Qg6 12. Nce4 Bb6
			variation => N__('Two Knights: Max Lange, 6. e5 d5'),
			moves => {
				'f2f4' => 1,
			},
		},
		'r3k2r/ppp2ppp/1bn1bPq1/6N1/2ppNPP1/8/PPP4P/R1BQR1K1 b kq' => {
			eco => 'C55w',
			# TRANSLATORS: C55w: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Bc5 6. e5 d5 7. exf6 dxc4 8. Re1+ Be6 9. Ng5 Qd5 10. Nc3 Qf5 11. g4 Qg6 12. Nce4 Bb6 13. f4
			variation => N__('Two Knights: Max Lange, 6. e5 d5'),
			moves => {
				'e8c8' => 1,
			},
		},
		'r2qk2r/ppp2pPp/2n1b3/2b5/2pp4/5N2/PPP2PPP/RNBQR1K1 b kq' => {
			eco => 'C55w',
			# TRANSLATORS: C55w: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Bc5 6. e5 d5 7. exf6 dxc4 8. Re1+ Be6 9. fxg7
			variation => N__('Two Knights: Max Lange, Schlechter Variation'),
			moves => {
			},
		},
		'r3k2r/ppp2ppp/2n1bP2/2b2qN1/2ppN3/8/PPP2PPP/R1BQR1K1 b kq' => {
			eco => 'C55x',
			# TRANSLATORS: C55x: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Bc5 6. e5 d5 7. exf6 dxc4 8. Re1+ Be6 9. Ng5 Qd5 10. Nc3 Qf5 11. Nce4
			variation => N__('Two Knights: Max Lange, Marshall Variation'),
			moves => {
				'c5f8' => 1,
			},
		},
		'r3kb1r/ppp2ppp/2n1bP2/5qN1/2ppN3/8/PPP2PPP/R1BQR1K1 w kq' => {
			eco => 'C55x',
			# TRANSLATORS: C55x: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Bc5 6. e5 d5 7. exf6 dxc4 8. Re1+ Be6 9. Ng5 Qd5 10. Nc3 Qf5 11. Nce4 Bf8
			variation => N__('Two Knights: Max Lange, Rubinstein Variation'),
			moves => {
			},
		},
		'2kr3r/ppp2ppp/1bn1bPq1/6N1/2ppNPP1/8/PPP4P/R1BQR1K1 w -' => {
			eco => 'C55x',
			# TRANSLATORS: C55x: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Bc5 6. e5 d5 7. exf6 dxc4 8. Re1+ Be6 9. Ng5 Qd5 10. Nc3 Qf5 11. g4 Qg6 12. Nce4 Bb6 13. f4 O-O-O
			variation => N__('Two Knights: Max Lange, Berger Variation'),
			moves => {
			},
		},
		'r2qk2r/ppp2p1p/2n1bPp1/2b3N1/2pp4/8/PPP2PPP/RNBQR1K1 w kq' => {
			eco => 'C55x',
			# TRANSLATORS: C55x: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Bc5 6. e5 d5 7. exf6 dxc4 8. Re1+ Be6 9. Ng5 g6
			variation => N__('Two Knights: Max Lange, Loman Defence'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n5/8/2Bpn3/5N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C56a',
			# TRANSLATORS: C56a: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Nxe4
			variation => N__('Two Knights: Classical'),
			moves => {
				'b1c3' => 1,
				'f1e1' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n5/8/2Bpn3/2N2N2/PPP2PPP/R1BQ1RK1 b kq' => {
			eco => 'C56a',
			# TRANSLATORS: C56a: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Nxe4 6. Nc3
			variation => N__('Two Knights: Classical, Nakhmanson Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n5/8/2Bpn3/5N2/PPP2PPP/RNBQR1K1 b kq' => {
			eco => 'C56b',
			# TRANSLATORS: C56b: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Nxe4 6. Re1
			variation => N__('Two Knights: Classical, 6. Re1'),
			moves => {
				'd7d5' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2n5/3p4/2Bpn3/5N2/PPP2PPP/RNBQR1K1 w kq' => {
			eco => 'C56b',
			# TRANSLATORS: C56b: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Nxe4 6. Re1 d5
			variation => N__('Two Knights: Classical, 6. Re1 d5'),
			moves => {
				'b1c3' => 1,
				'c4d5' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2n5/3p4/2Bpn3/2N2N2/PPP2PPP/R1BQR1K1 b kq' => {
			eco => 'C56c',
			# TRANSLATORS: C56c: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Nxe4 6. Re1 d5 7. Nc3
			variation => N__('Two Knights: Classical, Canal Variation'),
			moves => {
			},
		},
		'r1bqkb1r/ppp2ppp/2n5/3B4/3pn3/5N2/PPP2PPP/RNBQR1K1 b kq' => {
			eco => 'C56d',
			# TRANSLATORS: C56d: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Nxe4 6. Re1 d5 7. Bxd5
			variation => N__('Two Knights: Classical, 7.Bxd5'),
			moves => {
				'd8d5' => 1,
			},
		},
		'r1b1kb1r/ppp2ppp/2n5/3q4/3pn3/5N2/PPP2PPP/RNBQR1K1 w kq' => {
			eco => 'C56d',
			# TRANSLATORS: C56d: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Nxe4 6. Re1 d5 7. Bxd5 Qxd5
			variation => N__('Two Knights: Classical, 7.Bxd5 Qxd5'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r1b1kb1r/ppp2ppp/2n5/3q4/3pn3/2N2N2/PPP2PPP/R1BQR1K1 b kq' => {
			eco => 'C56d',
			# TRANSLATORS: C56d: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Nxe4 6. Re1 d5 7. Bxd5 Qxd5 8. Nc3
			variation => N__('Two Knights: Classical, 8. Nc3'),
			moves => {
				'd5a5' => 1,
				'd5d8' => 1,
				'd5h5' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2n5/8/3pn3/2N2N2/PPP2PPP/R1BQR1K1 w kq' => {
			eco => 'C56e',
			# TRANSLATORS: C56e: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Nxe4 6. Re1 d5 7. Bxd5 Qxd5 8. Nc3 Qd8
			variation => N__('Two Knights: Classical, 8. Nc3 Qd8'),
			moves => {
			},
		},
		'r1b1kb1r/ppp2ppp/2n5/7q/3pn3/2N2N2/PPP2PPP/R1BQR1K1 w kq' => {
			eco => 'C56f',
			# TRANSLATORS: C56f: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Nxe4 6. Re1 d5 7. Bxd5 Qxd5 8. Nc3 Qh5
			variation => N__('Two Knights: Classical, 8. Nc3 Qh5'),
			moves => {
				'c3e4' => 1,
			},
		},
		'r1b1kb1r/ppp2ppp/2n5/7q/3pN3/5N2/PPP2PPP/R1BQR1K1 b kq' => {
			eco => 'C56f',
			# TRANSLATORS: C56f: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Nxe4 6. Re1 d5 7. Bxd5 Qxd5 8. Nc3 Qh5 9. Nxe4
			variation => N__('Two Knights: Classical, 8. Nc3 Qh5'),
			moves => {
				'c8e6' => 1,
			},
		},
		'r3kb1r/ppp2ppp/2n1b3/7q/3pN3/5N2/PPP2PPP/R1BQR1K1 w kq' => {
			eco => 'C56f',
			# TRANSLATORS: C56f: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Nxe4 6. Re1 d5 7. Bxd5 Qxd5 8. Nc3 Qh5 9. Nxe4 Be6
			variation => N__('Two Knights: Classical, 8. Nc3 Qh5'),
			moves => {
				'c1g5' => 1,
			},
		},
		'r3kb1r/ppp2ppp/2n1b3/6Bq/3pN3/5N2/PPP2PPP/R2QR1K1 b kq' => {
			eco => 'C56f',
			# TRANSLATORS: C56f: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Nxe4 6. Re1 d5 7. Bxd5 Qxd5 8. Nc3 Qh5 9. Nxe4 Be6 10. Bg5
			variation => N__('Two Knights: Classical, 8. Nc3 Qh5'),
			moves => {
				'f8d6' => 1,
			},
		},
		'r3k2r/ppp2ppp/2nbb3/6Bq/3pN3/5N2/PPP2PPP/R2QR1K1 w kq' => {
			eco => 'C56g',
			# TRANSLATORS: C56g: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Nxe4 6. Re1 d5 7. Bxd5 Qxd5 8. Nc3 Qh5 9. Nxe4 Be6 10. Bg5 Bd6
			variation => N__('Two Knights: Classical, 8. Nc3 Qh5 9.Nxe4 Be6 10. Bg5 Bd6'),
			moves => {
			},
		},
		'r1b1kb1r/ppp2ppp/2n5/q7/3pn3/2N2N2/PPP2PPP/R1BQR1K1 w kq' => {
			eco => 'C56h',
			# TRANSLATORS: C56h: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Nxe4 6. Re1 d5 7. Bxd5 Qxd5 8. Nc3 Qa5
			variation => N__('Two Knights: Classical, Moller Variation'),
			moves => {
				'c3e4' => 1,
			},
		},
		'r1b1kb1r/ppp2ppp/2n5/q7/3pN3/5N2/PPP2PPP/R1BQR1K1 b kq' => {
			eco => 'C56h',
			# TRANSLATORS: C56h: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Nxe4 6. Re1 d5 7. Bxd5 Qxd5 8. Nc3 Qa5 9. Nxe4
			variation => N__('Two Knights: Classical, Moller, 9.Nxe4'),
			moves => {
				'c8e6' => 1,
			},
		},
		'r3kb1r/ppp2ppp/2n1b3/q7/3pN3/5N2/PPP2PPP/R1BQR1K1 w kq' => {
			eco => 'C56h',
			# TRANSLATORS: C56h: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Nxe4 6. Re1 d5 7. Bxd5 Qxd5 8. Nc3 Qa5 9. Nxe4 Be6
			variation => N__('Two Knights: Classical, Moller, 9.Nxe4 Be6'),
			moves => {
				'c1d2' => 1,
				'c1g5' => 1,
				'e4g5' => 1,
			},
		},
		'r3kb1r/ppp2ppp/2n1b3/q5B1/3pN3/5N2/PPP2PPP/R2QR1K1 b kq' => {
			eco => 'C56i',
			# TRANSLATORS: C56i: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Nxe4 6. Re1 d5 7. Bxd5 Qxd5 8. Nc3 Qa5 9. Nxe4 Be6 10. Bg5
			variation => N__('Two Knights: Classical, Moller, 10. Bg5'),
			moves => {
				'h7h6' => 1,
			},
		},
		'r3kb1r/ppp2pp1/2n1b2p/q5B1/3pN3/5N2/PPP2PPP/R2QR1K1 w kq' => {
			eco => 'C56i',
			# TRANSLATORS: C56i: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Nxe4 6. Re1 d5 7. Bxd5 Qxd5 8. Nc3 Qa5 9. Nxe4 Be6 10. Bg5 h6
			variation => N__('Two Knights: Classical, Moller, 10. Bg5'),
			moves => {
				'g5h4' => 1,
			},
		},
		'r3kb1r/ppp2pp1/2n1b2p/q7/3pN2B/5N2/PPP2PPP/R2QR1K1 b kq' => {
			eco => 'C56i',
			# TRANSLATORS: C56i: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Nxe4 6. Re1 d5 7. Bxd5 Qxd5 8. Nc3 Qa5 9. Nxe4 Be6 10. Bg5 h6 11. Bh4
			variation => N__('Two Knights: Classical, Moller, 10. Bg5'),
			moves => {
				'g7g5' => 1,
			},
		},
		'r3kb1r/ppp2p2/2n1b2p/q5p1/3pN2B/5N2/PPP2PPP/R2QR1K1 w kq' => {
			eco => 'C56i',
			# TRANSLATORS: C56i: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Nxe4 6. Re1 d5 7. Bxd5 Qxd5 8. Nc3 Qa5 9. Nxe4 Be6 10. Bg5 h6 11. Bh4 g5
			variation => N__('Two Knights: Classical, Moller, 10. Bg5'),
			moves => {
				'e4f6' => 1,
			},
		},
		'r3kb1r/ppp2p2/2n1bN1p/q5p1/3p3B/5N2/PPP2PPP/R2QR1K1 b kq' => {
			eco => 'C56i',
			# TRANSLATORS: C56i: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Nxe4 6. Re1 d5 7. Bxd5 Qxd5 8. Nc3 Qa5 9. Nxe4 Be6 10. Bg5 h6 11. Bh4 g5 12. Nf6+
			variation => N__('Two Knights: Classical, Moller, 10. Bg5'),
			moves => {
				'e8e7' => 1,
			},
		},
		'r4b1r/ppp1kp2/2n1bN1p/q5p1/3p3B/5N2/PPP2PPP/R2QR1K1 w -' => {
			eco => 'C56i',
			# TRANSLATORS: C56i: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Nxe4 6. Re1 d5 7. Bxd5 Qxd5 8. Nc3 Qa5 9. Nxe4 Be6 10. Bg5 h6 11. Bh4 g5 12. Nf6+ Ke7
			variation => N__('Two Knights: Classical, Moller, 10. Bg5'),
			moves => {
				'b2b4' => 1,
			},
		},
		'r4b1r/ppp1kp2/2n1bN1p/q5p1/1P1p3B/5N2/P1P2PPP/R2QR1K1 b -' => {
			eco => 'C56i',
			# TRANSLATORS: C56i: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Nxe4 6. Re1 d5 7. Bxd5 Qxd5 8. Nc3 Qa5 9. Nxe4 Be6 10. Bg5 h6 11. Bh4 g5 12. Nf6+ Ke7 13. b4
			variation => N__('Two Knights: Classical, Yurdansky Attack'),
			moves => {
			},
		},
		'r3kb1r/ppp2ppp/2n1b3/q5N1/3p4/5N2/PPP2PPP/R1BQR1K1 b kq' => {
			eco => 'C56j',
			# TRANSLATORS: C56j: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Nxe4 6. Re1 d5 7. Bxd5 Qxd5 8. Nc3 Qa5 9. Nxe4 Be6 10. Neg5
			variation => N__('Two Knights: Classical, Moller, 10.Neg5'),
			moves => {
				'e8c8' => 1,
			},
		},
		'2kr1b1r/ppp2ppp/2n1b3/q5N1/3p4/5N2/PPP2PPP/R1BQR1K1 w -' => {
			eco => 'C56j',
			# TRANSLATORS: C56j: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Nxe4 6. Re1 d5 7. Bxd5 Qxd5 8. Nc3 Qa5 9. Nxe4 Be6 10. Neg5 O-O-O
			variation => N__('Two Knights: Classical, Moller, 10.Neg5'),
			moves => {
				'g5e6' => 1,
			},
		},
		'2kr1b1r/ppp2ppp/2n1N3/q7/3p4/5N2/PPP2PPP/R1BQR1K1 b -' => {
			eco => 'C56j',
			# TRANSLATORS: C56j: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Nxe4 6. Re1 d5 7. Bxd5 Qxd5 8. Nc3 Qa5 9. Nxe4 Be6 10. Neg5 O-O-O 11. Nxe6
			variation => N__('Two Knights: Classical, Moller, 10.Neg5'),
			moves => {
				'f7e6' => 1,
			},
		},
		'2kr1b1r/ppp3pp/2n1p3/q7/3p4/5N2/PPP2PPP/R1BQR1K1 w -' => {
			eco => 'C56j',
			# TRANSLATORS: C56j: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Nxe4 6. Re1 d5 7. Bxd5 Qxd5 8. Nc3 Qa5 9. Nxe4 Be6 10. Neg5 O-O-O 11. Nxe6 fxe6
			variation => N__('Two Knights: Classical, Moller, 10.Neg5'),
			moves => {
				'e1e6' => 1,
			},
		},
		'2kr1b1r/ppp3pp/2n1R3/q7/3p4/5N2/PPP2PPP/R1BQ2K1 b -' => {
			eco => 'C56j',
			# TRANSLATORS: C56j: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Nxe4 6. Re1 d5 7. Bxd5 Qxd5 8. Nc3 Qa5 9. Nxe4 Be6 10. Neg5 O-O-O 11. Nxe6 fxe6 12. Rxe6
			variation => N__('Two Knights: Classical, Moller, 10.Neg5'),
			moves => {
				'f8d6' => 1,
			},
		},
		'2kr3r/ppp3pp/2nbR3/q7/3p4/5N2/PPP2PPP/R1BQ2K1 w -' => {
			eco => 'C56k',
			# TRANSLATORS: C56k: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Nxe4 6. Re1 d5 7. Bxd5 Qxd5 8. Nc3 Qa5 9. Nxe4 Be6 10. Neg5 O-O-O 11. Nxe6 fxe6 12. Rxe6 Bd6
			variation => N__('Two Knights: Classical, Moller, 10.Neg5 O-O-O 11.Nxe6 fxe6 12.Rxe6 Bd6'),
			moves => {
			},
		},
		'r3kb1r/ppp2ppp/2n1b3/q7/3pN3/5N2/PPPB1PPP/R2QR1K1 b kq' => {
			eco => 'C56l',
			# TRANSLATORS: C56l: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Nxe4 6. Re1 d5 7. Bxd5 Qxd5 8. Nc3 Qa5 9. Nxe4 Be6 10. Bd2
			variation => N__('Two Knights: Classical, Moller, 10. Bd2'),
			moves => {
				'a5d5' => 1,
				'a5f5' => 1,
				'f8b4' => 1,
			},
		},
		'r3kb1r/ppp2ppp/2n1b3/5q2/3pN3/5N2/PPPB1PPP/R2QR1K1 w kq' => {
			eco => 'C56m',
			# TRANSLATORS: C56m: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Nxe4 6. Re1 d5 7. Bxd5 Qxd5 8. Nc3 Qa5 9. Nxe4 Be6 10. Bd2 Qf5
			variation => N__('Two Knights: Classical, Moller, 10. Bd2 Qf5'),
			moves => {
			},
		},
		'r3kb1r/ppp2ppp/2n1b3/3q4/3pN3/5N2/PPPB1PPP/R2QR1K1 w kq' => {
			eco => 'C56n',
			# TRANSLATORS: C56n: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Nxe4 6. Re1 d5 7. Bxd5 Qxd5 8. Nc3 Qa5 9. Nxe4 Be6 10. Bd2 Qd5
			variation => N__('Two Knights: Classical, Moller, 10. Bd2 Qd5'),
			moves => {
			},
		},
		'r3k2r/ppp2ppp/2n1b3/q7/1b1pN3/5N2/PPPB1PPP/R2QR1K1 w kq' => {
			eco => 'C56o',
			# TRANSLATORS: C56o: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. d4 exd4 5. O-O Nxe4 6. Re1 d5 7. Bxd5 Qxd5 8. Nc3 Qa5 9. Nxe4 Be6 10. Bd2 Bb4
			variation => N__('Two Knights: Classical, Moller, 10. Bd2 Bb4'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/4p1N1/2B1P3/8/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'C57a',
			# TRANSLATORS: C57a: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5
			variation => N__('Two Knights: 4. Ng5'),
			moves => {
				'd7d5' => 1,
				'f8c5' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/2b1p1N1/2B1P3/8/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C57a',
			# TRANSLATORS: C57a: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 Bc5
			variation => N__('Two Knights: Traxler (Wilkes-Barre) Variation'),
			moves => {
				'c4f7' => 1,
				'd2d4' => 1,
				'g5f7' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/2b1p1N1/2BPP3/8/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C57a',
			# TRANSLATORS: C57a: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 Bc5 5. d4
			variation => N__('Two Knights: Traxler, 5. d4'),
			moves => {
			},
		},
		'r1bqk2r/pppp1Npp/2n2n2/2b1p3/2B1P3/8/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'C57b',
			# TRANSLATORS: C57b: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 Bc5 5. Nxf7
			variation => N__('Two Knights: Traxler, 5.Nxf7'),
			moves => {
				'c5f2' => 1,
			},
		},
		'r1bqk2r/pppp1Npp/2n2n2/4p3/2B1P3/8/PPPP1bPP/RNBQK2R w KQkq' => {
			eco => 'C57b',
			# TRANSLATORS: C57b: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 Bc5 5. Nxf7 Bxf2+
			variation => N__('Two Knights: Traxler, 5.Nxf7'),
			moves => {
				'e1f1' => 1,
				'e1f2' => 1,
			},
		},
		'r1bqk2r/pppp1Npp/2n2n2/4p3/2B1P3/8/PPPP1KPP/RNBQ3R b kq' => {
			eco => 'C57b',
			# TRANSLATORS: C57b: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 Bc5 5. Nxf7 Bxf2+ 6. Kxf2
			variation => N__('Two Knights: Traxler, 5.Nxf7 & 6.Kxf2'),
			moves => {
			},
		},
		'r1bqk2r/pppp1Npp/2n2n2/4p3/2B1P3/8/PPPP1bPP/RNBQ1K1R b kq' => {
			eco => 'C57c',
			# TRANSLATORS: C57c: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 Bc5 5. Nxf7 Bxf2+ 6. Kf1
			variation => N__('Two Knights: Traxler, 5.Nxf7 & 6. Kf1'),
			moves => {
				'd8e7' => 1,
			},
		},
		'r1b1k2r/ppppqNpp/2n2n2/4p3/2B1P3/8/PPPP1bPP/RNBQ1K1R w kq' => {
			eco => 'C57c',
			# TRANSLATORS: C57c: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 Bc5 5. Nxf7 Bxf2+ 6. Kf1 Qe7
			variation => N__('Two Knights: Traxler, 5.Nxf7 & 6. Kf1'),
			moves => {
				'f7h8' => 1,
			},
		},
		'r1b1k2N/ppppq1pp/2n2n2/4p3/2B1P3/8/PPPP1bPP/RNBQ1K1R b q' => {
			eco => 'C57c',
			# TRANSLATORS: C57c: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 Bc5 5. Nxf7 Bxf2+ 6. Kf1 Qe7 7. Nxh8
			variation => N__('Two Knights: Traxler, 5.Nxf7 & 6. Kf1'),
			moves => {
				'd7d5' => 1,
			},
		},
		'r1b1k2N/ppp1q1pp/2n2n2/3pp3/2B1P3/8/PPPP1bPP/RNBQ1K1R w q' => {
			eco => 'C57c',
			# TRANSLATORS: C57c: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 Bc5 5. Nxf7 Bxf2+ 6. Kf1 Qe7 7. Nxh8 d5
			variation => N__('Two Knights: Traxler, 5.Nxf7 & 6. Kf1'),
			moves => {
				'e4d5' => 1,
			},
		},
		'r1b1k2N/ppp1q1pp/2n2n2/3Pp3/2B5/8/PPPP1bPP/RNBQ1K1R b q' => {
			eco => 'C57c',
			# TRANSLATORS: C57c: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 Bc5 5. Nxf7 Bxf2+ 6. Kf1 Qe7 7. Nxh8 d5 8. exd5
			variation => N__('Two Knights: Traxler, 5.Nxf7 & 6. Kf1'),
			moves => {
				'c6d4' => 1,
				'c8g4' => 1,
			},
		},
		'r1b1k2N/ppp1q1pp/5n2/3Pp3/2Bn4/8/PPPP1bPP/RNBQ1K1R w q' => {
			eco => 'C57c',
			# TRANSLATORS: C57c: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 Bc5 5. Nxf7 Bxf2+ 6. Kf1 Qe7 7. Nxh8 d5 8. exd5 Nd4
			variation => N__('Two Knights: Traxler, 5.Nxf7 & 6. Kf1, 8... Nd4'),
			moves => {
				'd5d6' => 1,
				'h2h3' => 1,
			},
		},
		'r1b1k2N/ppp1q1pp/3P1n2/4p3/2Bn4/8/PPPP1bPP/RNBQ1K1R b q' => {
			eco => 'C57c',
			# TRANSLATORS: C57c: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 Bc5 5. Nxf7 Bxf2+ 6. Kf1 Qe7 7. Nxh8 d5 8. exd5 Nd4 9. d6
			variation => N__('Two Knights: Traxler, 5.Nxf7 & 6. Kf1, Menovsky Variation'),
			moves => {
			},
		},
		'r1b1k2N/ppp1q1pp/5n2/3Pp3/2Bn4/7P/PPPP1bP1/RNBQ1K1R b q' => {
			eco => 'C57c',
			# TRANSLATORS: C57c: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 Bc5 5. Nxf7 Bxf2+ 6. Kf1 Qe7 7. Nxh8 d5 8. exd5 Nd4 9. h3
			variation => N__('Two Knights: Traxler, 5.Nxf7 & 6. Kf1, Palkin Variation'),
			moves => {
			},
		},
		'r3k2N/ppp1q1pp/2n2n2/3Pp3/2B3b1/8/PPPP1bPP/RNBQ1K1R w q' => {
			eco => 'C57c',
			# TRANSLATORS: C57c: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 Bc5 5. Nxf7 Bxf2+ 6. Kf1 Qe7 7. Nxh8 d5 8. exd5 Bg4
			variation => N__('Two Knights: Traxler, 5.Nxf7 & 6. Kf1, Beyer\'s 8... Bg4'),
			moves => {
			},
		},
		'r1bqk2r/pppp1Bpp/2n2n2/2b1p1N1/4P3/8/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'C57d',
			# TRANSLATORS: C57d: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 Bc5 5. Bxf7+
			variation => N__('Two Knights: Traxler, 5.Bxf7+'),
			moves => {
				'e8e7' => 1,
			},
		},
		'r1bq3r/ppppkBpp/2n2n2/2b1p1N1/4P3/8/PPPP1PPP/RNBQK2R w KQ' => {
			eco => 'C57d',
			# TRANSLATORS: C57d: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 Bc5 5. Bxf7+ Ke7
			variation => N__('Two Knights: Traxler, 5.Bxf7+'),
			moves => {
				'f7b3' => 1,
				'f7d5' => 1,
			},
		},
		'r1bq3r/ppppk1pp/2n2n2/2b1p1N1/4P3/1B6/PPPP1PPP/RNBQK2R b KQ' => {
			eco => 'C57d',
			# TRANSLATORS: C57d: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 Bc5 5. Bxf7+ Ke7 6. Bb3
			variation => N__('Two Knights: Traxler, 5.Bxf7+ Ke7 6. Bb3'),
			moves => {
			},
		},
		'r1bq3r/ppppk1pp/2n2n2/2bBp1N1/4P3/8/PPPP1PPP/RNBQK2R b KQ' => {
			eco => 'C57d',
			# TRANSLATORS: C57d: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 Bc5 5. Bxf7+ Ke7 6. Bd5
			variation => N__('Two Knights: Traxler, Chigorin/Pithart Variation'),
			moves => {
			},
		},
		'r1bqkb1r/ppp2ppp/2n2n2/3pp1N1/2B1P3/8/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C57e',
			# TRANSLATORS: C57e: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5
			variation => N__('Two Knights: 4. Ng5 d5'),
			moves => {
				'e4d5' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2n2n2/3Pp1N1/2B5/8/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'C57e',
			# TRANSLATORS: C57e: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5
			variation => N__('Two Knights: 4. Ng5 d5'),
			moves => {
				'b7b5' => 1,
				'c6a5' => 1,
				'c6b4' => 1,
				'c6d4' => 1,
				'f6d5' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/5n2/3Pp1N1/1nB5/8/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C57e',
			# TRANSLATORS: C57e: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Nb4
			variation => N__('Two Knights: Kloss Variation'),
			moves => {
			},
		},
		'r1bqkb1r/ppp2ppp/2n5/3np1N1/2B5/8/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C57e',
			# TRANSLATORS: C57e: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Nxd5
			variation => N__('Two Knights: 4. Ng5 d5 5.exd5 Nxd5'),
			moves => {
				'd2d4' => 1,
				'g5f7' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2n5/3np1N1/2BP4/8/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C57f',
			# TRANSLATORS: C57f: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Nxd5 6. d4
			variation => N__('Two Knights: Lolli Attack'),
			moves => {
				'f8b4' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2n5/3np1N1/1bBP4/8/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C57f',
			# TRANSLATORS: C57f: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Nxd5 6. d4 Bb4+
			variation => N__('Two Knights: Lolli Attack, Pinkus Variation'),
			moves => {
			},
		},
		'r1bqkb1r/ppp2Npp/2n5/3np3/2B5/8/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'C57g',
			# TRANSLATORS: C57g: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Nxd5 6. Nxf7
			variation => N__('Two Knights: Fegatello (Fried Liver) Attack'),
			moves => {
				'e8f7' => 1,
			},
		},
		'r1bq1b1r/ppp2kpp/2n5/3np3/2B5/8/PPPP1PPP/RNBQK2R w KQ' => {
			eco => 'C57g',
			# TRANSLATORS: C57g: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Nxd5 6. Nxf7 Kxf7
			variation => N__('Two Knights: Fegatello (Fried Liver) Attack'),
			moves => {
				'd1f3' => 1,
			},
		},
		'r1bq1b1r/ppp2kpp/2n5/3np3/2B5/5Q2/PPPP1PPP/RNB1K2R b KQ' => {
			eco => 'C57g',
			# TRANSLATORS: C57g: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Nxd5 6. Nxf7 Kxf7 7. Qf3+
			variation => N__('Two Knights: Fegatello (Fried Liver) Attack'),
			moves => {
				'f7e6' => 1,
			},
		},
		'r1bq1b1r/ppp3pp/2n1k3/3np3/2B5/5Q2/PPPP1PPP/RNB1K2R w KQ' => {
			eco => 'C57g',
			# TRANSLATORS: C57g: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Nxd5 6. Nxf7 Kxf7 7. Qf3+ Ke6
			variation => N__('Two Knights: Fegatello (Fried Liver) Attack'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r1bq1b1r/ppp3pp/2n1k3/3np3/2B5/2N2Q2/PPPP1PPP/R1B1K2R b KQ' => {
			eco => 'C57g',
			# TRANSLATORS: C57g: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Nxd5 6. Nxf7 Kxf7 7. Qf3+ Ke6 8. Nc3
			variation => N__('Two Knights: Fegatello (Fried Liver) Attack'),
			moves => {
				'c6b4' => 1,
				'c6e7' => 1,
			},
		},
		'r1bq1b1r/ppp3pp/4k3/3np3/1nB5/2N2Q2/PPPP1PPP/R1B1K2R w KQ' => {
			eco => 'C57g',
			# TRANSLATORS: C57g: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Nxd5 6. Nxf7 Kxf7 7. Qf3+ Ke6 8. Nc3 Nb4
			variation => N__('Two Knights: Fegatello (Fried Liver) Attack'),
			moves => {
				'f3e4' => 1,
			},
		},
		'r1bq1b1r/ppp3pp/4k3/3np3/1nB1Q3/2N5/PPPP1PPP/R1B1K2R b KQ' => {
			eco => 'C57g',
			# TRANSLATORS: C57g: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Nxd5 6. Nxf7 Kxf7 7. Qf3+ Ke6 8. Nc3 Nb4 9. Qe4
			variation => N__('Two Knights: Fegatello (Fried Liver) Attack'),
			moves => {
				'c7c6' => 1,
			},
		},
		'r1bq1b1r/pp4pp/2p1k3/3np3/1nB1Q3/2N5/PPPP1PPP/R1B1K2R w KQ' => {
			eco => 'C57g',
			# TRANSLATORS: C57g: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Nxd5 6. Nxf7 Kxf7 7. Qf3+ Ke6 8. Nc3 Nb4 9. Qe4 c6
			variation => N__('Two Knights: Fegatello (Fried Liver) Attack'),
			moves => {
				'a2a3' => 1,
			},
		},
		'r1bq1b1r/pp4pp/2p1k3/3np3/1nB1Q3/P1N5/1PPP1PPP/R1B1K2R b KQ' => {
			eco => 'C57g',
			# TRANSLATORS: C57g: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Nxd5 6. Nxf7 Kxf7 7. Qf3+ Ke6 8. Nc3 Nb4 9. Qe4 c6 10. a3
			variation => N__('Two Knights: Fegatello (Fried Liver) Attack'),
			moves => {
				'b4a6' => 1,
			},
		},
		'r1bq1b1r/pp4pp/n1p1k3/3np3/2B1Q3/P1N5/1PPP1PPP/R1B1K2R w KQ' => {
			eco => 'C57g',
			# TRANSLATORS: C57g: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Nxd5 6. Nxf7 Kxf7 7. Qf3+ Ke6 8. Nc3 Nb4 9. Qe4 c6 10. a3 Na6
			variation => N__('Two Knights: Fegatello (Fried Liver) Attack'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bq1b1r/pp4pp/n1p1k3/3np3/2BPQ3/P1N5/1PP2PPP/R1B1K2R b KQ' => {
			eco => 'C57g',
			# TRANSLATORS: C57g: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Nxd5 6. Nxf7 Kxf7 7. Qf3+ Ke6 8. Nc3 Nb4 9. Qe4 c6 10. a3 Na6 11. d4
			variation => N__('Two Knights: Fegatello (Fried Liver) Attack'),
			moves => {
				'a6c7' => 1,
			},
		},
		'r1bq1b1r/ppn3pp/2p1k3/3np3/2BPQ3/P1N5/1PP2PPP/R1B1K2R w KQ' => {
			eco => 'C57g',
			# TRANSLATORS: C57g: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Nxd5 6. Nxf7 Kxf7 7. Qf3+ Ke6 8. Nc3 Nb4 9. Qe4 c6 10. a3 Na6 11. d4 Nc7
			variation => N__('Two Knights: Fegatello, Leonhardt Variation'),
			moves => {
			},
		},
		'r1bq1b1r/ppp1n1pp/4k3/3np3/2B5/2N2Q2/PPPP1PPP/R1B1K2R w KQ' => {
			eco => 'C57g',
			# TRANSLATORS: C57g: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Nxd5 6. Nxf7 Kxf7 7. Qf3+ Ke6 8. Nc3 Ne7
			variation => N__('Two Knights: Fegatello, Polerio Defence'),
			moves => {
			},
		},
		'r1bqkb1r/p1p2ppp/2n2n2/1p1Pp1N1/2B5/8/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C57h',
			# TRANSLATORS: C57h: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 b5
			variation => N__('Two Knights: Ulvestad Variation'),
			moves => {
			},
		},
		'r1bqkb1r/ppp2ppp/5n2/3Pp1N1/2Bn4/8/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C57i',
			# TRANSLATORS: C57i: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Nd4
			variation => N__('Two Knights: Fritz Variation'),
			moves => {
				'c2c3' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/5n2/3Pp1N1/2Bn4/2P5/PP1P1PPP/RNBQK2R b KQkq' => {
			eco => 'C57i',
			# TRANSLATORS: C57i: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Nd4 6. c3
			variation => N__('Two Knights: Fritz Variation'),
			moves => {
				'b7b5' => 1,
			},
		},
		'r1bqkb1r/p1p2ppp/5n2/1p1Pp1N1/2Bn4/2P5/PP1P1PPP/RNBQK2R w KQkq' => {
			eco => 'C57i',
			# TRANSLATORS: C57i: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Nd4 6. c3 b5
			variation => N__('Two Knights: Fritz Variation'),
			moves => {
				'c4f1' => 1,
			},
		},
		'r1bqkb1r/p1p2ppp/5n2/1p1Pp1N1/3n4/2P5/PP1P1PPP/RNBQKB1R b KQkq' => {
			eco => 'C57i',
			# TRANSLATORS: C57i: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Nd4 6. c3 b5 7. Bf1
			variation => N__('Two Knights: Fritz Variation'),
			moves => {
				'f6d5' => 1,
			},
		},
		'r1bqkb1r/p1p2ppp/8/1p1np1N1/3n4/2P5/PP1P1PPP/RNBQKB1R w KQkq' => {
			eco => 'C57i',
			# TRANSLATORS: C57i: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Nd4 6. c3 b5 7. Bf1 Nxd5
			variation => N__('Two Knights: Fritz Variation, Main Line'),
			moves => {
				'c3d4' => 1,
				'g5e4' => 1,
				'g5f7' => 1,
				'h2h4' => 1,
			},
		},
		'r1bqkb1r/p1p2ppp/8/1p1np1N1/3P4/8/PP1P1PPP/RNBQKB1R b KQkq' => {
			eco => 'C57j',
			# TRANSLATORS: C57j: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Nd4 6. c3 b5 7. Bf1 Nxd5 8. cxd4
			variation => N__('Two Knights: Fritz, 8.cxd5'),
			moves => {
			},
		},
		'r1bqkb1r/p1p2Npp/8/1p1np3/3n4/2P5/PP1P1PPP/RNBQKB1R b KQkq' => {
			eco => 'C57j',
			# TRANSLATORS: C57j: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Nd4 6. c3 b5 7. Bf1 Nxd5 8. Nxf7
			variation => N__('Two Knights: Fritz, 8.Nxf7'),
			moves => {
			},
		},
		'r1bqkb1r/p1p2ppp/8/1p1np1N1/3n3P/2P5/PP1P1PP1/RNBQKB1R b KQkq' => {
			eco => 'C57j',
			# TRANSLATORS: C57j: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Nd4 6. c3 b5 7. Bf1 Nxd5 8. h4
			variation => N__('Two Knights: Fritz, Paoli\'s 8. h4'),
			moves => {
			},
		},
		'r1bqkb1r/p1p2ppp/8/1p1np3/3nN3/2P5/PP1P1PPP/RNBQKB1R b KQkq' => {
			eco => 'C57k',
			# TRANSLATORS: C57k: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Nd4 6. c3 b5 7. Bf1 Nxd5 8. Ne4
			variation => N__('Two Knights: Fritz, Gruber Variation (8. Ne4)'),
			moves => {
				'd8h4' => 1,
			},
		},
		'r1b1kb1r/p1p2ppp/8/1p1np3/3nN2q/2P5/PP1P1PPP/RNBQKB1R w KQkq' => {
			eco => 'C57k',
			# TRANSLATORS: C57k: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Nd4 6. c3 b5 7. Bf1 Nxd5 8. Ne4 Qh4
			variation => N__('Two Knights: Fritz, Gruber Variation (8. Ne4)'),
			moves => {
				'e4g3' => 1,
			},
		},
		'r1b1kb1r/p1p2ppp/8/1p1np3/3n3q/2P3N1/PP1P1PPP/RNBQKB1R b KQkq' => {
			eco => 'C57k',
			# TRANSLATORS: C57k: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Nd4 6. c3 b5 7. Bf1 Nxd5 8. Ne4 Qh4 9. Ng3
			variation => N__('Two Knights: Fritz, Gruber Variation (8. Ne4)'),
			moves => {
				'c8b7' => 1,
				'c8g4' => 1,
			},
		},
		'r3kb1r/p1p2ppp/8/1p1np3/3n2bq/2P3N1/PP1P1PPP/RNBQKB1R w KQkq' => {
			eco => 'C57k',
			# TRANSLATORS: C57k: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Nd4 6. c3 b5 7. Bf1 Nxd5 8. Ne4 Qh4 9. Ng3 Bg4
			variation => N__('Two Knights: Fritz, Gruber Variation (8. Ne4)'),
			moves => {
				'f2f3' => 1,
			},
		},
		'r3kb1r/p1p2ppp/8/1p1np3/3n2bq/2P2PN1/PP1P2PP/RNBQKB1R b KQkq' => {
			eco => 'C57k',
			# TRANSLATORS: C57k: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Nd4 6. c3 b5 7. Bf1 Nxd5 8. Ne4 Qh4 9. Ng3 Bg4 10. f3
			variation => N__('Two Knights: Fritz, Gruber Variation (8. Ne4)'),
			moves => {
				'e5e4' => 1,
			},
		},
		'r3kb1r/pbp2ppp/8/1p1np3/3n3q/2P3N1/PP1P1PPP/RNBQKB1R w KQkq' => {
			eco => 'C57l',
			# TRANSLATORS: C57l: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Nd4 6. c3 b5 7. Bf1 Nxd5 8. Ne4 Qh4 9. Ng3 Bb7
			variation => N__('Two Knights: Fritz, Radchenko Variation'),
			moves => {
			},
		},
		'r3kb1r/p1p2ppp/8/1p1n4/3np1bq/2P2PN1/PP1P2PP/RNBQKB1R w KQkq' => {
			eco => 'C57m',
			# TRANSLATORS: C57m: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Nd4 6. c3 b5 7. Bf1 Nxd5 8. Ne4 Qh4 9. Ng3 Bg4 10. f3 e4
			variation => N__('Two Knights: Fritz, Berliner Variation'),
			moves => {
			},
		},
		'r1bqkb1r/ppp2ppp/5n2/n2Pp1N1/2B5/8/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C58a',
			# TRANSLATORS: C58a: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5
			variation => N__('Two Knights: Morphy Variation (5... Na5)'),
			moves => {
				'c4b5' => 1,
				'd2d3' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/5n2/n2Pp1N1/2B5/3P4/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C58b',
			# TRANSLATORS: C58b: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. d3
			variation => N__('Two Knights: Morphy, Kieseritsky Variation'),
			moves => {
				'h7h6' => 1,
			},
		},
		'r1bqkb1r/ppp2pp1/5n1p/n2Pp1N1/2B5/3P4/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C58b',
			# TRANSLATORS: C58b: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. d3 h6
			variation => N__('Two Knights: Morphy, Kieseritsky Variation'),
			moves => {
				'g5f3' => 1,
			},
		},
		'r1bqkb1r/ppp2pp1/5n1p/n2Pp3/2B5/3P1N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C58b',
			# TRANSLATORS: C58b: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. d3 h6 7. Nf3
			variation => N__('Two Knights: Morphy, Kieseritsky Variation'),
			moves => {
				'e5e4' => 1,
			},
		},
		'r1bqkb1r/ppp2pp1/5n1p/n2P4/2B1p3/3P1N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C58b',
			# TRANSLATORS: C58b: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. d3 h6 7. Nf3 e4
			variation => N__('Two Knights: Morphy, Kieseritsky Variation'),
			moves => {
				'd1e2' => 1,
			},
		},
		'r1bqkb1r/ppp2pp1/5n1p/n2P4/2B1p3/3P1N2/PPP1QPPP/RNB1K2R b KQkq' => {
			eco => 'C58c',
			# TRANSLATORS: C58c: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. d3 h6 7. Nf3 e4 8. Qe2
			variation => N__('Two Knights: Morphy, Kieseritsky Variation, 6... h6 7. Nf3 e4 8. Qe2'),
			moves => {
				'a5c4' => 1,
			},
		},
		'r1bqkb1r/ppp2pp1/5n1p/3P4/2n1p3/3P1N2/PPP1QPPP/RNB1K2R w KQkq' => {
			eco => 'C58c',
			# TRANSLATORS: C58c: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. d3 h6 7. Nf3 e4 8. Qe2 Nxc4
			variation => N__('Two Knights: Morphy, Kieseritsky Variation, 6... h6 7. Nf3 e4 8. Qe2'),
			moves => {
				'd3c4' => 1,
			},
		},
		'r1bqkb1r/ppp2pp1/5n1p/3P4/2P1p3/5N2/PPP1QPPP/RNB1K2R b KQkq' => {
			eco => 'C58c',
			# TRANSLATORS: C58c: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. d3 h6 7. Nf3 e4 8. Qe2 Nxc4 9. dxc4
			variation => N__('Two Knights: Morphy, Kieseritsky Variation, 6... h6 7. Nf3 e4 8. Qe2'),
			moves => {
				'f8c5' => 1,
				'f8e7' => 1,
			},
		},
		'r1bqk2r/ppp2pp1/5n1p/2bP4/2P1p3/5N2/PPP1QPPP/RNB1K2R w KQkq' => {
			eco => 'C58c',
			# TRANSLATORS: C58c: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. d3 h6 7. Nf3 e4 8. Qe2 Nxc4 9. dxc4 Bc5
			variation => N__('Two Knights: Morphy, Kieseritsky Variation, 6... h6 7. Nf3 e4 8. Qe2'),
			moves => {
				'f3d2' => 1,
			},
		},
		'r1bqk2r/ppp2pp1/5n1p/2bP4/2P1p3/8/PPPNQPPP/RNB1K2R b KQkq' => {
			eco => 'C58c',
			# TRANSLATORS: C58c: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. d3 h6 7. Nf3 e4 8. Qe2 Nxc4 9. dxc4 Bc5 10. Nfd2
			variation => N__('Two Knights: Morphy, Yankovich Variation'),
			moves => {
			},
		},
		'r1bqk2r/ppp1bpp1/5n1p/3P4/2P1p3/5N2/PPP1QPPP/RNB1K2R w KQkq' => {
			eco => 'C58c',
			# TRANSLATORS: C58c: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. d3 h6 7. Nf3 e4 8. Qe2 Nxc4 9. dxc4 Be7
			variation => N__('Two Knights: Morphy, Maroczy Variation'),
			moves => {
			},
		},
		'r1bqkb1r/ppp2ppp/5n2/nB1Pp1N1/8/8/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'C58d',
			# TRANSLATORS: C58d: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. Bb5+
			variation => N__('Two Knights: Morphy, Polerio (6. Bb5+)'),
			moves => {
				'c7c6' => 1,
				'c8d7' => 1,
			},
		},
		'r2qkb1r/pppb1ppp/5n2/nB1Pp1N1/8/8/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C58d',
			# TRANSLATORS: C58d: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. Bb5+ Bd7
			variation => N__('Two Knights: Morphy, Polerio, 6... Bd7'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2p2n2/nB1Pp1N1/8/8/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C58e',
			# TRANSLATORS: C58e: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. Bb5+ c6
			variation => N__('Two Knights: Morphy, Polerio, 6... c6'),
			moves => {
				'd5c6' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2P2n2/nB2p1N1/8/8/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'C58e',
			# TRANSLATORS: C58e: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. Bb5+ c6 7. dxc6
			variation => N__('Two Knights: Morphy, Polerio, 6... c6'),
			moves => {
				'b7c6' => 1,
			},
		},
		'r1bqkb1r/p4ppp/2p2n2/nB2p1N1/8/8/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C58e',
			# TRANSLATORS: C58e: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. Bb5+ c6 7. dxc6 bxc6
			variation => N__('Two Knights: Morphy, Polerio, 6... c6'),
			moves => {
				'b5e2' => 1,
				'd1f3' => 1,
			},
		},
		'r1bqkb1r/p4ppp/2p2n2/nB2p1N1/8/5Q2/PPPP1PPP/RNB1K2R b KQkq' => {
			eco => 'C58f',
			# TRANSLATORS: C58f: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. Bb5+ c6 7. dxc6 bxc6 8. Qf3
			variation => N__('Two Knights: Morphy, Bogoljubow Variation'),
			moves => {
				'a8b8' => 1,
				'c6b5' => 1,
				'd8c7' => 1,
			},
		},
		'r1bqkb1r/p4ppp/5n2/np2p1N1/8/5Q2/PPPP1PPP/RNB1K2R w KQkq' => {
			eco => 'C58f',
			# TRANSLATORS: C58f: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. Bb5+ c6 7. dxc6 bxc6 8. Qf3 cxb5
			variation => N__('Two Knights: Morphy, Blackburne Variation'),
			moves => {
			},
		},
		'r1b1kb1r/p1q2ppp/2p2n2/nB2p1N1/8/5Q2/PPPP1PPP/RNB1K2R w KQkq' => {
			eco => 'C58f',
			# TRANSLATORS: C58f: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. Bb5+ c6 7. dxc6 bxc6 8. Qf3 Qc7
			variation => N__('Two Knights: Morphy, Bogoljubow Variation'),
			moves => {
				'b5d3' => 1,
			},
		},
		'r1b1kb1r/p1q2ppp/2p2n2/n3p1N1/8/3B1Q2/PPPP1PPP/RNB1K2R b KQkq' => {
			eco => 'C58f',
			# TRANSLATORS: C58f: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. Bb5+ c6 7. dxc6 bxc6 8. Qf3 Qc7 9. Bd3
			variation => N__('Two Knights: Morphy, Paoli Variation'),
			moves => {
			},
		},
		'1rbqkb1r/p4ppp/2p2n2/nB2p1N1/8/5Q2/PPPP1PPP/RNB1K2R w KQk' => {
			eco => 'C58g',
			# TRANSLATORS: C58g: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. Bb5+ c6 7. dxc6 bxc6 8. Qf3 Rb8
			variation => N__('Two Knights: Morphy, Colman Variation'),
			moves => {
			},
		},
		'r1bqkb1r/p4ppp/2p2n2/n3p1N1/8/8/PPPPBPPP/RNBQK2R b KQkq' => {
			eco => 'C58h',
			# TRANSLATORS: C58h: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. Bb5+ c6 7. dxc6 bxc6 8. Be2
			variation => N__('Two Knights: Morphy, 8. Be2'),
			moves => {
				'h7h6' => 1,
			},
		},
		'r1bqkb1r/p4pp1/2p2n1p/n3p1N1/8/8/PPPPBPPP/RNBQK2R w KQkq' => {
			eco => 'C59a',
			# TRANSLATORS: C59a: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. Bb5+ c6 7. dxc6 bxc6 8. Be2 h6
			variation => N__('Two Knights: Morphy, 8. Be2 h6'),
			moves => {
				'g5f3' => 1,
				'g5h3' => 1,
			},
		},
		'r1bqkb1r/p4pp1/2p2n1p/n3p3/8/7N/PPPPBPPP/RNBQK2R b KQkq' => {
			eco => 'C59b',
			# TRANSLATORS: C59b: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. Bb5+ c6 7. dxc6 bxc6 8. Be2 h6 9. Nh3
			variation => N__('Two Knights: Morphy, Steinitz Variation'),
			moves => {
			},
		},
		'r1bqkb1r/p4pp1/2p2n1p/n3p3/8/5N2/PPPPBPPP/RNBQK2R b KQkq' => {
			eco => 'C59c',
			# TRANSLATORS: C59c: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. Bb5+ c6 7. dxc6 bxc6 8. Be2 h6 9. Nf3
			variation => N__('Two Knights: Morphy, Main Line 9. Nf3'),
			moves => {
				'e5e4' => 1,
			},
		},
		'r1bqkb1r/p4pp1/2p2n1p/n7/4p3/5N2/PPPPBPPP/RNBQK2R w KQkq' => {
			eco => 'C59c',
			# TRANSLATORS: C59c: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. Bb5+ c6 7. dxc6 bxc6 8. Be2 h6 9. Nf3 e4
			variation => N__('Two Knights: Morphy, Main Line 9. Nf3 e4'),
			moves => {
				'f3e5' => 1,
			},
		},
		'r1bqkb1r/p4pp1/2p2n1p/n3N3/4p3/8/PPPPBPPP/RNBQK2R b KQkq' => {
			eco => 'C59c',
			# TRANSLATORS: C59c: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. Bb5+ c6 7. dxc6 bxc6 8. Be2 h6 9. Nf3 e4 10. Ne5
			variation => N__('Two Knights: Morphy, Main Line 9. Nf3 e4 10. Ne5'),
			moves => {
				'd8c7' => 1,
				'd8d4' => 1,
				'f8c5' => 1,
				'f8d6' => 1,
			},
		},
		'r1bqk2r/p4pp1/2p2n1p/n1b1N3/4p3/8/PPPPBPPP/RNBQK2R w KQkq' => {
			eco => 'C59d',
			# TRANSLATORS: C59d: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. Bb5+ c6 7. dxc6 bxc6 8. Be2 h6 9. Nf3 e4 10. Ne5 Bc5
			variation => N__('Two Knights: Morphy, Steiner Variation'),
			moves => {
			},
		},
		'r1b1kb1r/p1q2pp1/2p2n1p/n3N3/4p3/8/PPPPBPPP/RNBQK2R w KQkq' => {
			eco => 'C59e',
			# TRANSLATORS: C59e: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. Bb5+ c6 7. dxc6 bxc6 8. Be2 h6 9. Nf3 e4 10. Ne5 Qc7
			variation => N__('Two Knights: Morphy, Göring Variation'),
			moves => {
			},
		},
		'r1b1kb1r/p4pp1/2p2n1p/n3N3/3qp3/8/PPPPBPPP/RNBQK2R w KQkq' => {
			eco => 'C59f',
			# TRANSLATORS: C59f: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. Bb5+ c6 7. dxc6 bxc6 8. Be2 h6 9. Nf3 e4 10. Ne5 Qd4
			variation => N__('Two Knights: Morphy, Geller Variation'),
			moves => {
			},
		},
		'r1bqk2r/p4pp1/2pb1n1p/n3N3/4p3/8/PPPPBPPP/RNBQK2R w KQkq' => {
			eco => 'C59g',
			# TRANSLATORS: C59g: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. Bb5+ c6 7. dxc6 bxc6 8. Be2 h6 9. Nf3 e4 10. Ne5 Bd6
			variation => N__('Two Knights: Main Line 10... Bd6'),
			moves => {
				'd2d4' => 1,
				'f2f4' => 1,
			},
		},
		'r1bqk2r/p4pp1/2pb1n1p/n3N3/4pP2/8/PPPPB1PP/RNBQK2R b KQkq' => {
			eco => 'C59h',
			# TRANSLATORS: C59h: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. Bb5+ c6 7. dxc6 bxc6 8. Be2 h6 9. Nf3 e4 10. Ne5 Bd6 11. f4
			variation => N__('Two Knights: Main Line, 11. f4'),
			moves => {
				'e4f3' => 1,
			},
		},
		'r1bqk2r/p4pp1/2pb1n1p/n3N3/8/5p2/PPPPB1PP/RNBQK2R w KQkq' => {
			eco => 'C59i',
			# TRANSLATORS: C59i: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. Bb5+ c6 7. dxc6 bxc6 8. Be2 h6 9. Nf3 e4 10. Ne5 Bd6 11. f4 exf3
			variation => N__('Two Knights: Main Line, 11. f4 exf3'),
			moves => {
			},
		},
		'r1bqk2r/p4pp1/2pb1n1p/n3N3/3Pp3/8/PPP1BPPP/RNBQK2R b KQkq' => {
			eco => 'C59j',
			# TRANSLATORS: C59j: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. Bb5+ c6 7. dxc6 bxc6 8. Be2 h6 9. Nf3 e4 10. Ne5 Bd6 11. d4
			variation => N__('Two Knights: Main Line, 11. d4'),
			moves => {
				'd8c7' => 1,
				'e4d3' => 1,
			},
		},
		'r1b1k2r/p1q2pp1/2pb1n1p/n3N3/3Pp3/8/PPP1BPPP/RNBQK2R w KQkq' => {
			eco => 'C59j',
			# TRANSLATORS: C59j: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. Bb5+ c6 7. dxc6 bxc6 8. Be2 h6 9. Nf3 e4 10. Ne5 Bd6 11. d4 Qc7
			variation => N__('Two Knights: Main Line, 11. d4 Qc7'),
			moves => {
				'c1d2' => 1,
			},
		},
		'r1b1k2r/p1q2pp1/2pb1n1p/n3N3/3Pp3/8/PPPBBPPP/RN1QK2R b KQkq' => {
			eco => 'C59j',
			# TRANSLATORS: C59j: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. Bb5+ c6 7. dxc6 bxc6 8. Be2 h6 9. Nf3 e4 10. Ne5 Bd6 11. d4 Qc7 12. Bd2
			variation => N__('Two Knights: Main Line, Knorre Variation'),
			moves => {
			},
		},
		'r1bqk2r/p4pp1/2pb1n1p/n3N3/8/3p4/PPP1BPPP/RNBQK2R w KQkq' => {
			eco => 'C59k',
			# TRANSLATORS: C59k: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. Bb5+ c6 7. dxc6 bxc6 8. Be2 h6 9. Nf3 e4 10. Ne5 Bd6 11. d4 exd3
			variation => N__('Two Knights: Main Line, 11. d4 exd3'),
			moves => {
				'e5d3' => 1,
			},
		},
		'r1bqk2r/p4pp1/2pb1n1p/n7/8/3N4/PPP1BPPP/RNBQK2R b KQkq' => {
			eco => 'C59k',
			# TRANSLATORS: C59k: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. Bb5+ c6 7. dxc6 bxc6 8. Be2 h6 9. Nf3 e4 10. Ne5 Bd6 11. d4 exd3 12. Nxd3
			variation => N__('Two Knights: Main Line, 11. d4 exd3'),
			moves => {
				'd8c7' => 1,
			},
		},
		'r1b1k2r/p1q2pp1/2pb1n1p/n7/8/3N4/PPP1BPPP/RNBQK2R w KQkq' => {
			eco => 'C59k',
			# TRANSLATORS: C59k: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. Bb5+ c6 7. dxc6 bxc6 8. Be2 h6 9. Nf3 e4 10. Ne5 Bd6 11. d4 exd3 12. Nxd3 Qc7
			variation => N__('Two Knights: Main Line, 11. d4 exd3 12.Nxd3 Qc7'),
			moves => {
				'b2b3' => 1,
			},
		},
		'r1b1k2r/p1q2pp1/2pb1n1p/n7/8/1P1N4/P1P1BPPP/RNBQK2R b KQkq' => {
			eco => 'C59l',
			# TRANSLATORS: C59l: 1. e4 e5 2. Nf3 Nc6 3. Bc4 Nf6 4. Ng5 d5 5. exd5 Na5 6. Bb5+ c6 7. dxc6 bxc6 8. Be2 h6 9. Nf3 e4 10. Ne5 Bd6 11. d4 exd3 12. Nxd3 Qc7 13. b3
			variation => N__('Two Knights: Main Line, 11. d4, Honfi Variation'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/2n5/1B2p3/4P3/5N2/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'C60a',
			# TRANSLATORS: C60a: 1. e4 e5 2. Nf3 Nc6 3. Bb5
			variation => N__('Spanish (Ruy Lopez)'),
			moves => {
				'a7a5' => 1,
				'a7a6' => 1,
				'c6a5' => 1,
				'c6d4' => 1,
				'd7d5' => 1,
				'd7d6' => 1,
				'd8e7' => 1,
				'f7f5' => 1,
				'f7f6' => 1,
				'f8b4' => 1,
				'f8c5' => 1,
				'f8e7' => 1,
				'g7g5' => 1,
				'g7g6' => 1,
				'g8e7' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkbnr/ppp2ppp/2n5/1B1pp3/4P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C60a',
			# TRANSLATORS: C60a: 1. e4 e5 2. Nf3 Nc6 3. Bb5 d5
			variation => N__('Spanish: Spanish Countergambit'),
			moves => {
			},
		},
		'r1bqkbnr/1ppp1ppp/2n5/pB2p3/4P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C60b',
			# TRANSLATORS: C60b: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a5
			variation => N__('Spanish: 3... a5'),
			moves => {
			},
		},
		'r1bqkbnr/pppp2pp/2n2p2/1B2p3/4P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C60c',
			# TRANSLATORS: C60c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 f6
			variation => N__('Spanish: Nürnberg Variation'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/8/nB2p3/4P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C60d',
			# TRANSLATORS: C60d: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Na5
			variation => N__('Spanish: Pollock Defence'),
			moves => {
			},
		},
		'r1bqk1nr/ppppbppp/2n5/1B2p3/4P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C60e',
			# TRANSLATORS: C60e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Be7
			variation => N__('Spanish: Lucena Defence'),
			moves => {
			},
		},
		'r1b1kbnr/ppppqppp/2n5/1B2p3/4P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C60f',
			# TRANSLATORS: C60f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Qe7
			variation => N__('Spanish: Vinogradov Variation'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1p1p/2n5/1B2p1p1/4P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C60g',
			# TRANSLATORS: C60g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 g5
			variation => N__('Spanish: Brentano Variation'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/1B2p3/1b2P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C60h',
			# TRANSLATORS: C60h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Bb4
			variation => N__('Spanish: Alapin Variation'),
			moves => {
				'c2c3' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/1B2p3/1b2P3/2P2N2/PP1P1PPP/RNBQK2R b KQkq' => {
			eco => 'C60i',
			# TRANSLATORS: C60i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Bb4 4. c3
			variation => N__('Spanish: Alapin, 4. c3'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1p1p/2n3p1/1B2p3/4P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C60j',
			# TRANSLATORS: C60j: 1. e4 e5 2. Nf3 Nc6 3. Bb5 g6
			variation => N__('Spanish: Fianchetto (Smyslov) Defence'),
			moves => {
				'c2c3' => 1,
				'd2d4' => 1,
				'e1g1' => 1,
			},
		},
		'r1bqkbnr/pppp1p1p/2n3p1/1B2p3/4P3/5N2/PPPP1PPP/RNBQ1RK1 b kq' => {
			eco => 'C60k',
			# TRANSLATORS: C60k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 g6 4. O-O
			variation => N__('Spanish: Fianchetto, 4.O-O'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1p1p/2n3p1/1B2p3/3PP3/5N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C60l',
			# TRANSLATORS: C60l: 1. e4 e5 2. Nf3 Nc6 3. Bb5 g6 4. d4
			variation => N__('Spanish: Fianchetto, 4. d4'),
			moves => {
				'e5d4' => 1,
			},
		},
		'r1bqkbnr/pppp1p1p/2n3p1/1B6/3pP3/5N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C60l',
			# TRANSLATORS: C60l: 1. e4 e5 2. Nf3 Nc6 3. Bb5 g6 4. d4 exd4
			variation => N__('Spanish: Fianchetto, 4. d4'),
			moves => {
				'c1g5' => 1,
			},
		},
		'r1bqkbnr/pppp1p1p/2n3p1/1B4B1/3pP3/5N2/PPP2PPP/RN1QK2R b KQkq' => {
			eco => 'C60m',
			# TRANSLATORS: C60m: 1. e4 e5 2. Nf3 Nc6 3. Bb5 g6 4. d4 exd4 5. Bg5
			variation => N__('Spanish: Fianchetto, 4. d4 exd4 5. Bg5'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1p1p/2n3p1/1B2p3/4P3/2P2N2/PP1P1PPP/RNBQK2R b KQkq' => {
			eco => 'C60n',
			# TRANSLATORS: C60n: 1. e4 e5 2. Nf3 Nc6 3. Bb5 g6 4. c3
			variation => N__('Spanish: Fianchetto, 4. c3'),
			moves => {
			},
		},
		'r1bqkb1r/ppppnppp/2n5/1B2p3/4P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C60o',
			# TRANSLATORS: C60o: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nge7
			variation => N__('Spanish: Cozio Defence'),
			moves => {
				'b1c3' => 1,
				'c2c3' => 1,
				'e1g1' => 1,
			},
		},
		'r1bqkb1r/ppppnppp/2n5/1B2p3/4P3/2N2N2/PPPP1PPP/R1BQK2R b KQkq' => {
			eco => 'C60p',
			# TRANSLATORS: C60p: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nge7 4. Nc3
			variation => N__('Spanish: Cozio, 4. Nc3'),
			moves => {
				'g7g6' => 1,
			},
		},
		'r1bqkb1r/ppppnp1p/2n3p1/1B2p3/4P3/2N2N2/PPPP1PPP/R1BQK2R w KQkq' => {
			eco => 'C60q',
			# TRANSLATORS: C60q: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nge7 4. Nc3 g6
			variation => N__('Spanish: Cozio, Paulsen Variation'),
			moves => {
			},
		},
		'r1bqkb1r/ppppnppp/2n5/1B2p3/4P3/2P2N2/PP1P1PPP/RNBQK2R b KQkq' => {
			eco => 'C60r',
			# TRANSLATORS: C60r: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nge7 4. c3
			variation => N__('Spanish: Cozio, 4.O-O'),
			moves => {
			},
		},
		'r1bqkb1r/ppppnppp/2n5/1B2p3/4P3/5N2/PPPP1PPP/RNBQ1RK1 b kq' => {
			eco => 'C60s',
			# TRANSLATORS: C60s: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nge7 4. O-O
			variation => N__('Spanish: Cozio, 4.O-O'),
			moves => {
				'g7g6' => 1,
			},
		},
		'r1bqkb1r/ppppnp1p/2n3p1/1B2p3/4P3/5N2/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C60t',
			# TRANSLATORS: C60t: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nge7 4. O-O g6
			variation => N__('Spanish: Cozio, 4.O-O g6'),
			moves => {
				'c2c3' => 1,
			},
		},
		'r1bqkb1r/ppppnp1p/2n3p1/1B2p3/4P3/2P2N2/PP1P1PPP/RNBQ1RK1 b kq' => {
			eco => 'C60u',
			# TRANSLATORS: C60u: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nge7 4. O-O g6 5. c3
			variation => N__('Spanish: Cozio, 4.O-O g6'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/8/1B2p3/3nP3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C61a',
			# TRANSLATORS: C61a: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nd4
			variation => N__('Spanish: Bird\'s Defence'),
			moves => {
				'b5c4' => 1,
				'f3d4' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/8/4p3/2BnP3/5N2/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'C61b',
			# TRANSLATORS: C61b: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nd4 4. Bc4
			variation => N__('Spanish: Bird\'s, 4. Bc4'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/8/1B2p3/3NP3/8/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'C61c',
			# TRANSLATORS: C61c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nd4 4. Nxd4
			variation => N__('Spanish: Bird\'s, 4.Nxd4'),
			moves => {
				'e5d4' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/8/1B6/3pP3/8/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C61c',
			# TRANSLATORS: C61c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nd4 4. Nxd4 exd4
			variation => N__('Spanish: Bird\'s, 4.Nxd4 exd4'),
			moves => {
				'b5c4' => 1,
				'd2d3' => 1,
				'e1g1' => 1,
			},
		},
		'r1bqkbnr/pppp1ppp/8/1B6/3pP3/3P4/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C61d',
			# TRANSLATORS: C61d: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nd4 4. Nxd4 exd4 5. d3
			variation => N__('Spanish: Bird\'s, 5. d3'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/8/8/2BpP3/8/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'C61e',
			# TRANSLATORS: C61e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nd4 4. Nxd4 exd4 5. Bc4
			variation => N__('Spanish: Bird\'s, 5. Bc4'),
			moves => {
			},
		},
		'r1bqkbnr/pppp1ppp/8/1B6/3pP3/8/PPPP1PPP/RNBQ1RK1 b kq' => {
			eco => 'C61f',
			# TRANSLATORS: C61f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nd4 4. Nxd4 exd4 5. O-O
			variation => N__('Spanish: Bird\'s, 5.O-O'),
			moves => {
				'c7c6' => 1,
				'f8c5' => 1,
				'g8e7' => 1,
			},
		},
		'r1bqkb1r/ppppnppp/8/1B6/3pP3/8/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C61f',
			# TRANSLATORS: C61f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nd4 4. Nxd4 exd4 5. O-O Ne7
			variation => N__('Spanish: Bird\'s, Paulsen Variation'),
			moves => {
			},
		},
		'r1bqkbnr/pp1p1ppp/2p5/1B6/3pP3/8/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C61g',
			# TRANSLATORS: C61g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nd4 4. Nxd4 exd4 5. O-O c6
			variation => N__('Spanish: Bird\'s, 5.O-O c6'),
			moves => {
				'b5c4' => 1,
			},
		},
		'r1bqkbnr/pp1p1ppp/2p5/8/2BpP3/8/PPPP1PPP/RNBQ1RK1 b kq' => {
			eco => 'C61h',
			# TRANSLATORS: C61h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nd4 4. Nxd4 exd4 5. O-O c6 6. Bc4
			variation => N__('Spanish: Bird\'s, 5.O-O c6 6. Bc4'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/8/1Bb5/3pP3/8/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C61i',
			# TRANSLATORS: C61i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nd4 4. Nxd4 exd4 5. O-O Bc5
			variation => N__('Spanish: Bird\'s, 5.O-O Bc5'),
			moves => {
				'd2d3' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/8/1Bb5/3pP3/3P4/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C61j',
			# TRANSLATORS: C61j: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nd4 4. Nxd4 exd4 5. O-O Bc5 6. d3
			variation => N__('Spanish: Bird\'s, 5.O-O Bc5 6. d3'),
			moves => {
				'c7c6' => 1,
			},
		},
		'r1bqk1nr/pp1p1ppp/2p5/1Bb5/3pP3/3P4/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C61k',
			# TRANSLATORS: C61k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nd4 4. Nxd4 exd4 5. O-O Bc5 6. d3 c6
			variation => N__('Spanish: Bird\'s, 5.O-O Bc5 6. d3 c6'),
			moves => {
				'b5c4' => 1,
			},
		},
		'r1bqk1nr/pp1p1ppp/2p5/2b5/2BpP3/3P4/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C61l',
			# TRANSLATORS: C61l: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nd4 4. Nxd4 exd4 5. O-O Bc5 6. d3 c6 7. Bc4
			variation => N__('Spanish: Bird\'s, 5.O-O Bc5 6. d3 c6 7. Bc4'),
			moves => {
				'd7d5' => 1,
			},
		},
		'r1bqk1nr/pp3ppp/2p5/2bp4/2BpP3/3P4/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C61m',
			# TRANSLATORS: C61m: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nd4 4. Nxd4 exd4 5. O-O Bc5 6. d3 c6 7. Bc4 d5
			variation => N__('Spanish: Bird\'s, 5.O-O Bc5 6. d3 c6 7. Bc4 d5'),
			moves => {
			},
		},
		'r1bqkbnr/ppp2ppp/2np4/1B2p3/4P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C62',
			# TRANSLATORS: C62: 1. e4 e5 2. Nf3 Nc6 3. Bb5 d6
			variation => N__('Spanish: Old Steinitz'),
			moves => {
				'b5c6' => 1,
				'c2c3' => 1,
				'd2d4' => 1,
				'e1g1' => 1,
			},
		},
		'r1bqkbnr/ppp2ppp/2Bp4/4p3/4P3/5N2/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'C62',
			# TRANSLATORS: C62: 1. e4 e5 2. Nf3 Nc6 3. Bb5 d6 4. Bxc6+
			variation => N__('Spanish: Old Steinitz, 4.Bxc6+'),
			moves => {
			},
		},
		'r1bqkbnr/ppp2ppp/2np4/1B2p3/4P3/2P2N2/PP1P1PPP/RNBQK2R b KQkq' => {
			eco => 'C62',
			# TRANSLATORS: C62: 1. e4 e5 2. Nf3 Nc6 3. Bb5 d6 4. c3
			variation => N__('Spanish: Old Steinitz, 4. c3'),
			moves => {
			},
		},
		'r1bqkbnr/ppp2ppp/2np4/1B2p3/3PP3/5N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C62',
			# TRANSLATORS: C62: 1. e4 e5 2. Nf3 Nc6 3. Bb5 d6 4. d4
			variation => N__('Spanish: Old Steinitz, 4. d4'),
			moves => {
				'c8d7' => 1,
				'e5d4' => 1,
			},
		},
		'r2qkbnr/pppb1ppp/2np4/1B2p3/3PP3/5N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C62',
			# TRANSLATORS: C62: 1. e4 e5 2. Nf3 Nc6 3. Bb5 d6 4. d4 Bd7
			variation => N__('Spanish: Old Steinitz, 4. d4 Bd7'),
			moves => {
				'b1c3' => 1,
				'c2c4' => 1,
			},
		},
		'r2qkbnr/pppb1ppp/2np4/1B2p3/3PP3/2N2N2/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'C62',
			# TRANSLATORS: C62: 1. e4 e5 2. Nf3 Nc6 3. Bb5 d6 4. d4 Bd7 5. Nc3
			variation => N__('Spanish: Old Steinitz, 4. d4 Bd7 5. Nc3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r2qkb1r/pppb1ppp/2np1n2/1B2p3/3PP3/2N2N2/PPP2PPP/R1BQK2R w KQkq' => {
			eco => 'C62',
			# TRANSLATORS: C62: 1. e4 e5 2. Nf3 Nc6 3. Bb5 d6 4. d4 Bd7 5. Nc3 Nf6
			variation => N__('Spanish: Old Steinitz, 4. d4 Bd7 5. Nc3'),
			moves => {
				'b5c6' => 1,
			},
		},
		'r2qkb1r/pppb1ppp/2Bp1n2/4p3/3PP3/2N2N2/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'C62',
			# TRANSLATORS: C62: 1. e4 e5 2. Nf3 Nc6 3. Bb5 d6 4. d4 Bd7 5. Nc3 Nf6 6. Bxc6
			variation => N__('Spanish: Old Steinitz, Nimzowitsch Attack'),
			moves => {
			},
		},
		'r2qkbnr/pppb1ppp/2np4/1B2p3/2PPP3/5N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'C62',
			# TRANSLATORS: C62: 1. e4 e5 2. Nf3 Nc6 3. Bb5 d6 4. d4 Bd7 5. c4
			variation => N__('Spanish: Old Steinitz, Semi-Duras Variation'),
			moves => {
			},
		},
		'r1bqkbnr/ppp2ppp/2np4/1B6/3pP3/5N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C62',
			# TRANSLATORS: C62: 1. e4 e5 2. Nf3 Nc6 3. Bb5 d6 4. d4 exd4
			variation => N__('Spanish: Old Steinitz, 4. d4 exd4'),
			moves => {
				'd1d4' => 1,
				'f3d4' => 1,
			},
		},
		'r1bqkbnr/ppp2ppp/2np4/1B6/3QP3/5N2/PPP2PPP/RNB1K2R b KQkq' => {
			eco => 'C62',
			# TRANSLATORS: C62: 1. e4 e5 2. Nf3 Nc6 3. Bb5 d6 4. d4 exd4 5. Qxd4
			variation => N__('Spanish: Old Steinitz, 4. d4 exd4 5.Qxd4'),
			moves => {
			},
		},
		'r1bqkbnr/ppp2ppp/2np4/1B6/3NP3/8/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C62',
			# TRANSLATORS: C62: 1. e4 e5 2. Nf3 Nc6 3. Bb5 d6 4. d4 exd4 5. Nxd4
			variation => N__('Spanish: Old Steinitz, 4. d4 exd4 5.Nxd4'),
			moves => {
			},
		},
		'r1bqkbnr/ppp2ppp/2np4/1B2p3/4P3/5N2/PPPP1PPP/RNBQ1RK1 b kq' => {
			eco => 'C62',
			# TRANSLATORS: C62: 1. e4 e5 2. Nf3 Nc6 3. Bb5 d6 4. O-O
			variation => N__('Spanish: Old Steinitz, 4.O-O'),
			moves => {
			},
		},
		'r1bqkbnr/pppp2pp/2n5/1B2pp2/4P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C63a',
			# TRANSLATORS: C63a: 1. e4 e5 2. Nf3 Nc6 3. Bb5 f5
			variation => N__('Spanish: Schliemann (Jänisch)'),
			moves => {
				'b1c3' => 1,
				'b5c6' => 1,
				'd1e2' => 1,
				'd2d3' => 1,
				'd2d4' => 1,
				'e4f5' => 1,
			},
		},
		'r1bqkbnr/pppp2pp/2n5/1B2pp2/4P3/5N2/PPPPQPPP/RNB1K2R b KQkq' => {
			eco => 'C63a',
			# TRANSLATORS: C63a: 1. e4 e5 2. Nf3 Nc6 3. Bb5 f5 4. Qe2
			variation => N__('Spanish: Schliemann, 4. Qe2'),
			moves => {
			},
		},
		'r1bqkbnr/pppp2pp/2n5/1B2pP2/8/5N2/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'C63b',
			# TRANSLATORS: C63b: 1. e4 e5 2. Nf3 Nc6 3. Bb5 f5 4. exf5
			variation => N__('Spanish: Schliemann, 4.exf5'),
			moves => {
			},
		},
		'r1bqkbnr/pppp2pp/2n5/1B2pp2/3PP3/5N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C63c',
			# TRANSLATORS: C63c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 f5 4. d4
			variation => N__('Spanish: Schliemann, 4. d4'),
			moves => {
			},
		},
		'r1bqkbnr/pppp2pp/2n5/1B2pp2/4P3/3P1N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C63d',
			# TRANSLATORS: C63d: 1. e4 e5 2. Nf3 Nc6 3. Bb5 f5 4. d3
			variation => N__('Spanish: Schliemann, 4. d3'),
			moves => {
				'f5e4' => 1,
			},
		},
		'r1bqkbnr/pppp2pp/2n5/1B2p3/4p3/3P1N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C63e',
			# TRANSLATORS: C63e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 f5 4. d3 fxe4
			variation => N__('Spanish: Schliemann, 4. d3 fxe4'),
			moves => {
				'd3e4' => 1,
			},
		},
		'r1bqkbnr/pppp2pp/2n5/1B2p3/4P3/5N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C63e',
			# TRANSLATORS: C63e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 f5 4. d3 fxe4 5. dxe4
			variation => N__('Spanish: Schliemann, 4. d3 fxe4'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r1bqkb1r/pppp2pp/2n2n2/1B2p3/4P3/5N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C63e',
			# TRANSLATORS: C63e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 f5 4. d3 fxe4 5. dxe4 Nf6
			variation => N__('Spanish: Schliemann, 4. d3 fxe4'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqkb1r/pppp2pp/2n2n2/1B2p3/4P3/5N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C63f',
			# TRANSLATORS: C63f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 f5 4. d3 fxe4 5. dxe4 Nf6 6. O-O
			variation => N__('Spanish: Schliemann, 4. d3 fxe4 5.dxe4 Nf6 6.O-O'),
			moves => {
			},
		},
		'r1bqkbnr/pppp2pp/2B5/4pp2/4P3/5N2/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'C63g',
			# TRANSLATORS: C63g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 f5 4. Bxc6
			variation => N__('Spanish: Schliemann, 4.Bxc6'),
			moves => {
				'd7c6' => 1,
			},
		},
		'r1bqkbnr/ppp3pp/2p5/4pp2/4P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C63h',
			# TRANSLATORS: C63h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 f5 4. Bxc6 dxc6
			variation => N__('Spanish: Schliemann, 4.Bxc6 dxc6'),
			moves => {
			},
		},
		'r1bqkbnr/pppp2pp/2n5/1B2pp2/4P3/2N2N2/PPPP1PPP/R1BQK2R b KQkq' => {
			eco => 'C63i',
			# TRANSLATORS: C63i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 f5 4. Nc3
			variation => N__('Spanish: Schliemann, 4. Nc3'),
			moves => {
				'c6d4' => 1,
				'f5e4' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkbnr/pppp2pp/8/1B2pp2/3nP3/2N2N2/PPPP1PPP/R1BQK2R w KQkq' => {
			eco => 'C63j',
			# TRANSLATORS: C63j: 1. e4 e5 2. Nf3 Nc6 3. Bb5 f5 4. Nc3 Nd4
			variation => N__('Spanish: Schliemann, 4. Nc3 Nd4'),
			moves => {
				'b5a4' => 1,
			},
		},
		'r1bqkbnr/pppp2pp/8/4pp2/B2nP3/2N2N2/PPPP1PPP/R1BQK2R b KQkq' => {
			eco => 'C63k',
			# TRANSLATORS: C63k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 f5 4. Nc3 Nd4 5. Ba4
			variation => N__('Spanish: Schliemann, 4. Nc3 Nd4 5. Ba4'),
			moves => {
			},
		},
		'r1bqkb1r/pppp2pp/2n2n2/1B2pp2/4P3/2N2N2/PPPP1PPP/R1BQK2R w KQkq' => {
			eco => 'C63l',
			# TRANSLATORS: C63l: 1. e4 e5 2. Nf3 Nc6 3. Bb5 f5 4. Nc3 Nf6
			variation => N__('Spanish: Schliemann, 4. Nc3 Nf6'),
			moves => {
				'e4f5' => 1,
			},
		},
		'r1bqkb1r/pppp2pp/2n2n2/1B2pP2/8/2N2N2/PPPP1PPP/R1BQK2R b KQkq' => {
			eco => 'C63m',
			# TRANSLATORS: C63m: 1. e4 e5 2. Nf3 Nc6 3. Bb5 f5 4. Nc3 Nf6 5. exf5
			variation => N__('Spanish: Schliemann, 4. Nc3 Nf6 5.exf5'),
			moves => {
			},
		},
		'r1bqkbnr/pppp2pp/2n5/1B2p3/4p3/2N2N2/PPPP1PPP/R1BQK2R w KQkq' => {
			eco => 'C63n',
			# TRANSLATORS: C63n: 1. e4 e5 2. Nf3 Nc6 3. Bb5 f5 4. Nc3 fxe4
			variation => N__('Spanish: Schliemann, 4. Nc3 fxe4'),
			moves => {
				'c3e4' => 1,
			},
		},
		'r1bqkbnr/pppp2pp/2n5/1B2p3/4N3/5N2/PPPP1PPP/R1BQK2R b KQkq' => {
			eco => 'C63n',
			# TRANSLATORS: C63n: 1. e4 e5 2. Nf3 Nc6 3. Bb5 f5 4. Nc3 fxe4 5. Nxe4
			variation => N__('Spanish: Schliemann, 4. Nc3 fxe4'),
			moves => {
				'd7d5' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkb1r/pppp2pp/2n2n2/1B2p3/4N3/5N2/PPPP1PPP/R1BQK2R w KQkq' => {
			eco => 'C63o',
			# TRANSLATORS: C63o: 1. e4 e5 2. Nf3 Nc6 3. Bb5 f5 4. Nc3 fxe4 5. Nxe4 Nf6
			variation => N__('Spanish: Schliemann, 4. Nc3 fxe4 5.Nxe4 Nf6'),
			moves => {
				'd1e2' => 1,
				'e4f6' => 1,
			},
		},
		'r1bqkb1r/pppp2pp/2n2n2/1B2p3/4N3/5N2/PPPPQPPP/R1B1K2R b KQkq' => {
			eco => 'C63p',
			# TRANSLATORS: C63p: 1. e4 e5 2. Nf3 Nc6 3. Bb5 f5 4. Nc3 fxe4 5. Nxe4 Nf6 6. Qe2
			variation => N__('Spanish: Schliemann, 4. Nc3 fxe4 5.Nxe4 Nf6 6. Qe2'),
			moves => {
			},
		},
		'r1bqkb1r/pppp2pp/2n2N2/1B2p3/8/5N2/PPPP1PPP/R1BQK2R b KQkq' => {
			eco => 'C63q',
			# TRANSLATORS: C63q: 1. e4 e5 2. Nf3 Nc6 3. Bb5 f5 4. Nc3 fxe4 5. Nxe4 Nf6 6. Nxf6+
			variation => N__('Spanish: Schliemann, 4. Nc3 fxe4 5.Nxe4 Nf6 6.Nxf6+'),
			moves => {
			},
		},
		'r1bqkbnr/ppp3pp/2n5/1B1pp3/4N3/5N2/PPPP1PPP/R1BQK2R w KQkq' => {
			eco => 'C63r',
			# TRANSLATORS: C63r: 1. e4 e5 2. Nf3 Nc6 3. Bb5 f5 4. Nc3 fxe4 5. Nxe4 d5
			variation => N__('Spanish: Schliemann, 4. Nc3 fxe4 5.Nxe4 d5'),
			moves => {
				'f3e5' => 1,
			},
		},
		'r1bqkbnr/ppp3pp/2n5/1B1pN3/4N3/8/PPPP1PPP/R1BQK2R b KQkq' => {
			eco => 'C63s',
			# TRANSLATORS: C63s: 1. e4 e5 2. Nf3 Nc6 3. Bb5 f5 4. Nc3 fxe4 5. Nxe4 d5 6. Nxe5
			variation => N__('Spanish: Schliemann, 4. Nc3 fxe4 5.Nxe4 d5 6.Nxe5'),
			moves => {
				'd5e4' => 1,
			},
		},
		'r1bqkbnr/ppp3pp/2n5/1B2N3/4p3/8/PPPP1PPP/R1BQK2R w KQkq' => {
			eco => 'C63s',
			# TRANSLATORS: C63s: 1. e4 e5 2. Nf3 Nc6 3. Bb5 f5 4. Nc3 fxe4 5. Nxe4 d5 6. Nxe5 dxe4
			variation => N__('Spanish: Schliemann, 4. Nc3 fxe4 5.Nxe4 d5 6.Nxe5'),
			moves => {
				'e5c6' => 1,
			},
		},
		'r1bqkbnr/ppp3pp/2N5/1B6/4p3/8/PPPP1PPP/R1BQK2R b KQkq' => {
			eco => 'C63s',
			# TRANSLATORS: C63s: 1. e4 e5 2. Nf3 Nc6 3. Bb5 f5 4. Nc3 fxe4 5. Nxe4 d5 6. Nxe5 dxe4 7. Nxc6
			variation => N__('Spanish: Schliemann, 4. Nc3 fxe4 5.Nxe4 d5 6.Nxe5'),
			moves => {
				'd8d5' => 1,
				'd8g5' => 1,
			},
		},
		'r1b1kbnr/ppp3pp/2N5/1B1q4/4p3/8/PPPP1PPP/R1BQK2R w KQkq' => {
			eco => 'C63t',
			# TRANSLATORS: C63t: 1. e4 e5 2. Nf3 Nc6 3. Bb5 f5 4. Nc3 fxe4 5. Nxe4 d5 6. Nxe5 dxe4 7. Nxc6 Qd5
			variation => N__('Spanish: Schliemann, 4. Nc3 fxe4 5.Nxe4 d5 6.Nxe5 dxe4 7.Nxc6 Qd5'),
			moves => {
			},
		},
		'r1b1kbnr/ppp3pp/2N5/1B4q1/4p3/8/PPPP1PPP/R1BQK2R w KQkq' => {
			eco => 'C63u',
			# TRANSLATORS: C63u: 1. e4 e5 2. Nf3 Nc6 3. Bb5 f5 4. Nc3 fxe4 5. Nxe4 d5 6. Nxe5 dxe4 7. Nxc6 Qg5
			variation => N__('Spanish: Schliemann, 4. Nc3 fxe4 5.Nxe4 d5 6.Nxe5 dxe4 7.Nxc6 Qg5'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/1Bb1p3/4P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C64a',
			# TRANSLATORS: C64a: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Bc5
			variation => N__('Spanish: Classical Defence'),
			moves => {
				'b5c6' => 1,
				'c2c3' => 1,
				'e1g1' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/2B5/2b1p3/4P3/5N2/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'C64a',
			# TRANSLATORS: C64a: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Bc5 4. Bxc6
			variation => N__('Spanish: Classical, Exchange'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/1Bb1p3/4P3/2P2N2/PP1P1PPP/RNBQK2R b KQkq' => {
			eco => 'C64b',
			# TRANSLATORS: C64b: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Bc5 4. c3
			variation => N__('Spanish: Classical, 4. c3'),
			moves => {
				'c5b6' => 1,
				'd8e7' => 1,
				'd8f6' => 1,
				'f7f5' => 1,
				'g8e7' => 1,
				'g8f6' => 1,
			},
		},
		'r1b1k1nr/ppppqppp/2n5/1Bb1p3/4P3/2P2N2/PP1P1PPP/RNBQK2R w KQkq' => {
			eco => 'C64b',
			# TRANSLATORS: C64b: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Bc5 4. c3 Qe7
			variation => N__('Spanish: Classical, Boden Variation'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/1bn5/1B2p3/4P3/2P2N2/PP1P1PPP/RNBQK2R w KQkq' => {
			eco => 'C64c',
			# TRANSLATORS: C64c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Bc5 4. c3 Bb6
			variation => N__('Spanish: Classical, Charousek Variation'),
			moves => {
			},
		},
		'r1bqk2r/ppppnppp/2n5/1Bb1p3/4P3/2P2N2/PP1P1PPP/RNBQK2R w KQkq' => {
			eco => 'C64d',
			# TRANSLATORS: C64d: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Bc5 4. c3 Nge7
			variation => N__('Spanish: Classical, 4. c3 Nge7'),
			moves => {
			},
		},
		'r1b1k1nr/pppp1ppp/2n2q2/1Bb1p3/4P3/2P2N2/PP1P1PPP/RNBQK2R w KQkq' => {
			eco => 'C64e',
			# TRANSLATORS: C64e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Bc5 4. c3 Qf6
			variation => N__('Spanish: Classical, 4. c3 Qf6'),
			moves => {
			},
		},
		'r1bqk1nr/pppp2pp/2n5/1Bb1pp2/4P3/2P2N2/PP1P1PPP/RNBQK2R w KQkq' => {
			eco => 'C64f',
			# TRANSLATORS: C64f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Bc5 4. c3 f5
			variation => N__('Spanish: Classical, Cordel Gambit'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bqk1nr/pppp2pp/2n5/1Bb1pp2/3PP3/2P2N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'C64g',
			# TRANSLATORS: C64g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Bc5 4. c3 f5 5. d4
			variation => N__('Spanish: Classical, Cordel Gambit, 5. d4'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/1Bb1p3/4P3/2P2N2/PP1P1PPP/RNBQK2R w KQkq' => {
			eco => 'C64h',
			# TRANSLATORS: C64h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Bc5 4. c3 Nf6
			variation => N__('Spanish: Classical, 4. c3 Nf6'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/1Bb1p3/3PP3/2P2N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'C64i',
			# TRANSLATORS: C64i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Bc5 4. c3 Nf6 5. d4
			variation => N__('Spanish: Classical, 4. c3 Nf6 5. d4'),
			moves => {
				'c5b6' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/1bn2n2/1B2p3/3PP3/2P2N2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'C64j',
			# TRANSLATORS: C64j: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Bc5 4. c3 Nf6 5. d4 Bb6
			variation => N__('Spanish: Classical, 4. c3 Nf6 5. d4 Bb6'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/2n5/1Bb1p3/4P3/5N2/PPPP1PPP/RNBQ1RK1 b kq' => {
			eco => 'C64k',
			# TRANSLATORS: C64k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Bc5 4. O-O
			variation => N__('Spanish: Classical, 4.O-O'),
			moves => {
				'c6d4' => 1,
				'd7d6' => 1,
				'd8f6' => 1,
				'g8e7' => 1,
			},
		},
		'r1bqk2r/ppppnppp/2n5/1Bb1p3/4P3/5N2/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C64l',
			# TRANSLATORS: C64l: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Bc5 4. O-O Nge7
			variation => N__('Spanish: Classical, 4.O-O Nge7'),
			moves => {
			},
		},
		'r1b1k1nr/pppp1ppp/2n2q2/1Bb1p3/4P3/5N2/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C64m',
			# TRANSLATORS: C64m: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Bc5 4. O-O Qf6
			variation => N__('Spanish: Classical, 4.O-O Qf6'),
			moves => {
			},
		},
		'r1bqk1nr/ppp2ppp/2np4/1Bb1p3/4P3/5N2/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C64n',
			# TRANSLATORS: C64n: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Bc5 4. O-O d6
			variation => N__('Spanish: Classical, 4.O-O d6'),
			moves => {
				'c2c3' => 1,
			},
		},
		'r1bqk1nr/ppp2ppp/2np4/1Bb1p3/4P3/2P2N2/PP1P1PPP/RNBQ1RK1 b kq' => {
			eco => 'C64o',
			# TRANSLATORS: C64o: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Bc5 4. O-O d6 5. c3
			variation => N__('Spanish: Classical, 4.O-O d6 5. c3'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/8/1Bb1p3/3nP3/5N2/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C64p',
			# TRANSLATORS: C64p: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Bc5 4. O-O Nd4
			variation => N__('Spanish: Classical, 4.O-O Nd4'),
			moves => {
				'b2b4' => 1,
				'b5c4' => 1,
				'f3d4' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/8/1Bb1p3/1P1nP3/5N2/P1PP1PPP/RNBQ1RK1 b kq' => {
			eco => 'C64q',
			# TRANSLATORS: C64q: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Bc5 4. O-O Nd4 5. b4
			variation => N__('Spanish: Classical, Zaitsev Variation'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/8/2b1p3/2BnP3/5N2/PPPP1PPP/RNBQ1RK1 b kq' => {
			eco => 'C64r',
			# TRANSLATORS: C64r: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Bc5 4. O-O Nd4 5. Bc4
			variation => N__('Spanish: Classical, 4.O-O Nd4 5. Bc4'),
			moves => {
			},
		},
		'r1bqk1nr/pppp1ppp/8/1Bb1p3/3NP3/8/PPPP1PPP/RNBQ1RK1 b kq' => {
			eco => 'C64s',
			# TRANSLATORS: C64s: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Bc5 4. O-O Nd4 5. Nxd4
			variation => N__('Spanish: Classical, 4.O-O Nd4 5.Nxd4'),
			moves => {
				'c5d4' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/8/1B2p3/3bP3/8/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C64s',
			# TRANSLATORS: C64s: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Bc5 4. O-O Nd4 5. Nxd4 Bxd4
			variation => N__('Spanish: Classical, 4.O-O Nd4 5.Nxd4 Bxd4'),
			moves => {
				'c2c3' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/8/1B2p3/3bP3/2P5/PP1P1PPP/RNBQ1RK1 b kq' => {
			eco => 'C64s',
			# TRANSLATORS: C64s: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Bc5 4. O-O Nd4 5. Nxd4 Bxd4 6. c3
			variation => N__('Spanish: Classical, 4.O-O Nd4 5.Nxd4 Bxd4 6. c3'),
			moves => {
				'd4b6' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/1b6/1B2p3/4P3/2P5/PP1P1PPP/RNBQ1RK1 w kq' => {
			eco => 'C64s',
			# TRANSLATORS: C64s: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Bc5 4. O-O Nd4 5. Nxd4 Bxd4 6. c3 Bb6
			variation => N__('Spanish: Classical, 4.O-O Nd4 5.Nxd4 Bxd4 6. c3 Bb6'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bqk1nr/pppp1ppp/1b6/1B2p3/3PP3/2P5/PP3PPP/RNBQ1RK1 b kq' => {
			eco => 'C64t',
			# TRANSLATORS: C64t: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Bc5 4. O-O Nd4 5. Nxd4 Bxd4 6. c3 Bb6 7. d4
			variation => N__('Spanish: Classical, 4.O-O Nd4 5.Nxd4 Bxd4 6. c3 Bb6 7. d4'),
			moves => {
				'c7c6' => 1,
			},
		},
		'r1bqk1nr/pp1p1ppp/1bp5/1B2p3/3PP3/2P5/PP3PPP/RNBQ1RK1 w kq' => {
			eco => 'C64t',
			# TRANSLATORS: C64t: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Bc5 4. O-O Nd4 5. Nxd4 Bxd4 6. c3 Bb6 7. d4 c6
			variation => N__('Spanish: Classical, 4.O-O Nd4 5.Nxd4 Bxd4 6. c3 Bb6 7. d4'),
			moves => {
				'b5a4' => 1,
			},
		},
		'r1bqk1nr/pp1p1ppp/1bp5/4p3/B2PP3/2P5/PP3PPP/RNBQ1RK1 b kq' => {
			eco => 'C64u',
			# TRANSLATORS: C64u: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Bc5 4. O-O Nd4 5. Nxd4 Bxd4 6. c3 Bb6 7. d4 c6 8. Ba4
			variation => N__('Spanish: Classical, 6. c3 Bb6 7. d4 c6 8. Ba4'),
			moves => {
				'd7d6' => 1,
			},
		},
		'r1bqk1nr/pp3ppp/1bpp4/4p3/B2PP3/2P5/PP3PPP/RNBQ1RK1 w kq' => {
			eco => 'C64u',
			# TRANSLATORS: C64u: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Bc5 4. O-O Nd4 5. Nxd4 Bxd4 6. c3 Bb6 7. d4 c6 8. Ba4 d6
			variation => N__('Spanish: Classical, 6. c3 Bb6 7. d4 c6 8. Ba4'),
			moves => {
				'b1a3' => 1,
			},
		},
		'r1bqk1nr/pp3ppp/1bpp4/4p3/B2PP3/N1P5/PP3PPP/R1BQ1RK1 b kq' => {
			eco => 'C64v',
			# TRANSLATORS: C64v: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Bc5 4. O-O Nd4 5. Nxd4 Bxd4 6. c3 Bb6 7. d4 c6 8. Ba4 d6 9. Na3
			variation => N__('Spanish: Classical, 6. c3 Bb6 7. d4 c6 8. Ba4 d6 9. Na3'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/1B2p3/4P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C65a',
			# TRANSLATORS: C65a: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6
			variation => N__('Spanish: Berlin Defence'),
			moves => {
				'd1e2' => 1,
				'd2d3' => 1,
				'd2d4' => 1,
				'e1g1' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/1B2p3/4P3/5N2/PPPPQPPP/RNB1K2R b KQkq' => {
			eco => 'C65b',
			# TRANSLATORS: C65b: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. Qe2
			variation => N__('Spanish: Berlin, 4. Qe2'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/1B2p3/3PP3/5N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C65c',
			# TRANSLATORS: C65c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. d4
			variation => N__('Spanish: Berlin, 4. d4'),
			moves => {
				'e5d4' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/1B6/3pP3/5N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C65d',
			# TRANSLATORS: C65d: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. d4 exd4
			variation => N__('Spanish: Berlin, 4. d4 exd4'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/1B6/3pP3/5N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C65e',
			# TRANSLATORS: C65e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. d4 exd4 5. O-O
			variation => N__('Spanish: Berlin, Nyholm Attack'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/1B2p3/4P3/3P1N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C65f',
			# TRANSLATORS: C65f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. d3
			variation => N__('Spanish: Berlin, 4. d3'),
			moves => {
				'c6e7' => 1,
				'd7d6' => 1,
				'f8c5' => 1,
			},
		},
		'r1bqkb1r/ppppnppp/5n2/1B2p3/4P3/3P1N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C65g',
			# TRANSLATORS: C65g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. d3 Ne7
			variation => N__('Spanish: Berlin, Mortimer Variation'),
			moves => {
				'f3e5' => 1,
			},
		},
		'r1bqkb1r/ppppnppp/5n2/1B2N3/4P3/3P4/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C65g',
			# TRANSLATORS: C65g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. d3 Ne7 5. Nxe5
			variation => N__('Spanish: Berlin, Mortimer Variation'),
			moves => {
				'c7c6' => 1,
			},
		},
		'r1bqkb1r/pp1pnppp/2p2n2/1B2N3/4P3/3P4/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C65g',
			# TRANSLATORS: C65g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. d3 Ne7 5. Nxe5 c6
			variation => N__('Spanish: Berlin, Mortimer Trap'),
			moves => {
			},
		},
		'r1bqkb1r/ppp2ppp/2np1n2/1B2p3/4P3/3P1N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C65h',
			# TRANSLATORS: C65h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. d3 d6
			variation => N__('Spanish: Berlin, 4. d3 d6'),
			moves => {
				'b5c6' => 1,
				'c2c3' => 1,
				'c2c4' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2Bp1n2/4p3/4P3/3P1N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C65h',
			# TRANSLATORS: C65h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. d3 d6 5. Bxc6+
			variation => N__('Spanish: Berlin, Anderssen Variation'),
			moves => {
			},
		},
		'r1bqkb1r/ppp2ppp/2np1n2/1B2p3/2P1P3/3P1N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'C65h',
			# TRANSLATORS: C65h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. d3 d6 5. c4
			variation => N__('Spanish: Berlin, Duras Variation'),
			moves => {
			},
		},
		'r1bqkb1r/ppp2ppp/2np1n2/1B2p3/4P3/2PP1N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'C65i',
			# TRANSLATORS: C65i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. d3 d6 5. c3
			variation => N__('Spanish: Berlin, 4. d3 d6 5. c3'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/1Bb1p3/4P3/3P1N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C65j',
			# TRANSLATORS: C65j: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. d3 Bc5
			variation => N__('Spanish: Berlin, 4. d3 Bc5'),
			moves => {
				'c1e3' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/1Bb1p3/4P3/3PBN2/PPP2PPP/RN1QK2R b KQkq' => {
			eco => 'C65j',
			# TRANSLATORS: C65j: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. d3 Bc5 5. Be3
			variation => N__('Spanish: Berlin, Kaufmann Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n2n2/1B2p3/4P3/5N2/PPPP1PPP/RNBQ1RK1 b kq' => {
			eco => 'C65k',
			# TRANSLATORS: C65k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O
			variation => N__('Spanish: Berlin, 4.O-O'),
			moves => {
				'd7d6' => 1,
				'f6e4' => 1,
				'f8c5' => 1,
				'f8e7' => 1,
			},
		},
		'r1bqk2r/ppppbppp/2n2n2/1B2p3/4P3/5N2/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C65l',
			# TRANSLATORS: C65l: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Be7
			variation => N__('Spanish: Berlin, 4.O-O Be7'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/1Bb1p3/4P3/5N2/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C65m',
			# TRANSLATORS: C65m: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Bc5
			variation => N__('Spanish: Berlin, Beverwijk Variation'),
			moves => {
				'c2c3' => 1,
				'f3e5' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/1Bb1p3/4P3/2P2N2/PP1P1PPP/RNBQ1RK1 b kq' => {
			eco => 'C65n',
			# TRANSLATORS: C65n: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Bc5 5. c3
			variation => N__('Spanish: Berlin, Beverwijk, 5. c3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pppp1ppp/2n2n2/1Bb1p3/4P3/2P2N2/PP1P1PPP/RNBQ1RK1 w -' => {
			eco => 'C65n',
			# TRANSLATORS: C65n: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Bc5 5. c3 O-O
			variation => N__('Spanish: Berlin, Beverwijk, 5. c3'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bq1rk1/pppp1ppp/2n2n2/1Bb1p3/3PP3/2P2N2/PP3PPP/RNBQ1RK1 b -' => {
			eco => 'C65n',
			# TRANSLATORS: C65n: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Bc5 5. c3 O-O 6. d4
			variation => N__('Spanish: Berlin, Beverwijk, 5. c3'),
			moves => {
				'c5b6' => 1,
			},
		},
		'r1bq1rk1/pppp1ppp/1bn2n2/1B2p3/3PP3/2P2N2/PP3PPP/RNBQ1RK1 w -' => {
			eco => 'C65o',
			# TRANSLATORS: C65o: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Bc5 5. c3 O-O 6. d4 Bb6
			variation => N__('Spanish: Berlin, Benelux Variation'),
			moves => {
				'c1g5' => 1,
			},
		},
		'r1bq1rk1/pppp1ppp/1bn2n2/1B2p1B1/3PP3/2P2N2/PP3PPP/RN1Q1RK1 b -' => {
			eco => 'C65p',
			# TRANSLATORS: C65p: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Bc5 5. c3 O-O 6. d4 Bb6 7. Bg5
			variation => N__('Spanish: Berlin, Benelux Variation, 7. Bg5'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n2n2/1Bb1N3/4P3/8/PPPP1PPP/RNBQ1RK1 b kq' => {
			eco => 'C65q',
			# TRANSLATORS: C65q: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Bc5 5. Nxe5
			variation => N__('Spanish: Berlin, Beverwijk, 5.Nxe5'),
			moves => {
			},
		},
		'r1bqkb1r/ppp2ppp/2np1n2/1B2p3/4P3/5N2/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C66',
			# TRANSLATORS: C66: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O d6
			variation => N__('Spanish: Closed Berlin'),
			moves => {
				'd2d4' => 1,
				'f1e1' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2np1n2/1B2p3/3PP3/5N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C66',
			# TRANSLATORS: C66: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O d6 5. d4
			variation => N__('Spanish: Closed Berlin, 5. d4'),
			moves => {
				'c8d7' => 1,
				'f6d7' => 1,
			},
		},
		'r2qkb1r/pppb1ppp/2np1n2/1B2p3/3PP3/5N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C66',
			# TRANSLATORS: C66: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O d6 5. d4 Bd7
			variation => N__('Spanish: Closed Berlin, 5. d4 Bd7'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r2qkb1r/pppb1ppp/2np1n2/1B2p3/3PP3/2N2N2/PPP2PPP/R1BQ1RK1 b kq' => {
			eco => 'C66',
			# TRANSLATORS: C66: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O d6 5. d4 Bd7 6. Nc3
			variation => N__('Spanish: Closed Berlin, 5. d4 Bd7'),
			moves => {
				'e5d4' => 1,
				'f8e7' => 1,
			},
		},
		'r2qkb1r/pppb1ppp/2np1n2/1B6/3pP3/2N2N2/PPP2PPP/R1BQ1RK1 w kq' => {
			eco => 'C66',
			# TRANSLATORS: C66: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O d6 5. d4 Bd7 6. Nc3 exd4
			variation => N__('Spanish: Closed Berlin, Wolf Variation'),
			moves => {
			},
		},
		'r2qk2r/pppbbppp/2np1n2/1B2p3/3PP3/2N2N2/PPP2PPP/R1BQ1RK1 w kq' => {
			eco => 'C66',
			# TRANSLATORS: C66: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O d6 5. d4 Bd7 6. Nc3 Be7
			variation => N__('Spanish: Closed Berlin, Hedgehog Variation'),
			moves => {
				'b5c6' => 1,
				'c1g5' => 1,
				'f1e1' => 1,
			},
		},
		'r2qk2r/pppbbppp/2Bp1n2/4p3/3PP3/2N2N2/PPP2PPP/R1BQ1RK1 b kq' => {
			eco => 'C66',
			# TRANSLATORS: C66: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O d6 5. d4 Bd7 6. Nc3 Be7 7. Bxc6
			variation => N__('Spanish: Closed Berlin, Showalter Variation'),
			moves => {
			},
		},
		'r2qk2r/pppbbppp/2np1n2/1B2p1B1/3PP3/2N2N2/PPP2PPP/R2Q1RK1 b kq' => {
			eco => 'C66',
			# TRANSLATORS: C66: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O d6 5. d4 Bd7 6. Nc3 Be7 7. Bg5
			variation => N__('Spanish: Closed Berlin, Bernstein Variation'),
			moves => {
			},
		},
		'r2qk2r/pppbbppp/2np1n2/1B2p3/3PP3/2N2N2/PPP2PPP/R1BQR1K1 b kq' => {
			eco => 'C66',
			# TRANSLATORS: C66: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O d6 5. d4 Bd7 6. Nc3 Be7 7. Re1
			variation => N__('Spanish: Closed Berlin, Hedgehog Variation'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r2q1rk1/pppbbppp/2np1n2/1B2p3/3PP3/2N2N2/PPP2PPP/R1BQR1K1 w -' => {
			eco => 'C66',
			# TRANSLATORS: C66: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O d6 5. d4 Bd7 6. Nc3 Be7 7. Re1 O-O
			variation => N__('Spanish: Closed Berlin, Tarrasch Trap'),
			moves => {
			},
		},
		'r1bqkb1r/pppn1ppp/2np4/1B2p3/3PP3/5N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C66',
			# TRANSLATORS: C66: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O d6 5. d4 Nd7
			variation => N__('Spanish: Closed Berlin, Chigorin Variation'),
			moves => {
			},
		},
		'r1bqkb1r/ppp2ppp/2np1n2/1B2p3/4P3/5N2/PPPP1PPP/RNBQR1K1 b kq' => {
			eco => 'C66',
			# TRANSLATORS: C66: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O d6 5. Re1
			variation => N__('Spanish: Closed Berlin, 5. Re1'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n5/1B2p3/4n3/5N2/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C67a',
			# TRANSLATORS: C67a: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4
			variation => N__('Spanish: Open Berlin'),
			moves => {
				'd1e2' => 1,
				'd2d4' => 1,
				'f1e1' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2n5/1B2p3/4n3/5N2/PPPPQPPP/RNB2RK1 b kq' => {
			eco => 'C67b',
			# TRANSLATORS: C67b: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4 5. Qe2
			variation => N__('Spanish: Open Berlin, 5. Qe2'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n5/1B2p3/4n3/5N2/PPPP1PPP/RNBQR1K1 b kq' => {
			eco => 'C67c',
			# TRANSLATORS: C67c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4 5. Re1
			variation => N__('Spanish: Open Berlin, 5. Re1'),
			moves => {
				'e4d6' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2nn4/1B2p3/8/5N2/PPPP1PPP/RNBQR1K1 w kq' => {
			eco => 'C67c',
			# TRANSLATORS: C67c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4 5. Re1 Nd6
			variation => N__('Spanish: Open Berlin, 5. Re1'),
			moves => {
				'f3e5' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2nn4/1B2N3/8/8/PPPP1PPP/RNBQR1K1 b kq' => {
			eco => 'C67d',
			# TRANSLATORS: C67d: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4 5. Re1 Nd6 6. Nxe5
			variation => N__('Spanish: Open Berlin, 5. Re1 Nd6 6.Nxe5'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2n5/1B2p3/3Pn3/5N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C67e',
			# TRANSLATORS: C67e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4 5. d4
			variation => N__('Spanish: Open Berlin, 5. d4'),
			moves => {
				'a7a6' => 1,
				'e4d6' => 1,
				'f8e7' => 1,
			},
		},
		'r1bqkb1r/1ppp1ppp/p1n5/1B2p3/3Pn3/5N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C67e',
			# TRANSLATORS: C67e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4 5. d4 a6
			variation => N__('Spanish: Open Berlin, Rosenthal Variation'),
			moves => {
			},
		},
		'r1bqk2r/ppppbppp/2n5/1B2p3/3Pn3/5N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C67f',
			# TRANSLATORS: C67f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4 5. d4 Be7
			variation => N__('Spanish: Open Berlin, 5... Be7'),
			moves => {
				'd1e2' => 1,
				'd4e5' => 1,
			},
		},
		'r1bqk2r/ppppbppp/2n5/1B2P3/4n3/5N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C67g',
			# TRANSLATORS: C67g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4 5. d4 Be7 6. dxe5
			variation => N__('Spanish: Berlin, Minckwitz Variation'),
			moves => {
			},
		},
		'r1bqk2r/ppppbppp/2n5/1B2p3/3Pn3/5N2/PPP1QPPP/RNB2RK1 b kq' => {
			eco => 'C67h',
			# TRANSLATORS: C67h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4 5. d4 Be7 6. Qe2
			variation => N__('Spanish: Open Berlin, 5... Be7 6. Qe2'),
			moves => {
				'd7d5' => 1,
				'e4d6' => 1,
			},
		},
		'r1bqk2r/ppp1bppp/2n5/1B1pp3/3Pn3/5N2/PPP1QPPP/RNB2RK1 w kq' => {
			eco => 'C67h',
			# TRANSLATORS: C67h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4 5. d4 Be7 6. Qe2 d5
			variation => N__('Spanish: Open Berlin, Trifunovic Variation'),
			moves => {
			},
		},
		'r1bqk2r/ppppbppp/2nn4/1B2p3/3P4/5N2/PPP1QPPP/RNB2RK1 w kq' => {
			eco => 'C67i',
			# TRANSLATORS: C67i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4 5. d4 Be7 6. Qe2 Nd6
			variation => N__('Spanish: Open Berlin, 5... Be7 6. Qd2 Nd6'),
			moves => {
				'b5c6' => 1,
			},
		},
		'r1bqk2r/ppppbppp/2Bn4/4p3/3P4/5N2/PPP1QPPP/RNB2RK1 b kq' => {
			eco => 'C67i',
			# TRANSLATORS: C67i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4 5. d4 Be7 6. Qe2 Nd6 7. Bxc6
			variation => N__('Spanish: Open Berlin, 5... Be7 6. Qd2 Nd6'),
			moves => {
				'b7c6' => 1,
			},
		},
		'r1bqk2r/p1ppbppp/2pn4/4p3/3P4/5N2/PPP1QPPP/RNB2RK1 w kq' => {
			eco => 'C67i',
			# TRANSLATORS: C67i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4 5. d4 Be7 6. Qe2 Nd6 7. Bxc6 bxc6
			variation => N__('Spanish: Open Berlin, 5... Be7 6. Qd2 Nd6'),
			moves => {
				'd4e5' => 1,
			},
		},
		'r1bqk2r/p1ppbppp/2pn4/4P3/8/5N2/PPP1QPPP/RNB2RK1 b kq' => {
			eco => 'C67i',
			# TRANSLATORS: C67i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4 5. d4 Be7 6. Qe2 Nd6 7. Bxc6 bxc6 8. dxe5
			variation => N__('Spanish: Open Berlin, 5... Be7 6. Qd2 Nd6'),
			moves => {
				'd6b7' => 1,
				'd6f5' => 1,
			},
		},
		'r1bqk2r/p1ppbppp/2p5/4Pn2/8/5N2/PPP1QPPP/RNB2RK1 w kq' => {
			eco => 'C67i',
			# TRANSLATORS: C67i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4 5. d4 Be7 6. Qe2 Nd6 7. Bxc6 bxc6 8. dxe5 Nf5
			variation => N__('Spanish: Open Berlin, Cordel Variation'),
			moves => {
			},
		},
		'r1bqk2r/pnppbppp/2p5/4P3/8/5N2/PPP1QPPP/RNB2RK1 w kq' => {
			eco => 'C67j',
			# TRANSLATORS: C67j: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4 5. d4 Be7 6. Qe2 Nd6 7. Bxc6 bxc6 8. dxe5 Nb7
			variation => N__('Spanish: Open Berlin, 5... Be7 6. Qd2 Nd6 7.Bxc6 bxc6 8.dxe5 Nb7'),
			moves => {
				'b1c3' => 1,
				'b2b3' => 1,
				'c2c4' => 1,
				'f3d4' => 1,
			},
		},
		'r1bqk2r/pnppbppp/2p5/4P3/8/1P3N2/P1P1QPPP/RNB2RK1 b kq' => {
			eco => 'C67j',
			# TRANSLATORS: C67j: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4 5. d4 Be7 6. Qe2 Nd6 7. Bxc6 bxc6 8. dxe5 Nb7 9. b3
			variation => N__('Spanish: Open Berlin, Pillsbury Variation'),
			moves => {
			},
		},
		'r1bqk2r/pnppbppp/2p5/4P3/2P5/5N2/PP2QPPP/RNB2RK1 b kq' => {
			eco => 'C67j',
			# TRANSLATORS: C67j: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4 5. d4 Be7 6. Qe2 Nd6 7. Bxc6 bxc6 8. dxe5 Nb7 9. c4
			variation => N__('Spanish: Open Berlin, Zukertort Variation'),
			moves => {
			},
		},
		'r1bqk2r/pnppbppp/2p5/4P3/3N4/8/PPP1QPPP/RNB2RK1 b kq' => {
			eco => 'C67k',
			# TRANSLATORS: C67k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4 5. d4 Be7 6. Qe2 Nd6 7. Bxc6 bxc6 8. dxe5 Nb7 9. Nd4
			variation => N__('Spanish: Open Berlin, Winawer Attack'),
			moves => {
			},
		},
		'r1bqk2r/pnppbppp/2p5/4P3/8/2N2N2/PPP1QPPP/R1B2RK1 b kq' => {
			eco => 'C67l',
			# TRANSLATORS: C67l: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4 5. d4 Be7 6. Qe2 Nd6 7. Bxc6 bxc6 8. dxe5 Nb7 9. Nc3
			variation => N__('Spanish: Open Berlin, Main Line 9. Nc3 (Rio de Janerio)'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2nn4/1B2p3/3P4/5N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C67m',
			# TRANSLATORS: C67m: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4 5. d4 Nd6
			variation => N__('Spanish: Open Berlin, 5. d4 Nd6'),
			moves => {
				'b5a4' => 1,
				'b5c6' => 1,
				'd4e5' => 1,
			},
		},
		'r1bqkb1r/pppp1ppp/2nn4/4p3/B2P4/5N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C67m',
			# TRANSLATORS: C67m: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4 5. d4 Nd6 6. Ba4
			variation => N__('Spanish: Open Berlin, Showalter Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2nn4/1B2P3/8/5N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C67n',
			# TRANSLATORS: C67n: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4 5. d4 Nd6 6. dxe5
			variation => N__('Spanish: Open Berlin, 5. d4 Nd6 6.dxe5'),
			moves => {
			},
		},
		'r1bqkb1r/pppp1ppp/2Bn4/4p3/3P4/5N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C67o',
			# TRANSLATORS: C67o: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4 5. d4 Nd6 6. Bxc6
			variation => N__('Spanish: Open Berlin, 5. d4 Nd6 6.Bxc6'),
			moves => {
				'd7c6' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2pn4/4p3/3P4/5N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C67p',
			# TRANSLATORS: C67p: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4 5. d4 Nd6 6. Bxc6 dxc6
			variation => N__('Spanish: Open Berlin, 5. d4 Nd6 6.Bxc6 dxc6'),
			moves => {
				'd4e5' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2pn4/4P3/8/5N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C67p',
			# TRANSLATORS: C67p: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4 5. d4 Nd6 6. Bxc6 dxc6 7. dxe5
			variation => N__('Spanish: Open Berlin, 5. d4 Nd6 6.Bxc6 dxc6'),
			moves => {
				'd6f5' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2p5/4Pn2/8/5N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C67q',
			# TRANSLATORS: C67q: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4 5. d4 Nd6 6. Bxc6 dxc6 7. dxe5 Nf5
			variation => N__('Spanish: Open Berlin, 5. d4 Nd6 6.Bxc6 dxc6 7.dxe5 Nf5'),
			moves => {
				'd1d8' => 1,
			},
		},
		'r1bQkb1r/ppp2ppp/2p5/4Pn2/8/5N2/PPP2PPP/RNB2RK1 b kq' => {
			eco => 'C67r',
			# TRANSLATORS: C67r: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4 5. d4 Nd6 6. Bxc6 dxc6 7. dxe5 Nf5 8. Qxd8+
			variation => N__('Spanish: Open Berlin, 5. d4 Nd6 Queenswap'),
			moves => {
				'e8d8' => 1,
			},
		},
		'r1bk1b1r/ppp2ppp/2p5/4Pn2/8/5N2/PPP2PPP/RNB2RK1 w -' => {
			eco => 'C67r',
			# TRANSLATORS: C67r: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4 5. d4 Nd6 6. Bxc6 dxc6 7. dxe5 Nf5 8. Qxd8+ Kxd8
			variation => N__('Spanish: Open Berlin, 5. d4 Nd6 Queenswap'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r1bk1b1r/ppp2ppp/2p5/4Pn2/8/2N2N2/PPP2PPP/R1B2RK1 b -' => {
			eco => 'C67s',
			# TRANSLATORS: C67s: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4 5. d4 Nd6 6. Bxc6 dxc6 7. dxe5 Nf5 8. Qxd8+ Kxd8 9. Nc3
			variation => N__('Spanish: Open Berlin, 5. d4 Nd6 Queenswap, 9. Nc3'),
			moves => {
				'd8e8' => 1,
				'h7h6' => 1,
			},
		},
		'r1bk1b1r/ppp2pp1/2p4p/4Pn2/8/2N2N2/PPP2PPP/R1B2RK1 w -' => {
			eco => 'C67t',
			# TRANSLATORS: C67t: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4 5. d4 Nd6 6. Bxc6 dxc6 7. dxe5 Nf5 8. Qxd8+ Kxd8 9. Nc3 h6
			variation => N__('Spanish: Open Berlin, 5. d4 Nd6 Queenswap, 9. Nc3 h6'),
			moves => {
			},
		},
		'r1b1kb1r/ppp2ppp/2p5/4Pn2/8/2N2N2/PPP2PPP/R1B2RK1 w -' => {
			eco => 'C67u',
			# TRANSLATORS: C67u: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4 5. d4 Nd6 6. Bxc6 dxc6 7. dxe5 Nf5 8. Qxd8+ Kxd8 9. Nc3 Ke8
			variation => N__('Spanish: Open Berlin, 5. d4 Nd6 Queenswap, 9. Nc3 Ke8'),
			moves => {
				'f1d1' => 1,
				'h2h3' => 1,
			},
		},
		'r1b1kb1r/ppp2ppp/2p5/4Pn2/8/2N2N2/PPP2PPP/R1BR2K1 b -' => {
			eco => 'C67v',
			# TRANSLATORS: C67v: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4 5. d4 Nd6 6. Bxc6 dxc6 7. dxe5 Nf5 8. Qxd8+ Kxd8 9. Nc3 Ke8 10. Rd1
			variation => N__('Spanish: Open Berlin, 5. d4 Nd6 Queenswap, 9. Nc3 Ke8 10. Rd1'),
			moves => {
			},
		},
		'r1b1kb1r/ppp2ppp/2p5/4Pn2/8/2N2N1P/PPP2PP1/R1B2RK1 b -' => {
			eco => 'C67w',
			# TRANSLATORS: C67w: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4 5. d4 Nd6 6. Bxc6 dxc6 7. dxe5 Nf5 8. Qxd8+ Kxd8 9. Nc3 Ke8 10. h3
			variation => N__('Spanish: Open Berlin, 5. d4 Nd6 Queenswap, 9. Nc3 Ke8 10. h3'),
			moves => {
				'a7a5' => 1,
			},
		},
		'r1b1kb1r/1pp2ppp/2p5/p3Pn2/8/2N2N1P/PPP2PP1/R1B2RK1 w -' => {
			eco => 'C67x',
			# TRANSLATORS: C67x: 1. e4 e5 2. Nf3 Nc6 3. Bb5 Nf6 4. O-O Nxe4 5. d4 Nd6 6. Bxc6 dxc6 7. dxe5 Nf5 8. Qxd8+ Kxd8 9. Nc3 Ke8 10. h3 a5
			variation => N__('Spanish: Open Berlin, 5. d4 Nd6 Queenswap, 9. Nc3 Ke8 10. h3 a5'),
			moves => {
			},
		},
		'r1bqkbnr/1ppp1ppp/p1n5/1B2p3/4P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C68a',
			# TRANSLATORS: C68a: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6
			variation => N__('Spanish: 3... a6'),
			moves => {
				'b5a4' => 1,
				'b5c4' => 1,
				'b5c6' => 1,
			},
		},
		'r1bqkbnr/1ppp1ppp/p1n5/4p3/2B1P3/5N2/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'C68b',
			# TRANSLATORS: C68b: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bc4
			variation => N__('Spanish: 3... a6 4. Bc4'),
			moves => {
			},
		},
		'r1bqkbnr/1ppp1ppp/p1B5/4p3/4P3/5N2/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'C68c',
			# TRANSLATORS: C68c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6
			variation => N__('Spanish: Exchange Variation'),
			moves => {
				'b7c6' => 1,
				'd7c6' => 1,
			},
		},
		'r1bqkbnr/2pp1ppp/p1p5/4p3/4P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C68c',
			# TRANSLATORS: C68c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 bxc6
			variation => N__('Spanish: Exchange, 4...bxc6'),
			moves => {
			},
		},
		'r1bqkbnr/1pp2ppp/p1p5/4p3/4P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C68d',
			# TRANSLATORS: C68d: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6
			variation => N__('Spanish: Exchange, 4...dxc6'),
			moves => {
				'b1c3' => 1,
				'd2d4' => 1,
				'e1g1' => 1,
			},
		},
		'r1bqkbnr/1pp2ppp/p1p5/4p3/3PP3/5N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C68e',
			# TRANSLATORS: C68e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. d4
			variation => N__('Spanish: Exchange, Lasker Variation'),
			moves => {
				'e5d4' => 1,
			},
		},
		'r1bqkbnr/1pp2ppp/p1p5/8/3pP3/5N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C68e',
			# TRANSLATORS: C68e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. d4 exd4
			variation => N__('Spanish: Exchange, Lasker Variation'),
			moves => {
				'd1d4' => 1,
			},
		},
		'r1bqkbnr/1pp2ppp/p1p5/8/3QP3/5N2/PPP2PPP/RNB1K2R b KQkq' => {
			eco => 'C68e',
			# TRANSLATORS: C68e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. d4 exd4 6. Qxd4
			variation => N__('Spanish: Exchange, Lasker Variation'),
			moves => {
				'd8d4' => 1,
			},
		},
		'r1b1kbnr/1pp2ppp/p1p5/8/3qP3/5N2/PPP2PPP/RNB1K2R w KQkq' => {
			eco => 'C68e',
			# TRANSLATORS: C68e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. d4 exd4 6. Qxd4 Qxd4
			variation => N__('Spanish: Exchange, Lasker Variation'),
			moves => {
				'f3d4' => 1,
			},
		},
		'r1b1kbnr/1pp2ppp/p1p5/8/3NP3/8/PPP2PPP/RNB1K2R b KQkq' => {
			eco => 'C68e',
			# TRANSLATORS: C68e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. d4 exd4 6. Qxd4 Qxd4 7. Nxd4
			variation => N__('Spanish: Exchange, Lasker Variation'),
			moves => {
				'c8d7' => 1,
			},
		},
		'r3kbnr/1ppb1ppp/p1p5/8/3NP3/8/PPP2PPP/RNB1K2R w KQkq' => {
			eco => 'C68f',
			# TRANSLATORS: C68f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. d4 exd4 6. Qxd4 Qxd4 7. Nxd4 Bd7
			variation => N__('Spanish: Exchange, Alekhine Variation'),
			moves => {
			},
		},
		'r1bqkbnr/1pp2ppp/p1p5/4p3/4P3/2N2N2/PPPP1PPP/R1BQK2R b KQkq' => {
			eco => 'C68g',
			# TRANSLATORS: C68g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. Nc3
			variation => N__('Spanish: Exchange, Keres Variation'),
			moves => {
				'f7f6' => 1,
			},
		},
		'r1bqkbnr/1pp3pp/p1p2p2/4p3/4P3/2N2N2/PPPP1PPP/R1BQK2R w KQkq' => {
			eco => 'C68h',
			# TRANSLATORS: C68h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. Nc3 f6
			variation => N__('Spanish: Exchange, Keres, 5... f6'),
			moves => {
				'd2d3' => 1,
				'd2d4' => 1,
			},
		},
		'r1bqkbnr/1pp3pp/p1p2p2/4p3/4P3/2NP1N2/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'C68h',
			# TRANSLATORS: C68h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. Nc3 f6 6. d3
			variation => N__('Spanish: Exchange, Romanovsky Variation'),
			moves => {
			},
		},
		'r1bqkbnr/1pp3pp/p1p2p2/4p3/3PP3/2N2N2/PPP2PPP/R1BQK2R b KQkq' => {
			eco => 'C68i',
			# TRANSLATORS: C68i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. Nc3 f6 6. d4
			variation => N__('Spanish: Exchange, 5. Nc3 f6 6. d4'),
			moves => {
			},
		},
		'r1bqkbnr/1pp2ppp/p1p5/4p3/4P3/5N2/PPPP1PPP/RNBQ1RK1 b kq' => {
			eco => 'C68j',
			# TRANSLATORS: C68j: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O
			variation => N__('Spanish: Exchange, 5.O-O'),
			moves => {
				'c8g4' => 1,
				'd8d6' => 1,
				'f7f6' => 1,
				'f8d6' => 1,
				'g8e7' => 1,
			},
		},
		'r1bqkb1r/1pp1nppp/p1p5/4p3/4P3/5N2/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C68k',
			# TRANSLATORS: C68k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O Ne7
			variation => N__('Spanish: Exchange, 5.O-O Ne7'),
			moves => {
			},
		},
		'r1bqk1nr/1pp2ppp/p1pb4/4p3/4P3/5N2/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C68l',
			# TRANSLATORS: C68l: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O Bd6
			variation => N__('Spanish: Exchange, 5.O-O Bd6'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bqk1nr/1pp2ppp/p1pb4/4p3/3PP3/5N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C68l',
			# TRANSLATORS: C68l: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O Bd6 6. d4
			variation => N__('Spanish: Exchange, 5.O-O Bd6'),
			moves => {
				'e5d4' => 1,
			},
		},
		'r1bqk1nr/1pp2ppp/p1pb4/8/3pP3/5N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C68m',
			# TRANSLATORS: C68m: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O Bd6 6. d4 exd4
			variation => N__('Spanish: Exchange, 5.O-O Bd6 6. d4 exd4'),
			moves => {
			},
		},
		'r2qkbnr/1pp2ppp/p1p5/4p3/4P1b1/5N2/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C68n',
			# TRANSLATORS: C68n: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O Bg4
			variation => N__('Spanish: Exchange, 5.O-O Bg4'),
			moves => {
				'h2h3' => 1,
			},
		},
		'r2qkbnr/1pp2ppp/p1p5/4p3/4P1b1/5N1P/PPPP1PP1/RNBQ1RK1 b kq' => {
			eco => 'C68n',
			# TRANSLATORS: C68n: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O Bg4 6. h3
			variation => N__('Spanish: Exchange, 5.O-O Bg4 6. h3'),
			moves => {
				'h7h5' => 1,
			},
		},
		'r2qkbnr/1pp2pp1/p1p5/4p2p/4P1b1/5N1P/PPPP1PP1/RNBQ1RK1 w kq' => {
			eco => 'C68o',
			# TRANSLATORS: C68o: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O Bg4 6. h3 h5
			variation => N__('Spanish: Exchange, Alapin Gambit'),
			moves => {
				'd2d3' => 1,
			},
		},
		'r2qkbnr/1pp2pp1/p1p5/4p2p/4P1b1/3P1N1P/PPP2PP1/RNBQ1RK1 b kq' => {
			eco => 'C68o',
			# TRANSLATORS: C68o: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O Bg4 6. h3 h5 7. d3
			variation => N__('Spanish: Exchange, Alapin Gambit'),
			moves => {
				'd8f6' => 1,
			},
		},
		'r3kbnr/1pp2pp1/p1p2q2/4p2p/4P1b1/3P1N1P/PPP2PP1/RNBQ1RK1 w kq' => {
			eco => 'C68o',
			# TRANSLATORS: C68o: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O Bg4 6. h3 h5 7. d3 Qf6
			variation => N__('Spanish: Exchange, Alapin Gambit'),
			moves => {
				'b1d2' => 1,
			},
		},
		'r3kbnr/1pp2pp1/p1p2q2/4p2p/4P1b1/3P1N1P/PPPN1PP1/R1BQ1RK1 b kq' => {
			eco => 'C68p',
			# TRANSLATORS: C68p: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O Bg4 6. h3 h5 7. d3 Qf6 8. Nbd2
			variation => N__('Spanish: Exchange, Alapin Gambit, 7. d3 Qf6 8.Nbd2'),
			moves => {
			},
		},
		'r1b1kbnr/1pp2ppp/p1pq4/4p3/4P3/5N2/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C68q',
			# TRANSLATORS: C68q: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O Qd6
			variation => N__('Spanish: Exchange, Bronstein Variation'),
			moves => {
				'b1a3' => 1,
				'd2d3' => 1,
			},
		},
		'r1b1kbnr/1pp2ppp/p1pq4/4p3/4P3/3P1N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C68r',
			# TRANSLATORS: C68r: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O Qd6 6. d3
			variation => N__('Spanish: Exchange, Bronstein, 6. d3'),
			moves => {
			},
		},
		'r1b1kbnr/1pp2ppp/p1pq4/4p3/4P3/N4N2/PPPP1PPP/R1BQ1RK1 b kq' => {
			eco => 'C68s',
			# TRANSLATORS: C68s: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O Qd6 6. Na3
			variation => N__('Spanish: Exchange, Bronstein, 6. Na3'),
			moves => {
				'b7b5' => 1,
				'c8e6' => 1,
			},
		},
		'r1b1kbnr/2p2ppp/p1pq4/1p2p3/4P3/N4N2/PPPP1PPP/R1BQ1RK1 w kq' => {
			eco => 'C68t',
			# TRANSLATORS: C68t: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O Qd6 6. Na3 b5
			variation => N__('Spanish: Exchange, Bronstein, 6. Na3 b5'),
			moves => {
			},
		},
		'r3kbnr/1pp2ppp/p1pqb3/4p3/4P3/N4N2/PPPP1PPP/R1BQ1RK1 w kq' => {
			eco => 'C68u',
			# TRANSLATORS: C68u: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O Qd6 6. Na3 Be6
			variation => N__('Spanish: Exchange, Bronstein, 6. Na3 Be6'),
			moves => {
			},
		},
		'r1bqkbnr/1pp3pp/p1p2p2/4p3/4P3/5N2/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C69a',
			# TRANSLATORS: C69a: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O f6
			variation => N__('Spanish: Exchange, Gligoric Variation'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bqkbnr/1pp3pp/p1p2p2/4p3/3PP3/5N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C69b',
			# TRANSLATORS: C69b: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O f6 6. d4
			variation => N__('Spanish: Exchange, Gligoric, 6. d4'),
			moves => {
				'c8g4' => 1,
				'e5d4' => 1,
			},
		},
		'r2qkbnr/1pp3pp/p1p2p2/4p3/3PP1b1/5N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C69b',
			# TRANSLATORS: C69b: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O f6 6. d4 Bg4
			variation => N__('Spanish: Exchange, Gligoric, 6. d4 Bg4'),
			moves => {
				'c2c3' => 1,
				'd4e5' => 1,
			},
		},
		'r2qkbnr/1pp3pp/p1p2p2/4p3/3PP1b1/2P2N2/PP3PPP/RNBQ1RK1 b kq' => {
			eco => 'C69c',
			# TRANSLATORS: C69c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O f6 6. d4 Bg4 7. c3
			variation => N__('Spanish: Exchange, Gligoric, 6. d4 Bg4 7. c3'),
			moves => {
				'f8d6' => 1,
			},
		},
		'r2qk1nr/1pp3pp/p1pb1p2/4p3/3PP1b1/2P2N2/PP3PPP/RNBQ1RK1 w kq' => {
			eco => 'C69d',
			# TRANSLATORS: C69d: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O f6 6. d4 Bg4 7. c3 Bd6
			variation => N__('Spanish: Exchange, Gligoric, 6. d4 Bg4 7. c3 Bd6'),
			moves => {
			},
		},
		'r2qkbnr/1pp3pp/p1p2p2/4P3/4P1b1/5N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C69e',
			# TRANSLATORS: C69e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O f6 6. d4 Bg4 7. dxe5
			variation => N__('Spanish: Exchange, Gligoric, 6. d4 Bg4 7.dxe5'),
			moves => {
				'd8d1' => 1,
			},
		},
		'r3kbnr/1pp3pp/p1p2p2/4P3/4P1b1/5N2/PPP2PPP/RNBq1RK1 w kq' => {
			eco => 'C69e',
			# TRANSLATORS: C69e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O f6 6. d4 Bg4 7. dxe5 Qxd1
			variation => N__('Spanish: Exchange, Gligoric, 6. d4 Bg4 7.dxe5'),
			moves => {
				'f1d1' => 1,
			},
		},
		'r3kbnr/1pp3pp/p1p2p2/4P3/4P1b1/5N2/PPP2PPP/RNBR2K1 b kq' => {
			eco => 'C69e',
			# TRANSLATORS: C69e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O f6 6. d4 Bg4 7. dxe5 Qxd1 8. Rxd1
			variation => N__('Spanish: Exchange, Gligoric, 6. d4 Bg4 7.dxe5'),
			moves => {
				'f6e5' => 1,
			},
		},
		'r3kbnr/1pp3pp/p1p5/4p3/4P1b1/5N2/PPP2PPP/RNBR2K1 w kq' => {
			eco => 'C69e',
			# TRANSLATORS: C69e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O f6 6. d4 Bg4 7. dxe5 Qxd1 8. Rxd1 fxe5
			variation => N__('Spanish: Exchange, Gligoric, 6. d4 Bg4 7.dxe5'),
			moves => {
				'd1d3' => 1,
			},
		},
		'r3kbnr/1pp3pp/p1p5/4p3/4P1b1/3R1N2/PPP2PPP/RNB3K1 b kq' => {
			eco => 'C69f',
			# TRANSLATORS: C69f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O f6 6. d4 Bg4 7. dxe5 Qxd1 8. Rxd1 fxe5 9. Rd3
			variation => N__('Spanish: Exchange, Gligoric, 6. d4 Bg4 Queenswap, 9. Rd3'),
			moves => {
				'f8d6' => 1,
			},
		},
		'r3k1nr/1pp3pp/p1pb4/4p3/4P1b1/3R1N2/PPP2PPP/RNB3K1 w kq' => {
			eco => 'C69g',
			# TRANSLATORS: C69g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O f6 6. d4 Bg4 7. dxe5 Qxd1 8. Rxd1 fxe5 9. Rd3 Bd6
			variation => N__('Spanish: Exchange, Gligoric, 6. d4 Bg4 Queenswap, 9. Rd3 Bd6'),
			moves => {
			},
		},
		'r1bqkbnr/1pp3pp/p1p2p2/8/3pP3/5N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C69h',
			# TRANSLATORS: C69h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O f6 6. d4 exd4
			variation => N__('Spanish: Exchange, Gligoric, 6. d4 exd4'),
			moves => {
				'd1d4' => 1,
				'f3d4' => 1,
			},
		},
		'r1bqkbnr/1pp3pp/p1p2p2/8/3NP3/8/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C69h',
			# TRANSLATORS: C69h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O f6 6. d4 exd4 7. Nxd4
			variation => N__('Spanish: Exchange, Gligoric, 6. d4 exd4 7.Qxd4'),
			moves => {
				'c6c5' => 1,
				'g8e7' => 1,
			},
		},
		'r1bqkbnr/1pp3pp/p1p2p2/8/3QP3/5N2/PPP2PPP/RNB2RK1 b kq' => {
			eco => 'C69i',
			# TRANSLATORS: C69i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O f6 6. d4 exd4 7. Qxd4
			variation => N__('Spanish: Exchange, Gligoric, 6. d4 exd4 7.Nxd4'),
			moves => {
			},
		},
		'r1bqkb1r/1pp1n1pp/p1p2p2/8/3NP3/8/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C69i',
			# TRANSLATORS: C69i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O f6 6. d4 exd4 7. Nxd4 Ne7
			variation => N__('Spanish: Exchange, Gligoric, 6. d4 exd4 7.Nxd4 Ne7'),
			moves => {
			},
		},
		'r1bqkbnr/1pp3pp/p4p2/2p5/3NP3/8/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C69j',
			# TRANSLATORS: C69j: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O f6 6. d4 exd4 7. Nxd4 c5
			variation => N__('Spanish: Exchange, Gligoric, 6. d4 exd4 7.Nxd4 c5'),
			moves => {
				'd4b3' => 1,
				'd4e2' => 1,
			},
		},
		'r1bqkbnr/1pp3pp/p4p2/2p5/4P3/8/PPP1NPPP/RNBQ1RK1 b kq' => {
			eco => 'C69j',
			# TRANSLATORS: C69j: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O f6 6. d4 exd4 7. Nxd4 c5 8. Ne2
			variation => N__('Spanish: Exchange, Gligoric, 8. Ne2'),
			moves => {
			},
		},
		'r1bqkbnr/1pp3pp/p4p2/2p5/4P3/1N6/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C69k',
			# TRANSLATORS: C69k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O f6 6. d4 exd4 7. Nxd4 c5 8. Nb3
			variation => N__('Spanish: Exchange, Gligoric, 8. Nb3'),
			moves => {
				'd8d1' => 1,
			},
		},
		'r1b1kbnr/1pp3pp/p4p2/2p5/4P3/1N6/PPP2PPP/RNBq1RK1 w kq' => {
			eco => 'C69k',
			# TRANSLATORS: C69k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O f6 6. d4 exd4 7. Nxd4 c5 8. Nb3 Qxd1
			variation => N__('Spanish: Exchange, Gligoric, 8. Nb3'),
			moves => {
				'f1d1' => 1,
			},
		},
		'r1b1kbnr/1pp3pp/p4p2/2p5/4P3/1N6/PPP2PPP/RNBR2K1 b kq' => {
			eco => 'C69k',
			# TRANSLATORS: C69k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O f6 6. d4 exd4 7. Nxd4 c5 8. Nb3 Qxd1 9. Rxd1
			variation => N__('Spanish: Exchange, Gligoric, 8. Nb3 Queenswap'),
			moves => {
				'c8d7' => 1,
				'c8g4' => 1,
			},
		},
		'r3kbnr/1ppb2pp/p4p2/2p5/4P3/1N6/PPP2PPP/RNBR2K1 w kq' => {
			eco => 'C69l',
			# TRANSLATORS: C69l: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O f6 6. d4 exd4 7. Nxd4 c5 8. Nb3 Qxd1 9. Rxd1 Bd7
			variation => N__('Spanish: Exchange, Gligoric, 8. Nb3 Queenswap, 9... Bd7'),
			moves => {
			},
		},
		'r3kbnr/1pp3pp/p4p2/2p5/4P1b1/1N6/PPP2PPP/RNBR2K1 w kq' => {
			eco => 'C69m',
			# TRANSLATORS: C69m: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O f6 6. d4 exd4 7. Nxd4 c5 8. Nb3 Qxd1 9. Rxd1 Bg4
			variation => N__('Spanish: Exchange, Gligoric, 8. Nb3 Queenswap, 9... Bg4'),
			moves => {
				'f2f3' => 1,
			},
		},
		'r3kbnr/1pp3pp/p4p2/2p5/4P1b1/1N3P2/PPP3PP/RNBR2K1 b kq' => {
			eco => 'C69m',
			# TRANSLATORS: C69m: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O f6 6. d4 exd4 7. Nxd4 c5 8. Nb3 Qxd1 9. Rxd1 Bg4 10. f3
			variation => N__('Spanish: Exchange, Gligoric, 8. Nb3 Queenswap, 9... Bg4'),
			moves => {
				'g4e6' => 1,
			},
		},
		'r3kbnr/1pp3pp/p3bp2/2p5/4P3/1N3P2/PPP3PP/RNBR2K1 w kq' => {
			eco => 'C69n',
			# TRANSLATORS: C69n: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Bxc6 dxc6 5. O-O f6 6. d4 exd4 7. Nxd4 c5 8. Nb3 Qxd1 9. Rxd1 Bg4 10. f3 Be6
			variation => N__('Spanish: Exchange, Gligoric, 8. Nb3 Queenswap, 9... Bg4 10. f3 Be6'),
			moves => {
			},
		},
		'r1bqkbnr/1ppp1ppp/p1n5/4p3/B3P3/5N2/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'C70',
			# TRANSLATORS: C70: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4
			variation => N__('Spanish: 4. Ba4'),
			moves => {
				'b7b5' => 1,
				'c6d4' => 1,
				'd7d6' => 1,
				'f7f5' => 1,
				'f8b4' => 1,
				'f8c5' => 1,
				'f8e7' => 1,
				'g7g5' => 1,
				'g7g6' => 1,
				'g8e7' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkbnr/2pp1ppp/p1n5/1p2p3/B3P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C70',
			# TRANSLATORS: C70: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 b5
			variation => N__('Spanish: Caro Variation'),
			moves => {
				'a4b3' => 1,
			},
		},
		'r1bqkbnr/2pp1ppp/p1n5/1p2p3/4P3/1B3N2/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'C70',
			# TRANSLATORS: C70: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 b5 5. Bb3
			variation => N__('Spanish: Caro Variation'),
			moves => {
				'c6a5' => 1,
				'f8c5' => 1,
			},
		},
		'r1bqkbnr/2pp1ppp/p7/np2p3/4P3/1B3N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C70',
			# TRANSLATORS: C70: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 b5 5. Bb3 Na5
			variation => N__('Spanish: Taimanov (Wing) Variation'),
			moves => {
			},
		},
		'r1bqk1nr/2pp1ppp/p1n5/1pb1p3/4P3/1B3N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C70',
			# TRANSLATORS: C70: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 b5 5. Bb3 Bc5
			variation => N__('Spanish: Graz Variation'),
			moves => {
			},
		},
		'r1bqkbnr/1ppp1ppp/p7/4p3/B2nP3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C70',
			# TRANSLATORS: C70: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nd4
			variation => N__('Spanish: Bird\'s Deferred'),
			moves => {
			},
		},
		'r1bqkbnr/1ppp2pp/p1n5/4pp2/B3P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C70',
			# TRANSLATORS: C70: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 f5
			variation => N__('Spanish: Schliemann Deferred'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bqkbnr/1ppp2pp/p1n5/4pp2/B2PP3/5N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C70',
			# TRANSLATORS: C70: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 f5 5. d4
			variation => N__('Spanish: Schliemann Deferred, 5. d4'),
			moves => {
				'e5d4' => 1,
			},
		},
		'r1bqkbnr/1ppp2pp/p1n5/5p2/B2pP3/5N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C70',
			# TRANSLATORS: C70: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 f5 5. d4 exd4
			variation => N__('Spanish: Schliemann Deferred, 5. d4'),
			moves => {
				'e4e5' => 1,
			},
		},
		'r1bqkbnr/1ppp2pp/p1n5/4Pp2/B2p4/5N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C70',
			# TRANSLATORS: C70: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 f5 5. d4 exd4 6. e5
			variation => N__('Spanish: Schliemann Deferred, 5. d4 exd4 6. e5'),
			moves => {
			},
		},
		'r1bqk1nr/1ppp1ppp/p1n5/4p3/Bb2P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C70',
			# TRANSLATORS: C70: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Bb4
			variation => N__('Spanish: Alapin Deferred'),
			moves => {
			},
		},
		'r1bqk1nr/1ppp1ppp/p1n5/2b1p3/B3P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C70',
			# TRANSLATORS: C70: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Bc5
			variation => N__('Spanish: Classical Deferred'),
			moves => {
			},
		},
		'r1bqk1nr/1pppbppp/p1n5/4p3/B3P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C70',
			# TRANSLATORS: C70: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Be7
			variation => N__('Spanish: 4. Ba4 Be7'),
			moves => {
			},
		},
		'r1bqkbnr/1ppp1p1p/p1n5/4p1p1/B3P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C70',
			# TRANSLATORS: C70: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 g5
			variation => N__('Spanish: Brentano Variation'),
			moves => {
			},
		},
		'r1bqkbnr/1ppp1p1p/p1n3p1/4p3/B3P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C70',
			# TRANSLATORS: C70: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 g6
			variation => N__('Spanish: Fianchetto Deferred'),
			moves => {
			},
		},
		'r1bqkb1r/1pppnppp/p1n5/4p3/B3P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C70',
			# TRANSLATORS: C70: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nge7
			variation => N__('Spanish: Cozio Deferred'),
			moves => {
			},
		},
		'r1bqkbnr/1pp2ppp/p1np4/4p3/B3P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C71',
			# TRANSLATORS: C71: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6
			variation => N__('Spanish: Modern Steinitz Defence'),
			moves => {
				'a4c6' => 1,
				'b1c3' => 1,
				'c2c3' => 1,
				'c2c4' => 1,
				'd2d4' => 1,
				'e1g1' => 1,
			},
		},
		'r1bqkbnr/1pp2ppp/p1np4/4p3/B3P3/2N2N2/PPPP1PPP/R1BQK2R b KQkq' => {
			eco => 'C71',
			# TRANSLATORS: C71: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. Nc3
			variation => N__('Spanish: Modern Steinitz, Three Knights Variation'),
			moves => {
			},
		},
		'r1bqkbnr/1pp2ppp/p1np4/4p3/B1P1P3/5N2/PP1P1PPP/RNBQK2R b KQkq' => {
			eco => 'C71',
			# TRANSLATORS: C71: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. c4
			variation => N__('Spanish: Modern Steinitz, Keres Variation'),
			moves => {
			},
		},
		'r1bqkbnr/1pp2ppp/p1np4/4p3/B2PP3/5N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C71',
			# TRANSLATORS: C71: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. d4
			variation => N__('Spanish: Modern Steinitz, 5. d4'),
			moves => {
				'b7b5' => 1,
			},
		},
		'r1bqkbnr/2p2ppp/p1np4/1p2p3/B2PP3/5N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C71',
			# TRANSLATORS: C71: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. d4 b5
			variation => N__('Spanish: Modern Steinitz, 5. d4'),
			moves => {
				'a4b3' => 1,
			},
		},
		'r1bqkbnr/2p2ppp/p1np4/1p2p3/3PP3/1B3N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C71',
			# TRANSLATORS: C71: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. d4 b5 6. Bb3
			variation => N__('Spanish: Modern Steinitz, 5. d4'),
			moves => {
				'c6d4' => 1,
			},
		},
		'r1bqkbnr/2p2ppp/p2p4/1p2p3/3nP3/1B3N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C71',
			# TRANSLATORS: C71: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. d4 b5 6. Bb3 Nxd4
			variation => N__('Spanish: Modern Steinitz, 5. d4'),
			moves => {
				'f3d4' => 1,
			},
		},
		'r1bqkbnr/2p2ppp/p2p4/1p2p3/3NP3/1B6/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C71',
			# TRANSLATORS: C71: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. d4 b5 6. Bb3 Nxd4 7. Nxd4
			variation => N__('Spanish: Modern Steinitz, 5. d4'),
			moves => {
				'e5d4' => 1,
			},
		},
		'r1bqkbnr/2p2ppp/p2p4/1p6/3pP3/1B6/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C71',
			# TRANSLATORS: C71: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. d4 b5 6. Bb3 Nxd4 7. Nxd4 exd4
			variation => N__('Spanish: Modern Steinitz, 5. d4'),
			moves => {
				'd1d4' => 1,
			},
		},
		'r1bqkbnr/2p2ppp/p2p4/1p6/3QP3/1B6/PPP2PPP/RNB1K2R b KQkq' => {
			eco => 'C71',
			# TRANSLATORS: C71: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. d4 b5 6. Bb3 Nxd4 7. Nxd4 exd4 8. Qxd4
			variation => N__('Spanish: Modern Steinitz, 5. d4'),
			moves => {
				'c7c5' => 1,
			},
		},
		'r1bqkbnr/5ppp/p2p4/1pp5/3QP3/1B6/PPP2PPP/RNB1K2R w KQkq' => {
			eco => 'C71',
			# TRANSLATORS: C71: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. d4 b5 6. Bb3 Nxd4 7. Nxd4 exd4 8. Qxd4 c5
			variation => N__('Spanish: Modern Steinitz, Noah\'s Ark Trap'),
			moves => {
			},
		},
		'r1bqkbnr/1pp2ppp/p1np4/4p3/B3P3/5N2/PPPP1PPP/RNBQ1RK1 b kq' => {
			eco => 'C72',
			# TRANSLATORS: C72: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. O-O
			variation => N__('Spanish: Modern Steinitz, 5.O-O'),
			moves => {
				'c8d7' => 1,
				'c8g4' => 1,
				'g8e7' => 1,
			},
		},
		'r2qkbnr/1ppb1ppp/p1np4/4p3/B3P3/5N2/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C72',
			# TRANSLATORS: C72: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. O-O Bd7
			variation => N__('Spanish: Modern Steinitz, 5.O-O Bd7'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r2qkbnr/1ppb1ppp/p1np4/4p3/B2PP3/5N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C72',
			# TRANSLATORS: C72: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. O-O Bd7 6. d4
			variation => N__('Spanish: Modern Steinitz, 5.O-O Bd7 6. d4'),
			moves => {
			},
		},
		'r2qkbnr/1pp2ppp/p1np4/4p3/B3P1b1/5N2/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C72',
			# TRANSLATORS: C72: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. O-O Bg4
			variation => N__('Spanish: Modern Steinitz, 5.O-O Bg4'),
			moves => {
				'h2h3' => 1,
			},
		},
		'r2qkbnr/1pp2ppp/p1np4/4p3/B3P1b1/5N1P/PPPP1PP1/RNBQ1RK1 b kq' => {
			eco => 'C72',
			# TRANSLATORS: C72: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. O-O Bg4 6. h3
			variation => N__('Spanish: Modern Steinitz, 5.O-O Bg4 6. h3'),
			moves => {
			},
		},
		'r1bqkb1r/1pp1nppp/p1np4/4p3/B3P3/5N2/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C72',
			# TRANSLATORS: C72: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. O-O Ne7
			variation => N__('Spanish: Modern Steinitz, 5.O-O Ne7'),
			moves => {
			},
		},
		'r1bqkbnr/1pp2ppp/p1Bp4/4p3/4P3/5N2/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'C73',
			# TRANSLATORS: C73: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. Bxc6+
			variation => N__('Spanish: Modern Steinitz, Richter Variation'),
			moves => {
				'b7c6' => 1,
			},
		},
		'r1bqkbnr/2p2ppp/p1pp4/4p3/4P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C73',
			# TRANSLATORS: C73: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. Bxc6+ bxc6
			variation => N__('Spanish: Modern Steinitz, Richter Variation'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bqkbnr/2p2ppp/p1pp4/4p3/3PP3/5N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C73',
			# TRANSLATORS: C73: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. Bxc6+ bxc6 6. d4
			variation => N__('Spanish: Modern Steinitz, Richter Variation'),
			moves => {
				'f7f6' => 1,
			},
		},
		'r1bqkbnr/2p3pp/p1pp1p2/4p3/3PP3/5N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C73',
			# TRANSLATORS: C73: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. Bxc6+ bxc6 6. d4 f6
			variation => N__('Spanish: Modern Steinitz, Alapin Variation'),
			moves => {
			},
		},
		'r1bqkbnr/1pp2ppp/p1np4/4p3/B3P3/2P2N2/PP1P1PPP/RNBQK2R b KQkq' => {
			eco => 'C74',
			# TRANSLATORS: C74: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. c3
			variation => N__('Spanish: Modern Steinitz, 5. c3'),
			moves => {
				'c8d7' => 1,
				'f7f5' => 1,
				'g7g6' => 1,
			},
		},
		'r1bqkbnr/1pp3pp/p1np4/4pp2/B3P3/2P2N2/PP1P1PPP/RNBQK2R w KQkq' => {
			eco => 'C74',
			# TRANSLATORS: C74: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. c3 f5
			variation => N__('Spanish: Modern Steinitz, Siesta Variation'),
			moves => {
				'e4f5' => 1,
			},
		},
		'r1bqkbnr/1pp3pp/p1np4/4pP2/B7/2P2N2/PP1P1PPP/RNBQK2R b KQkq' => {
			eco => 'C74',
			# TRANSLATORS: C74: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. c3 f5 6. exf5
			variation => N__('Spanish: Modern Steinitz, Siesta, 6.exf5'),
			moves => {
				'c8f5' => 1,
			},
		},
		'r2qkbnr/1pp3pp/p1np4/4pb2/B7/2P2N2/PP1P1PPP/RNBQK2R w KQkq' => {
			eco => 'C74',
			# TRANSLATORS: C74: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. c3 f5 6. exf5 Bxf5
			variation => N__('Spanish: Modern Steinitz, Siesta, 6.exf5'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r2qkbnr/1pp3pp/p1np4/4pb2/B7/2P2N2/PP1P1PPP/RNBQ1RK1 b kq' => {
			eco => 'C74',
			# TRANSLATORS: C74: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. c3 f5 6. exf5 Bxf5 7. O-O
			variation => N__('Spanish: Modern Steinitz, Siesta, Kopayev Variation'),
			moves => {
				'f5d3' => 1,
			},
		},
		'r2qkbnr/1pp3pp/p1np4/4p3/B7/2Pb1N2/PP1P1PPP/RNBQ1RK1 w kq' => {
			eco => 'C74',
			# TRANSLATORS: C74: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. c3 f5 6. exf5 Bxf5 7. O-O Bd3
			variation => N__('Spanish: Modern Steinitz, Siesta, Kopayev Variation'),
			moves => {
				'f1e1' => 1,
			},
		},
		'r2qkbnr/1pp3pp/p1np4/4p3/B7/2Pb1N2/PP1P1PPP/RNBQR1K1 b kq' => {
			eco => 'C74',
			# TRANSLATORS: C74: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. c3 f5 6. exf5 Bxf5 7. O-O Bd3 8. Re1
			variation => N__('Spanish: Modern Steinitz, Siesta, Kopayev Variation'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r2qk1nr/1pp1b1pp/p1np4/4p3/B7/2Pb1N2/PP1P1PPP/RNBQR1K1 w kq' => {
			eco => 'C74',
			# TRANSLATORS: C74: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. c3 f5 6. exf5 Bxf5 7. O-O Bd3 8. Re1 Be7
			variation => N__('Spanish: Modern Steinitz, Siesta, Kopayev Variation'),
			moves => {
				'a4c2' => 1,
			},
		},
		'r2qk1nr/1pp1b1pp/p1np4/4p3/8/2Pb1N2/PPBP1PPP/RNBQR1K1 b kq' => {
			eco => 'C74',
			# TRANSLATORS: C74: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. c3 f5 6. exf5 Bxf5 7. O-O Bd3 8. Re1 Be7 9. Bc2
			variation => N__('Spanish: Modern Steinitz, Siesta, Kopayev Variation'),
			moves => {
				'd3c2' => 1,
			},
		},
		'r2qk1nr/1pp1b1pp/p1np4/4p3/8/2P2N2/PPbP1PPP/RNBQR1K1 w kq' => {
			eco => 'C74',
			# TRANSLATORS: C74: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. c3 f5 6. exf5 Bxf5 7. O-O Bd3 8. Re1 Be7 9. Bc2 Bxc2
			variation => N__('Spanish: Modern Steinitz, Siesta, Kopayev Variation'),
			moves => {
				'd1c2' => 1,
			},
		},
		'r2qk1nr/1pp1b1pp/p1np4/4p3/8/2P2N2/PPQP1PPP/RNB1R1K1 b kq' => {
			eco => 'C74',
			# TRANSLATORS: C74: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. c3 f5 6. exf5 Bxf5 7. O-O Bd3 8. Re1 Be7 9. Bc2 Bxc2 10. Qxc2
			variation => N__('Spanish: Modern Steinitz, Siesta, Kopayev, Main Line'),
			moves => {
			},
		},
		'r1bqkbnr/1pp2p1p/p1np2p1/4p3/B3P3/2P2N2/PP1P1PPP/RNBQK2R w KQkq' => {
			eco => 'C74',
			# TRANSLATORS: C74: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. c3 g6
			variation => N__('Spanish: Modern Steinitz, 5. c3 g6'),
			moves => {
			},
		},
		'r2qkbnr/1ppb1ppp/p1np4/4p3/B3P3/2P2N2/PP1P1PPP/RNBQK2R w KQkq' => {
			eco => 'C75',
			# TRANSLATORS: C75: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. c3 Bd7
			variation => N__('Spanish: Modern Steinitz, 5. c3 Bd7'),
			moves => {
				'd2d4' => 1,
				'e1g1' => 1,
			},
		},
		'r2qkbnr/1ppb1ppp/p1np4/4p3/B2PP3/2P2N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'C75',
			# TRANSLATORS: C75: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. c3 Bd7 6. d4
			variation => N__('Spanish: Modern Steinitz, 5. c3 Bd7 6. d4'),
			moves => {
				'g7g6' => 1,
				'g8e7' => 1,
				'g8f6' => 1,
			},
		},
		'r2qkb1r/1ppbnppp/p1np4/4p3/B2PP3/2P2N2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'C75',
			# TRANSLATORS: C75: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. c3 Bd7 6. d4 Nge7
			variation => N__('Spanish: Modern Steinitz, Rubinstein Variation'),
			moves => {
				'a4b3' => 1,
				'c1e3' => 1,
			},
		},
		'r2qkb1r/1ppbnppp/p1np4/4p3/3PP3/1BP2N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'C75',
			# TRANSLATORS: C75: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. c3 Bd7 6. d4 Nge7 7. Bb3
			variation => N__('Spanish: Modern Steinitz, Rubinstein, 7. Bb3'),
			moves => {
			},
		},
		'r2qkb1r/1ppbnppp/p1np4/4p3/B2PP3/2P1BN2/PP3PPP/RN1QK2R b KQkq' => {
			eco => 'C75',
			# TRANSLATORS: C75: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. c3 Bd7 6. d4 Nge7 7. Be3
			variation => N__('Spanish: Modern Steinitz, Rubinstein, 7. Be3'),
			moves => {
			},
		},
		'r2qkb1r/1ppb1ppp/p1np1n2/4p3/B2PP3/2P2N2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'C75',
			# TRANSLATORS: C75: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. c3 Bd7 6. d4 Nf6
			variation => N__('Spanish: Modern Steinitz, 5. c3 Bd7 6. d4 Nf6'),
			moves => {
			},
		},
		'r2qkbnr/1ppb1ppp/p1np4/4p3/B3P3/2P2N2/PP1P1PPP/RNBQ1RK1 b kq' => {
			eco => 'C75',
			# TRANSLATORS: C75: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. c3 Bd7 6. O-O
			variation => N__('Spanish: Modern Steinitz, 5. c3 Bd7 6.O-O'),
			moves => {
			},
		},
		'r2qkbnr/1ppb1p1p/p1np2p1/4p3/B2PP3/2P2N2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'C76',
			# TRANSLATORS: C76: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. c3 Bd7 6. d4 g6
			variation => N__('Spanish: Modern Steinitz, Bronstein Variation'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r2qkbnr/1ppb1p1p/p1np2p1/4p3/B2PP3/2P2N2/PP3PPP/RNBQ1RK1 b kq' => {
			eco => 'C76',
			# TRANSLATORS: C76: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. c3 Bd7 6. d4 g6 7. O-O
			variation => N__('Spanish: Modern Steinitz, Bronstein, 7.O-O'),
			moves => {
				'f8g7' => 1,
			},
		},
		'r2qk1nr/1ppb1pbp/p1np2p1/4p3/B2PP3/2P2N2/PP3PPP/RNBQ1RK1 w kq' => {
			eco => 'C76',
			# TRANSLATORS: C76: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. c3 Bd7 6. d4 g6 7. O-O Bg7
			variation => N__('Spanish: Modern Steinitz, Bronstein, 7.O-O'),
			moves => {
				'd4d5' => 1,
				'd4e5' => 1,
				'f1e1' => 1,
			},
		},
		'r2qk1nr/1ppb1pbp/p1np2p1/3Pp3/B3P3/2P2N2/PP3PPP/RNBQ1RK1 b kq' => {
			eco => 'C76',
			# TRANSLATORS: C76: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. c3 Bd7 6. d4 g6 7. O-O Bg7 8. d5
			variation => N__('Spanish: Modern Steinitz, Bronstein, 7.O-O Bg7 8. d5'),
			moves => {
			},
		},
		'r2qk1nr/1ppb1pbp/p1np2p1/4P3/B3P3/2P2N2/PP3PPP/RNBQ1RK1 b kq' => {
			eco => 'C76',
			# TRANSLATORS: C76: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. c3 Bd7 6. d4 g6 7. O-O Bg7 8. dxe5
			variation => N__('Spanish: Modern Steinitz, Bronstein, 7.O-O Bg7 8.dxe5'),
			moves => {
				'c6e5' => 1,
				'd6e5' => 1,
			},
		},
		'r2qk1nr/1ppb1pbp/p2p2p1/4n3/B3P3/2P2N2/PP3PPP/RNBQ1RK1 w kq' => {
			eco => 'C76',
			# TRANSLATORS: C76: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. c3 Bd7 6. d4 g6 7. O-O Bg7 8. dxe5 Nxe5
			variation => N__('Spanish: Modern Steinitz, Bronstein, 7.O-O Bg7 8.dxe5 Nxe5'),
			moves => {
			},
		},
		'r2qk1nr/1ppb1pbp/p1n3p1/4p3/B3P3/2P2N2/PP3PPP/RNBQ1RK1 w kq' => {
			eco => 'C76',
			# TRANSLATORS: C76: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. c3 Bd7 6. d4 g6 7. O-O Bg7 8. dxe5 dxe5
			variation => N__('Spanish: Modern Steinitz, Bronstein, 7.O-O Bg7 8.dxe5 dxe5'),
			moves => {
			},
		},
		'r2qk1nr/1ppb1pbp/p1np2p1/4p3/B2PP3/2P2N2/PP3PPP/RNBQR1K1 b kq' => {
			eco => 'C76',
			# TRANSLATORS: C76: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 d6 5. c3 Bd7 6. d4 g6 7. O-O Bg7 8. Re1
			variation => N__('Spanish: Modern Steinitz, Bronstein, 7.O-O Bg7 8. Re1'),
			moves => {
			},
		},
		'r1bqkb1r/1ppp1ppp/p1n2n2/4p3/B3P3/5N2/PPPP1PPP/RNBQK2R w KQkq' => {
			eco => 'C77a',
			# TRANSLATORS: C77a: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6
			variation => N__('Spanish: Morphy Defence'),
			moves => {
				'a4c6' => 1,
				'b1c3' => 1,
				'd1e2' => 1,
				'd2d3' => 1,
				'd2d4' => 1,
				'e1g1' => 1,
			},
		},
		'r1bqkb1r/1ppp1ppp/p1n2n2/4p3/B3P3/3P1N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C77b',
			# TRANSLATORS: C77b: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. d3
			variation => N__('Spanish: Anderssen Variation'),
			moves => {
				'b7b5' => 1,
				'd7d6' => 1,
			},
		},
		'r1bqkb1r/2pp1ppp/p1n2n2/1p2p3/B3P3/3P1N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C77c',
			# TRANSLATORS: C77c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. d3 b5
			variation => N__('Spanish: Anderssen, 5... b5'),
			moves => {
			},
		},
		'r1bqkb1r/1pp2ppp/p1np1n2/4p3/B3P3/3P1N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C77d',
			# TRANSLATORS: C77d: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. d3 d6
			variation => N__('Spanish: Anderssen, 5... d6'),
			moves => {
				'c2c3' => 1,
				'c2c4' => 1,
			},
		},
		'r1bqkb1r/1pp2ppp/p1np1n2/4p3/B1P1P3/3P1N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'C77e',
			# TRANSLATORS: C77e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. d3 d6 6. c4
			variation => N__('Spanish: Duras Variation'),
			moves => {
			},
		},
		'r1bqkb1r/1pp2ppp/p1np1n2/4p3/B3P3/2PP1N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'C77f',
			# TRANSLATORS: C77f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. d3 d6 6. c3
			variation => N__('Spanish: Anderssen, 5... d6 6. c3'),
			moves => {
				'g7g6' => 1,
			},
		},
		'r1bqkb1r/1pp2p1p/p1np1np1/4p3/B3P3/2PP1N2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'C77g',
			# TRANSLATORS: C77g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. d3 d6 6. c3 g6
			variation => N__('Spanish: Anderssen, 5... d6 6. c3 g6'),
			moves => {
			},
		},
		'r1bqkb1r/1ppp1ppp/p1n2n2/4p3/B3P3/2N2N2/PPPP1PPP/R1BQK2R b KQkq' => {
			eco => 'C77h',
			# TRANSLATORS: C77h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. Nc3
			variation => N__('Spanish: Four Knights (Tarrasch) Variation'),
			moves => {
			},
		},
		'r1bqkb1r/1ppp1ppp/p1B2n2/4p3/4P3/5N2/PPPP1PPP/RNBQK2R b KQkq' => {
			eco => 'C77i',
			# TRANSLATORS: C77i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. Bxc6
			variation => N__('Spanish: Exchange Deferred'),
			moves => {
			},
		},
		'r1bqkb1r/1ppp1ppp/p1n2n2/4p3/B2PP3/5N2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'C77j',
			# TRANSLATORS: C77j: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. d4
			variation => N__('Spanish: Centre Attack'),
			moves => {
				'b7b5' => 1,
				'c6d4' => 1,
				'e5d4' => 1,
				'f6e4' => 1,
				'f8e7' => 1,
			},
		},
		'r1bqkb1r/2pp1ppp/p1n2n2/1p2p3/B2PP3/5N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C77k',
			# TRANSLATORS: C77k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. d4 b5
			variation => N__('Spanish: Centre Attack, 5... b5'),
			moves => {
			},
		},
		'r1bqkb1r/1ppp1ppp/p4n2/4p3/B2nP3/5N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C77l',
			# TRANSLATORS: C77l: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. d4 Nxd4
			variation => N__('Spanish: Centre Attack, 5...Nxd4'),
			moves => {
			},
		},
		'r1bqkb1r/1ppp1ppp/p1n5/4p3/B2Pn3/5N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C77m',
			# TRANSLATORS: C77m: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. d4 Nxe4
			variation => N__('Spanish: Centre Attack, 5...Nxe4'),
			moves => {
			},
		},
		'r1bqk2r/1pppbppp/p1n2n2/4p3/B2PP3/5N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C77n',
			# TRANSLATORS: C77n: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. d4 Be7
			variation => N__('Spanish: Centre Attack, 5... Be7'),
			moves => {
			},
		},
		'r1bqkb1r/1ppp1ppp/p1n2n2/8/B2pP3/5N2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'C77o',
			# TRANSLATORS: C77o: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. d4 exd4
			variation => N__('Spanish: Centre Attack, 5...exd4'),
			moves => {
			},
		},
		'r1bqkb1r/1ppp1ppp/p1n2n2/4p3/B3P3/5N2/PPPPQPPP/RNB1K2R b KQkq' => {
			eco => 'C77p',
			# TRANSLATORS: C77p: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. Qe2
			variation => N__('Spanish: Wormald Attack'),
			moves => {
				'b7b5' => 1,
				'f8e7' => 1,
			},
		},
		'r1bqk2r/1pppbppp/p1n2n2/4p3/B3P3/5N2/PPPPQPPP/RNB1K2R w KQkq' => {
			eco => 'C77q',
			# TRANSLATORS: C77q: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. Qe2 Be7
			variation => N__('Spanish: Wormald Attack, 5... Be7'),
			moves => {
			},
		},
		'r1bqkb1r/2pp1ppp/p1n2n2/1p2p3/B3P3/5N2/PPPPQPPP/RNB1K2R w KQkq' => {
			eco => 'C77r',
			# TRANSLATORS: C77r: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. Qe2 b5
			variation => N__('Spanish: Wormald Attack, 5... b5'),
			moves => {
				'a4b3' => 1,
			},
		},
		'r1bqkb1r/2pp1ppp/p1n2n2/1p2p3/4P3/1B3N2/PPPPQPPP/RNB1K2R b KQkq' => {
			eco => 'C77r',
			# TRANSLATORS: C77r: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. Qe2 b5 6. Bb3
			variation => N__('Spanish: Wormald Attack, 5... b5'),
			moves => {
				'f8c5' => 1,
				'f8e7' => 1,
			},
		},
		'r1bqk2r/2pp1ppp/p1n2n2/1pb1p3/4P3/1B3N2/PPPPQPPP/RNB1K2R w KQkq' => {
			eco => 'C77s',
			# TRANSLATORS: C77s: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. Qe2 b5 6. Bb3 Bc5
			variation => N__('Spanish: Wormald Attack, 5... b5 6. Bb3 Bc5'),
			moves => {
				'c2c3' => 1,
			},
		},
		'r1bqk2r/2pp1ppp/p1n2n2/1pb1p3/4P3/1BP2N2/PP1PQPPP/RNB1K2R b KQkq' => {
			eco => 'C77t',
			# TRANSLATORS: C77t: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. Qe2 b5 6. Bb3 Bc5 7. c3
			variation => N__('Spanish: Wormald Attack, 5... b5 6. Bb3 Bc5 7. c3'),
			moves => {
			},
		},
		'r1bqk2r/2ppbppp/p1n2n2/1p2p3/4P3/1B3N2/PPPPQPPP/RNB1K2R w KQkq' => {
			eco => 'C77u',
			# TRANSLATORS: C77u: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. Qe2 b5 6. Bb3 Be7
			variation => N__('Spanish: Wormald Attack, 5... b5 6. Bb3 Be7'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bqk2r/2ppbppp/p1n2n2/1p2p3/3PP3/1B3N2/PPP1QPPP/RNB1K2R b KQkq' => {
			eco => 'C77u',
			# TRANSLATORS: C77u: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. Qe2 b5 6. Bb3 Be7 7. d4
			variation => N__('Spanish: Wormald Attack, 5... b5 6. Bb3 Be7'),
			moves => {
				'd7d6' => 1,
			},
		},
		'r1bqk2r/2p1bppp/p1np1n2/1p2p3/3PP3/1B3N2/PPP1QPPP/RNB1K2R w KQkq' => {
			eco => 'C77u',
			# TRANSLATORS: C77u: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. Qe2 b5 6. Bb3 Be7 7. d4 d6
			variation => N__('Spanish: Wormald Attack, 5... b5 6. Bb3 Be7'),
			moves => {
				'c2c3' => 1,
			},
		},
		'r1bqk2r/2p1bppp/p1np1n2/1p2p3/3PP3/1BP2N2/PP2QPPP/RNB1K2R b KQkq' => {
			eco => 'C77u',
			# TRANSLATORS: C77u: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. Qe2 b5 6. Bb3 Be7 7. d4 d6 8. c3
			variation => N__('Spanish: Wormald Attack, 5... b5 6. Bb3 Be7'),
			moves => {
				'c8g4' => 1,
			},
		},
		'r2qk2r/2p1bppp/p1np1n2/1p2p3/3PP1b1/1BP2N2/PP2QPPP/RNB1K2R w KQkq' => {
			eco => 'C77u',
			# TRANSLATORS: C77u: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. Qe2 b5 6. Bb3 Be7 7. d4 d6 8. c3 Bg4
			variation => N__('Spanish: Wormald Attack, Grünfeld Variation'),
			moves => {
			},
		},
		'r1bqkb1r/1ppp1ppp/p1n2n2/4p3/B3P3/5N2/PPPP1PPP/RNBQ1RK1 b kq' => {
			eco => 'C78a',
			# TRANSLATORS: C78a: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O
			variation => N__('Spanish: 5.O-O'),
			moves => {
				'b7b5' => 1,
				'd7d6' => 1,
				'f6e4' => 1,
				'f8c5' => 1,
				'f8e7' => 1,
			},
		},
		'r1bqk2r/1ppp1ppp/p1n2n2/2b1p3/B3P3/5N2/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C78b',
			# TRANSLATORS: C78b: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Bc5
			variation => N__('Spanish: Möller Defence'),
			moves => {
				'c2c3' => 1,
				'f3e5' => 1,
			},
		},
		'r1bqk2r/1ppp1ppp/p1n2n2/2b1N3/B3P3/8/PPPP1PPP/RNBQ1RK1 b kq' => {
			eco => 'C78c',
			# TRANSLATORS: C78c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Bc5 6. Nxe5
			variation => N__('Spanish: Möller Defence, 6.Nxe5'),
			moves => {
			},
		},
		'r1bqk2r/1ppp1ppp/p1n2n2/2b1p3/B3P3/2P2N2/PP1P1PPP/RNBQ1RK1 b kq' => {
			eco => 'C78d',
			# TRANSLATORS: C78d: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Bc5 6. c3
			variation => N__('Spanish: Möller Defence, 6. c3'),
			moves => {
			},
		},
		'r1bqkb1r/2pp1ppp/p1n2n2/1p2p3/B3P3/5N2/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C78e',
			# TRANSLATORS: C78e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5
			variation => N__('Spanish: 5.O-O b5'),
			moves => {
				'a4b3' => 1,
			},
		},
		'r1bqkb1r/2pp1ppp/p1n2n2/1p2p3/4P3/1B3N2/PPPP1PPP/RNBQ1RK1 b kq' => {
			eco => 'C78e',
			# TRANSLATORS: C78e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3
			variation => N__('Spanish: 5.O-O b5 6. Bb3'),
			moves => {
				'c8b7' => 1,
				'd7d6' => 1,
				'f8c5' => 1,
				'f8e7' => 1,
			},
		},
		'r1bqkb1r/2p2ppp/p1np1n2/1p2p3/4P3/1B3N2/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C78f',
			# TRANSLATORS: C78f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3 d6
			variation => N__('Spanish: 5.O-O b5 6. Bb3 d6'),
			moves => {
				'f3g5' => 1,
			},
		},
		'r1bqkb1r/2p2ppp/p1np1n2/1p2p1N1/4P3/1B6/PPPP1PPP/RNBQ1RK1 b kq' => {
			eco => 'C78f',
			# TRANSLATORS: C78f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3 d6 7. Ng5
			variation => N__('Spanish: 5.O-O b5 6. Bb3 d6'),
			moves => {
				'd6d5' => 1,
			},
		},
		'r1bqkb1r/2p2ppp/p1n2n2/1p1pp1N1/4P3/1B6/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C78f',
			# TRANSLATORS: C78f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3 d6 7. Ng5 d5
			variation => N__('Spanish: 5.O-O b5 6. Bb3 d6'),
			moves => {
				'e4d5' => 1,
			},
		},
		'r1bqkb1r/2p2ppp/p1n2n2/1p1Pp1N1/8/1B6/PPPP1PPP/RNBQ1RK1 b kq' => {
			eco => 'C78f',
			# TRANSLATORS: C78f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3 d6 7. Ng5 d5 8. exd5
			variation => N__('Spanish: 5.O-O b5 6. Bb3 d6'),
			moves => {
				'c6d4' => 1,
			},
		},
		'r1bqkb1r/2p2ppp/p4n2/1p1Pp1N1/3n4/1B6/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C78f',
			# TRANSLATORS: C78f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3 d6 7. Ng5 d5 8. exd5 Nd4
			variation => N__('Spanish: 5.O-O b5 6. Bb3 d6'),
			moves => {
				'f1e1' => 1,
			},
		},
		'r1bqkb1r/2p2ppp/p4n2/1p1Pp1N1/3n4/1B6/PPPP1PPP/RNBQR1K1 b kq' => {
			eco => 'C78f',
			# TRANSLATORS: C78f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3 d6 7. Ng5 d5 8. exd5 Nd4 9. Re1
			variation => N__('Spanish: 5.O-O b5 6. Bb3 d6'),
			moves => {
				'f8c5' => 1,
			},
		},
		'r1bqk2r/2p2ppp/p4n2/1pbPp1N1/3n4/1B6/PPPP1PPP/RNBQR1K1 w kq' => {
			eco => 'C78f',
			# TRANSLATORS: C78f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3 d6 7. Ng5 d5 8. exd5 Nd4 9. Re1 Bc5
			variation => N__('Spanish: 5.O-O b5 6. Bb3 d6'),
			moves => {
				'e1e5' => 1,
			},
		},
		'r1bqk2r/2p2ppp/p4n2/1pbPR1N1/3n4/1B6/PPPP1PPP/RNBQ2K1 b kq' => {
			eco => 'C78f',
			# TRANSLATORS: C78f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3 d6 7. Ng5 d5 8. exd5 Nd4 9. Re1 Bc5 10. Rxe5+
			variation => N__('Spanish: 5.O-O b5 6. Bb3 d6'),
			moves => {
				'e8f8' => 1,
			},
		},
		'r1bq1k1r/2p2ppp/p4n2/1pbPR1N1/3n4/1B6/PPPP1PPP/RNBQ2K1 w -' => {
			eco => 'C78f',
			# TRANSLATORS: C78f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3 d6 7. Ng5 d5 8. exd5 Nd4 9. Re1 Bc5 10. Rxe5+ Kf8
			variation => N__('Spanish: Rabinovich Variation'),
			moves => {
			},
		},
		'r1bqk2r/2ppbppp/p1n2n2/1p2p3/4P3/1B3N2/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C78g',
			# TRANSLATORS: C78g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3 Be7
			variation => N__('Spanish: 5.O-O b5 6. Bb3 Be7'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bqk2r/2ppbppp/p1n2n2/1p2p3/3PP3/1B3N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C78g',
			# TRANSLATORS: C78g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3 Be7 7. d4
			variation => N__('Spanish: 5.O-O b5 6. Bb3 Be7'),
			moves => {
			},
		},
		'r1bqk2r/2pp1ppp/p1n2n2/1pb1p3/4P3/1B3N2/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C78h',
			# TRANSLATORS: C78h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3 Bc5
			variation => N__('Spanish: 5.O-O b5 6. Bb3 Bc5'),
			moves => {
				'a2a4' => 1,
				'c2c3' => 1,
				'f3e5' => 1,
			},
		},
		'r1bqk2r/2pp1ppp/p1n2n2/1pb1N3/4P3/1B6/PPPP1PPP/RNBQ1RK1 b kq' => {
			eco => 'C78i',
			# TRANSLATORS: C78i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3 Bc5 7. Nxe5
			variation => N__('Spanish: 5.O-O b5 6. Bb3 Bc5 7.Nxe5'),
			moves => {
				'c6e5' => 1,
			},
		},
		'r1bqk2r/2pp1ppp/p4n2/1pb1n3/4P3/1B6/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C78i',
			# TRANSLATORS: C78i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3 Bc5 7. Nxe5 Nxe5
			variation => N__('Spanish: 5.O-O b5 6. Bb3 Bc5 7.Nxe5'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bqk2r/2pp1ppp/p4n2/1pb1n3/3PP3/1B6/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C78i',
			# TRANSLATORS: C78i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3 Bc5 7. Nxe5 Nxe5 8. d4
			variation => N__('Spanish: 5.O-O b5 6. Bb3 Bc5 7.Nxe5'),
			moves => {
			},
		},
		'r1bqk2r/2pp1ppp/p1n2n2/1pb1p3/4P3/1BP2N2/PP1P1PPP/RNBQ1RK1 b kq' => {
			eco => 'C78j',
			# TRANSLATORS: C78j: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3 Bc5 7. c3
			variation => N__('Spanish: 5.O-O b5 6. Bb3 Bc5 7. c3'),
			moves => {
				'd7d6' => 1,
			},
		},
		'r1bqk2r/2p2ppp/p1np1n2/1pb1p3/4P3/1BP2N2/PP1P1PPP/RNBQ1RK1 w kq' => {
			eco => 'C78j',
			# TRANSLATORS: C78j: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3 Bc5 7. c3 d6
			variation => N__('Spanish: 5.O-O b5 6. Bb3 Bc5 7. c3 d6'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bqk2r/2p2ppp/p1np1n2/1pb1p3/3PP3/1BP2N2/PP3PPP/RNBQ1RK1 b kq' => {
			eco => 'C78k',
			# TRANSLATORS: C78k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3 Bc5 7. c3 d6 8. d4
			variation => N__('Spanish: 5.O-O b5 6. Bb3 Bc5 7. c3 d6 8. d4'),
			moves => {
			},
		},
		'r1bqk2r/2pp1ppp/p1n2n2/1pb1p3/P3P3/1B3N2/1PPP1PPP/RNBQ1RK1 b kq' => {
			eco => 'C78l',
			# TRANSLATORS: C78l: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3 Bc5 7. a4
			variation => N__('Spanish: 5.O-O b5 6. Bb3 Bc5 7. a4'),
			moves => {
				'a8b8' => 1,
			},
		},
		'1rbqk2r/2pp1ppp/p1n2n2/1pb1p3/P3P3/1B3N2/1PPP1PPP/RNBQ1RK1 w k' => {
			eco => 'C78m',
			# TRANSLATORS: C78m: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3 Bc5 7. a4 Rb8
			variation => N__('Spanish: 5.O-O b5 6. Bb3 Bc5 7. a4 Rb8'),
			moves => {
			},
		},
		'r2qkb1r/1bpp1ppp/p1n2n2/1p2p3/4P3/1B3N2/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C78n',
			# TRANSLATORS: C78n: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3 Bb7
			variation => N__('Spanish: Archangelsk Variation'),
			moves => {
				'c2c3' => 1,
				'd2d3' => 1,
				'd2d4' => 1,
				'f1e1' => 1,
			},
		},
		'r2qkb1r/1bpp1ppp/p1n2n2/1p2p3/3PP3/1B3N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C78o',
			# TRANSLATORS: C78o: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3 Bb7 7. d4
			variation => N__('Spanish: Archangelsk, 7. d4'),
			moves => {
			},
		},
		'r2qkb1r/1bpp1ppp/p1n2n2/1p2p3/4P3/1B1P1N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C78p',
			# TRANSLATORS: C78p: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3 Bb7 7. d3
			variation => N__('Spanish: Archangelsk, 7. d3'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r2qk2r/1bppbppp/p1n2n2/1p2p3/4P3/1B1P1N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C78q',
			# TRANSLATORS: C78q: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3 Bb7 7. d3 Be7
			variation => N__('Spanish: Archangelsk, 7. d3 Be7'),
			moves => {
			},
		},
		'r2qkb1r/1bpp1ppp/p1n2n2/1p2p3/4P3/1BP2N2/PP1P1PPP/RNBQ1RK1 b kq' => {
			eco => 'C78r',
			# TRANSLATORS: C78r: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3 Bb7 7. c3
			variation => N__('Spanish: Archangelsk, 7. c3'),
			moves => {
				'f6e4' => 1,
			},
		},
		'r2qkb1r/1bpp1ppp/p1n5/1p2p3/4n3/1BP2N2/PP1P1PPP/RNBQ1RK1 w kq' => {
			eco => 'C78s',
			# TRANSLATORS: C78s: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3 Bb7 7. c3 Nxe4
			variation => N__('Spanish: Archangelsk, 7. c3 Nxe4'),
			moves => {
			},
		},
		'r2qkb1r/1bpp1ppp/p1n2n2/1p2p3/4P3/1B3N2/PPPP1PPP/RNBQR1K1 b kq' => {
			eco => 'C78t',
			# TRANSLATORS: C78t: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3 Bb7 7. Re1
			variation => N__('Spanish: Archangelsk, 7. Re1'),
			moves => {
				'f8c5' => 1,
			},
		},
		'r2qk2r/1bpp1ppp/p1n2n2/1pb1p3/4P3/1B3N2/PPPP1PPP/RNBQR1K1 w kq' => {
			eco => 'C78t',
			# TRANSLATORS: C78t: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3 Bb7 7. Re1 Bc5
			variation => N__('Spanish: Archangelsk, 7. Re1 Bc5'),
			moves => {
				'c2c3' => 1,
			},
		},
		'r2qk2r/1bpp1ppp/p1n2n2/1pb1p3/4P3/1BP2N2/PP1P1PPP/RNBQR1K1 b kq' => {
			eco => 'C78t',
			# TRANSLATORS: C78t: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3 Bb7 7. Re1 Bc5 8. c3
			variation => N__('Spanish: Archangelsk, 7. Re1 Bc5'),
			moves => {
				'd7d6' => 1,
			},
		},
		'r2qk2r/1bp2ppp/p1np1n2/1pb1p3/4P3/1BP2N2/PP1P1PPP/RNBQR1K1 w kq' => {
			eco => 'C78u',
			# TRANSLATORS: C78u: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3 Bb7 7. Re1 Bc5 8. c3 d6
			variation => N__('Spanish: Archangelsk, 7. Re1 Bc5 8. c3 d6'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r2qk2r/1bp2ppp/p1np1n2/1pb1p3/3PP3/1BP2N2/PP3PPP/RNBQR1K1 b kq' => {
			eco => 'C78u',
			# TRANSLATORS: C78u: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3 Bb7 7. Re1 Bc5 8. c3 d6 9. d4
			variation => N__('Spanish: Archangelsk, 7. Re1 Bc5 8. c3 d6'),
			moves => {
				'c5b6' => 1,
			},
		},
		'r2qk2r/1bp2ppp/pbnp1n2/1p2p3/3PP3/1BP2N2/PP3PPP/RNBQR1K1 w kq' => {
			eco => 'C78u',
			# TRANSLATORS: C78u: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3 Bb7 7. Re1 Bc5 8. c3 d6 9. d4 Bb6
			variation => N__('Spanish: Archangelsk, Main Line'),
			moves => {
				'a2a4' => 1,
				'c1e3' => 1,
				'c1g5' => 1,
			},
		},
		'r2qk2r/1bp2ppp/pbnp1n2/1p2p3/P2PP3/1BP2N2/1P3PPP/RNBQR1K1 b kq' => {
			eco => 'C78v',
			# TRANSLATORS: C78v: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3 Bb7 7. Re1 Bc5 8. c3 d6 9. d4 Bb6 10. a4
			variation => N__('Spanish: Archangelsk, Main Line, 10. a4'),
			moves => {
			},
		},
		'r2qk2r/1bp2ppp/pbnp1n2/1p2p1B1/3PP3/1BP2N2/PP3PPP/RN1QR1K1 b kq' => {
			eco => 'C78w',
			# TRANSLATORS: C78w: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3 Bb7 7. Re1 Bc5 8. c3 d6 9. d4 Bb6 10. Bg5
			variation => N__('Spanish: Archangelsk, Main Line, 10. Bg5'),
			moves => {
			},
		},
		'r2qk2r/1bp2ppp/pbnp1n2/1p2p3/3PP3/1BP1BN2/PP3PPP/RN1QR1K1 b kq' => {
			eco => 'C78x',
			# TRANSLATORS: C78x: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O b5 6. Bb3 Bb7 7. Re1 Bc5 8. c3 d6 9. d4 Bb6 10. Be3
			variation => N__('Spanish: Archangelsk, Main Line, 10. Be3'),
			moves => {
			},
		},
		'r1bqkb1r/1pp2ppp/p1np1n2/4p3/B3P3/5N2/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C79',
			# TRANSLATORS: C79: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O d6
			variation => N__('Spanish: Steinitz Deferred'),
			moves => {
				'a4c6' => 1,
				'c2c3' => 1,
				'f1e1' => 1,
			},
		},
		'r1bqkb1r/1pp2ppp/p1Bp1n2/4p3/4P3/5N2/PPPP1PPP/RNBQ1RK1 b kq' => {
			eco => 'C79',
			# TRANSLATORS: C79: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O d6 6. Bxc6+
			variation => N__('Spanish: Steinitz Deferred, Exchange'),
			moves => {
				'b7c6' => 1,
			},
		},
		'r1bqkb1r/2p2ppp/p1pp1n2/4p3/4P3/5N2/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C79',
			# TRANSLATORS: C79: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O d6 6. Bxc6+ bxc6
			variation => N__('Spanish: Steinitz Deferred, Exchange'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bqkb1r/2p2ppp/p1pp1n2/4p3/3PP3/5N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C79',
			# TRANSLATORS: C79: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O d6 6. Bxc6+ bxc6 7. d4
			variation => N__('Spanish: Steinitz Deferred, Exchange'),
			moves => {
				'c8g4' => 1,
				'f6e4' => 1,
			},
		},
		'r2qkb1r/2p2ppp/p1pp1n2/4p3/3PP1b1/5N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C79',
			# TRANSLATORS: C79: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O d6 6. Bxc6+ bxc6 7. d4 Bg4
			variation => N__('Spanish: Steinitz Deferred, Lipnitsky Variation'),
			moves => {
			},
		},
		'r1bqkb1r/2p2ppp/p1pp4/4p3/3Pn3/5N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C79',
			# TRANSLATORS: C79: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O d6 6. Bxc6+ bxc6 7. d4 Nxe4
			variation => N__('Spanish: Steinitz Deferred, Rubinstein Variation'),
			moves => {
				'f1e1' => 1,
			},
		},
		'r1bqkb1r/2p2ppp/p1pp4/4p3/3Pn3/5N2/PPP2PPP/RNBQR1K1 b kq' => {
			eco => 'C79',
			# TRANSLATORS: C79: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O d6 6. Bxc6+ bxc6 7. d4 Nxe4 8. Re1
			variation => N__('Spanish: Steinitz Deferred, Rubinstein Variation'),
			moves => {
				'f7f5' => 1,
			},
		},
		'r1bqkb1r/2p3pp/p1pp4/4pp2/3Pn3/5N2/PPP2PPP/RNBQR1K1 w kq' => {
			eco => 'C79',
			# TRANSLATORS: C79: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O d6 6. Bxc6+ bxc6 7. d4 Nxe4 8. Re1 f5
			variation => N__('Spanish: Steinitz Deferred, Rubinstein Variation'),
			moves => {
				'd4e5' => 1,
			},
		},
		'r1bqkb1r/2p3pp/p1pp4/4Pp2/4n3/5N2/PPP2PPP/RNBQR1K1 b kq' => {
			eco => 'C79',
			# TRANSLATORS: C79: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O d6 6. Bxc6+ bxc6 7. d4 Nxe4 8. Re1 f5 9. dxe5
			variation => N__('Spanish: Steinitz Deferred, Rubinstein Variation'),
			moves => {
				'd6d5' => 1,
			},
		},
		'r1bqkb1r/2p3pp/p1p5/3pPp2/4n3/5N2/PPP2PPP/RNBQR1K1 w kq' => {
			eco => 'C79',
			# TRANSLATORS: C79: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O d6 6. Bxc6+ bxc6 7. d4 Nxe4 8. Re1 f5 9. dxe5 d5
			variation => N__('Spanish: Steinitz Deferred, Rubinstein Variation'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r1bqkb1r/2p3pp/p1p5/3pPp2/4n3/2N2N2/PPP2PPP/R1BQR1K1 b kq' => {
			eco => 'C79',
			# TRANSLATORS: C79: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O d6 6. Bxc6+ bxc6 7. d4 Nxe4 8. Re1 f5 9. dxe5 d5 10. Nc3
			variation => N__('Spanish: Steinitz Deferred, Boleslavsky Variation'),
			moves => {
			},
		},
		'r1bqkb1r/1pp2ppp/p1np1n2/4p3/B3P3/2P2N2/PP1P1PPP/RNBQ1RK1 b kq' => {
			eco => 'C79',
			# TRANSLATORS: C79: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O d6 6. c3
			variation => N__('Spanish: Steinitz Deferred, 6. c3'),
			moves => {
			},
		},
		'r1bqkb1r/1pp2ppp/p1np1n2/4p3/B3P3/5N2/PPPP1PPP/RNBQR1K1 b kq' => {
			eco => 'C79',
			# TRANSLATORS: C79: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O d6 6. Re1
			variation => N__('Spanish: Steinitz Deferred, 6. Re1'),
			moves => {
			},
		},
		'r1bqkb1r/1ppp1ppp/p1n5/4p3/B3n3/5N2/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C80a',
			# TRANSLATORS: C80a: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4
			variation => N__('Spanish: Open'),
			moves => {
				'b1c3' => 1,
				'd1e2' => 1,
				'd2d4' => 1,
				'f1e1' => 1,
			},
		},
		'r1bqkb1r/1ppp1ppp/p1n5/4p3/B3n3/2N2N2/PPPP1PPP/R1BQ1RK1 b kq' => {
			eco => 'C80b',
			# TRANSLATORS: C80b: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. Nc3
			variation => N__('Spanish: Open, Knorre Variation'),
			moves => {
			},
		},
		'r1bqkb1r/1ppp1ppp/p1n5/4p3/B3n3/5N2/PPPPQPPP/RNB2RK1 b kq' => {
			eco => 'C80c',
			# TRANSLATORS: C80c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. Qe2
			variation => N__('Spanish: Open, Tartakower Variation'),
			moves => {
			},
		},
		'r1bqkb1r/1ppp1ppp/p1n5/4p3/B3n3/5N2/PPPP1PPP/RNBQR1K1 b kq' => {
			eco => 'C80d',
			# TRANSLATORS: C80d: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. Re1
			variation => N__('Spanish: Open, 6. Re1'),
			moves => {
				'e4c5' => 1,
			},
		},
		'r1bqkb1r/1ppp1ppp/p1n5/2n1p3/B7/5N2/PPPP1PPP/RNBQR1K1 w kq' => {
			eco => 'C80d',
			# TRANSLATORS: C80d: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. Re1 Nc5
			variation => N__('Spanish: Open, 6. Re1'),
			moves => {
				'a4c6' => 1,
			},
		},
		'r1bqkb1r/1ppp1ppp/p1B5/2n1p3/8/5N2/PPPP1PPP/RNBQR1K1 b kq' => {
			eco => 'C80e',
			# TRANSLATORS: C80e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. Re1 Nc5 7. Bxc6
			variation => N__('Spanish: Open, 6. Re1 Nc5 7.Bxc6'),
			moves => {
			},
		},
		'r1bqkb1r/1ppp1ppp/p1n5/4p3/B2Pn3/5N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C80f',
			# TRANSLATORS: C80f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4
			variation => N__('Spanish: Open, 6. d4'),
			moves => {
				'b7b5' => 1,
				'e5d4' => 1,
				'f8e7' => 1,
			},
		},
		'r1bqkb1r/1ppp1ppp/p1n5/8/B2pn3/5N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C80g',
			# TRANSLATORS: C80g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 exd4
			variation => N__('Spanish: Open, Riga Variation'),
			moves => {
			},
		},
		'r1bqk2r/1pppbppp/p1n5/4p3/B2Pn3/5N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C80h',
			# TRANSLATORS: C80h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 Be7
			variation => N__('Spanish: Open, 6. d4 Be7'),
			moves => {
			},
		},
		'r1bqkb1r/2pp1ppp/p1n5/1p2p3/B2Pn3/5N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C80i',
			# TRANSLATORS: C80i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5
			variation => N__('Spanish: Open, 6. d4 b5'),
			moves => {
				'a4b3' => 1,
				'd4d5' => 1,
				'f3e5' => 1,
			},
		},
		'r1bqkb1r/2pp1ppp/p1n5/1p1Pp3/B3n3/5N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C80i',
			# TRANSLATORS: C80i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. d5
			variation => N__('Spanish: Open, Richter Variation'),
			moves => {
			},
		},
		'r1bqkb1r/2pp1ppp/p1n5/1p2N3/B2Pn3/8/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C80i',
			# TRANSLATORS: C80i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Nxe5
			variation => N__('Spanish: Open, Friess Attack'),
			moves => {
			},
		},
		'r1bqkb1r/2pp1ppp/p1n5/1p2p3/3Pn3/1B3N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C80j',
			# TRANSLATORS: C80j: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3
			variation => N__('Spanish: Open, 7. Bb3'),
			moves => {
				'd7d5' => 1,
			},
		},
		'r1bqkb1r/2p2ppp/p1n5/1p1pp3/3Pn3/1B3N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C80k',
			# TRANSLATORS: C80k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5
			variation => N__('Spanish: Open, 7. Bb3 d5'),
			moves => {
				'a2a4' => 1,
				'c2c4' => 1,
				'd4e5' => 1,
				'f3e5' => 1,
			},
		},
		'r1bqkb1r/2p2ppp/p1n5/1p1pp3/P2Pn3/1B3N2/1PP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C80k',
			# TRANSLATORS: C80k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. a4
			variation => N__('Spanish: Open, 7. Bb3 d5 8. a4'),
			moves => {
				'c6d4' => 1,
			},
		},
		'r1bqkb1r/2p2ppp/p7/1p1pp3/P2nn3/1B3N2/1PP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C80k',
			# TRANSLATORS: C80k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. a4 Nxd4
			variation => N__('Spanish: Open, Schlechter Defence'),
			moves => {
				'f3d4' => 1,
			},
		},
		'r1bqkb1r/2p2ppp/p7/1p1pp3/P2Nn3/1B6/1PP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C80k',
			# TRANSLATORS: C80k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. a4 Nxd4 9. Nxd4
			variation => N__('Spanish: Open, Schlechter Defence'),
			moves => {
				'e5d4' => 1,
			},
		},
		'r1bqkb1r/2p2ppp/p7/1p1p4/P2pn3/1B6/1PP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C80k',
			# TRANSLATORS: C80k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. a4 Nxd4 9. Nxd4 exd4
			variation => N__('Spanish: Open, Schlechter Defence'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r1bqkb1r/2p2ppp/p7/1p1p4/P2pn3/1BN5/1PP2PPP/R1BQ1RK1 b kq' => {
			eco => 'C80k',
			# TRANSLATORS: C80k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. a4 Nxd4 9. Nxd4 exd4 10. Nc3
			variation => N__('Spanish: Open, Schlecter, Berger Variation'),
			moves => {
			},
		},
		'r1bqkb1r/2p2ppp/p1n5/1p1pp3/2PPn3/1B3N2/PP3PPP/RNBQ1RK1 b kq' => {
			eco => 'C80k',
			# TRANSLATORS: C80k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. c4
			variation => N__('Spanish: Open, Harksen Gambit'),
			moves => {
			},
		},
		'r1bqkb1r/2p2ppp/p1n5/1p1pN3/3Pn3/1B6/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C80l',
			# TRANSLATORS: C80l: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. Nxe5
			variation => N__('Spanish: Open, 8.Nxe5'),
			moves => {
			},
		},
		'r1bqkb1r/2p2ppp/p1n5/1p1pP3/4n3/1B3N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C80m',
			# TRANSLATORS: C80m: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5
			variation => N__('Spanish: Open, 8.dxe5'),
			moves => {
				'c6e7' => 1,
				'c8e6' => 1,
			},
		},
		'r1bqkb1r/2p1nppp/p7/1p1pP3/4n3/1B3N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C80m',
			# TRANSLATORS: C80m: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Ne7
			variation => N__('Spanish: Open, Zukertort Variation'),
			moves => {
			},
		},
		'r2qkb1r/2p2ppp/p1n1b3/1p1pP3/4n3/1B3N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C80n',
			# TRANSLATORS: C80n: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6
			variation => N__('Spanish: Open, 8... Be6'),
			moves => {
				'a2a4' => 1,
				'b1d2' => 1,
				'c1e3' => 1,
				'c2c3' => 1,
				'd1e2' => 1,
			},
		},
		'r2qkb1r/2p2ppp/p1n1b3/1p1pP3/P3n3/1B3N2/1PP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C80n',
			# TRANSLATORS: C80n: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. a4
			variation => N__('Spanish: Open, 8... Be6 9. a4'),
			moves => {
			},
		},
		'r2qkb1r/2p2ppp/p1n1b3/1p1pP3/4n3/1B2BN2/PPP2PPP/RN1Q1RK1 b kq' => {
			eco => 'C80o',
			# TRANSLATORS: C80o: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. Be3
			variation => N__('Spanish: Open, 8... Be6 9. Be3'),
			moves => {
			},
		},
		'r2qkb1r/2p2ppp/p1n1b3/1p1pP3/4n3/1B3N2/PPPN1PPP/R1BQ1RK1 b kq' => {
			eco => 'C80p',
			# TRANSLATORS: C80p: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. Nbd2
			variation => N__('Spanish: Open, Bernstein Variation'),
			moves => {
				'e4c5' => 1,
				'f8c5' => 1,
			},
		},
		'r2qk2r/2p2ppp/p1n1b3/1pbpP3/4n3/1B3N2/PPPN1PPP/R1BQ1RK1 w kq' => {
			eco => 'C80q',
			# TRANSLATORS: C80q: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. Nbd2 Bc5
			variation => N__('Spanish: Open, Bernstein, 9... Bc5'),
			moves => {
			},
		},
		'r2qkb1r/2p2ppp/p1n1b3/1pnpP3/8/1B3N2/PPPN1PPP/R1BQ1RK1 w kq' => {
			eco => 'C80r',
			# TRANSLATORS: C80r: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. Nbd2 Nc5
			variation => N__('Spanish: Open, Bernstein, 9... Nc5'),
			moves => {
				'c2c3' => 1,
			},
		},
		'r2qkb1r/2p2ppp/p1n1b3/1pnpP3/8/1BP2N2/PP1N1PPP/R1BQ1RK1 b kq' => {
			eco => 'C80r',
			# TRANSLATORS: C80r: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. Nbd2 Nc5 10. c3
			variation => N__('Spanish: Open, Bernstein, 9... Nc5'),
			moves => {
				'd5d4' => 1,
			},
		},
		'r2qkb1r/2p2ppp/p1n1b3/1pn1P3/3p4/1BP2N2/PP1N1PPP/R1BQ1RK1 w kq' => {
			eco => 'C80s',
			# TRANSLATORS: C80s: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. Nbd2 Nc5 10. c3 d4
			variation => N__('Spanish: Open, Bernstein, 9... Nc5 10. c3 d4'),
			moves => {
				'b3e6' => 1,
				'c3d4' => 1,
				'f3g5' => 1,
			},
		},
		'r2qkb1r/2p2ppp/p1n1b3/1pn1P3/3P4/1B3N2/PP1N1PPP/R1BQ1RK1 b kq' => {
			eco => 'C80s',
			# TRANSLATORS: C80s: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. Nbd2 Nc5 10. c3 d4 11. cxd4
			variation => N__('Spanish: Open, Bernstein, 11.cxd4'),
			moves => {
			},
		},
		'r2qkb1r/2p2ppp/p1n1b3/1pn1P1N1/3p4/1BP5/PP1N1PPP/R1BQ1RK1 b kq' => {
			eco => 'C80t',
			# TRANSLATORS: C80t: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. Nbd2 Nc5 10. c3 d4 11. Ng5
			variation => N__('Spanish: Open, Bernstein, Karpov Gambit'),
			moves => {
			},
		},
		'r2qkb1r/2p2ppp/p1n1B3/1pn1P3/3p4/2P2N2/PP1N1PPP/R1BQ1RK1 b kq' => {
			eco => 'C80u',
			# TRANSLATORS: C80u: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. Nbd2 Nc5 10. c3 d4 11. Bxe6
			variation => N__('Spanish: Open, Bernstein, 11.Bxe6'),
			moves => {
			},
		},
		'r2qkb1r/2p2ppp/p1n1b3/1p1pP3/4n3/1B3N2/PPP1QPPP/RNB2RK1 b kq' => {
			eco => 'C81',
			# TRANSLATORS: C81: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. Qe2
			variation => N__('Spanish: Open, Keres Attack'),
			moves => {
				'f8c5' => 1,
				'f8e7' => 1,
			},
		},
		'r2qk2r/2p2ppp/p1n1b3/1pbpP3/4n3/1B3N2/PPP1QPPP/RNB2RK1 w kq' => {
			eco => 'C81',
			# TRANSLATORS: C81: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. Qe2 Bc5
			variation => N__('Spanish: Open, Keres Attack, 9... Bc5'),
			moves => {
			},
		},
		'r2qk2r/2p1bppp/p1n1b3/1p1pP3/4n3/1B3N2/PPP1QPPP/RNB2RK1 w kq' => {
			eco => 'C81',
			# TRANSLATORS: C81: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. Qe2 Be7
			variation => N__('Spanish: Open, Keres Attack, 9... Be7'),
			moves => {
				'c2c4' => 1,
				'f1d1' => 1,
			},
		},
		'r2qk2r/2p1bppp/p1n1b3/1p1pP3/2P1n3/1B3N2/PP2QPPP/RNB2RK1 b kq' => {
			eco => 'C81',
			# TRANSLATORS: C81: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. Qe2 Be7 10. c4
			variation => N__('Spanish: Open, Keres, Adam Variation'),
			moves => {
			},
		},
		'r2qk2r/2p1bppp/p1n1b3/1p1pP3/4n3/1B3N2/PPP1QPPP/RNBR2K1 b kq' => {
			eco => 'C81',
			# TRANSLATORS: C81: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. Qe2 Be7 10. Rd1
			variation => N__('Spanish: Open, Keres, 10. Rd1'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r2q1rk1/2p1bppp/p1n1b3/1p1pP3/4n3/1B3N2/PPP1QPPP/RNBR2K1 w -' => {
			eco => 'C81',
			# TRANSLATORS: C81: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. Qe2 Be7 10. Rd1 O-O
			variation => N__('Spanish: Open, Keres, 10. Rd1 O-O'),
			moves => {
				'c2c3' => 1,
				'c2c4' => 1,
			},
		},
		'r2q1rk1/2p1bppp/p1n1b3/1p1pP3/4n3/1BP2N2/PP2QPPP/RNBR2K1 b -' => {
			eco => 'C81',
			# TRANSLATORS: C81: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. Qe2 Be7 10. Rd1 O-O 11. c3
			variation => N__('Spanish: Open, Keres, 10. Rd1 O-O 11. c3'),
			moves => {
			},
		},
		'r2q1rk1/2p1bppp/p1n1b3/1p1pP3/2P1n3/1B3N2/PP2QPPP/RNBR2K1 b -' => {
			eco => 'C81',
			# TRANSLATORS: C81: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. Qe2 Be7 10. Rd1 O-O 11. c4
			variation => N__('Spanish: Open, Keres, 10. Rd1 O-O 11. c4'),
			moves => {
				'b5c4' => 1,
			},
		},
		'r2q1rk1/2p1bppp/p1n1b3/3pP3/2p1n3/1B3N2/PP2QPPP/RNBR2K1 w -' => {
			eco => 'C81',
			# TRANSLATORS: C81: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. Qe2 Be7 10. Rd1 O-O 11. c4 bxc4
			variation => N__('Spanish: Open, Keres, 10. Rd1 O-O 11. c4'),
			moves => {
				'b3c4' => 1,
			},
		},
		'r2q1rk1/2p1bppp/p1n1b3/3pP3/2B1n3/5N2/PP2QPPP/RNBR2K1 b -' => {
			eco => 'C81',
			# TRANSLATORS: C81: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. Qe2 Be7 10. Rd1 O-O 11. c4 bxc4 12. Bxc4
			variation => N__('Spanish: Open, Keres, 10. Rd1 O-O 11. c4'),
			moves => {
				'd8d7' => 1,
				'e7c5' => 1,
			},
		},
		'r4rk1/2pqbppp/p1n1b3/3pP3/2B1n3/5N2/PP2QPPP/RNBR2K1 w -' => {
			eco => 'C81',
			# TRANSLATORS: C81: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. Qe2 Be7 10. Rd1 O-O 11. c4 bxc4 12. Bxc4 Qd7
			variation => N__('Spanish: Open, Keres, Ekstrom Variation'),
			moves => {
			},
		},
		'r2q1rk1/2p2ppp/p1n1b3/2bpP3/2B1n3/5N2/PP2QPPP/RNBR2K1 w -' => {
			eco => 'C81',
			# TRANSLATORS: C81: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. Qe2 Be7 10. Rd1 O-O 11. c4 bxc4 12. Bxc4 Bc5
			variation => N__('Spanish: Open, Keres, 10. Rd1 O-O 11. c4 bxc4 12.Bxc4 Bc5'),
			moves => {
			},
		},
		'r2qkb1r/2p2ppp/p1n1b3/1p1pP3/4n3/1BP2N2/PP3PPP/RNBQ1RK1 b kq' => {
			eco => 'C82a',
			# TRANSLATORS: C82a: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3
			variation => N__('Spanish: Open, 9. c3'),
			moves => {
				'e4c5' => 1,
				'f8c5' => 1,
				'f8e7' => 1,
			},
		},
		'r2qkb1r/2p2ppp/p1n1b3/1pnpP3/8/1BP2N2/PP3PPP/RNBQ1RK1 w kq' => {
			eco => 'C82b',
			# TRANSLATORS: C82b: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Nc5
			variation => N__('Spanish: Open, Berlin Variation'),
			moves => {
				'b3c2' => 1,
			},
		},
		'r2qkb1r/2p2ppp/p1n1b3/1pnpP3/8/2P2N2/PPB2PPP/RNBQ1RK1 b kq' => {
			eco => 'C82b',
			# TRANSLATORS: C82b: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Nc5 10. Bc2
			variation => N__('Spanish: Open, Berlin, 10. Bc2'),
			moves => {
				'e6g4' => 1,
			},
		},
		'r2qkb1r/2p2ppp/p1n5/1pnpP3/6b1/2P2N2/PPB2PPP/RNBQ1RK1 w kq' => {
			eco => 'C82c',
			# TRANSLATORS: C82c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Nc5 10. Bc2 Bg4
			variation => N__('Spanish: Open, Berlin, 10. Bc2 Bg4'),
			moves => {
				'b1d2' => 1,
				'f1e1' => 1,
			},
		},
		'r2qkb1r/2p2ppp/p1n5/1pnpP3/6b1/2P2N2/PPB2PPP/RNBQR1K1 b kq' => {
			eco => 'C82d',
			# TRANSLATORS: C82d: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Nc5 10. Bc2 Bg4 11. Re1
			variation => N__('Spanish: Open, Berlin, 10. Bc2 Bg4 11. Re1'),
			moves => {
			},
		},
		'r2qkb1r/2p2ppp/p1n5/1pnpP3/6b1/2P2N2/PPBN1PPP/R1BQ1RK1 b kq' => {
			eco => 'C82e',
			# TRANSLATORS: C82e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Nc5 10. Bc2 Bg4 11. Nbd2
			variation => N__('Spanish: Open, Berlin, 10. Bc2 Bg4 11.Nbd2'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r2qk2r/2p1bppp/p1n5/1pnpP3/6b1/2P2N2/PPBN1PPP/R1BQ1RK1 w kq' => {
			eco => 'C82e',
			# TRANSLATORS: C82e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Nc5 10. Bc2 Bg4 11. Nbd2 Be7
			variation => N__('Spanish: Open, Berlin, 10. Bc2 Bg4 11.Nbd2 Be7'),
			moves => {
				'f1e1' => 1,
			},
		},
		'r2qk2r/2p1bppp/p1n5/1pnpP3/6b1/2P2N2/PPBN1PPP/R1BQR1K1 b kq' => {
			eco => 'C82f',
			# TRANSLATORS: C82f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Nc5 10. Bc2 Bg4 11. Nbd2 Be7 12. Re1
			variation => N__('Spanish: Open, Berlin, 10. Bc2 Bg4 11.Nbd2 Be7 12. Re1'),
			moves => {
				'd8d7' => 1,
				'e8g8' => 1,
			},
		},
		'r3k2r/2pqbppp/p1n5/1pnpP3/6b1/2P2N2/PPBN1PPP/R1BQR1K1 w kq' => {
			eco => 'C82g',
			# TRANSLATORS: C82g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Nc5 10. Bc2 Bg4 11. Nbd2 Be7 12. Re1 Qd7
			variation => N__('Spanish: Open, Berlin, 10. Bc2 Bg4 11.Nbd2 Be7 12. Re1 Qd7'),
			moves => {
			},
		},
		'r2q1rk1/2p1bppp/p1n5/1pnpP3/6b1/2P2N2/PPBN1PPP/R1BQR1K1 w -' => {
			eco => 'C82h',
			# TRANSLATORS: C82h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Nc5 10. Bc2 Bg4 11. Nbd2 Be7 12. Re1 O-O
			variation => N__('Spanish: Open, Berlin, 10. Bc2 Bg4 11.Nbd2 Be7 12. Re1 O-O'),
			moves => {
			},
		},
		'r2qk2r/2p2ppp/p1n1b3/1pbpP3/4n3/1BP2N2/PP3PPP/RNBQ1RK1 w kq' => {
			eco => 'C82i',
			# TRANSLATORS: C82i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Bc5
			variation => N__('Spanish: Open, Italian Variation'),
			moves => {
				'b1d2' => 1,
				'd1d3' => 1,
			},
		},
		'r2qk2r/2p2ppp/p1n1b3/1pbpP3/4n3/1BPQ1N2/PP3PPP/RNB2RK1 b kq' => {
			eco => 'C82j',
			# TRANSLATORS: C82j: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Bc5 10. Qd3
			variation => N__('Spanish: Open, Motzko Attack'),
			moves => {
				'c6e7' => 1,
			},
		},
		'r2qk2r/2p1nppp/p3b3/1pbpP3/4n3/1BPQ1N2/PP3PPP/RNB2RK1 w kq' => {
			eco => 'C82j',
			# TRANSLATORS: C82j: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Bc5 10. Qd3 Ne7
			variation => N__('Spanish: Open, Motzko Attack, Nenarokov Variation'),
			moves => {
			},
		},
		'r2qk2r/2p2ppp/p1n1b3/1pbpP3/4n3/1BP2N2/PP1N1PPP/R1BQ1RK1 b kq' => {
			eco => 'C82k',
			# TRANSLATORS: C82k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Bc5 10. Nbd2
			variation => N__('Spanish: Open, St. Petersburg Variation'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r2q1rk1/2p2ppp/p1n1b3/1pbpP3/4n3/1BP2N2/PP1N1PPP/R1BQ1RK1 w -' => {
			eco => 'C82k',
			# TRANSLATORS: C82k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Bc5 10. Nbd2 O-O
			variation => N__('Spanish: Open, St. Petersburg Variation'),
			moves => {
				'b3c2' => 1,
			},
		},
		'r2q1rk1/2p2ppp/p1n1b3/1pbpP3/4n3/2P2N2/PPBN1PPP/R1BQ1RK1 b -' => {
			eco => 'C82l',
			# TRANSLATORS: C82l: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Bc5 10. Nbd2 O-O 11. Bc2
			variation => N__('Spanish: Open, St. Petersburg, 11. Bc2'),
			moves => {
				'e4f2' => 1,
				'e6f5' => 1,
				'f7f5' => 1,
			},
		},
		'r2q1rk1/2p3pp/p1n1b3/1pbpPp2/4n3/2P2N2/PPBN1PPP/R1BQ1RK1 w -' => {
			eco => 'C82m',
			# TRANSLATORS: C82m: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Bc5 10. Nbd2 O-O 11. Bc2 f5
			variation => N__('Spanish: Open, St. Petersburg, 11. Bc2 f5'),
			moves => {
			},
		},
		'r2q1rk1/2p2ppp/p1n5/1pbpPb2/4n3/2P2N2/PPBN1PPP/R1BQ1RK1 w -' => {
			eco => 'C82n',
			# TRANSLATORS: C82n: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Bc5 10. Nbd2 O-O 11. Bc2 Bf5
			variation => N__('Spanish: Open, Baguio Variation'),
			moves => {
				'd2b3' => 1,
			},
		},
		'r2q1rk1/2p2ppp/p1n5/1pbpPb2/4n3/1NP2N2/PPB2PPP/R1BQ1RK1 b -' => {
			eco => 'C82n',
			# TRANSLATORS: C82n: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Bc5 10. Nbd2 O-O 11. Bc2 Bf5 12. Nb3
			variation => N__('Spanish: Open, Baguio, 12. Nb3'),
			moves => {
			},
		},
		'r2q1rk1/2p2ppp/p1n1b3/1pbpP3/8/2P2N2/PPBN1nPP/R1BQ1RK1 w -' => {
			eco => 'C82o',
			# TRANSLATORS: C82o: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Bc5 10. Nbd2 O-O 11. Bc2 Nxf2
			variation => N__('Spanish: Open, Dilworth Variation'),
			moves => {
				'f1f2' => 1,
			},
		},
		'r2q1rk1/2p2ppp/p1n1b3/1pbpP3/8/2P2N2/PPBN1RPP/R1BQ2K1 b -' => {
			eco => 'C82o',
			# TRANSLATORS: C82o: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Bc5 10. Nbd2 O-O 11. Bc2 Nxf2 12. Rxf2
			variation => N__('Spanish: Open, Dilworth Variation'),
			moves => {
				'f7f6' => 1,
			},
		},
		'r2q1rk1/2p3pp/p1n1bp2/1pbpP3/8/2P2N2/PPBN1RPP/R1BQ2K1 w -' => {
			eco => 'C82o',
			# TRANSLATORS: C82o: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Bc5 10. Nbd2 O-O 11. Bc2 Nxf2 12. Rxf2 f6
			variation => N__('Spanish: Open, Dilworth Variation'),
			moves => {
				'e5f6' => 1,
			},
		},
		'r2q1rk1/2p3pp/p1n1bP2/1pbp4/8/2P2N2/PPBN1RPP/R1BQ2K1 b -' => {
			eco => 'C82o',
			# TRANSLATORS: C82o: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Bc5 10. Nbd2 O-O 11. Bc2 Nxf2 12. Rxf2 f6 13. exf6
			variation => N__('Spanish: Open, Dilworth, 12.Rxf2 f6 13.exf6'),
			moves => {
				'c5f2' => 1,
			},
		},
		'r2q1rk1/2p3pp/p1n1bP2/1p1p4/8/2P2N2/PPBN1bPP/R1BQ2K1 w -' => {
			eco => 'C82o',
			# TRANSLATORS: C82o: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Bc5 10. Nbd2 O-O 11. Bc2 Nxf2 12. Rxf2 f6 13. exf6 Bxf2+
			variation => N__('Spanish: Open, Dilworth, 12.Rxf2 f6 13.exf6'),
			moves => {
				'g1f2' => 1,
			},
		},
		'r2q1rk1/2p3pp/p1n1bP2/1p1p4/8/2P2N2/PPBN1KPP/R1BQ4 b -' => {
			eco => 'C82p',
			# TRANSLATORS: C82p: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Bc5 10. Nbd2 O-O 11. Bc2 Nxf2 12. Rxf2 f6 13. exf6 Bxf2+ 14. Kxf2
			variation => N__('Spanish: Open, Dilworth, 14.Kxf2'),
			moves => {
				'd8f6' => 1,
			},
		},
		'r4rk1/2p3pp/p1n1bq2/1p1p4/8/2P2N2/PPBN1KPP/R1BQ4 w -' => {
			eco => 'C82p',
			# TRANSLATORS: C82p: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Bc5 10. Nbd2 O-O 11. Bc2 Nxf2 12. Rxf2 f6 13. exf6 Bxf2+ 14. Kxf2 Qxf6
			variation => N__('Spanish: Open, Dilworth, 14.Kxf2'),
			moves => {
				'd2f1' => 1,
				'f2g1' => 1,
			},
		},
		'r4rk1/2p3pp/p1n1bq2/1p1p4/8/2P2N2/PPB2KPP/R1BQ1N2 b -' => {
			eco => 'C82q',
			# TRANSLATORS: C82q: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Bc5 10. Nbd2 O-O 11. Bc2 Nxf2 12. Rxf2 f6 13. exf6 Bxf2+ 14. Kxf2 Qxf6 15. Nf1
			variation => N__('Spanish: Open, Dilworth, 14.Kxf2 Qxf6 15. Nf1'),
			moves => {
			},
		},
		'r4rk1/2p3pp/p1n1bq2/1p1p4/8/2P2N2/PPBN2PP/R1BQ2K1 b -' => {
			eco => 'C82r',
			# TRANSLATORS: C82r: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Bc5 10. Nbd2 O-O 11. Bc2 Nxf2 12. Rxf2 f6 13. exf6 Bxf2+ 14. Kxf2 Qxf6 15. Kg1
			variation => N__('Spanish: Open, Dilworth, 14.Kxf2 Qxf6 15. Kg1'),
			moves => {
				'g7g5' => 1,
			},
		},
		'r4rk1/2p4p/p1n1bq2/1p1p2p1/8/2P2N2/PPBN2PP/R1BQ2K1 w -' => {
			eco => 'C82s',
			# TRANSLATORS: C82s: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Bc5 10. Nbd2 O-O 11. Bc2 Nxf2 12. Rxf2 f6 13. exf6 Bxf2+ 14. Kxf2 Qxf6 15. Kg1 g5
			variation => N__('Spanish: Open, Dilworth, 14.Kxf2 Qxf6 15. Kg1 g5'),
			moves => {
			},
		},
		'r2qk2r/2p1bppp/p1n1b3/1p1pP3/4n3/1BP2N2/PP3PPP/RNBQ1RK1 w kq' => {
			eco => 'C83',
			# TRANSLATORS: C83: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Be7
			variation => N__('Spanish: Open, Classical Defence'),
			moves => {
				'b1d2' => 1,
				'c1e3' => 1,
				'f1e1' => 1,
			},
		},
		'r2qk2r/2p1bppp/p1n1b3/1p1pP3/4n3/1BP2N2/PP1N1PPP/R1BQ1RK1 b kq' => {
			eco => 'C83',
			# TRANSLATORS: C83: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Be7 10. Nbd2
			variation => N__('Spanish: Open, Classical, 10.Nbd2'),
			moves => {
				'e4c5' => 1,
				'e8g8' => 1,
			},
		},
		'r2qk2r/2p1bppp/p1n1b3/1pnpP3/8/1BP2N2/PP1N1PPP/R1BQ1RK1 w kq' => {
			eco => 'C83',
			# TRANSLATORS: C83: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Be7 10. Nbd2 Nc5
			variation => N__('Spanish: Open, Classical, 10.Nbd2 Nc5'),
			moves => {
			},
		},
		'r2q1rk1/2p1bppp/p1n1b3/1p1pP3/4n3/1BP2N2/PP1N1PPP/R1BQ1RK1 w -' => {
			eco => 'C83',
			# TRANSLATORS: C83: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Be7 10. Nbd2 O-O
			variation => N__('Spanish: Open, Classical, 10.Nbd2 O-O'),
			moves => {
				'b3c2' => 1,
				'd1e2' => 1,
			},
		},
		'r2q1rk1/2p1bppp/p1n1b3/1p1pP3/4n3/2P2N2/PPBN1PPP/R1BQ1RK1 b -' => {
			eco => 'C83',
			# TRANSLATORS: C83: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Be7 10. Nbd2 O-O 11. Bc2
			variation => N__('Spanish: Open, Classical, 10.Nbd2 O-O 11. Bc2'),
			moves => {
				'f7f5' => 1,
			},
		},
		'r2q1rk1/2p1b1pp/p1n1b3/1p1pPp2/4n3/2P2N2/PPBN1PPP/R1BQ1RK1 w -' => {
			eco => 'C83',
			# TRANSLATORS: C83: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Be7 10. Nbd2 O-O 11. Bc2 f5
			variation => N__('Spanish: Open, Classical, 10.Nbd2 O-O 11. Bc2'),
			moves => {
				'd2b3' => 1,
				'e5f6' => 1,
			},
		},
		'r2q1rk1/2p1b1pp/p1n1b3/1p1pPp2/4n3/1NP2N2/PPB2PPP/R1BQ1RK1 b -' => {
			eco => 'C83',
			# TRANSLATORS: C83: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Be7 10. Nbd2 O-O 11. Bc2 f5 12. Nb3
			variation => N__('Spanish: Open, Classical, 10.Nbd2 O-O 11. Bc2 f5 12. Nb3'),
			moves => {
			},
		},
		'r2q1rk1/2p1b1pp/p1n1bP2/1p1p4/4n3/2P2N2/PPBN1PPP/R1BQ1RK1 b -' => {
			eco => 'C83',
			# TRANSLATORS: C83: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Be7 10. Nbd2 O-O 11. Bc2 f5 12. exf6
			variation => N__('Spanish: Open, Classical, 10.Nbd2 O-O 11. Bc2 f5 12.exf6'),
			moves => {
			},
		},
		'r2q1rk1/2p1bppp/p1n1b3/1p1pP3/4n3/1BP2N2/PP1NQPPP/R1B2RK1 b -' => {
			eco => 'C83',
			# TRANSLATORS: C83: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Be7 10. Nbd2 O-O 11. Qe2
			variation => N__('Spanish: Open, Classical, Malkin Variation'),
			moves => {
			},
		},
		'r2qk2r/2p1bppp/p1n1b3/1p1pP3/4n3/1BP1BN2/PP3PPP/RN1Q1RK1 b kq' => {
			eco => 'C83',
			# TRANSLATORS: C83: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Be7 10. Be3
			variation => N__('Spanish: Open, Classical, 10. Be3'),
			moves => {
			},
		},
		'r2qk2r/2p1bppp/p1n1b3/1p1pP3/4n3/1BP2N2/PP3PPP/RNBQR1K1 b kq' => {
			eco => 'C83',
			# TRANSLATORS: C83: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Be7 10. Re1
			variation => N__('Spanish: Open, Classical, 10. Re1'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r2q1rk1/2p1bppp/p1n1b3/1p1pP3/4n3/1BP2N2/PP3PPP/RNBQR1K1 w -' => {
			eco => 'C83',
			# TRANSLATORS: C83: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Be7 10. Re1 O-O
			variation => N__('Spanish: Open, Classical, 10. Re1'),
			moves => {
				'f3d4' => 1,
			},
		},
		'r2q1rk1/2p1bppp/p1n1b3/1p1pP3/3Nn3/1BP5/PP3PPP/RNBQR1K1 b -' => {
			eco => 'C83',
			# TRANSLATORS: C83: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Be7 10. Re1 O-O 11. Nd4
			variation => N__('Spanish: Open, Classical, 10. Re1'),
			moves => {
				'c6e5' => 1,
				'd8d7' => 1,
			},
		},
		'r2q1rk1/2p1bppp/p3b3/1p1pn3/3Nn3/1BP5/PP3PPP/RNBQR1K1 w -' => {
			eco => 'C83',
			# TRANSLATORS: C83: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Be7 10. Re1 O-O 11. Nd4 Nxe5
			variation => N__('Spanish: Open, Classical, Breslau Variation'),
			moves => {
			},
		},
		'r4rk1/2pqbppp/p1n1b3/1p1pP3/3Nn3/1BP5/PP3PPP/RNBQR1K1 w -' => {
			eco => 'C83',
			# TRANSLATORS: C83: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Be7 10. Re1 O-O 11. Nd4 Qd7
			variation => N__('Spanish: Open, Classical, 10. Re1'),
			moves => {
				'd4e6' => 1,
			},
		},
		'r4rk1/2pqbppp/p1n1N3/1p1pP3/4n3/1BP5/PP3PPP/RNBQR1K1 b -' => {
			eco => 'C83',
			# TRANSLATORS: C83: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Be7 10. Re1 O-O 11. Nd4 Qd7 12. Nxe6
			variation => N__('Spanish: Open, Classical, 10. Re1'),
			moves => {
				'f7e6' => 1,
			},
		},
		'r4rk1/2pqb1pp/p1n1p3/1p1pP3/4n3/1BP5/PP3PPP/RNBQR1K1 w -' => {
			eco => 'C83',
			# TRANSLATORS: C83: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Be7 10. Re1 O-O 11. Nd4 Qd7 12. Nxe6 fxe6
			variation => N__('Spanish: Open, Classical, 10. Re1'),
			moves => {
				'e1e4' => 1,
			},
		},
		'r4rk1/2pqb1pp/p1n1p3/1p1pP3/4R3/1BP5/PP3PPP/RNBQ2K1 b -' => {
			eco => 'C83',
			# TRANSLATORS: C83: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Nxe4 6. d4 b5 7. Bb3 d5 8. dxe5 Be6 9. c3 Be7 10. Re1 O-O 11. Nd4 Qd7 12. Nxe6 fxe6 13. Rxe4
			variation => N__('Spanish: Open, Classical, Tarrasch Trap'),
			moves => {
			},
		},
		'r1bqk2r/1pppbppp/p1n2n2/4p3/B3P3/5N2/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C84a',
			# TRANSLATORS: C84a: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7
			variation => N__('Spanish: Closed System'),
			moves => {
				'a4c6' => 1,
				'b1c3' => 1,
				'd1e2' => 1,
				'd2d3' => 1,
				'd2d4' => 1,
				'f1e1' => 1,
			},
		},
		'r1bqk2r/1pppbppp/p1n2n2/4p3/B3P3/2N2N2/PPPP1PPP/R1BQ1RK1 b kq' => {
			eco => 'C84b',
			# TRANSLATORS: C84b: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Nc3
			variation => N__('Spanish: Closed, 6. Nc3'),
			moves => {
				'b7b5' => 1,
			},
		},
		'r1bqk2r/2ppbppp/p1n2n2/1p2p3/B3P3/2N2N2/PPPP1PPP/R1BQ1RK1 w kq' => {
			eco => 'C84c',
			# TRANSLATORS: C84c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Nc3 b5
			variation => N__('Spanish: Closed, 6. Nc3 b5'),
			moves => {
				'a4b3' => 1,
			},
		},
		'r1bqk2r/2ppbppp/p1n2n2/1p2p3/4P3/1BN2N2/PPPP1PPP/R1BQ1RK1 b kq' => {
			eco => 'C84c',
			# TRANSLATORS: C84c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Nc3 b5 7. Bb3
			variation => N__('Spanish: Closed, 6. Nc3 b5 7. Bb3'),
			moves => {
				'd7d6' => 1,
			},
		},
		'r1bqk2r/2p1bppp/p1np1n2/1p2p3/4P3/1BN2N2/PPPP1PPP/R1BQ1RK1 w kq' => {
			eco => 'C84c',
			# TRANSLATORS: C84c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Nc3 b5 7. Bb3 d6
			variation => N__('Spanish: Closed, 6. Nc3 b5 7. Bb3 d6'),
			moves => {
				'c3d5' => 1,
			},
		},
		'r1bqk2r/2p1bppp/p1np1n2/1p1Np3/4P3/1B3N2/PPPP1PPP/R1BQ1RK1 b kq' => {
			eco => 'C84d',
			# TRANSLATORS: C84d: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Nc3 b5 7. Bb3 d6 8. Nd5
			variation => N__('Spanish: Closed, 6. Nc3 b5 7. Bb3 d6 8. Nd5'),
			moves => {
			},
		},
		'r1bqk2r/1pppbppp/p1n2n2/4p3/B3P3/3P1N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C84e',
			# TRANSLATORS: C84e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. d3
			variation => N__('Spanish: Closed, 6. d3'),
			moves => {
				'b7b5' => 1,
			},
		},
		'r1bqk2r/2ppbppp/p1n2n2/1p2p3/B3P3/3P1N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C84f',
			# TRANSLATORS: C84f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. d3 b5
			variation => N__('Spanish: Closed, 6. d3 b5'),
			moves => {
				'a4b3' => 1,
			},
		},
		'r1bqk2r/2ppbppp/p1n2n2/1p2p3/4P3/1B1P1N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C84f',
			# TRANSLATORS: C84f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. d3 b5 7. Bb3
			variation => N__('Spanish: Closed, 6. d3 b5'),
			moves => {
			},
		},
		'r1bqk2r/1pppbppp/p1n2n2/4p3/B2PP3/5N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C84g',
			# TRANSLATORS: C84g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. d4
			variation => N__('Spanish: Closed, Centre Attack'),
			moves => {
				'e5d4' => 1,
			},
		},
		'r1bqk2r/1pppbppp/p1n2n2/8/B2pP3/5N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C84g',
			# TRANSLATORS: C84g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. d4 exd4
			variation => N__('Spanish: Closed, Centre Attack'),
			moves => {
				'e4e5' => 1,
				'f1e1' => 1,
			},
		},
		'r1bqk2r/1pppbppp/p1n2n2/4P3/B2p4/5N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C84h',
			# TRANSLATORS: C84h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. d4 exd4 7. e5
			variation => N__('Spanish: Closed, Centre Attack, 7. e5'),
			moves => {
				'f6e4' => 1,
			},
		},
		'r1bqk2r/1pppbppp/p1n5/4P3/B2pn3/5N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C84h',
			# TRANSLATORS: C84h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. d4 exd4 7. e5 Ne4
			variation => N__('Spanish: Closed, Centre Attack, 7. e5 Ne4'),
			moves => {
				'b2b4' => 1,
				'c2c3' => 1,
				'f3d4' => 1,
			},
		},
		'r1bqk2r/1pppbppp/p1n5/4P3/BP1pn3/5N2/P1P2PPP/RNBQ1RK1 b kq' => {
			eco => 'C84h',
			# TRANSLATORS: C84h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. d4 exd4 7. e5 Ne4 8. b4
			variation => N__('Spanish: Closed, Centre Attack, 7. e5 Ne4 8. b4'),
			moves => {
			},
		},
		'r1bqk2r/1pppbppp/p1n5/4P3/B2pn3/2P2N2/PP3PPP/RNBQ1RK1 b kq' => {
			eco => 'C84h',
			# TRANSLATORS: C84h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. d4 exd4 7. e5 Ne4 8. c3
			variation => N__('Spanish: Closed, Centre Attack, Basque Gambit'),
			moves => {
				'd4c3' => 1,
			},
		},
		'r1bqk2r/1pppbppp/p1n5/4P3/B3n3/2p2N2/PP3PPP/RNBQ1RK1 w kq' => {
			eco => 'C84h',
			# TRANSLATORS: C84h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. d4 exd4 7. e5 Ne4 8. c3 dxc3
			variation => N__('Spanish: Closed, Centre Attack, Basque Gambit Accepted'),
			moves => {
			},
		},
		'r1bqk2r/1pppbppp/p1n5/4P3/B2Nn3/8/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C84i',
			# TRANSLATORS: C84i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. d4 exd4 7. e5 Ne4 8. Nxd4
			variation => N__('Spanish: Closed, Centre Attack, 7. e5 Ne4 8.Nxd4'),
			moves => {
				'c6d4' => 1,
				'e8g8' => 1,
			},
		},
		'r1bqk2r/1pppbppp/p7/4P3/B2nn3/8/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C84j',
			# TRANSLATORS: C84j: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. d4 exd4 7. e5 Ne4 8. Nxd4 Nxd4
			variation => N__('Spanish: Closed, Centre Attack, 7. e5 Ne4 8.Nxd4 Nxd4'),
			moves => {
			},
		},
		'r1bq1rk1/1pppbppp/p1n5/4P3/B2Nn3/8/PPP2PPP/RNBQ1RK1 w -' => {
			eco => 'C84k',
			# TRANSLATORS: C84k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. d4 exd4 7. e5 Ne4 8. Nxd4 O-O
			variation => N__('Spanish: Closed, Centre Attack, 7. e5 Ne4 8.Nxd4 O-O'),
			moves => {
			},
		},
		'r1bqk2r/1pppbppp/p1n2n2/8/B2pP3/5N2/PPP2PPP/RNBQR1K1 b kq' => {
			eco => 'C84l',
			# TRANSLATORS: C84l: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. d4 exd4 7. Re1
			variation => N__('Spanish: Closed, Centre Attack, 7. Re1'),
			moves => {
				'b7b5' => 1,
				'e8g8' => 1,
			},
		},
		'r1bqk2r/2ppbppp/p1n2n2/1p6/B2pP3/5N2/PPP2PPP/RNBQR1K1 w kq' => {
			eco => 'C84m',
			# TRANSLATORS: C84m: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. d4 exd4 7. Re1 b5
			variation => N__('Spanish: Closed, Centre Attack, 7. Re1 b5'),
			moves => {
				'e4e5' => 1,
			},
		},
		'r1bqk2r/2ppbppp/p1n2n2/1p2P3/B2p4/5N2/PPP2PPP/RNBQR1K1 b kq' => {
			eco => 'C84n',
			# TRANSLATORS: C84n: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. d4 exd4 7. Re1 b5 8. e5
			variation => N__('Spanish: Closed, Centre Attack, 7. Re1 b5 8. e5'),
			moves => {
				'c6e5' => 1,
			},
		},
		'r1bqk2r/2ppbppp/p4n2/1p2n3/B2p4/5N2/PPP2PPP/RNBQR1K1 w kq' => {
			eco => 'C84n',
			# TRANSLATORS: C84n: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. d4 exd4 7. Re1 b5 8. e5 Nxe5
			variation => N__('Spanish: Closed, Centre Attack, 7. Re1 b5 8. e5 Nxe5'),
			moves => {
				'e1e5' => 1,
			},
		},
		'r1bqk2r/2ppbppp/p4n2/1p2R3/B2p4/5N2/PPP2PPP/RNBQ2K1 b kq' => {
			eco => 'C84n',
			# TRANSLATORS: C84n: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. d4 exd4 7. Re1 b5 8. e5 Nxe5 9. Rxe5
			variation => N__('Spanish: Closed, Centre Attack, 7. Re1 b5 8. e5 Nxe5 9.Rxe5'),
			moves => {
			},
		},
		'r1bq1rk1/1pppbppp/p1n2n2/8/B2pP3/5N2/PPP2PPP/RNBQR1K1 w -' => {
			eco => 'C84o',
			# TRANSLATORS: C84o: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. d4 exd4 7. Re1 O-O
			variation => N__('Spanish: Closed, Centre Attack, 7. Re1 O-O'),
			moves => {
				'e4e5' => 1,
			},
		},
		'r1bq1rk1/1pppbppp/p1n2n2/4P3/B2p4/5N2/PPP2PPP/RNBQR1K1 b -' => {
			eco => 'C84o',
			# TRANSLATORS: C84o: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. d4 exd4 7. Re1 O-O 8. e5
			variation => N__('Spanish: Closed, Centre Attack, 7. Re1 O-O'),
			moves => {
				'f6e8' => 1,
			},
		},
		'r1bqnrk1/1pppbppp/p1n5/4P3/B2p4/5N2/PPP2PPP/RNBQR1K1 w -' => {
			eco => 'C84p',
			# TRANSLATORS: C84p: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. d4 exd4 7. Re1 O-O 8. e5 Ne8
			variation => N__('Spanish: Closed, Centre Attack, 7. Re1 O-O 8. e5 Ne8'),
			moves => {
				'c1f4' => 1,
				'c2c3' => 1,
			},
		},
		'r1bqnrk1/1pppbppp/p1n5/4P3/B2p4/2P2N2/PP3PPP/RNBQR1K1 b -' => {
			eco => 'C84p',
			# TRANSLATORS: C84p: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. d4 exd4 7. Re1 O-O 8. e5 Ne8 9. c3
			variation => N__('Spanish: Closed, Centre Attack, 7. Re1 O-O 8. e5 Ne8 9. c3'),
			moves => {
			},
		},
		'r1bqnrk1/1pppbppp/p1n5/4P3/B2p1B2/5N2/PPP2PPP/RN1QR1K1 b -' => {
			eco => 'C84q',
			# TRANSLATORS: C84q: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. d4 exd4 7. Re1 O-O 8. e5 Ne8 9. Bf4
			variation => N__('Spanish: Closed, Centre Attack, 7. Re1 O-O 8. e5 Ne8 9. Bf4'),
			moves => {
			},
		},
		'r1bqk2r/1pppbppp/p1B2n2/4p3/4P3/5N2/PPPP1PPP/RNBQ1RK1 b kq' => {
			eco => 'C85a',
			# TRANSLATORS: C85a: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Bxc6
			variation => N__('Spanish: Closed, Exchange'),
			moves => {
				'd7c6' => 1,
			},
		},
		'r1bqk2r/1pp1bppp/p1p2n2/4p3/4P3/5N2/PPPP1PPP/RNBQ1RK1 w kq' => {
			eco => 'C85b',
			# TRANSLATORS: C85b: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Bxc6 dxc6
			variation => N__('Spanish: Closed, Exchange'),
			moves => {
				'b1c3' => 1,
				'd1e1' => 1,
				'd1e2' => 1,
				'd2d3' => 1,
			},
		},
		'r1bqk2r/1pp1bppp/p1p2n2/4p3/4P3/5N2/PPPPQPPP/RNB2RK1 b kq' => {
			eco => 'C85c',
			# TRANSLATORS: C85c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Bxc6 dxc6 7. Qe2
			variation => N__('Spanish: Closed, Exchange, 7. Qe2'),
			moves => {
			},
		},
		'r1bqk2r/1pp1bppp/p1p2n2/4p3/4P3/2N2N2/PPPP1PPP/R1BQ1RK1 b kq' => {
			eco => 'C85d',
			# TRANSLATORS: C85d: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Bxc6 dxc6 7. Nc3
			variation => N__('Spanish: Closed, Exchange, 7. Nc3'),
			moves => {
				'c8g4' => 1,
			},
		},
		'r2qk2r/1pp1bppp/p1p2n2/4p3/4P1b1/2N2N2/PPPP1PPP/R1BQ1RK1 w kq' => {
			eco => 'C85e',
			# TRANSLATORS: C85e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Bxc6 dxc6 7. Nc3 Bg4
			variation => N__('Spanish: Closed, Exchange, 7. Nc3 Bg4'),
			moves => {
			},
		},
		'r1bqk2r/1pp1bppp/p1p2n2/4p3/4P3/5N2/PPPP1PPP/RNB1QRK1 b kq' => {
			eco => 'C85f',
			# TRANSLATORS: C85f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Bxc6 dxc6 7. Qe1
			variation => N__('Spanish: Closed, Exchange, 7. Qe1'),
			moves => {
				'c6c5' => 1,
				'f6d7' => 1,
			},
		},
		'r1bqk2r/1pp1bppp/p4n2/2p1p3/4P3/5N2/PPPP1PPP/RNB1QRK1 w kq' => {
			eco => 'C85g',
			# TRANSLATORS: C85g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Bxc6 dxc6 7. Qe1 c5
			variation => N__('Spanish: Closed, Exchange, 7. Qe1 c5'),
			moves => {
			},
		},
		'r1bqk2r/1ppnbppp/p1p5/4p3/4P3/5N2/PPPP1PPP/RNB1QRK1 w kq' => {
			eco => 'C85h',
			# TRANSLATORS: C85h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Bxc6 dxc6 7. Qe1 Nd7
			variation => N__('Spanish: Closed, Exchange, 7. Qe1 Nd7'),
			moves => {
				'b2b3' => 1,
			},
		},
		'r1bqk2r/1ppnbppp/p1p5/4p3/4P3/1P3N2/P1PP1PPP/RNB1QRK1 b kq' => {
			eco => 'C85i',
			# TRANSLATORS: C85i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Bxc6 dxc6 7. Qe1 Nd7 8. b3
			variation => N__('Spanish: Closed, Exchange, 7. Qe1 Nd7 8. b3'),
			moves => {
			},
		},
		'r1bqk2r/1pp1bppp/p1p2n2/4p3/4P3/3P1N2/PPP2PPP/RNBQ1RK1 b kq' => {
			eco => 'C85j',
			# TRANSLATORS: C85j: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Bxc6 dxc6 7. d3
			variation => N__('Spanish: Closed, Exchange, 7. d3'),
			moves => {
				'c8g4' => 1,
				'f6d7' => 1,
			},
		},
		'r2qk2r/1pp1bppp/p1p2n2/4p3/4P1b1/3P1N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C85k',
			# TRANSLATORS: C85k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Bxc6 dxc6 7. d3 Bg4
			variation => N__('Spanish: Closed, Exchange, 7. d3 Bg4'),
			moves => {
			},
		},
		'r1bqk2r/1ppnbppp/p1p5/4p3/4P3/3P1N2/PPP2PPP/RNBQ1RK1 w kq' => {
			eco => 'C85l',
			# TRANSLATORS: C85l: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Bxc6 dxc6 7. d3 Nd7
			variation => N__('Spanish: Closed, Exchange, 7. d3 Nd7'),
			moves => {
				'b1d2' => 1,
			},
		},
		'r1bqk2r/1ppnbppp/p1p5/4p3/4P3/3P1N2/PPPN1PPP/R1BQ1RK1 b kq' => {
			eco => 'C85m',
			# TRANSLATORS: C85m: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Bxc6 dxc6 7. d3 Nd7 8. Nbd2
			variation => N__('Spanish: Closed, Exchange, 7. d3 Nd7 8.Nbd2'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/1ppnbppp/p1p5/4p3/4P3/3P1N2/PPPN1PPP/R1BQ1RK1 w -' => {
			eco => 'C85m',
			# TRANSLATORS: C85m: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Bxc6 dxc6 7. d3 Nd7 8. Nbd2 O-O
			variation => N__('Spanish: Closed, Exchange, 7. d3 Nd7 8.Nbd2'),
			moves => {
				'd2c4' => 1,
			},
		},
		'r1bq1rk1/1ppnbppp/p1p5/4p3/2N1P3/3P1N2/PPP2PPP/R1BQ1RK1 b -' => {
			eco => 'C85n',
			# TRANSLATORS: C85n: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Bxc6 dxc6 7. d3 Nd7 8. Nbd2 O-O 9. Nc4
			variation => N__('Spanish: Closed, Exchange, 7. d3 Nd7 8.Nbd2 O-O 9. Nc4'),
			moves => {
				'f7f6' => 1,
			},
		},
		'r1bq1rk1/1ppnb1pp/p1p2p2/4p3/2N1P3/3P1N2/PPP2PPP/R1BQ1RK1 w -' => {
			eco => 'C85o',
			# TRANSLATORS: C85o: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Bxc6 dxc6 7. d3 Nd7 8. Nbd2 O-O 9. Nc4 f6
			variation => N__('Spanish: Closed, Exchange, 7. d3 Nd7 8.Nbd2 O-O 9. Nc4 f6'),
			moves => {
				'f3h4' => 1,
			},
		},
		'r1bq1rk1/1ppnb1pp/p1p2p2/4p3/2N1P2N/3P4/PPP2PPP/R1BQ1RK1 b -' => {
			eco => 'C85p',
			# TRANSLATORS: C85p: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Bxc6 dxc6 7. d3 Nd7 8. Nbd2 O-O 9. Nc4 f6 10. Nh4
			variation => N__('Spanish: Closed, Exchange, 7. d3 Nd7 8.Nbd2 O-O 9. Nc4 f6 10. Nh4'),
			moves => {
				'd7c5' => 1,
			},
		},
		'r1bq1rk1/1pp1b1pp/p1p2p2/2n1p3/2N1P2N/3P4/PPP2PPP/R1BQ1RK1 w -' => {
			eco => 'C85q',
			# TRANSLATORS: C85q: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Bxc6 dxc6 7. d3 Nd7 8. Nbd2 O-O 9. Nc4 f6 10. Nh4 Nc5
			variation => N__('Spanish: Closed, Exchange, 7. d3 Nd7 8.Nbd2 O-O 9. Nc4 f6 10. Nh4 Nc5'),
			moves => {
				'h4f5' => 1,
			},
		},
		'r1bq1rk1/1pp1b1pp/p1p2p2/2n1pN2/2N1P3/3P4/PPP2PPP/R1BQ1RK1 b -' => {
			eco => 'C85r',
			# TRANSLATORS: C85r: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Bxc6 dxc6 7. d3 Nd7 8. Nbd2 O-O 9. Nc4 f6 10. Nh4 Nc5 11. Nf5
			variation => N__('Spanish: Closed, Exchange, 7. d3 Nd7 8.Nbd2 O-O 9. Nc4 f6 10. Nh4 Nc5 11. Nf5'),
			moves => {
			},
		},
		'r1bqk2r/1pppbppp/p1n2n2/4p3/B3P3/5N2/PPPPQPPP/RNB2RK1 b kq' => {
			eco => 'C86a',
			# TRANSLATORS: C86a: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Qe2
			variation => N__('Spanish: Worrall Attack'),
			moves => {
				'b7b5' => 1,
				'd7d6' => 1,
			},
		},
		'r1bqk2r/1pp1bppp/p1np1n2/4p3/B3P3/5N2/PPPPQPPP/RNB2RK1 w kq' => {
			eco => 'C86a',
			# TRANSLATORS: C86a: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Qe2 d6
			variation => N__('Spanish: Worrall Attack, 6... d6'),
			moves => {
			},
		},
		'r1bqk2r/2ppbppp/p1n2n2/1p2p3/B3P3/5N2/PPPPQPPP/RNB2RK1 w kq' => {
			eco => 'C86b',
			# TRANSLATORS: C86b: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Qe2 b5
			variation => N__('Spanish: Worrall Attack, 6... b5'),
			moves => {
				'a4b3' => 1,
			},
		},
		'r1bqk2r/2ppbppp/p1n2n2/1p2p3/4P3/1B3N2/PPPPQPPP/RNB2RK1 b kq' => {
			eco => 'C86b',
			# TRANSLATORS: C86b: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Qe2 b5 7. Bb3
			variation => N__('Spanish: Worrall Attack, 6... b5 7. Bb3'),
			moves => {
				'd7d6' => 1,
				'e8g8' => 1,
			},
		},
		'r1bqk2r/2p1bppp/p1np1n2/1p2p3/4P3/1B3N2/PPPPQPPP/RNB2RK1 w kq' => {
			eco => 'C86c',
			# TRANSLATORS: C86c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Qe2 b5 7. Bb3 d6
			variation => N__('Spanish: Worrall Attack, 7... d6'),
			moves => {
				'c2c3' => 1,
			},
		},
		'r1bqk2r/2p1bppp/p1np1n2/1p2p3/4P3/1BP2N2/PP1PQPPP/RNB2RK1 b kq' => {
			eco => 'C86d',
			# TRANSLATORS: C86d: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Qe2 b5 7. Bb3 d6 8. c3
			variation => N__('Spanish: Worrall Attack, 7... d6 8. c3'),
			moves => {
			},
		},
		'r1bq1rk1/2ppbppp/p1n2n2/1p2p3/4P3/1B3N2/PPPPQPPP/RNB2RK1 w -' => {
			eco => 'C86e',
			# TRANSLATORS: C86e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Qe2 b5 7. Bb3 O-O
			variation => N__('Spanish: Worrall Attack, 7...O-O'),
			moves => {
				'a2a4' => 1,
				'c2c3' => 1,
			},
		},
		'r1bq1rk1/2ppbppp/p1n2n2/1p2p3/P3P3/1B3N2/1PPPQPPP/RNB2RK1 b -' => {
			eco => 'C86e',
			# TRANSLATORS: C86e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Qe2 b5 7. Bb3 O-O 8. a4
			variation => N__('Spanish: Worrall Attack, 7...O-O 8. a4'),
			moves => {
			},
		},
		'r1bq1rk1/2ppbppp/p1n2n2/1p2p3/4P3/1BP2N2/PP1PQPPP/RNB2RK1 b -' => {
			eco => 'C86f',
			# TRANSLATORS: C86f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Qe2 b5 7. Bb3 O-O 8. c3
			variation => N__('Spanish: Worrall Attack, 7...O-O 8. c3'),
			moves => {
				'd7d5' => 1,
				'd7d6' => 1,
			},
		},
		'r1bq1rk1/2p1bppp/p1np1n2/1p2p3/4P3/1BP2N2/PP1PQPPP/RNB2RK1 w -' => {
			eco => 'C86g',
			# TRANSLATORS: C86g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Qe2 b5 7. Bb3 O-O 8. c3 d6
			variation => N__('Spanish: Worrall Attack, 7...O-O 8. c3 d6'),
			moves => {
				'd2d4' => 1,
				'f1d1' => 1,
			},
		},
		'r1bq1rk1/2p1bppp/p1np1n2/1p2p3/3PP3/1BP2N2/PP2QPPP/RNB2RK1 b -' => {
			eco => 'C86h',
			# TRANSLATORS: C86h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Qe2 b5 7. Bb3 O-O 8. c3 d6 9. d4
			variation => N__('Spanish: Worrall Attack, 7...O-O 8. c3 d6 9. d4'),
			moves => {
			},
		},
		'r1bq1rk1/2p1bppp/p1np1n2/1p2p3/4P3/1BP2N2/PP1PQPPP/RNBR2K1 b -' => {
			eco => 'C86i',
			# TRANSLATORS: C86i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Qe2 b5 7. Bb3 O-O 8. c3 d6 9. Rd1
			variation => N__('Spanish: Worrall Attack, 7...O-O 8. c3 d6 9. Rd1'),
			moves => {
			},
		},
		'r1bq1rk1/2p1bppp/p1n2n2/1p1pp3/4P3/1BP2N2/PP1PQPPP/RNB2RK1 w -' => {
			eco => 'C86j',
			# TRANSLATORS: C86j: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Qe2 b5 7. Bb3 O-O 8. c3 d5
			variation => N__('Spanish: Worrall Attack, 7...O-O 8. c3 d5'),
			moves => {
				'd2d3' => 1,
				'e4d5' => 1,
			},
		},
		'r1bq1rk1/2p1bppp/p1n2n2/1p1Pp3/8/1BP2N2/PP1PQPPP/RNB2RK1 b -' => {
			eco => 'C86j',
			# TRANSLATORS: C86j: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Qe2 b5 7. Bb3 O-O 8. c3 d5 9. exd5
			variation => N__('Spanish: Worrall Attack, 7...O-O 8. c3 d5 9.exd5'),
			moves => {
			},
		},
		'r1bq1rk1/2p1bppp/p1n2n2/1p1pp3/4P3/1BPP1N2/PP2QPPP/RNB2RK1 b -' => {
			eco => 'C86k',
			# TRANSLATORS: C86k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Qe2 b5 7. Bb3 O-O 8. c3 d5 9. d3
			variation => N__('Spanish: Worrall Attack, 7...O-O 8. c3 d5 9. d3'),
			moves => {
				'c8b7' => 1,
			},
		},
		'r2q1rk1/1bp1bppp/p1n2n2/1p1pp3/4P3/1BPP1N2/PP2QPPP/RNB2RK1 w -' => {
			eco => 'C86l',
			# TRANSLATORS: C86l: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Qe2 b5 7. Bb3 O-O 8. c3 d5 9. d3 Bb7
			variation => N__('Spanish: Worrall Attack, 7...O-O 8. c3 d5 9. d3 Bb7'),
			moves => {
			},
		},
		'r1bqk2r/1pppbppp/p1n2n2/4p3/B3P3/5N2/PPPP1PPP/RNBQR1K1 b kq' => {
			eco => 'C87a',
			# TRANSLATORS: C87a: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1
			variation => N__('Spanish: Closed, 6. Re1'),
			moves => {
				'b7b5' => 1,
				'd7d6' => 1,
			},
		},
		'r1bqk2r/1pp1bppp/p1np1n2/4p3/B3P3/5N2/PPPP1PPP/RNBQR1K1 w kq' => {
			eco => 'C87b',
			# TRANSLATORS: C87b: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 d6
			variation => N__('Spanish: Closed, Averbakh (Russian) Variation'),
			moves => {
				'a4c6' => 1,
				'c2c3' => 1,
			},
		},
		'r1bqk2r/1pp1bppp/p1Bp1n2/4p3/4P3/5N2/PPPP1PPP/RNBQR1K1 b kq' => {
			eco => 'C87c',
			# TRANSLATORS: C87c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 d6 7. Bxc6+
			variation => N__('Spanish: Closed, Averbakh, 7.Bxc6+'),
			moves => {
				'b7c6' => 1,
			},
		},
		'r1bqk2r/2p1bppp/p1pp1n2/4p3/4P3/5N2/PPPP1PPP/RNBQR1K1 w kq' => {
			eco => 'C87c',
			# TRANSLATORS: C87c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 d6 7. Bxc6+ bxc6
			variation => N__('Spanish: Closed, Averbakh, 7.Bxc6+'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bqk2r/2p1bppp/p1pp1n2/4p3/3PP3/5N2/PPP2PPP/RNBQR1K1 b kq' => {
			eco => 'C87c',
			# TRANSLATORS: C87c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 d6 7. Bxc6+ bxc6 8. d4
			variation => N__('Spanish: Closed, Averbakh, 7.Bxc6+ bxc6 8. d4'),
			moves => {
				'e5d4' => 1,
			},
		},
		'r1bqk2r/2p1bppp/p1pp1n2/8/3pP3/5N2/PPP2PPP/RNBQR1K1 w kq' => {
			eco => 'C87d',
			# TRANSLATORS: C87d: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 d6 7. Bxc6+ bxc6 8. d4 exd4
			variation => N__('Spanish: Closed, Averbakh, 7.Bxc6+ bxc6 8. d4 exd4'),
			moves => {
				'f3d4' => 1,
			},
		},
		'r1bqk2r/2p1bppp/p1pp1n2/8/3NP3/8/PPP2PPP/RNBQR1K1 b kq' => {
			eco => 'C87d',
			# TRANSLATORS: C87d: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 d6 7. Bxc6+ bxc6 8. d4 exd4 9. Nxd4
			variation => N__('Spanish: Closed, Averbakh, 7.Bxc6+ bxc6 8. d4 exd4'),
			moves => {
			},
		},
		'r1bqk2r/1pp1bppp/p1np1n2/4p3/B3P3/2P2N2/PP1P1PPP/RNBQR1K1 b kq' => {
			eco => 'C87e',
			# TRANSLATORS: C87e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 d6 7. c3
			variation => N__('Spanish: Closed, Averbakh, 7. c3'),
			moves => {
				'c8g4' => 1,
				'e8g8' => 1,
			},
		},
		'r2qk2r/1pp1bppp/p1np1n2/4p3/B3P1b1/2P2N2/PP1P1PPP/RNBQR1K1 w kq' => {
			eco => 'C87f',
			# TRANSLATORS: C87f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 d6 7. c3 Bg4
			variation => N__('Spanish: Closed, Averbakh, 7. c3 Bg4'),
			moves => {
				'd2d3' => 1,
				'h2h3' => 1,
			},
		},
		'r2qk2r/1pp1bppp/p1np1n2/4p3/B3P1b1/2P2N1P/PP1P1PP1/RNBQR1K1 b kq' => {
			eco => 'C87g',
			# TRANSLATORS: C87g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 d6 7. c3 Bg4 8. h3
			variation => N__('Spanish: Closed, Averbakh, 7. c3 Bg4 8. h3'),
			moves => {
			},
		},
		'r2qk2r/1pp1bppp/p1np1n2/4p3/B3P1b1/2PP1N2/PP3PPP/RNBQR1K1 b kq' => {
			eco => 'C87h',
			# TRANSLATORS: C87h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 d6 7. c3 Bg4 8. d3
			variation => N__('Spanish: Closed, Averbakh, 7. c3 Bg4 8. d3'),
			moves => {
			},
		},
		'r1bq1rk1/1pp1bppp/p1np1n2/4p3/B3P3/2P2N2/PP1P1PPP/RNBQR1K1 w -' => {
			eco => 'C87i',
			# TRANSLATORS: C87i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 d6 7. c3 O-O
			variation => N__('Spanish: Closed, Averbakh, 7. c3 O-O'),
			moves => {
				'd2d4' => 1,
				'h2h3' => 1,
			},
		},
		'r1bq1rk1/1pp1bppp/p1np1n2/4p3/B2PP3/2P2N2/PP3PPP/RNBQR1K1 b -' => {
			eco => 'C87j',
			# TRANSLATORS: C87j: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 d6 7. c3 O-O 8. d4
			variation => N__('Spanish: Closed, Averbakh, 7. c3 O-O 8. d4'),
			moves => {
				'c8d7' => 1,
			},
		},
		'r2q1rk1/1ppbbppp/p1np1n2/4p3/B2PP3/2P2N2/PP3PPP/RNBQR1K1 w -' => {
			eco => 'C87k',
			# TRANSLATORS: C87k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 d6 7. c3 O-O 8. d4 Bd7
			variation => N__('Spanish: Closed, Averbakh, 7. c3 O-O 8. d4 Bd7'),
			moves => {
				'b1d2' => 1,
			},
		},
		'r2q1rk1/1ppbbppp/p1np1n2/4p3/B2PP3/2P2N2/PP1N1PPP/R1BQR1K1 b -' => {
			eco => 'C87l',
			# TRANSLATORS: C87l: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 d6 7. c3 O-O 8. d4 Bd7 9. Nbd2
			variation => N__('Spanish: Closed, Averbakh, 7. c3 O-O 8. d4 Bd7 9.Nbd2'),
			moves => {
				'f8e8' => 1,
			},
		},
		'r2qr1k1/1ppbbppp/p1np1n2/4p3/B2PP3/2P2N2/PP1N1PPP/R1BQR1K1 w -' => {
			eco => 'C87m',
			# TRANSLATORS: C87m: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 d6 7. c3 O-O 8. d4 Bd7 9. Nbd2 Re8
			variation => N__('Spanish: Closed, Averbakh, 7. c3 O-O 8. d4 Bd7 9.Nbd2 Re8'),
			moves => {
			},
		},
		'r1bq1rk1/1pp1bppp/p1np1n2/4p3/B3P3/2P2N1P/PP1P1PP1/RNBQR1K1 b -' => {
			eco => 'C87n',
			# TRANSLATORS: C87n: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 d6 7. c3 O-O 8. h3
			variation => N__('Spanish: Closed, Averbakh, 7. c3 O-O 8. h3'),
			moves => {
				'c8d7' => 1,
			},
		},
		'r2q1rk1/1ppbbppp/p1np1n2/4p3/B3P3/2P2N1P/PP1P1PP1/RNBQR1K1 w -' => {
			eco => 'C87o',
			# TRANSLATORS: C87o: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 d6 7. c3 O-O 8. h3 Bd7
			variation => N__('Spanish: Closed, Averbakh, 7. c3 O-O 8. h3 Bd7'),
			moves => {
			},
		},
		'r1bqk2r/2ppbppp/p1n2n2/1p2p3/B3P3/5N2/PPPP1PPP/RNBQR1K1 w kq' => {
			eco => 'C88a',
			# TRANSLATORS: C88a: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5
			variation => N__('Spanish: Closed, 6... b5'),
			moves => {
				'a4b3' => 1,
			},
		},
		'r1bqk2r/2ppbppp/p1n2n2/1p2p3/4P3/1B3N2/PPPP1PPP/RNBQR1K1 b kq' => {
			eco => 'C88a',
			# TRANSLATORS: C88a: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3
			variation => N__('Spanish: Closed, 6... b5 7. Bb3'),
			moves => {
				'c8b7' => 1,
				'd7d6' => 1,
				'e8g8' => 1,
			},
		},
		'r2qk2r/1bppbppp/p1n2n2/1p2p3/4P3/1B3N2/PPPP1PPP/RNBQR1K1 w kq' => {
			eco => 'C88b',
			# TRANSLATORS: C88b: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 Bb7
			variation => N__('Spanish: Closed, Trajkovic Counterattack'),
			moves => {
			},
		},
		'r1bqk2r/2p1bppp/p1np1n2/1p2p3/4P3/1B3N2/PPPP1PPP/RNBQR1K1 w kq' => {
			eco => 'C88c',
			# TRANSLATORS: C88c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 d6
			variation => N__('Spanish: Closed 7... d6'),
			moves => {
				'c2c3' => 1,
				'd2d4' => 1,
			},
		},
		'r1bqk2r/2p1bppp/p1np1n2/1p2p3/3PP3/1B3N2/PPP2PPP/RNBQR1K1 b kq' => {
			eco => 'C88c',
			# TRANSLATORS: C88c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 d6 8. d4
			variation => N__('Spanish: Closed, 7... d6 8. d4'),
			moves => {
				'c6d4' => 1,
			},
		},
		'r1bqk2r/2p1bppp/p2p1n2/1p2p3/3nP3/1B3N2/PPP2PPP/RNBQR1K1 w kq' => {
			eco => 'C88c',
			# TRANSLATORS: C88c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 d6 8. d4 Nxd4
			variation => N__('Spanish: Closed, 7... d6 8. d4'),
			moves => {
				'f3d4' => 1,
			},
		},
		'r1bqk2r/2p1bppp/p2p1n2/1p2p3/3NP3/1B6/PPP2PPP/RNBQR1K1 b kq' => {
			eco => 'C88c',
			# TRANSLATORS: C88c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 d6 8. d4 Nxd4 9. Nxd4
			variation => N__('Spanish: Closed, 7... d6 8. d4'),
			moves => {
				'e5d4' => 1,
			},
		},
		'r1bqk2r/2p1bppp/p2p1n2/1p6/3pP3/1B6/PPP2PPP/RNBQR1K1 w kq' => {
			eco => 'C88c',
			# TRANSLATORS: C88c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 d6 8. d4 Nxd4 9. Nxd4 exd4
			variation => N__('Spanish: Closed, 7... d6 8. d4'),
			moves => {
				'd1d4' => 1,
			},
		},
		'r1bqk2r/2p1bppp/p2p1n2/1p6/3QP3/1B6/PPP2PPP/RNB1R1K1 b kq' => {
			eco => 'C88c',
			# TRANSLATORS: C88c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 d6 8. d4 Nxd4 9. Nxd4 exd4 10. Qxd4
			variation => N__('Spanish: Closed, 7... d6 8. d4'),
			moves => {
				'c7c5' => 1,
			},
		},
		'r1bqk2r/4bppp/p2p1n2/1pp5/3QP3/1B6/PPP2PPP/RNB1R1K1 w kq' => {
			eco => 'C88c',
			# TRANSLATORS: C88c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 d6 8. d4 Nxd4 9. Nxd4 exd4 10. Qxd4 c5
			variation => N__('Spanish: Closed, Noah\'s Ark Trap'),
			moves => {
			},
		},
		'r1bqk2r/2p1bppp/p1np1n2/1p2p3/4P3/1BP2N2/PP1P1PPP/RNBQR1K1 b kq' => {
			eco => 'C88d',
			# TRANSLATORS: C88d: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 d6 8. c3
			variation => N__('Spanish: Closed 7... d6 8. c3'),
			moves => {
				'c6a5' => 1,
				'c8g4' => 1,
			},
		},
		'r2qk2r/2p1bppp/p1np1n2/1p2p3/4P1b1/1BP2N2/PP1P1PPP/RNBQR1K1 w kq' => {
			eco => 'C88d',
			# TRANSLATORS: C88d: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 d6 8. c3 Bg4
			variation => N__('Spanish: Closed 7... d6 8. c3 Bg4'),
			moves => {
			},
		},
		'r1bqk2r/2p1bppp/p2p1n2/np2p3/4P3/1BP2N2/PP1P1PPP/RNBQR1K1 w kq' => {
			eco => 'C88e',
			# TRANSLATORS: C88e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 d6 8. c3 Na5
			variation => N__('Spanish: Closed 7... d6 8. c3 Na5'),
			moves => {
				'b3c2' => 1,
			},
		},
		'r1bqk2r/2p1bppp/p2p1n2/np2p3/4P3/2P2N2/PPBP1PPP/RNBQR1K1 b kq' => {
			eco => 'C88e',
			# TRANSLATORS: C88e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 d6 8. c3 Na5 9. Bc2
			variation => N__('Spanish: Closed 7... d6 8. c3 Na5'),
			moves => {
				'c7c5' => 1,
			},
		},
		'r1bqk2r/4bppp/p2p1n2/npp1p3/4P3/2P2N2/PPBP1PPP/RNBQR1K1 w kq' => {
			eco => 'C88e',
			# TRANSLATORS: C88e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 d6 8. c3 Na5 9. Bc2 c5
			variation => N__('Spanish: Closed 7... d6 8. c3 Na5'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bqk2r/4bppp/p2p1n2/npp1p3/3PP3/2P2N2/PPB2PPP/RNBQR1K1 b kq' => {
			eco => 'C88e',
			# TRANSLATORS: C88e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 d6 8. c3 Na5 9. Bc2 c5 10. d4
			variation => N__('Spanish: Closed 7... d6 8. c3 Na5'),
			moves => {
				'd8c7' => 1,
			},
		},
		'r1b1k2r/2q1bppp/p2p1n2/npp1p3/3PP3/2P2N2/PPB2PPP/RNBQR1K1 w kq' => {
			eco => 'C88e',
			# TRANSLATORS: C88e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 d6 8. c3 Na5 9. Bc2 c5 10. d4 Qc7
			variation => N__('Spanish: Closed 7... d6 8. c3 Na5'),
			moves => {
				'a2a4' => 1,
				'h2h3' => 1,
			},
		},
		'r1b1k2r/2q1bppp/p2p1n2/npp1p3/P2PP3/2P2N2/1PB2PPP/RNBQR1K1 b kq' => {
			eco => 'C88e',
			# TRANSLATORS: C88e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 d6 8. c3 Na5 9. Bc2 c5 10. d4 Qc7 11. a4
			variation => N__('Spanish: Closed, Balla Variation'),
			moves => {
			},
		},
		'r1b1k2r/2q1bppp/p2p1n2/npp1p3/3PP3/2P2N1P/PPB2PP1/RNBQR1K1 b kq' => {
			eco => 'C88e',
			# TRANSLATORS: C88e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 d6 8. c3 Na5 9. Bc2 c5 10. d4 Qc7 11. h3
			variation => N__('Spanish: Closed 7... d6 8. c3 Na5'),
			moves => {
				'a5c6' => 1,
			},
		},
		'r1b1k2r/2q1bppp/p1np1n2/1pp1p3/3PP3/2P2N1P/PPB2PP1/RNBQR1K1 w kq' => {
			eco => 'C88e',
			# TRANSLATORS: C88e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 d6 8. c3 Na5 9. Bc2 c5 10. d4 Qc7 11. h3 Nc6
			variation => N__('Spanish: Closed 7... d6 8. c3 Na5'),
			moves => {
				'd4d5' => 1,
			},
		},
		'r1b1k2r/2q1bppp/p1np1n2/1ppPp3/4P3/2P2N1P/PPB2PP1/RNBQR1K1 b kq' => {
			eco => 'C88e',
			# TRANSLATORS: C88e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 d6 8. c3 Na5 9. Bc2 c5 10. d4 Qc7 11. h3 Nc6 12. d5
			variation => N__('Spanish: Closed 7... d6 8. c3 Na5'),
			moves => {
				'c6b8' => 1,
			},
		},
		'rnb1k2r/2q1bppp/p2p1n2/1ppPp3/4P3/2P2N1P/PPB2PP1/RNBQR1K1 w kq' => {
			eco => 'C88e',
			# TRANSLATORS: C88e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 d6 8. c3 Na5 9. Bc2 c5 10. d4 Qc7 11. h3 Nc6 12. d5 Nb8
			variation => N__('Spanish: Closed 7... d6 8. c3 Na5'),
			moves => {
				'b1d2' => 1,
			},
		},
		'rnb1k2r/2q1bppp/p2p1n2/1ppPp3/4P3/2P2N1P/PPBN1PP1/R1BQR1K1 b kq' => {
			eco => 'C88e',
			# TRANSLATORS: C88e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 d6 8. c3 Na5 9. Bc2 c5 10. d4 Qc7 11. h3 Nc6 12. d5 Nb8 13. Nbd2
			variation => N__('Spanish: Closed 7... d6 8. c3 Na5'),
			moves => {
				'g7g5' => 1,
			},
		},
		'rnb1k2r/2q1bp1p/p2p1n2/1ppPp1p1/4P3/2P2N1P/PPBN1PP1/R1BQR1K1 w kq' => {
			eco => 'C88e',
			# TRANSLATORS: C88e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 d6 8. c3 Na5 9. Bc2 c5 10. d4 Qc7 11. h3 Nc6 12. d5 Nb8 13. Nbd2 g5
			variation => N__('Spanish: Closed, Leonhardt Variation'),
			moves => {
			},
		},
		'r1bq1rk1/2ppbppp/p1n2n2/1p2p3/4P3/1B3N2/PPPP1PPP/RNBQR1K1 w -' => {
			eco => 'C88f',
			# TRANSLATORS: C88f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O
			variation => N__('Spanish: Closed, 7...O-O'),
			moves => {
				'a2a4' => 1,
				'c2c3' => 1,
				'd2d3' => 1,
				'h2h3' => 1,
			},
		},
		'r1bq1rk1/2ppbppp/p1n2n2/1p2p3/4P3/1B1P1N2/PPP2PPP/RNBQR1K1 b -' => {
			eco => 'C88g',
			# TRANSLATORS: C88g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. d3
			variation => N__('Spanish: Closed, 8. d3'),
			moves => {
				'd7d6' => 1,
			},
		},
		'r1bq1rk1/2p1bppp/p1np1n2/1p2p3/4P3/1B1P1N2/PPP2PPP/RNBQR1K1 w -' => {
			eco => 'C88g',
			# TRANSLATORS: C88g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. d3 d6
			variation => N__('Spanish: Closed, 8. d3 d6'),
			moves => {
			},
		},
		'r1bq1rk1/2ppbppp/p1n2n2/1p2p3/4P3/1B3N1P/PPPP1PP1/RNBQR1K1 b -' => {
			eco => 'C88h',
			# TRANSLATORS: C88h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. h3
			variation => N__('Spanish: Closed, 8. h3'),
			moves => {
				'c8b7' => 1,
			},
		},
		'r2q1rk1/1bppbppp/p1n2n2/1p2p3/4P3/1B3N1P/PPPP1PP1/RNBQR1K1 w -' => {
			eco => 'C88h',
			# TRANSLATORS: C88h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. h3 Bb7
			variation => N__('Spanish: Closed, 8. h3'),
			moves => {
				'd2d3' => 1,
			},
		},
		'r2q1rk1/1bppbppp/p1n2n2/1p2p3/4P3/1B1P1N1P/PPP2PP1/RNBQR1K1 b -' => {
			eco => 'C88h',
			# TRANSLATORS: C88h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. h3 Bb7 9. d3
			variation => N__('Spanish: Closed, 8. h3'),
			moves => {
				'd7d6' => 1,
			},
		},
		'r2q1rk1/1bp1bppp/p1np1n2/1p2p3/4P3/1B1P1N1P/PPP2PP1/RNBQR1K1 w -' => {
			eco => 'C88i',
			# TRANSLATORS: C88i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. h3 Bb7 9. d3 d6
			variation => N__('Spanish: Closed, 8. h3 Bb7 9. d3 d6'),
			moves => {
			},
		},
		'r1bq1rk1/2ppbppp/p1n2n2/1p2p3/P3P3/1B3N2/1PPP1PPP/RNBQR1K1 b -' => {
			eco => 'C88j',
			# TRANSLATORS: C88j: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. a4
			variation => N__('Spanish: Closed, Anti-Marshall 8. a4'),
			moves => {
				'b5b4' => 1,
				'c8b7' => 1,
			},
		},
		'r1bq1rk1/2ppbppp/p1n2n2/4p3/Pp2P3/1B3N2/1PPP1PPP/RNBQR1K1 w -' => {
			eco => 'C88k',
			# TRANSLATORS: C88k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. a4 b4
			variation => N__('Spanish: Closed, Anti-Marshall 8. a4 b4'),
			moves => {
			},
		},
		'r2q1rk1/1bppbppp/p1n2n2/1p2p3/P3P3/1B3N2/1PPP1PPP/RNBQR1K1 w -' => {
			eco => 'C88l',
			# TRANSLATORS: C88l: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. a4 Bb7
			variation => N__('Spanish: Closed, Anti-Marshall 8. a4 Bb7'),
			moves => {
				'd2d3' => 1,
			},
		},
		'r2q1rk1/1bppbppp/p1n2n2/1p2p3/P3P3/1B1P1N2/1PP2PPP/RNBQR1K1 b -' => {
			eco => 'C88m',
			# TRANSLATORS: C88m: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. a4 Bb7 9. d3
			variation => N__('Spanish: Closed, Anti-Marshall 8. a4 Bb7 9. d3'),
			moves => {
				'd7d6' => 1,
			},
		},
		'r2q1rk1/1bp1bppp/p1np1n2/1p2p3/P3P3/1B1P1N2/1PP2PPP/RNBQR1K1 w -' => {
			eco => 'C88n',
			# TRANSLATORS: C88n: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. a4 Bb7 9. d3 d6
			variation => N__('Spanish: Closed, Anti-Marshall 8. a4 Bb7 9. d3 d6'),
			moves => {
				'b1c3' => 1,
				'c2c3' => 1,
			},
		},
		'r2q1rk1/1bp1bppp/p1np1n2/1p2p3/P3P3/1BNP1N2/1PP2PPP/R1BQR1K1 b -' => {
			eco => 'C88o',
			# TRANSLATORS: C88o: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. a4 Bb7 9. d3 d6 10. Nc3
			variation => N__('Spanish: Closed, Anti-Marshall 8. a4 Bb7 9. d3 d6 10. Nc3'),
			moves => {
			},
		},
		'r2q1rk1/1bp1bppp/p1np1n2/1p2p3/P3P3/1BPP1N2/1P3PPP/RNBQR1K1 b -' => {
			eco => 'C88p',
			# TRANSLATORS: C88p: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. a4 Bb7 9. d3 d6 10. c3
			variation => N__('Spanish: Closed, Anti-Marshall 8. a4 Bb7 9. d3 d6 10. c3'),
			moves => {
			},
		},
		'r1bq1rk1/2ppbppp/p1n2n2/1p2p3/4P3/1BP2N2/PP1P1PPP/RNBQR1K1 b -' => {
			eco => 'C88q',
			# TRANSLATORS: C88q: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3
			variation => N__('Spanish: Closed, 8. c3'),
			moves => {
				'd7d5' => 1,
				'd7d6' => 1,
			},
		},
		'r1bq1rk1/2p1bppp/p1n2n2/1p1pp3/4P3/1BP2N2/PP1P1PPP/RNBQR1K1 w -' => {
			eco => 'C89a',
			# TRANSLATORS: C89a: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5
			variation => N__('Spanish: Marshall Counterattack'),
			moves => {
				'e4d5' => 1,
			},
		},
		'r1bq1rk1/2p1bppp/p1n2n2/1p1Pp3/8/1BP2N2/PP1P1PPP/RNBQR1K1 b -' => {
			eco => 'C89b',
			# TRANSLATORS: C89b: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5
			variation => N__('Spanish: Marshall, 9.exd5'),
			moves => {
				'e5e4' => 1,
				'f6d5' => 1,
			},
		},
		'r1bq1rk1/2p1bppp/p1n2n2/1p1P4/4p3/1BP2N2/PP1P1PPP/RNBQR1K1 w -' => {
			eco => 'C89b',
			# TRANSLATORS: C89b: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 e4
			variation => N__('Spanish: Marshall, Herman Steiner Variation'),
			moves => {
			},
		},
		'r1bq1rk1/2p1bppp/p1n5/1p1np3/8/1BP2N2/PP1P1PPP/RNBQR1K1 w -' => {
			eco => 'C89c',
			# TRANSLATORS: C89c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5
			variation => N__('Spanish: Marshall, 9.exd5 Nxd5'),
			moves => {
				'f3e5' => 1,
			},
		},
		'r1bq1rk1/2p1bppp/p1n5/1p1nN3/8/1BP5/PP1P1PPP/RNBQR1K1 b -' => {
			eco => 'C89d',
			# TRANSLATORS: C89d: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5 10. Nxe5
			variation => N__('Spanish: Marshall, 9.exd5 Nxd5 10.Nxe5'),
			moves => {
				'c6e5' => 1,
			},
		},
		'r1bq1rk1/2p1bppp/p7/1p1nn3/8/1BP5/PP1P1PPP/RNBQR1K1 w -' => {
			eco => 'C89d',
			# TRANSLATORS: C89d: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5 10. Nxe5 Nxe5
			variation => N__('Spanish: Marshall, 9.exd5 Nxd5 10.Nxe5 Nxe5'),
			moves => {
				'e1e5' => 1,
			},
		},
		'r1bq1rk1/2p1bppp/p7/1p1nR3/8/1BP5/PP1P1PPP/RNBQ2K1 b -' => {
			eco => 'C89d',
			# TRANSLATORS: C89d: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5 10. Nxe5 Nxe5 11. Rxe5
			variation => N__('Spanish: Marshall, 11.Rxe5'),
			moves => {
				'c7c6' => 1,
				'd5f6' => 1,
			},
		},
		'r1bq1rk1/2p1bppp/p4n2/1p2R3/8/1BP5/PP1P1PPP/RNBQ2K1 w -' => {
			eco => 'C89e',
			# TRANSLATORS: C89e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5 10. Nxe5 Nxe5 11. Rxe5 Nf6
			variation => N__('Spanish: Marshall, 11.Rxe5 Nf6'),
			moves => {
			},
		},
		'r1bq1rk1/4bppp/p1p5/1p1nR3/8/1BP5/PP1P1PPP/RNBQ2K1 w -' => {
			eco => 'C89f',
			# TRANSLATORS: C89f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5 10. Nxe5 Nxe5 11. Rxe5 c6
			variation => N__('Spanish: Marshall, 11.Rxe5 c6'),
			moves => {
				'b3d5' => 1,
				'd2d3' => 1,
				'd2d4' => 1,
			},
		},
		'r1bq1rk1/4bppp/p1p5/1p1BR3/8/2P5/PP1P1PPP/RNBQ2K1 b -' => {
			eco => 'C89g',
			# TRANSLATORS: C89g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5 10. Nxe5 Nxe5 11. Rxe5 c6 12. Bxd5
			variation => N__('Spanish: Marshall, 12.Bxd5'),
			moves => {
				'c6d5' => 1,
			},
		},
		'r1bq1rk1/4bppp/p7/1p1pR3/8/2P5/PP1P1PPP/RNBQ2K1 w -' => {
			eco => 'C89g',
			# TRANSLATORS: C89g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5 10. Nxe5 Nxe5 11. Rxe5 c6 12. Bxd5 cxd5
			variation => N__('Spanish: Marshall, 12.Bxd5'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bq1rk1/4bppp/p7/1p1pR3/3P4/2P5/PP3PPP/RNBQ2K1 b -' => {
			eco => 'C89g',
			# TRANSLATORS: C89g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5 10. Nxe5 Nxe5 11. Rxe5 c6 12. Bxd5 cxd5 13. d4
			variation => N__('Spanish: Marshall, 12.Bxd5'),
			moves => {
				'e7d6' => 1,
			},
		},
		'r1bq1rk1/5ppp/p2b4/1p1pR3/3P4/2P5/PP3PPP/RNBQ2K1 w -' => {
			eco => 'C89g',
			# TRANSLATORS: C89g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5 10. Nxe5 Nxe5 11. Rxe5 c6 12. Bxd5 cxd5 13. d4 Bd6
			variation => N__('Spanish: Marshall, 12.Bxd5'),
			moves => {
				'e5e3' => 1,
			},
		},
		'r1bq1rk1/5ppp/p2b4/1p1p4/3P4/2P1R3/PP3PPP/RNBQ2K1 b -' => {
			eco => 'C89h',
			# TRANSLATORS: C89h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5 10. Nxe5 Nxe5 11. Rxe5 c6 12. Bxd5 cxd5 13. d4 Bd6 14. Re3
			variation => N__('Spanish: Marshall, Kevitz Variation'),
			moves => {
			},
		},
		'r1bq1rk1/4bppp/p1p5/1p1nR3/8/1BPP4/PP3PPP/RNBQ2K1 b -' => {
			eco => 'C89i',
			# TRANSLATORS: C89i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5 10. Nxe5 Nxe5 11. Rxe5 c6 12. d3
			variation => N__('Spanish: Marshall, 12. d3'),
			moves => {
				'e7d6' => 1,
			},
		},
		'r1bq1rk1/5ppp/p1pb4/1p1nR3/8/1BPP4/PP3PPP/RNBQ2K1 w -' => {
			eco => 'C89i',
			# TRANSLATORS: C89i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5 10. Nxe5 Nxe5 11. Rxe5 c6 12. d3 Bd6
			variation => N__('Spanish: Marshall, 12. d3'),
			moves => {
				'e5e1' => 1,
			},
		},
		'r1bq1rk1/5ppp/p1pb4/1p1n4/8/1BPP4/PP3PPP/RNBQR1K1 b -' => {
			eco => 'C89i',
			# TRANSLATORS: C89i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5 10. Nxe5 Nxe5 11. Rxe5 c6 12. d3 Bd6 13. Re1
			variation => N__('Spanish: Marshall, 12. d3 Bd6 13. Re1'),
			moves => {
				'd8h4' => 1,
			},
		},
		'r1b2rk1/5ppp/p1pb4/1p1n4/7q/1BPP4/PP3PPP/RNBQR1K1 w -' => {
			eco => 'C89j',
			# TRANSLATORS: C89j: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5 10. Nxe5 Nxe5 11. Rxe5 c6 12. d3 Bd6 13. Re1 Qh4
			variation => N__('Spanish: Marshall, 12. d3 Bd6 13. Re1 Qh4'),
			moves => {
			},
		},
		'r1bq1rk1/4bppp/p1p5/1p1nR3/3P4/1BP5/PP3PPP/RNBQ2K1 b -' => {
			eco => 'C89k',
			# TRANSLATORS: C89k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5 10. Nxe5 Nxe5 11. Rxe5 c6 12. d4
			variation => N__('Spanish: Marshall, Main Line (12. d4)'),
			moves => {
				'e7d6' => 1,
			},
		},
		'r1bq1rk1/5ppp/p1pb4/1p1nR3/3P4/1BP5/PP3PPP/RNBQ2K1 w -' => {
			eco => 'C89k',
			# TRANSLATORS: C89k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5 10. Nxe5 Nxe5 11. Rxe5 c6 12. d4 Bd6
			variation => N__('Spanish: Marshall, Main Line (12. d4 Bd6)'),
			moves => {
				'e5e1' => 1,
				'e5e2' => 1,
			},
		},
		'r1bq1rk1/5ppp/p1pb4/1p1n4/3P4/1BP5/PP2RPPP/RNBQ2K1 b -' => {
			eco => 'C89l',
			# TRANSLATORS: C89l: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5 10. Nxe5 Nxe5 11. Rxe5 c6 12. d4 Bd6 13. Re2
			variation => N__('Spanish: Marshall, Main Line, 13. Re2'),
			moves => {
			},
		},
		'r1bq1rk1/5ppp/p1pb4/1p1n4/3P4/1BP5/PP3PPP/RNBQR1K1 b -' => {
			eco => 'C89m',
			# TRANSLATORS: C89m: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5 10. Nxe5 Nxe5 11. Rxe5 c6 12. d4 Bd6 13. Re1
			variation => N__('Spanish: Marshall, Main Line, 13. Re1'),
			moves => {
				'd8h4' => 1,
			},
		},
		'r1b2rk1/5ppp/p1pb4/1p1n4/3P3q/1BP5/PP3PPP/RNBQR1K1 w -' => {
			eco => 'C89m',
			# TRANSLATORS: C89m: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5 10. Nxe5 Nxe5 11. Rxe5 c6 12. d4 Bd6 13. Re1 Qh4
			variation => N__('Spanish: Marshall, Main Line, 13. Re1 Qh4'),
			moves => {
				'g2g3' => 1,
			},
		},
		'r1b2rk1/5ppp/p1pb4/1p1n4/3P3q/1BP3P1/PP3P1P/RNBQR1K1 b -' => {
			eco => 'C89m',
			# TRANSLATORS: C89m: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5 10. Nxe5 Nxe5 11. Rxe5 c6 12. d4 Bd6 13. Re1 Qh4 14. g3
			variation => N__('Spanish: Marshall, Main Line, 13. Re1 Qh4 14. g3'),
			moves => {
				'h4h3' => 1,
			},
		},
		'r1b2rk1/5ppp/p1pb4/1p1n4/3P4/1BP3Pq/PP3P1P/RNBQR1K1 w -' => {
			eco => 'C89n',
			# TRANSLATORS: C89n: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5 10. Nxe5 Nxe5 11. Rxe5 c6 12. d4 Bd6 13. Re1 Qh4 14. g3 Qh3
			variation => N__('Spanish: Marshall, Main Line, 14. g3 Qh3'),
			moves => {
				'c1e3' => 1,
				'e1e4' => 1,
			},
		},
		'r1b2rk1/5ppp/p1pb4/1p1n4/3PR3/1BP3Pq/PP3P1P/RNBQ2K1 b -' => {
			eco => 'C89o',
			# TRANSLATORS: C89o: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5 10. Nxe5 Nxe5 11. Rxe5 c6 12. d4 Bd6 13. Re1 Qh4 14. g3 Qh3 15. Re4
			variation => N__('Spanish: Marshall, Main Line, 15. Re4'),
			moves => {
			},
		},
		'r1b2rk1/5ppp/p1pb4/1p1n4/3P4/1BP1B1Pq/PP3P1P/RN1QR1K1 b -' => {
			eco => 'C89p',
			# TRANSLATORS: C89p: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5 10. Nxe5 Nxe5 11. Rxe5 c6 12. d4 Bd6 13. Re1 Qh4 14. g3 Qh3 15. Be3
			variation => N__('Spanish: Marshall, Main Line, 15. Be3'),
			moves => {
				'c8g4' => 1,
			},
		},
		'r4rk1/5ppp/p1pb4/1p1n4/3P2b1/1BP1B1Pq/PP3P1P/RN1QR1K1 w -' => {
			eco => 'C89p',
			# TRANSLATORS: C89p: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5 10. Nxe5 Nxe5 11. Rxe5 c6 12. d4 Bd6 13. Re1 Qh4 14. g3 Qh3 15. Be3 Bg4
			variation => N__('Spanish: Marshall, Main Line, 15. Be3 Bg4'),
			moves => {
				'd1d3' => 1,
			},
		},
		'r4rk1/5ppp/p1pb4/1p1n4/3P2b1/1BPQB1Pq/PP3P1P/RN2R1K1 b -' => {
			eco => 'C89p',
			# TRANSLATORS: C89p: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5 10. Nxe5 Nxe5 11. Rxe5 c6 12. d4 Bd6 13. Re1 Qh4 14. g3 Qh3 15. Be3 Bg4 16. Qd3
			variation => N__('Spanish: Marshall, Main Line, 15. Be3 Bg4 16. Qd3'),
			moves => {
				'a8e8' => 1,
			},
		},
		'4rrk1/5ppp/p1pb4/1p1n4/3P2b1/1BPQB1Pq/PP3P1P/RN2R1K1 w -' => {
			eco => 'C89q',
			# TRANSLATORS: C89q: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5 10. Nxe5 Nxe5 11. Rxe5 c6 12. d4 Bd6 13. Re1 Qh4 14. g3 Qh3 15. Be3 Bg4 16. Qd3 Rae8
			variation => N__('Spanish: Marshall, Main Line, 15. Be3 Bg4 16. Qd3 Rae8'),
			moves => {
				'b1d2' => 1,
			},
		},
		'4rrk1/5ppp/p1pb4/1p1n4/3P2b1/1BPQB1Pq/PP1N1P1P/R3R1K1 b -' => {
			eco => 'C89q',
			# TRANSLATORS: C89q: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5 10. Nxe5 Nxe5 11. Rxe5 c6 12. d4 Bd6 13. Re1 Qh4 14. g3 Qh3 15. Be3 Bg4 16. Qd3 Rae8 17. Nd2
			variation => N__('Spanish: Marshall, Main Line, 16. Qd3 Rae8 17. Nd2'),
			moves => {
				'e8e6' => 1,
				'f7f5' => 1,
			},
		},
		'4rrk1/6pp/p1pb4/1p1n1p2/3P2b1/1BPQB1Pq/PP1N1P1P/R3R1K1 w -' => {
			eco => 'C89r',
			# TRANSLATORS: C89r: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5 10. Nxe5 Nxe5 11. Rxe5 c6 12. d4 Bd6 13. Re1 Qh4 14. g3 Qh3 15. Be3 Bg4 16. Qd3 Rae8 17. Nd2 f5
			variation => N__('Spanish: Marshall, Main Line, Pawn Push Variation'),
			moves => {
			},
		},
		'5rk1/5ppp/p1pbr3/1p1n4/3P2b1/1BPQB1Pq/PP1N1P1P/R3R1K1 w -' => {
			eco => 'C89s',
			# TRANSLATORS: C89s: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5 10. Nxe5 Nxe5 11. Rxe5 c6 12. d4 Bd6 13. Re1 Qh4 14. g3 Qh3 15. Be3 Bg4 16. Qd3 Rae8 17. Nd2 Re6
			variation => N__('Spanish: Marshall, Main Line, Classical Variation'),
			moves => {
				'a2a4' => 1,
				'b3d5' => 1,
				'c3c4' => 1,
				'd3f1' => 1,
			},
		},
		'5rk1/5ppp/p1pbr3/1p1n4/2PP2b1/1B1QB1Pq/PP1N1P1P/R3R1K1 b -' => {
			eco => 'C89t',
			# TRANSLATORS: C89t: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5 10. Nxe5 Nxe5 11. Rxe5 c6 12. d4 Bd6 13. Re1 Qh4 14. g3 Qh3 15. Be3 Bg4 16. Qd3 Rae8 17. Nd2 Re6 18. c4
			variation => N__('Spanish: Marshall, Main Line, Classical, 18. c4'),
			moves => {
			},
		},
		'5rk1/5ppp/p1pbr3/1p1B4/3P2b1/2PQB1Pq/PP1N1P1P/R3R1K1 b -' => {
			eco => 'C89u',
			# TRANSLATORS: C89u: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5 10. Nxe5 Nxe5 11. Rxe5 c6 12. d4 Bd6 13. Re1 Qh4 14. g3 Qh3 15. Be3 Bg4 16. Qd3 Rae8 17. Nd2 Re6 18. Bxd5
			variation => N__('Spanish: Marshall, Main Line, Classical, 18.Bxd5'),
			moves => {
			},
		},
		'5rk1/5ppp/p1pbr3/1p1n4/3P2b1/1BP1B1Pq/PP1N1P1P/R3RQK1 b -' => {
			eco => 'C89v',
			# TRANSLATORS: C89v: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5 10. Nxe5 Nxe5 11. Rxe5 c6 12. d4 Bd6 13. Re1 Qh4 14. g3 Qh3 15. Be3 Bg4 16. Qd3 Rae8 17. Nd2 Re6 18. Qf1
			variation => N__('Spanish: Marshall, Main Line, Classical, 18. Qf1'),
			moves => {
			},
		},
		'5rk1/5ppp/p1pbr3/1p1n4/P2P2b1/1BPQB1Pq/1P1N1P1P/R3R1K1 b -' => {
			eco => 'C89w',
			# TRANSLATORS: C89w: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5 10. Nxe5 Nxe5 11. Rxe5 c6 12. d4 Bd6 13. Re1 Qh4 14. g3 Qh3 15. Be3 Bg4 16. Qd3 Rae8 17. Nd2 Re6 18. a4
			variation => N__('Spanish: Marshall, Main Line, Classical, 18. a4'),
			moves => {
				'f7f5' => 1,
				'h3h5' => 1,
			},
		},
		'5rk1/5ppp/p1pbr3/1p1n3q/P2P2b1/1BPQB1P1/1P1N1P1P/R3R1K1 w -' => {
			eco => 'C89x',
			# TRANSLATORS: C89x: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5 10. Nxe5 Nxe5 11. Rxe5 c6 12. d4 Bd6 13. Re1 Qh4 14. g3 Qh3 15. Be3 Bg4 16. Qd3 Rae8 17. Nd2 Re6 18. a4 Qh5
			variation => N__('Spanish: Marshall, Main Line, Classical, Spassky Variation'),
			moves => {
			},
		},
		'5rk1/6pp/p1pbr3/1p1n1p2/P2P2b1/1BPQB1Pq/1P1N1P1P/R3R1K1 w -' => {
			eco => 'C89y',
			# TRANSLATORS: C89y: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d5 9. exd5 Nxd5 10. Nxe5 Nxe5 11. Rxe5 c6 12. d4 Bd6 13. Re1 Qh4 14. g3 Qh3 15. Be3 Bg4 16. Qd3 Rae8 17. Nd2 Re6 18. a4 f5
			variation => N__('Spanish: Marshall, Main Line, Classical, 18. a4 f5'),
			moves => {
			},
		},
		'r1bq1rk1/2p1bppp/p1np1n2/1p2p3/4P3/1BP2N2/PP1P1PPP/RNBQR1K1 w -' => {
			eco => 'C90a',
			# TRANSLATORS: C90a: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6
			variation => N__('Spanish: Closed, 8... d6'),
			moves => {
				'a2a3' => 1,
				'a2a4' => 1,
				'b3c2' => 1,
				'd2d3' => 1,
				'd2d4' => 1,
				'h2h3' => 1,
			},
		},
		'r1bq1rk1/2p1bppp/p1np1n2/1p2p3/4P3/2P2N2/PPBP1PPP/RNBQR1K1 b -' => {
			eco => 'C90b',
			# TRANSLATORS: C90b: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. Bc2
			variation => N__('Spanish: Closed, Lutikov Variation'),
			moves => {
			},
		},
		'r1bq1rk1/2p1bppp/p1np1n2/1p2p3/4P3/PBP2N2/1P1P1PPP/RNBQR1K1 b -' => {
			eco => 'C90c',
			# TRANSLATORS: C90c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. a3
			variation => N__('Spanish: Closed, Suetin Variation'),
			moves => {
			},
		},
		'r1bq1rk1/2p1bppp/p1np1n2/1p2p3/P3P3/1BP2N2/1P1P1PPP/RNBQR1K1 b -' => {
			eco => 'C90d',
			# TRANSLATORS: C90d: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. a4
			variation => N__('Spanish: Closed, 8... d6 9. a4'),
			moves => {
				'c8g4' => 1,
			},
		},
		'r2q1rk1/2p1bppp/p1np1n2/1p2p3/P3P1b1/1BP2N2/1P1P1PPP/RNBQR1K1 w -' => {
			eco => 'C90d',
			# TRANSLATORS: C90d: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. a4 Bg4
			variation => N__('Spanish: Closed, 8... d6 9. a4 Bg4'),
			moves => {
			},
		},
		'r1bq1rk1/2p1bppp/p1np1n2/1p2p3/4P3/1BPP1N2/PP3PPP/RNBQR1K1 b -' => {
			eco => 'C90e',
			# TRANSLATORS: C90e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. d3
			variation => N__('Spanish: Closed, Pilnik Variation'),
			moves => {
				'c6a5' => 1,
				'h7h6' => 1,
			},
		},
		'r1bq1rk1/2p1bpp1/p1np1n1p/1p2p3/4P3/1BPP1N2/PP3PPP/RNBQR1K1 w -' => {
			eco => 'C90f',
			# TRANSLATORS: C90f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. d3 h6
			variation => N__('Spanish: Closed, Pilnik, 9... h6'),
			moves => {
			},
		},
		'r1bq1rk1/2p1bppp/p2p1n2/np2p3/4P3/1BPP1N2/PP3PPP/RNBQR1K1 w -' => {
			eco => 'C90g',
			# TRANSLATORS: C90g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. d3 Na5
			variation => N__('Spanish: Closed, Pilnik, 9... Na5'),
			moves => {
				'b3c2' => 1,
			},
		},
		'r1bq1rk1/2p1bppp/p2p1n2/np2p3/4P3/2PP1N2/PPB2PPP/RNBQR1K1 b -' => {
			eco => 'C90g',
			# TRANSLATORS: C90g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. d3 Na5 10. Bc2
			variation => N__('Spanish: Closed, Pilnik, 9... Na5'),
			moves => {
				'c7c5' => 1,
			},
		},
		'r1bq1rk1/4bppp/p2p1n2/npp1p3/4P3/2PP1N2/PPB2PPP/RNBQR1K1 w -' => {
			eco => 'C90g',
			# TRANSLATORS: C90g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. d3 Na5 10. Bc2 c5
			variation => N__('Spanish: Closed, Pilnik, 9... Na5'),
			moves => {
				'b1d2' => 1,
			},
		},
		'r1bq1rk1/4bppp/p2p1n2/npp1p3/4P3/2PP1N2/PPBN1PPP/R1BQR1K1 b -' => {
			eco => 'C90h',
			# TRANSLATORS: C90h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. d3 Na5 10. Bc2 c5 11. Nbd2
			variation => N__('Spanish: Closed, Pilnik, 11.Nbd2'),
			moves => {
				'a5c6' => 1,
				'd8c7' => 1,
				'f8e8' => 1,
			},
		},
		'r1b2rk1/2q1bppp/p2p1n2/npp1p3/4P3/2PP1N2/PPBN1PPP/R1BQR1K1 w -' => {
			eco => 'C90i',
			# TRANSLATORS: C90i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. d3 Na5 10. Bc2 c5 11. Nbd2 Qc7
			variation => N__('Spanish: Closed, Pilnik, 11.Nbd2 Qc7'),
			moves => {
			},
		},
		'r1bq1rk1/4bppp/p1np1n2/1pp1p3/4P3/2PP1N2/PPBN1PPP/R1BQR1K1 w -' => {
			eco => 'C90j',
			# TRANSLATORS: C90j: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. d3 Na5 10. Bc2 c5 11. Nbd2 Nc6
			variation => N__('Spanish: Closed, Pilnik, 11.Nbd2 Nc6'),
			moves => {
			},
		},
		'r1bqr1k1/4bppp/p2p1n2/npp1p3/4P3/2PP1N2/PPBN1PPP/R1BQR1K1 w -' => {
			eco => 'C90k',
			# TRANSLATORS: C90k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. d3 Na5 10. Bc2 c5 11. Nbd2 Re8
			variation => N__('Spanish: Closed, Pilnik, 11.Nbd2 Re8'),
			moves => {
				'd2f1' => 1,
			},
		},
		'r1bqr1k1/4bppp/p2p1n2/npp1p3/4P3/2PP1N2/PPB2PPP/R1BQRNK1 b -' => {
			eco => 'C90k',
			# TRANSLATORS: C90k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. d3 Na5 10. Bc2 c5 11. Nbd2 Re8 12. Nf1
			variation => N__('Spanish: Closed, Pilnik, 12. Nf1'),
			moves => {
				'a5c6' => 1,
				'e7f8' => 1,
				'h7h6' => 1,
			},
		},
		'r1bqr1k1/4bppp/p1np1n2/1pp1p3/4P3/2PP1N2/PPB2PPP/R1BQRNK1 w -' => {
			eco => 'C90l',
			# TRANSLATORS: C90l: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. d3 Na5 10. Bc2 c5 11. Nbd2 Re8 12. Nf1 Nc6
			variation => N__('Spanish: Closed, Pilnik, 12. Nf1 Nc6'),
			moves => {
			},
		},
		'r1bqrbk1/5ppp/p2p1n2/npp1p3/4P3/2PP1N2/PPB2PPP/R1BQRNK1 w -' => {
			eco => 'C90m',
			# TRANSLATORS: C90m: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. d3 Na5 10. Bc2 c5 11. Nbd2 Re8 12. Nf1 Bf8
			variation => N__('Spanish: Closed, Pilnik, 12. Nf1 Bf8'),
			moves => {
			},
		},
		'r1bqr1k1/4bpp1/p2p1n1p/npp1p3/4P3/2PP1N2/PPB2PPP/R1BQRNK1 w -' => {
			eco => 'C90n',
			# TRANSLATORS: C90n: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. d3 Na5 10. Bc2 c5 11. Nbd2 Re8 12. Nf1 h6
			variation => N__('Spanish: Closed, Pilnik, 12. Nf1 h6'),
			moves => {
			},
		},
		'r1bq1rk1/2p1bppp/p1np1n2/1p2p3/3PP3/1BP2N2/PP3PPP/RNBQR1K1 b -' => {
			eco => 'C91a',
			# TRANSLATORS: C91a: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. d4
			variation => N__('Spanish: Closed, 9. d4'),
			moves => {
				'c8g4' => 1,
			},
		},
		'r2q1rk1/2p1bppp/p1np1n2/1p2p3/3PP1b1/1BP2N2/PP3PPP/RNBQR1K1 w -' => {
			eco => 'C91b',
			# TRANSLATORS: C91b: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. d4 Bg4
			variation => N__('Spanish: Closed, Bogoljubow Variation'),
			moves => {
				'c1e3' => 1,
				'd4d5' => 1,
			},
		},
		'r2q1rk1/2p1bppp/p1np1n2/1p2p3/3PP1b1/1BP1BN2/PP3PPP/RN1QR1K1 b -' => {
			eco => 'C91c',
			# TRANSLATORS: C91c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. d4 Bg4 10. Be3
			variation => N__('Spanish: Closed, Bogoljubow, 10. Be3'),
			moves => {
				'e5d4' => 1,
			},
		},
		'r2q1rk1/2p1bppp/p1np1n2/1p6/3pP1b1/1BP1BN2/PP3PPP/RN1QR1K1 w -' => {
			eco => 'C91d',
			# TRANSLATORS: C91d: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. d4 Bg4 10. Be3 exd4
			variation => N__('Spanish: Closed, Bogoljubow, 10. Be3 exd4'),
			moves => {
			},
		},
		'r2q1rk1/2p1bppp/p1np1n2/1p1Pp3/4P1b1/1BP2N2/PP3PPP/RNBQR1K1 b -' => {
			eco => 'C91e',
			# TRANSLATORS: C91e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. d4 Bg4 10. d5
			variation => N__('Spanish: Closed, Bogoljubow, 10. d5'),
			moves => {
				'c6a5' => 1,
			},
		},
		'r2q1rk1/2p1bppp/p2p1n2/np1Pp3/4P1b1/1BP2N2/PP3PPP/RNBQR1K1 w -' => {
			eco => 'C91f',
			# TRANSLATORS: C91f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. d4 Bg4 10. d5 Na5
			variation => N__('Spanish: Closed, Bogoljubow, 10. d5 Na5'),
			moves => {
				'b3c2' => 1,
			},
		},
		'r2q1rk1/2p1bppp/p2p1n2/np1Pp3/4P1b1/2P2N2/PPB2PPP/RNBQR1K1 b -' => {
			eco => 'C91f',
			# TRANSLATORS: C91f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. d4 Bg4 10. d5 Na5 11. Bc2
			variation => N__('Spanish: Closed, Bogoljubow, 10. d5 Na5'),
			moves => {
				'c7c6' => 1,
				'd8c8' => 1,
			},
		},
		'r1q2rk1/2p1bppp/p2p1n2/np1Pp3/4P1b1/2P2N2/PPB2PPP/RNBQR1K1 w -' => {
			eco => 'C91g',
			# TRANSLATORS: C91g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. d4 Bg4 10. d5 Na5 11. Bc2 Qc8
			variation => N__('Spanish: Closed, Bogoljubow, 10. d5 Na5 11. Bc2 Qc8'),
			moves => {
			},
		},
		'r2q1rk1/4bppp/p1pp1n2/np1Pp3/4P1b1/2P2N2/PPB2PPP/RNBQR1K1 w -' => {
			eco => 'C91h',
			# TRANSLATORS: C91h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. d4 Bg4 10. d5 Na5 11. Bc2 c6
			variation => N__('Spanish: Closed, Bogoljubow, 10. d5 Na5 11. Bc2 c6'),
			moves => {
				'h2h3' => 1,
			},
		},
		'r2q1rk1/4bppp/p1pp1n2/np1Pp3/4P1b1/2P2N1P/PPB2PP1/RNBQR1K1 b -' => {
			eco => 'C91h',
			# TRANSLATORS: C91h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. d4 Bg4 10. d5 Na5 11. Bc2 c6 12. h3
			variation => N__('Spanish: Closed, Bogoljubow, 10. d5 Na5 11. Bc2 c6'),
			moves => {
				'g4c8' => 1,
			},
		},
		'r1bq1rk1/4bppp/p1pp1n2/np1Pp3/4P3/2P2N1P/PPB2PP1/RNBQR1K1 w -' => {
			eco => 'C91i',
			# TRANSLATORS: C91i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. d4 Bg4 10. d5 Na5 11. Bc2 c6 12. h3 Bc8
			variation => N__('Spanish: Closed, Bogoljubow, 10. d5 Na5 11. Bc2 c6 12. h3 Bc8'),
			moves => {
			},
		},
		'r1bq1rk1/2p1bppp/p1np1n2/1p2p3/4P3/1BP2N1P/PP1P1PP1/RNBQR1K1 b -' => {
			eco => 'C92a',
			# TRANSLATORS: C92a: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3
			variation => N__('Spanish: Closed, 9. h3'),
			moves => {
				'a6a5' => 1,
				'c6a5' => 1,
				'c6b8' => 1,
				'c8b7' => 1,
				'c8e6' => 1,
				'f6d7' => 1,
				'h7h6' => 1,
			},
		},
		'r1bq1rk1/2p1bppp/2np1n2/pp2p3/4P3/1BP2N1P/PP1P1PP1/RNBQR1K1 w -' => {
			eco => 'C92b',
			# TRANSLATORS: C92b: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 a5
			variation => N__('Spanish: Closed, Keres Variation'),
			moves => {
			},
		},
		'r2q1rk1/2p1bppp/p1npbn2/1p2p3/4P3/1BP2N1P/PP1P1PP1/RNBQR1K1 w -' => {
			eco => 'C92c',
			# TRANSLATORS: C92c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Be6
			variation => N__('Spanish: Closed, Kholmov Variation'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r2q1rk1/2p1bppp/p1npbn2/1p2p3/3PP3/1BP2N1P/PP3PP1/RNBQR1K1 b -' => {
			eco => 'C92c',
			# TRANSLATORS: C92c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Be6 10. d4
			variation => N__('Spanish: Closed, Kholmov Variation'),
			moves => {
				'e6b3' => 1,
			},
		},
		'r2q1rk1/2p1bppp/p1np1n2/1p2p3/3PP3/1bP2N1P/PP3PP1/RNBQR1K1 w -' => {
			eco => 'C92c',
			# TRANSLATORS: C92c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Be6 10. d4 Bxb3
			variation => N__('Spanish: Closed, Kholmov Variation'),
			moves => {
				'd1b3' => 1,
			},
		},
		'r2q1rk1/2p1bppp/p1np1n2/1p2p3/3PP3/1QP2N1P/PP3PP1/RNB1R1K1 b -' => {
			eco => 'C92d',
			# TRANSLATORS: C92d: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Be6 10. d4 Bxb3 11. Qxb3
			variation => N__('Spanish: Closed, Kholmov, 11.Qxb3'),
			moves => {
			},
		},
		'r1bq1rk1/2pnbppp/p1np4/1p2p3/4P3/1BP2N1P/PP1P1PP1/RNBQR1K1 w -' => {
			eco => 'C92e',
			# TRANSLATORS: C92e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nd7
			variation => N__('Spanish: Closed, Karpov Variation'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bq1rk1/2pnbppp/p1np4/1p2p3/3PP3/1BP2N1P/PP3PP1/RNBQR1K1 b -' => {
			eco => 'C92e',
			# TRANSLATORS: C92e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nd7 10. d4
			variation => N__('Spanish: Closed, Karpov Variation'),
			moves => {
				'e7f6' => 1,
			},
		},
		'r1bq1rk1/2pn1ppp/p1np1b2/1p2p3/3PP3/1BP2N1P/PP3PP1/RNBQR1K1 w -' => {
			eco => 'C92f',
			# TRANSLATORS: C92f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nd7 10. d4 Bf6
			variation => N__('Spanish: Closed, Karpov Variation, 10. d4 Bf6'),
			moves => {
				'a2a4' => 1,
			},
		},
		'r1bq1rk1/2pn1ppp/p1np1b2/1p2p3/P2PP3/1BP2N1P/1P3PP1/RNBQR1K1 b -' => {
			eco => 'C92g',
			# TRANSLATORS: C92g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nd7 10. d4 Bf6 11. a4
			variation => N__('Spanish: Closed, Karpov Variation, 10. d4 Bf6 11. a4'),
			moves => {
				'c8b7' => 1,
			},
		},
		'r2q1rk1/1bpn1ppp/p1np1b2/1p2p3/P2PP3/1BP2N1P/1P3PP1/RNBQR1K1 w -' => {
			eco => 'C92g',
			# TRANSLATORS: C92g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nd7 10. d4 Bf6 11. a4 Bb7
			variation => N__('Spanish: Closed, Karpov Variation, 10. d4 Bf6 11. a4'),
			moves => {
				'b1a3' => 1,
			},
		},
		'r2q1rk1/1bpn1ppp/p1np1b2/1p2p3/P2PP3/NBP2N1P/1P3PP1/R1BQR1K1 b -' => {
			eco => 'C92h',
			# TRANSLATORS: C92h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nd7 10. d4 Bf6 11. a4 Bb7 12. Na3
			variation => N__('Spanish: Closed, Karpov Variation, 10. d4 Bf6 11. a4 Bb7 12. Na3'),
			moves => {
			},
		},
		'r2q1rk1/1bp1bppp/p1np1n2/1p2p3/4P3/1BP2N1P/PP1P1PP1/RNBQR1K1 w -' => {
			eco => 'C92i',
			# TRANSLATORS: C92i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Bb7
			variation => N__('Spanish: Closed, Zaitsev (Flohr) Variation'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r2q1rk1/1bp1bppp/p1np1n2/1p2p3/3PP3/1BP2N1P/PP3PP1/RNBQR1K1 b -' => {
			eco => 'C92j',
			# TRANSLATORS: C92j: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Bb7 10. d4
			variation => N__('Spanish: Closed, Zaitsev, 10. d4'),
			moves => {
				'f8e8' => 1,
			},
		},
		'r2qr1k1/1bp1bppp/p1np1n2/1p2p3/3PP3/1BP2N1P/PP3PP1/RNBQR1K1 w -' => {
			eco => 'C92k',
			# TRANSLATORS: C92k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Bb7 10. d4 Re8
			variation => N__('Spanish: Closed, Zaitsev, 10. d4 Re8'),
			moves => {
				'b1d2' => 1,
				'f3g5' => 1,
			},
		},
		'r2qr1k1/1bp1bppp/p1np1n2/1p2p1N1/3PP3/1BP4P/PP3PP1/RNBQR1K1 b -' => {
			eco => 'C92l',
			# TRANSLATORS: C92l: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Bb7 10. d4 Re8 11. Ng5
			variation => N__('Spanish: Closed, Zaitsev, 11. Ng5'),
			moves => {
			},
		},
		'r2qr1k1/1bp1bppp/p1np1n2/1p2p3/3PP3/1BP2N1P/PP1N1PP1/R1BQR1K1 b -' => {
			eco => 'C92m',
			# TRANSLATORS: C92m: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Bb7 10. d4 Re8 11. Nbd2
			variation => N__('Spanish: Closed, Zaitsev, 11.Nbd2'),
			moves => {
				'e7f8' => 1,
			},
		},
		'r2qrbk1/1bp2ppp/p1np1n2/1p2p3/3PP3/1BP2N1P/PP1N1PP1/R1BQR1K1 w -' => {
			eco => 'C92m',
			# TRANSLATORS: C92m: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Bb7 10. d4 Re8 11. Nbd2 Bf8
			variation => N__('Spanish: Closed, Zaitsev, 11.Nbd2'),
			moves => {
				'a2a3' => 1,
				'a2a4' => 1,
				'b3c2' => 1,
				'd4d5' => 1,
			},
		},
		'r2qrbk1/1bp2ppp/p1np1n2/1p1Pp3/4P3/1BP2N1P/PP1N1PP1/R1BQR1K1 b -' => {
			eco => 'C92m',
			# TRANSLATORS: C92m: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Bb7 10. d4 Re8 11. Nbd2 Bf8 12. d5
			variation => N__('Spanish: Closed, Zaitsev, 11.Nbd2'),
			moves => {
				'c6b8' => 1,
			},
		},
		'rn1qrbk1/1bp2ppp/p2p1n2/1p1Pp3/4P3/1BP2N1P/PP1N1PP1/R1BQR1K1 w -' => {
			eco => 'C92n',
			# TRANSLATORS: C92n: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Bb7 10. d4 Re8 11. Nbd2 Bf8 12. d5 Nb8
			variation => N__('Spanish: Closed, Zaitsev, 11.Nbd2 Bf8 12. d5 Nb8'),
			moves => {
			},
		},
		'r2qrbk1/1bp2ppp/p1np1n2/1p2p3/3PP3/2P2N1P/PPBN1PP1/R1BQR1K1 b -' => {
			eco => 'C92o',
			# TRANSLATORS: C92o: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Bb7 10. d4 Re8 11. Nbd2 Bf8 12. Bc2
			variation => N__('Spanish: Closed, Zaitsev, 12. Bc2'),
			moves => {
			},
		},
		'r2qrbk1/1bp2ppp/p1np1n2/1p2p3/3PP3/PBP2N1P/1P1N1PP1/R1BQR1K1 b -' => {
			eco => 'C92p',
			# TRANSLATORS: C92p: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Bb7 10. d4 Re8 11. Nbd2 Bf8 12. a3
			variation => N__('Spanish: Closed, Zaitsev, 12. a3'),
			moves => {
			},
		},
		'r2qrbk1/1bp2ppp/p1np1n2/1p2p3/P2PP3/1BP2N1P/1P1N1PP1/R1BQR1K1 b -' => {
			eco => 'C92q',
			# TRANSLATORS: C92q: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Bb7 10. d4 Re8 11. Nbd2 Bf8 12. a4
			variation => N__('Spanish: Closed, Zaitsev, 12. a4'),
			moves => {
				'h7h6' => 1,
			},
		},
		'r2qrbk1/1bp2pp1/p1np1n1p/1p2p3/P2PP3/1BP2N1P/1P1N1PP1/R1BQR1K1 w -' => {
			eco => 'C92r',
			# TRANSLATORS: C92r: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Bb7 10. d4 Re8 11. Nbd2 Bf8 12. a4 h6
			variation => N__('Spanish: Closed, Zaitsev, 12. a4 h6'),
			moves => {
				'b3c2' => 1,
			},
		},
		'r2qrbk1/1bp2pp1/p1np1n1p/1p2p3/P2PP3/2P2N1P/1PBN1PP1/R1BQR1K1 b -' => {
			eco => 'C92s',
			# TRANSLATORS: C92s: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Bb7 10. d4 Re8 11. Nbd2 Bf8 12. a4 h6 13. Bc2
			variation => N__('Spanish: Closed, Zaitsev, 12. a4 h6 13. Bc2'),
			moves => {
				'e5d4' => 1,
			},
		},
		'r2qrbk1/1bp2pp1/p1np1n1p/1p6/P2pP3/2P2N1P/1PBN1PP1/R1BQR1K1 w -' => {
			eco => 'C92t',
			# TRANSLATORS: C92t: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Bb7 10. d4 Re8 11. Nbd2 Bf8 12. a4 h6 13. Bc2 exd4
			variation => N__('Spanish: Closed, Zaitsev, 12. a4 h6 13. Bc2 exd4'),
			moves => {
				'c3d4' => 1,
			},
		},
		'r2qrbk1/1bp2pp1/p1np1n1p/1p6/P2PP3/5N1P/1PBN1PP1/R1BQR1K1 b -' => {
			eco => 'C92t',
			# TRANSLATORS: C92t: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Bb7 10. d4 Re8 11. Nbd2 Bf8 12. a4 h6 13. Bc2 exd4 14. cxd4
			variation => N__('Spanish: Closed, Zaitsev, 12. a4 h6 13. Bc2 exd4'),
			moves => {
				'c6b4' => 1,
			},
		},
		'r2qrbk1/1bp2pp1/p2p1n1p/1p6/Pn1PP3/5N1P/1PBN1PP1/R1BQR1K1 w -' => {
			eco => 'C92t',
			# TRANSLATORS: C92t: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Bb7 10. d4 Re8 11. Nbd2 Bf8 12. a4 h6 13. Bc2 exd4 14. cxd4 Nb4
			variation => N__('Spanish: Closed, Zaitsev, 12. a4 h6 13. Bc2 exd4'),
			moves => {
				'c2b1' => 1,
			},
		},
		'r2qrbk1/1bp2pp1/p2p1n1p/1p6/Pn1PP3/5N1P/1P1N1PP1/RBBQR1K1 b -' => {
			eco => 'C92t',
			# TRANSLATORS: C92t: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Bb7 10. d4 Re8 11. Nbd2 Bf8 12. a4 h6 13. Bc2 exd4 14. cxd4 Nb4 15. Bb1
			variation => N__('Spanish: Closed, Zaitsev, 12. a4 h6 13. Bc2 exd4'),
			moves => {
				'c7c5' => 1,
			},
		},
		'r2qrbk1/1b3pp1/p2p1n1p/1pp5/Pn1PP3/5N1P/1P1N1PP1/RBBQR1K1 w -' => {
			eco => 'C92u',
			# TRANSLATORS: C92u: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Bb7 10. d4 Re8 11. Nbd2 Bf8 12. a4 h6 13. Bc2 exd4 14. cxd4 Nb4 15. Bb1 c5
			variation => N__('Spanish: Closed, Zaitsev, 12. a4 h6 13. Bc2 exd4 14.cxd4 Nb4 15. Bb1 c5'),
			moves => {
			},
		},
		'r1bq1rk1/2p1bpp1/p1np1n1p/1p2p3/4P3/1BP2N1P/PP1P1PP1/RNBQR1K1 w -' => {
			eco => 'C93',
			# TRANSLATORS: C93: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 h6
			variation => N__('Spanish: Closed, Smyslov Defence'),
			moves => {
				'd2d3' => 1,
				'd2d4' => 1,
			},
		},
		'r1bq1rk1/2p1bpp1/p1np1n1p/1p2p3/4P3/1BPP1N1P/PP3PP1/RNBQR1K1 b -' => {
			eco => 'C93',
			# TRANSLATORS: C93: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 h6 10. d3
			variation => N__('Spanish: Closed, Smyslov, 10. d3'),
			moves => {
			},
		},
		'r1bq1rk1/2p1bpp1/p1np1n1p/1p2p3/3PP3/1BP2N1P/PP3PP1/RNBQR1K1 b -' => {
			eco => 'C93',
			# TRANSLATORS: C93: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 h6 10. d4
			variation => N__('Spanish: Closed, Smyslov, 10. d4'),
			moves => {
				'f8e8' => 1,
			},
		},
		'r1bqr1k1/2p1bpp1/p1np1n1p/1p2p3/3PP3/1BP2N1P/PP3PP1/RNBQR1K1 w -' => {
			eco => 'C93',
			# TRANSLATORS: C93: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 h6 10. d4 Re8
			variation => N__('Spanish: Closed, Smyslov, 10. d4 Re8'),
			moves => {
				'a2a4' => 1,
				'b1d2' => 1,
				'c1e3' => 1,
			},
		},
		'r1bqr1k1/2p1bpp1/p1np1n1p/1p2p3/P2PP3/1BP2N1P/1P3PP1/RNBQR1K1 b -' => {
			eco => 'C93',
			# TRANSLATORS: C93: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 h6 10. d4 Re8 11. a4
			variation => N__('Spanish: Closed, Smyslov, 10. d4 Re8 11. a4'),
			moves => {
			},
		},
		'r1bqr1k1/2p1bpp1/p1np1n1p/1p2p3/3PP3/1BP2N1P/PP1N1PP1/R1BQR1K1 b -' => {
			eco => 'C93',
			# TRANSLATORS: C93: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 h6 10. d4 Re8 11. Nbd2
			variation => N__('Spanish: Closed, Smyslov, 10. d4 Re8 11.Nbd2'),
			moves => {
				'e7f8' => 1,
			},
		},
		'r1bqrbk1/2p2pp1/p1np1n1p/1p2p3/3PP3/1BP2N1P/PP1N1PP1/R1BQR1K1 w -' => {
			eco => 'C93',
			# TRANSLATORS: C93: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 h6 10. d4 Re8 11. Nbd2 Bf8
			variation => N__('Spanish: Closed, Smyslov, 10. d4 Re8 11.Nbd2 Bf8'),
			moves => {
				'a2a3' => 1,
				'b3c2' => 1,
				'd2f1' => 1,
			},
		},
		'r1bqrbk1/2p2pp1/p1np1n1p/1p2p3/3PP3/PBP2N1P/1P1N1PP1/R1BQR1K1 b -' => {
			eco => 'C93',
			# TRANSLATORS: C93: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 h6 10. d4 Re8 11. Nbd2 Bf8 12. a3
			variation => N__('Spanish: Closed, Smyslov, 12. a3'),
			moves => {
			},
		},
		'r1bqrbk1/2p2pp1/p1np1n1p/1p2p3/3PP3/2P2N1P/PPBN1PP1/R1BQR1K1 b -' => {
			eco => 'C93',
			# TRANSLATORS: C93: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 h6 10. d4 Re8 11. Nbd2 Bf8 12. Bc2
			variation => N__('Spanish: Closed, Smyslov, 12. Bc2'),
			moves => {
			},
		},
		'r1bqrbk1/2p2pp1/p1np1n1p/1p2p3/3PP3/1BP2N1P/PP3PP1/R1BQRNK1 b -' => {
			eco => 'C93',
			# TRANSLATORS: C93: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 h6 10. d4 Re8 11. Nbd2 Bf8 12. Nf1
			variation => N__('Spanish: Closed, Smyslov, 12. Nf1'),
			moves => {
				'c8b7' => 1,
				'c8d7' => 1,
			},
		},
		'r2qrbk1/1bp2pp1/p1np1n1p/1p2p3/3PP3/1BP2N1P/PP3PP1/R1BQRNK1 w -' => {
			eco => 'C93',
			# TRANSLATORS: C93: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 h6 10. d4 Re8 11. Nbd2 Bf8 12. Nf1 Bb7
			variation => N__('Spanish: Closed, Smyslov, 12. Nf1 Bb7'),
			moves => {
				'f1g3' => 1,
			},
		},
		'r2qrbk1/1bp2pp1/p1np1n1p/1p2p3/3PP3/1BP2NNP/PP3PP1/R1BQR1K1 b -' => {
			eco => 'C93',
			# TRANSLATORS: C93: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 h6 10. d4 Re8 11. Nbd2 Bf8 12. Nf1 Bb7 13. Ng3
			variation => N__('Spanish: Closed, Smyslov, 12. Nf1 Bb7'),
			moves => {
				'c6a5' => 1,
			},
		},
		'r2qrbk1/1bp2pp1/p2p1n1p/np2p3/3PP3/1BP2NNP/PP3PP1/R1BQR1K1 w -' => {
			eco => 'C93',
			# TRANSLATORS: C93: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 h6 10. d4 Re8 11. Nbd2 Bf8 12. Nf1 Bb7 13. Ng3 Na5
			variation => N__('Spanish: Closed, Smyslov, 12. Nf1 Bb7'),
			moves => {
				'b3c2' => 1,
			},
		},
		'r2qrbk1/1bp2pp1/p2p1n1p/np2p3/3PP3/2P2NNP/PPB2PP1/R1BQR1K1 b -' => {
			eco => 'C93',
			# TRANSLATORS: C93: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 h6 10. d4 Re8 11. Nbd2 Bf8 12. Nf1 Bb7 13. Ng3 Na5 14. Bc2
			variation => N__('Spanish: Closed, Smyslov, 12. Nf1 Bb7'),
			moves => {
				'a5c4' => 1,
			},
		},
		'r2qrbk1/1bp2pp1/p2p1n1p/1p2p3/2nPP3/2P2NNP/PPB2PP1/R1BQR1K1 w -' => {
			eco => 'C93',
			# TRANSLATORS: C93: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 h6 10. d4 Re8 11. Nbd2 Bf8 12. Nf1 Bb7 13. Ng3 Na5 14. Bc2 Nc4
			variation => N__('Spanish: Closed, Smyslov, 12. Nf1 Bb7 13. Ng3 Na5 14. Bc2 Nc4'),
			moves => {
			},
		},
		'r2qrbk1/2pb1pp1/p1np1n1p/1p2p3/3PP3/1BP2N1P/PP3PP1/R1BQRNK1 w -' => {
			eco => 'C93',
			# TRANSLATORS: C93: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 h6 10. d4 Re8 11. Nbd2 Bf8 12. Nf1 Bd7
			variation => N__('Spanish: Closed, Smyslov, 12. Nf1 Bd7'),
			moves => {
				'f1g3' => 1,
			},
		},
		'r2qrbk1/2pb1pp1/p1np1n1p/1p2p3/3PP3/1BP2NNP/PP3PP1/R1BQR1K1 b -' => {
			eco => 'C93',
			# TRANSLATORS: C93: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 h6 10. d4 Re8 11. Nbd2 Bf8 12. Nf1 Bd7 13. Ng3
			variation => N__('Spanish: Closed, Smyslov, 12. Nf1 Bd7'),
			moves => {
				'c6a5' => 1,
			},
		},
		'r2qrbk1/2pb1pp1/p2p1n1p/np2p3/3PP3/1BP2NNP/PP3PP1/R1BQR1K1 w -' => {
			eco => 'C93',
			# TRANSLATORS: C93: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 h6 10. d4 Re8 11. Nbd2 Bf8 12. Nf1 Bd7 13. Ng3 Na5
			variation => N__('Spanish: Closed, Smyslov, 12. Nf1 Bd7'),
			moves => {
				'b3c2' => 1,
			},
		},
		'r2qrbk1/2pb1pp1/p2p1n1p/np2p3/3PP3/2P2NNP/PPB2PP1/R1BQR1K1 b -' => {
			eco => 'C93',
			# TRANSLATORS: C93: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 h6 10. d4 Re8 11. Nbd2 Bf8 12. Nf1 Bd7 13. Ng3 Na5 14. Bc2
			variation => N__('Spanish: Closed, Smyslov, 12. Nf1 Bd7'),
			moves => {
				'c7c5' => 1,
			},
		},
		'r2qrbk1/3b1pp1/p2p1n1p/npp1p3/3PP3/2P2NNP/PPB2PP1/R1BQR1K1 w -' => {
			eco => 'C93',
			# TRANSLATORS: C93: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 h6 10. d4 Re8 11. Nbd2 Bf8 12. Nf1 Bd7 13. Ng3 Na5 14. Bc2 c5
			variation => N__('Spanish: Closed, Smyslov, 12. Nf1 Bd7 13. Ng3 Na5 14. Bc2 c5'),
			moves => {
			},
		},
		'r1bqr1k1/2p1bpp1/p1np1n1p/1p2p3/3PP3/1BP1BN1P/PP3PP1/RN1QR1K1 b -' => {
			eco => 'C93',
			# TRANSLATORS: C93: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 h6 10. d4 Re8 11. Be3
			variation => N__('Spanish: Closed, Smyslov, 10. d4 Re8 11. Be3'),
			moves => {
			},
		},
		'rnbq1rk1/2p1bppp/p2p1n2/1p2p3/4P3/1BP2N1P/PP1P1PP1/RNBQR1K1 w -' => {
			eco => 'C94a',
			# TRANSLATORS: C94a: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nb8
			variation => N__('Spanish: Closed, Breyer Defence'),
			moves => {
				'a2a4' => 1,
				'd2d3' => 1,
				'd2d4' => 1,
			},
		},
		'rnbq1rk1/2p1bppp/p2p1n2/1p2p3/P3P3/1BP2N1P/1P1P1PP1/RNBQR1K1 b -' => {
			eco => 'C94b',
			# TRANSLATORS: C94b: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nb8 10. a4
			variation => N__('Spanish: Closed, Breyer, Matulovic Variation'),
			moves => {
			},
		},
		'rnbq1rk1/2p1bppp/p2p1n2/1p2p3/4P3/1BPP1N1P/PP3PP1/RNBQR1K1 b -' => {
			eco => 'C94c',
			# TRANSLATORS: C94c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nb8 10. d3
			variation => N__('Spanish: Closed, Breyer, 10. d3'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r1bq1rk1/2pnbppp/p2p1n2/1p2p3/4P3/1BPP1N1P/PP3PP1/RNBQR1K1 w -' => {
			eco => 'C94d',
			# TRANSLATORS: C94d: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nb8 10. d3 Nbd7
			variation => N__('Spanish: Closed, Breyer, 10. d3 Nbd7'),
			moves => {
				'b1d2' => 1,
			},
		},
		'r1bq1rk1/2pnbppp/p2p1n2/1p2p3/4P3/1BPP1N1P/PP1N1PP1/R1BQR1K1 b -' => {
			eco => 'C94e',
			# TRANSLATORS: C94e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nb8 10. d3 Nbd7 11. Nbd2
			variation => N__('Spanish: Closed, Breyer, 10. d3 Nbd7 11.Nbd2'),
			moves => {
				'c8b7' => 1,
			},
		},
		'r2q1rk1/1bpnbppp/p2p1n2/1p2p3/4P3/1BPP1N1P/PP1N1PP1/R1BQR1K1 w -' => {
			eco => 'C94f',
			# TRANSLATORS: C94f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nb8 10. d3 Nbd7 11. Nbd2 Bb7
			variation => N__('Spanish: Closed, Breyer, 10. d3 Nbd7 11.Nbd2 Bb7'),
			moves => {
			},
		},
		'rnbq1rk1/2p1bppp/p2p1n2/1p2p3/3PP3/1BP2N1P/PP3PP1/RNBQR1K1 b -' => {
			eco => 'C95a',
			# TRANSLATORS: C95a: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nb8 10. d4
			variation => N__('Spanish: Closed, Breyer, 10. d4'),
			moves => {
				'b8d7' => 1,
				'c8b7' => 1,
			},
		},
		'rn1q1rk1/1bp1bppp/p2p1n2/1p2p3/3PP3/1BP2N1P/PP3PP1/RNBQR1K1 w -' => {
			eco => 'C95a',
			# TRANSLATORS: C95a: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nb8 10. d4 Bb7
			variation => N__('Spanish: Closed, Breyer, 10. d4 Bb7'),
			moves => {
			},
		},
		'r1bq1rk1/2pnbppp/p2p1n2/1p2p3/3PP3/1BP2N1P/PP3PP1/RNBQR1K1 w -' => {
			eco => 'C95b',
			# TRANSLATORS: C95b: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nb8 10. d4 Nbd7
			variation => N__('Spanish: Closed, Breyer, 10. d4 Nbd7'),
			moves => {
				'b1d2' => 1,
				'c1g5' => 1,
				'c3c4' => 1,
				'f3h4' => 1,
			},
		},
		'r1bq1rk1/2pnbppp/p2p1n2/1p2p3/3PP2N/1BP4P/PP3PP1/RNBQR1K1 b -' => {
			eco => 'C95c',
			# TRANSLATORS: C95c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nb8 10. d4 Nbd7 11. Nh4
			variation => N__('Spanish: Closed, Breyer, Simagin Variation'),
			moves => {
			},
		},
		'r1bq1rk1/2pnbppp/p2p1n2/1p2p1B1/3PP3/1BP2N1P/PP3PP1/RN1QR1K1 b -' => {
			eco => 'C95d',
			# TRANSLATORS: C95d: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nb8 10. d4 Nbd7 11. Bg5
			variation => N__('Spanish: Closed, Breyer, 10. d4 Nbd7 11. Bg5'),
			moves => {
			},
		},
		'r1bq1rk1/2pnbppp/p2p1n2/1p2p3/2PPP3/1B3N1P/PP3PP1/RNBQR1K1 b -' => {
			eco => 'C95e',
			# TRANSLATORS: C95e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nb8 10. d4 Nbd7 11. c4
			variation => N__('Spanish: Closed, Breyer, Arseniev Variation'),
			moves => {
				'c7c6' => 1,
			},
		},
		'r1bq1rk1/3nbppp/p1pp1n2/1p2p3/2PPP3/1B3N1P/PP3PP1/RNBQR1K1 w -' => {
			eco => 'C95e',
			# TRANSLATORS: C95e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nb8 10. d4 Nbd7 11. c4 c6
			variation => N__('Spanish: Closed, Breyer, Arseniev, 11... c6'),
			moves => {
			},
		},
		'r1bq1rk1/2pnbppp/p2p1n2/1p2p3/3PP3/1BP2N1P/PP1N1PP1/R1BQR1K1 b -' => {
			eco => 'C95f',
			# TRANSLATORS: C95f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nb8 10. d4 Nbd7 11. Nbd2
			variation => N__('Spanish: Closed, Breyer, 10. d4 Nbd7 11.Nbd2'),
			moves => {
				'c8b7' => 1,
			},
		},
		'r2q1rk1/1bpnbppp/p2p1n2/1p2p3/3PP3/1BP2N1P/PP1N1PP1/R1BQR1K1 w -' => {
			eco => 'C95f',
			# TRANSLATORS: C95f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nb8 10. d4 Nbd7 11. Nbd2 Bb7
			variation => N__('Spanish: Closed, Breyer, 10. d4 Nbd7 11.Nbd2 Bb7'),
			moves => {
				'a2a4' => 1,
				'b3c2' => 1,
			},
		},
		'r2q1rk1/1bpnbppp/p2p1n2/1p2p3/P2PP3/1BP2N1P/1P1N1PP1/R1BQR1K1 b -' => {
			eco => 'C95f',
			# TRANSLATORS: C95f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nb8 10. d4 Nbd7 11. Nbd2 Bb7 12. a4
			variation => N__('Spanish: Closed, Breyer, 10. d4 Nbd7 11.Nbd2 Bb7 12. a4'),
			moves => {
			},
		},
		'r2q1rk1/1bpnbppp/p2p1n2/1p2p3/3PP3/2P2N1P/PPBN1PP1/R1BQR1K1 b -' => {
			eco => 'C95g',
			# TRANSLATORS: C95g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nb8 10. d4 Nbd7 11. Nbd2 Bb7 12. Bc2
			variation => N__('Spanish: Closed, Breyer, 10. d4 Nbd7 11.Nbd2 Bb7 12. Bc2'),
			moves => {
				'c7c5' => 1,
				'f8e8' => 1,
			},
		},
		'r2q1rk1/1b1nbppp/p2p1n2/1pp1p3/3PP3/2P2N1P/PPBN1PP1/R1BQR1K1 w -' => {
			eco => 'C95g',
			# TRANSLATORS: C95g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nb8 10. d4 Nbd7 11. Nbd2 Bb7 12. Bc2 c5
			variation => N__('Spanish: Closed, Breyer, Gligoric Variation'),
			moves => {
			},
		},
		'r2qr1k1/1bpnbppp/p2p1n2/1p2p3/3PP3/2P2N1P/PPBN1PP1/R1BQR1K1 w -' => {
			eco => 'C95h',
			# TRANSLATORS: C95h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nb8 10. d4 Nbd7 11. Nbd2 Bb7 12. Bc2 Re8
			variation => N__('Spanish: Closed, Breyer, Main Line'),
			moves => {
				'a2a4' => 1,
				'b2b4' => 1,
				'd2f1' => 1,
			},
		},
		'r2qr1k1/1bpnbppp/p2p1n2/1p2p3/1P1PP3/2P2N1P/P1BN1PP1/R1BQR1K1 b -' => {
			eco => 'C95i',
			# TRANSLATORS: C95i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nb8 10. d4 Nbd7 11. Nbd2 Bb7 12. Bc2 Re8 13. b4
			variation => N__('Spanish: Closed, Breyer, Main Line, 13. b4'),
			moves => {
			},
		},
		'r2qr1k1/1bpnbppp/p2p1n2/1p2p3/P2PP3/2P2N1P/1PBN1PP1/R1BQR1K1 b -' => {
			eco => 'C95j',
			# TRANSLATORS: C95j: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nb8 10. d4 Nbd7 11. Nbd2 Bb7 12. Bc2 Re8 13. a4
			variation => N__('Spanish: Closed, Breyer, Main Line, 13. a4'),
			moves => {
			},
		},
		'r2qr1k1/1bpnbppp/p2p1n2/1p2p3/3PP3/2P2N1P/PPB2PP1/R1BQRNK1 b -' => {
			eco => 'C95k',
			# TRANSLATORS: C95k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nb8 10. d4 Nbd7 11. Nbd2 Bb7 12. Bc2 Re8 13. Nf1
			variation => N__('Spanish: Closed, Breyer, Main Line, 13. Nf1'),
			moves => {
				'e7f8' => 1,
			},
		},
		'r2qrbk1/1bpn1ppp/p2p1n2/1p2p3/3PP3/2P2N1P/PPB2PP1/R1BQRNK1 w -' => {
			eco => 'C95k',
			# TRANSLATORS: C95k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nb8 10. d4 Nbd7 11. Nbd2 Bb7 12. Bc2 Re8 13. Nf1 Bf8
			variation => N__('Spanish: Closed, Breyer, Main Line, 13. Nf1 Bf8'),
			moves => {
				'f1g3' => 1,
			},
		},
		'r2qrbk1/1bpn1ppp/p2p1n2/1p2p3/3PP3/2P2NNP/PPB2PP1/R1BQR1K1 b -' => {
			eco => 'C95k',
			# TRANSLATORS: C95k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nb8 10. d4 Nbd7 11. Nbd2 Bb7 12. Bc2 Re8 13. Nf1 Bf8 14. Ng3
			variation => N__('Spanish: Closed, Breyer, Main Line, 13. Nf1 Bf8 14. Ng3'),
			moves => {
				'c7c5' => 1,
				'g7g6' => 1,
			},
		},
		'r2qrbk1/1b1n1ppp/p2p1n2/1pp1p3/3PP3/2P2NNP/PPB2PP1/R1BQR1K1 w -' => {
			eco => 'C95k',
			# TRANSLATORS: C95k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nb8 10. d4 Nbd7 11. Nbd2 Bb7 12. Bc2 Re8 13. Nf1 Bf8 14. Ng3 c5
			variation => N__('Spanish: Closed, Breyer, Main Line, 14. Ng3 c5'),
			moves => {
			},
		},
		'r2qrbk1/1bpn1p1p/p2p1np1/1p2p3/3PP3/2P2NNP/PPB2PP1/R1BQR1K1 w -' => {
			eco => 'C95l',
			# TRANSLATORS: C95l: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nb8 10. d4 Nbd7 11. Nbd2 Bb7 12. Bc2 Re8 13. Nf1 Bf8 14. Ng3 g6
			variation => N__('Spanish: Closed, Breyer, Main Line, 14. Ng3 g6'),
			moves => {
				'a2a4' => 1,
				'b2b3' => 1,
			},
		},
		'r2qrbk1/1bpn1p1p/p2p1np1/1p2p3/3PP3/1PP2NNP/P1B2PP1/R1BQR1K1 b -' => {
			eco => 'C95l',
			# TRANSLATORS: C95l: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nb8 10. d4 Nbd7 11. Nbd2 Bb7 12. Bc2 Re8 13. Nf1 Bf8 14. Ng3 g6 15. b3
			variation => N__('Spanish: Closed, Breyer, Main Line, 14. Ng3 g6 15. b3'),
			moves => {
			},
		},
		'r2qrbk1/1bpn1p1p/p2p1np1/1p2p3/P2PP3/2P2NNP/1PB2PP1/R1BQR1K1 b -' => {
			eco => 'C95m',
			# TRANSLATORS: C95m: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nb8 10. d4 Nbd7 11. Nbd2 Bb7 12. Bc2 Re8 13. Nf1 Bf8 14. Ng3 g6 15. a4
			variation => N__('Spanish: Closed, Breyer, Main Line, 14. Ng3 g6 15. a4'),
			moves => {
				'c7c5' => 1,
			},
		},
		'r2qrbk1/1b1n1p1p/p2p1np1/1pp1p3/P2PP3/2P2NNP/1PB2PP1/R1BQR1K1 w -' => {
			eco => 'C95n',
			# TRANSLATORS: C95n: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nb8 10. d4 Nbd7 11. Nbd2 Bb7 12. Bc2 Re8 13. Nf1 Bf8 14. Ng3 g6 15. a4 c5
			variation => N__('Spanish: Closed, Breyer, Main Line, 15. a4 c5'),
			moves => {
				'd4d5' => 1,
			},
		},
		'r2qrbk1/1b1n1p1p/p2p1np1/1ppPp3/P3P3/2P2NNP/1PB2PP1/R1BQR1K1 b -' => {
			eco => 'C95n',
			# TRANSLATORS: C95n: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nb8 10. d4 Nbd7 11. Nbd2 Bb7 12. Bc2 Re8 13. Nf1 Bf8 14. Ng3 g6 15. a4 c5 16. d5
			variation => N__('Spanish: Closed, Breyer, Main Line, 15. a4 c5'),
			moves => {
				'c5c4' => 1,
			},
		},
		'r2qrbk1/1b1n1p1p/p2p1np1/1p1Pp3/P1p1P3/2P2NNP/1PB2PP1/R1BQR1K1 w -' => {
			eco => 'C95o',
			# TRANSLATORS: C95o: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Nb8 10. d4 Nbd7 11. Nbd2 Bb7 12. Bc2 Re8 13. Nf1 Bf8 14. Ng3 g6 15. a4 c5 16. d5 c4
			variation => N__('Spanish: Closed, Breyer, Main Line, 15. a4 c5 16. d5 c4'),
			moves => {
			},
		},
		'r1bq1rk1/2p1bppp/p2p1n2/np2p3/4P3/1BP2N1P/PP1P1PP1/RNBQR1K1 w -' => {
			eco => 'C96a',
			# TRANSLATORS: C96a: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5
			variation => N__('Spanish: Closed, Chigorin'),
			moves => {
				'b3c2' => 1,
			},
		},
		'r1bq1rk1/2p1bppp/p2p1n2/np2p3/4P3/2P2N1P/PPBP1PP1/RNBQR1K1 b -' => {
			eco => 'C96b',
			# TRANSLATORS: C96b: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2
			variation => N__('Spanish: Closed, Chigorin, 10. Bc2'),
			moves => {
				'c7c5' => 1,
				'c7c6' => 1,
				'c8b7' => 1,
			},
		},
		'r1bq1rk1/4bppp/p1pp1n2/np2p3/4P3/2P2N1P/PPBP1PP1/RNBQR1K1 w -' => {
			eco => 'C96c',
			# TRANSLATORS: C96c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c6
			variation => N__('Spanish: Closed, Chigorin, 10... c6'),
			moves => {
				'd2d4' => 1,
			},
		},
		'r1bq1rk1/4bppp/p1pp1n2/np2p3/3PP3/2P2N1P/PPB2PP1/RNBQR1K1 b -' => {
			eco => 'C96c',
			# TRANSLATORS: C96c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c6 11. d4
			variation => N__('Spanish: Closed, Chigorin, 10... c6'),
			moves => {
				'd8c7' => 1,
			},
		},
		'r1b2rk1/2q1bppp/p1pp1n2/np2p3/3PP3/2P2N1P/PPB2PP1/RNBQR1K1 w -' => {
			eco => 'C96d',
			# TRANSLATORS: C96d: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c6 11. d4 Qc7
			variation => N__('Spanish: Closed, Chigorin, Rossolimo Variation'),
			moves => {
			},
		},
		'r2q1rk1/1bp1bppp/p2p1n2/np2p3/4P3/2P2N1P/PPBP1PP1/RNBQR1K1 w -' => {
			eco => 'C96e',
			# TRANSLATORS: C96e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 Bb7
			variation => N__('Spanish: Closed, Chigorin, 10... Bb7'),
			moves => {
			},
		},
		'r1bq1rk1/4bppp/p2p1n2/npp1p3/4P3/2P2N1P/PPBP1PP1/RNBQR1K1 w -' => {
			eco => 'C96f',
			# TRANSLATORS: C96f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5
			variation => N__('Spanish: Closed, Chigorin, 10... c5'),
			moves => {
				'd2d3' => 1,
				'd2d4' => 1,
			},
		},
		'r1bq1rk1/4bppp/p2p1n2/npp1p3/4P3/2PP1N1P/PPB2PP1/RNBQR1K1 b -' => {
			eco => 'C96g',
			# TRANSLATORS: C96g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d3
			variation => N__('Spanish: Closed, Chigorin, 11. d3'),
			moves => {
				'a5c6' => 1,
			},
		},
		'r1bq1rk1/4bppp/p1np1n2/1pp1p3/4P3/2PP1N1P/PPB2PP1/RNBQR1K1 w -' => {
			eco => 'C96h',
			# TRANSLATORS: C96h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d3 Nc6
			variation => N__('Spanish: Closed, Chigorin, 11. d3 Nc6'),
			moves => {
			},
		},
		'r1bq1rk1/4bppp/p2p1n2/npp1p3/3PP3/2P2N1P/PPB2PP1/RNBQR1K1 b -' => {
			eco => 'C96i',
			# TRANSLATORS: C96i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4
			variation => N__('Spanish: Closed, Chigorin, 11. d4'),
			moves => {
				'a5c6' => 1,
				'c5d4' => 1,
				'c8b7' => 1,
				'd8c7' => 1,
				'f6d7' => 1,
			},
		},
		'r1bq1rk1/4bppp/p2p1n2/np2p3/3pP3/2P2N1P/PPB2PP1/RNBQR1K1 w -' => {
			eco => 'C96j',
			# TRANSLATORS: C96j: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 cxd4
			variation => N__('Spanish: Closed, Chigorin, 11. d4 cxd4'),
			moves => {
			},
		},
		'r2q1rk1/1b2bppp/p2p1n2/npp1p3/3PP3/2P2N1P/PPB2PP1/RNBQR1K1 w -' => {
			eco => 'C96k',
			# TRANSLATORS: C96k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Bb7
			variation => N__('Spanish: Closed, Chigorin, 11. d4 Bb7'),
			moves => {
				'b1d2' => 1,
			},
		},
		'r2q1rk1/1b2bppp/p2p1n2/npp1p3/3PP3/2P2N1P/PPBN1PP1/R1BQR1K1 b -' => {
			eco => 'C96l',
			# TRANSLATORS: C96l: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Bb7 12. Nbd2
			variation => N__('Spanish: Closed, Chigorin, 11. d4 Bb7 12.Nbd2'),
			moves => {
			},
		},
		'r1bq1rk1/4bppp/p1np1n2/1pp1p3/3PP3/2P2N1P/PPB2PP1/RNBQR1K1 w -' => {
			eco => 'C96m',
			# TRANSLATORS: C96m: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Nc6
			variation => N__('Spanish: Closed, Chigorin, Borisenko Variation'),
			moves => {
			},
		},
		'r1bq1rk1/3nbppp/p2p4/npp1p3/3PP3/2P2N1P/PPB2PP1/RNBQR1K1 w -' => {
			eco => 'C96n',
			# TRANSLATORS: C96n: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Nd7
			variation => N__('Spanish: Closed, Chigorin, Keres Variation'),
			moves => {
				'b1d2' => 1,
			},
		},
		'r1bq1rk1/3nbppp/p2p4/npp1p3/3PP3/2P2N1P/PPBN1PP1/R1BQR1K1 b -' => {
			eco => 'C96n',
			# TRANSLATORS: C96n: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Nd7 12. Nbd2
			variation => N__('Spanish: Closed, Chigorin, Keres Variation'),
			moves => {
				'c5d4' => 1,
			},
		},
		'r1bq1rk1/3nbppp/p2p4/np2p3/3pP3/2P2N1P/PPBN1PP1/R1BQR1K1 w -' => {
			eco => 'C96o',
			# TRANSLATORS: C96o: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Nd7 12. Nbd2 cxd4
			variation => N__('Spanish: Closed, Chigorin, Keres, 11.Nbd2 cxd4'),
			moves => {
			},
		},
		'r1b2rk1/2q1bppp/p2p1n2/npp1p3/3PP3/2P2N1P/PPB2PP1/RNBQR1K1 w -' => {
			eco => 'C97a',
			# TRANSLATORS: C97a: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7
			variation => N__('Spanish: Closed, Chigorin, 11. d4 Qc7'),
			moves => {
				'b1d2' => 1,
				'd4d5' => 1,
			},
		},
		'r1b2rk1/2q1bppp/p2p1n2/nppPp3/4P3/2P2N1P/PPB2PP1/RNBQR1K1 b -' => {
			eco => 'C97b',
			# TRANSLATORS: C97b: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. d5
			variation => N__('Spanish: Closed, Chigorin, 11. d4 Qc7 12. d5'),
			moves => {
				'c5c4' => 1,
			},
		},
		'r1b2rk1/2q1bppp/p2p1n2/np1Pp3/2p1P3/2P2N1P/PPB2PP1/RNBQR1K1 w -' => {
			eco => 'C97c',
			# TRANSLATORS: C97c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. d5 c4
			variation => N__('Spanish: Closed, Chigorin, 11. d4 Qc7 12. d5 c4'),
			moves => {
			},
		},
		'r1b2rk1/2q1bppp/p2p1n2/npp1p3/3PP3/2P2N1P/PPBN1PP1/R1BQR1K1 b -' => {
			eco => 'C97d',
			# TRANSLATORS: C97d: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2
			variation => N__('Spanish: Closed, Chigorin, 11. d4 Qc7 12.Nbd2'),
			moves => {
				'a5c6' => 1,
				'c5d4' => 1,
				'c8b7' => 1,
				'c8d7' => 1,
				'f8d8' => 1,
				'f8e8' => 1,
			},
		},
		'r4rk1/1bq1bppp/p2p1n2/npp1p3/3PP3/2P2N1P/PPBN1PP1/R1BQR1K1 w -' => {
			eco => 'C97e',
			# TRANSLATORS: C97e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 Bb7
			variation => N__('Spanish: Closed, Chigorin, 12... Bb7'),
			moves => {
			},
		},
		'r1b1r1k1/2q1bppp/p2p1n2/npp1p3/3PP3/2P2N1P/PPBN1PP1/R1BQR1K1 w -' => {
			eco => 'C97f',
			# TRANSLATORS: C97f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 Re8
			variation => N__('Spanish: Closed, Chigorin, 12... Re8'),
			moves => {
			},
		},
		'r1br2k1/2q1bppp/p2p1n2/npp1p3/3PP3/2P2N1P/PPBN1PP1/R1BQR1K1 w -' => {
			eco => 'C97g',
			# TRANSLATORS: C97g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 Rd8
			variation => N__('Spanish: Closed, Chigorin, 12... Rd8'),
			moves => {
			},
		},
		'r4rk1/2qbbppp/p2p1n2/npp1p3/3PP3/2P2N1P/PPBN1PP1/R1BQR1K1 w -' => {
			eco => 'C97h',
			# TRANSLATORS: C97h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 Bd7
			variation => N__('Spanish: Closed, Chigorin, 12... Bd7'),
			moves => {
				'd2f1' => 1,
			},
		},
		'r4rk1/2qbbppp/p2p1n2/npp1p3/3PP3/2P2N1P/PPB2PP1/R1BQRNK1 b -' => {
			eco => 'C97i',
			# TRANSLATORS: C97i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 Bd7 13. Nf1
			variation => N__('Spanish: Closed, Chigorin, 12... Bd7 13. Nf1'),
			moves => {
				'a5c4' => 1,
				'f8e8' => 1,
			},
		},
		'r4rk1/2qbbppp/p2p1n2/1pp1p3/2nPP3/2P2N1P/PPB2PP1/R1BQRNK1 w -' => {
			eco => 'C97j',
			# TRANSLATORS: C97j: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 Bd7 13. Nf1 Nc4
			variation => N__('Spanish: Closed, Chigorin, 12... Bd7 13. Nf1 Nc4'),
			moves => {
			},
		},
		'r3r1k1/2qbbppp/p2p1n2/npp1p3/3PP3/2P2N1P/PPB2PP1/R1BQRNK1 w -' => {
			eco => 'C97k',
			# TRANSLATORS: C97k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 Bd7 13. Nf1 Rfe8
			variation => N__('Spanish: Closed, Chigorin, 12... Bd7 13. Nf1 Rfe8'),
			moves => {
				'f1e3' => 1,
			},
		},
		'r3r1k1/2qbbppp/p2p1n2/npp1p3/3PP3/2P1NN1P/PPB2PP1/R1BQR1K1 b -' => {
			eco => 'C97k',
			# TRANSLATORS: C97k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 Bd7 13. Nf1 Rfe8 14. Ne3
			variation => N__('Spanish: Closed, Chigorin, 12... Bd7 13. Nf1 Rfe8'),
			moves => {
				'g7g6' => 1,
			},
		},
		'r3r1k1/2qbbp1p/p2p1np1/npp1p3/3PP3/2P1NN1P/PPB2PP1/R1BQR1K1 w -' => {
			eco => 'C97l',
			# TRANSLATORS: C97l: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 Bd7 13. Nf1 Rfe8 14. Ne3 g6
			variation => N__('Spanish: Closed, Chigorin, Yugoslav System'),
			moves => {
			},
		},
		'r1b2rk1/2q1bppp/p1np1n2/1pp1p3/3PP3/2P2N1P/PPBN1PP1/R1BQR1K1 w -' => {
			eco => 'C98a',
			# TRANSLATORS: C98a: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 Nc6
			variation => N__('Spanish: Closed, Chigorin, 12... Nc6'),
			moves => {
				'd4c5' => 1,
				'd4d5' => 1,
			},
		},
		'r1b2rk1/2q1bppp/p1np1n2/1pP1p3/4P3/2P2N1P/PPBN1PP1/R1BQR1K1 b -' => {
			eco => 'C98b',
			# TRANSLATORS: C98b: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 Nc6 13. dxc5
			variation => N__('Spanish: Closed, Chigorin, Rauzer Attack'),
			moves => {
				'd6c5' => 1,
			},
		},
		'r1b2rk1/2q1bppp/p1n2n2/1pp1p3/4P3/2P2N1P/PPBN1PP1/R1BQR1K1 w -' => {
			eco => 'C98b',
			# TRANSLATORS: C98b: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 Nc6 13. dxc5 dxc5
			variation => N__('Spanish: Closed, Chigorin, Rauzer Attack'),
			moves => {
				'd2f1' => 1,
			},
		},
		'r1b2rk1/2q1bppp/p1n2n2/1pp1p3/4P3/2P2N1P/PPB2PP1/R1BQRNK1 b -' => {
			eco => 'C98c',
			# TRANSLATORS: C98c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 Nc6 13. dxc5 dxc5 14. Nf1
			variation => N__('Spanish: Closed, Chigorin, Rauzer, 14. Nf1'),
			moves => {
				'c8e6' => 1,
			},
		},
		'r4rk1/2q1bppp/p1n1bn2/1pp1p3/4P3/2P2N1P/PPB2PP1/R1BQRNK1 w -' => {
			eco => 'C98d',
			# TRANSLATORS: C98d: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 Nc6 13. dxc5 dxc5 14. Nf1 Be6
			variation => N__('Spanish: Closed, Chigorin, Rauzer, 14. Nf1 Be6'),
			moves => {
			},
		},
		'r1b2rk1/2q1bppp/p1np1n2/1ppPp3/4P3/2P2N1P/PPBN1PP1/R1BQR1K1 b -' => {
			eco => 'C98e',
			# TRANSLATORS: C98e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 Nc6 13. d5
			variation => N__('Spanish: Closed, Chigorin, 12... Nc6 13. d5'),
			moves => {
				'c6a5' => 1,
				'c6d8' => 1,
			},
		},
		'r1b2rk1/2q1bppp/p2p1n2/nppPp3/4P3/2P2N1P/PPBN1PP1/R1BQR1K1 w -' => {
			eco => 'C98f',
			# TRANSLATORS: C98f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 Nc6 13. d5 Na5
			variation => N__('Spanish: Closed, Chigorin, 12... Nc6 13. d5 Na5'),
			moves => {
			},
		},
		'r1bn1rk1/2q1bppp/p2p1n2/1ppPp3/4P3/2P2N1P/PPBN1PP1/R1BQR1K1 w -' => {
			eco => 'C98g',
			# TRANSLATORS: C98g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 Nc6 13. d5 Nd8
			variation => N__('Spanish: Closed, Chigorin, 12... Nc6 13. d5 Nd8'),
			moves => {
				'a2a4' => 1,
				'd2f1' => 1,
			},
		},
		'r1bn1rk1/2q1bppp/p2p1n2/1ppPp3/4P3/2P2N1P/PPB2PP1/R1BQRNK1 b -' => {
			eco => 'C98h',
			# TRANSLATORS: C98h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 Nc6 13. d5 Nd8 14. Nf1
			variation => N__('Spanish: Closed, Chigorin, 12... Nc6 13. d5 Nd8 14. Nf1'),
			moves => {
			},
		},
		'r1bn1rk1/2q1bppp/p2p1n2/1ppPp3/P3P3/2P2N1P/1PBN1PP1/R1BQR1K1 b -' => {
			eco => 'C98i',
			# TRANSLATORS: C98i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 Nc6 13. d5 Nd8 14. a4
			variation => N__('Spanish: Closed, Chigorin, 12... Nc6 13. d5 Nd8 14. a4'),
			moves => {
			},
		},
		'r1b2rk1/2q1bppp/p2p1n2/np2p3/3pP3/2P2N1P/PPBN1PP1/R1BQR1K1 w -' => {
			eco => 'C99a',
			# TRANSLATORS: C99a: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 cxd4
			variation => N__('Spanish: Closed, Chigorin, 12...cxd4'),
			moves => {
				'c3d4' => 1,
			},
		},
		'r1b2rk1/2q1bppp/p2p1n2/np2p3/3PP3/5N1P/PPBN1PP1/R1BQR1K1 b -' => {
			eco => 'C99a',
			# TRANSLATORS: C99a: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 cxd4 13. cxd4
			variation => N__('Spanish: Closed, Chigorin, 12...cxd4 13.cxd4'),
			moves => {
				'a5c6' => 1,
				'c8b7' => 1,
				'c8d7' => 1,
				'f8d8' => 1,
			},
		},
		'r1br2k1/2q1bppp/p2p1n2/np2p3/3PP3/5N1P/PPBN1PP1/R1BQR1K1 w -' => {
			eco => 'C99b',
			# TRANSLATORS: C99b: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 cxd4 13. cxd4 Rd8
			variation => N__('Spanish: Closed, Chigorin, 13... Rd8'),
			moves => {
			},
		},
		'r4rk1/2qbbppp/p2p1n2/np2p3/3PP3/5N1P/PPBN1PP1/R1BQR1K1 w -' => {
			eco => 'C99c',
			# TRANSLATORS: C99c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 cxd4 13. cxd4 Bd7
			variation => N__('Spanish: Closed, Chigorin, 13... Bd7'),
			moves => {
				'd2f1' => 1,
			},
		},
		'r4rk1/2qbbppp/p2p1n2/np2p3/3PP3/5N1P/PPB2PP1/R1BQRNK1 b -' => {
			eco => 'C99c',
			# TRANSLATORS: C99c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 cxd4 13. cxd4 Bd7 14. Nf1
			variation => N__('Spanish: Closed, Chigorin, 13... Bd7 14. Nf1'),
			moves => {
				'a8c8' => 1,
			},
		},
		'2r2rk1/2qbbppp/p2p1n2/np2p3/3PP3/5N1P/PPB2PP1/R1BQRNK1 w -' => {
			eco => 'C99c',
			# TRANSLATORS: C99c: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 cxd4 13. cxd4 Bd7 14. Nf1 Rac8
			variation => N__('Spanish: Closed, Chigorin, 13... Bd7 14. Nf1'),
			moves => {
				'f1e3' => 1,
			},
		},
		'2r2rk1/2qbbppp/p2p1n2/np2p3/3PP3/4NN1P/PPB2PP1/R1BQR1K1 b -' => {
			eco => 'C99d',
			# TRANSLATORS: C99d: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 cxd4 13. cxd4 Bd7 14. Nf1 Rac8 15. Ne3
			variation => N__('Spanish: Closed, Chigorin, 13... Bd7 14. Nf1 Rac8 15. Ne3'),
			moves => {
			},
		},
		'r4rk1/1bq1bppp/p2p1n2/np2p3/3PP3/5N1P/PPBN1PP1/R1BQR1K1 w -' => {
			eco => 'C99e',
			# TRANSLATORS: C99e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 cxd4 13. cxd4 Bb7
			variation => N__('Spanish: Closed, Chigorin, 13... Bb7'),
			moves => {
				'd2f1' => 1,
				'd4d5' => 1,
			},
		},
		'r4rk1/1bq1bppp/p2p1n2/np2p3/3PP3/5N1P/PPB2PP1/R1BQRNK1 b -' => {
			eco => 'C99e',
			# TRANSLATORS: C99e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 cxd4 13. cxd4 Bb7 14. Nf1
			variation => N__('Spanish: Closed, Chigorin, 13... Bb7 14. Nf1'),
			moves => {
				'a8c8' => 1,
			},
		},
		'2r2rk1/1bq1bppp/p2p1n2/np2p3/3PP3/5N1P/PPB2PP1/R1BQRNK1 w -' => {
			eco => 'C99e',
			# TRANSLATORS: C99e: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 cxd4 13. cxd4 Bb7 14. Nf1 Rac8
			variation => N__('Spanish: Closed, Chigorin, 13... Bb7 14. Nf1 Rac8'),
			moves => {
				'e1e2' => 1,
			},
		},
		'2r2rk1/1bq1bppp/p2p1n2/np2p3/3PP3/5N1P/PPB1RPP1/R1BQ1NK1 b -' => {
			eco => 'C99f',
			# TRANSLATORS: C99f: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 cxd4 13. cxd4 Bb7 14. Nf1 Rac8 15. Re2
			variation => N__('Spanish: Closed, Chigorin, 13... Bb7 14. Nf1 Rac8 15. Re2'),
			moves => {
			},
		},
		'r4rk1/1bq1bppp/p2p1n2/np1Pp3/4P3/5N1P/PPBN1PP1/R1BQR1K1 b -' => {
			eco => 'C99g',
			# TRANSLATORS: C99g: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 cxd4 13. cxd4 Bb7 14. d5
			variation => N__('Spanish: Closed, Chigorin, 13... Bb7 14. d5'),
			moves => {
				'a8c8' => 1,
			},
		},
		'2r2rk1/1bq1bppp/p2p1n2/np1Pp3/4P3/5N1P/PPBN1PP1/R1BQR1K1 w -' => {
			eco => 'C99h',
			# TRANSLATORS: C99h: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 cxd4 13. cxd4 Bb7 14. d5 Rac8
			variation => N__('Spanish: Closed, Chigorin, 13... Bb7 14. d5 Rac8'),
			moves => {
			},
		},
		'r1b2rk1/2q1bppp/p1np1n2/1p2p3/3PP3/5N1P/PPBN1PP1/R1BQR1K1 w -' => {
			eco => 'C99i',
			# TRANSLATORS: C99i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 cxd4 13. cxd4 Nc6
			variation => N__('Spanish: Closed, Chigorin, 13... Nc6'),
			moves => {
				'a2a3' => 1,
				'd2b3' => 1,
				'd2f1' => 1,
				'd4d5' => 1,
			},
		},
		'r1b2rk1/2q1bppp/p1np1n2/1p2p3/3PP3/P4N1P/1PBN1PP1/R1BQR1K1 b -' => {
			eco => 'C99i',
			# TRANSLATORS: C99i: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 cxd4 13. cxd4 Nc6 14. a3
			variation => N__('Spanish: Closed, Chigorin, 13... Nc6 14. a3'),
			moves => {
			},
		},
		'r1b2rk1/2q1bppp/p1np1n2/1p2p3/3PP3/5N1P/PPB2PP1/R1BQRNK1 b -' => {
			eco => 'C99j',
			# TRANSLATORS: C99j: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 cxd4 13. cxd4 Nc6 14. Nf1
			variation => N__('Spanish: Closed, Chigorin, 13... Nc6 14. Nf1'),
			moves => {
			},
		},
		'r1b2rk1/2q1bppp/p1np1n2/1p1Pp3/4P3/5N1P/PPBN1PP1/R1BQR1K1 b -' => {
			eco => 'C99k',
			# TRANSLATORS: C99k: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 cxd4 13. cxd4 Nc6 14. d5
			variation => N__('Spanish: Closed, Chigorin, 13... Nc6 14. d5'),
			moves => {
			},
		},
		'r1b2rk1/2q1bppp/p1np1n2/1p2p3/3PP3/1N3N1P/PPB2PP1/R1BQR1K1 b -' => {
			eco => 'C99l',
			# TRANSLATORS: C99l: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 cxd4 13. cxd4 Nc6 14. Nb3
			variation => N__('Spanish: Closed, Chigorin, 13... Nc6 14. Nb3'),
			moves => {
				'a6a5' => 1,
			},
		},
		'r1b2rk1/2q1bppp/2np1n2/pp2p3/3PP3/1N3N1P/PPB2PP1/R1BQR1K1 w -' => {
			eco => 'C99l',
			# TRANSLATORS: C99l: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 cxd4 13. cxd4 Nc6 14. Nb3 a5
			variation => N__('Spanish: Closed, Chigorin, 13... Nc6 14. Nb3 a5'),
			moves => {
				'c1e3' => 1,
			},
		},
		'r1b2rk1/2q1bppp/2np1n2/pp2p3/3PP3/1N2BN1P/PPB2PP1/R2QR1K1 b -' => {
			eco => 'C99l',
			# TRANSLATORS: C99l: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 cxd4 13. cxd4 Nc6 14. Nb3 a5 15. Be3
			variation => N__('Spanish: Closed, Chigorin, 13... Nc6 14. Nb3 a5'),
			moves => {
				'a5a4' => 1,
			},
		},
		'r1b2rk1/2q1bppp/2np1n2/1p2p3/p2PP3/1N2BN1P/PPB2PP1/R2QR1K1 w -' => {
			eco => 'C99m',
			# TRANSLATORS: C99m: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 cxd4 13. cxd4 Nc6 14. Nb3 a5 15. Be3 a4
			variation => N__('Spanish: Closed, Chigorin, 13... Nc6 14. Nb3 a5 15. Be3 a4'),
			moves => {
				'b3d2' => 1,
			},
		},
		'r1b2rk1/2q1bppp/2np1n2/1p2p3/p2PP3/4BN1P/PPBN1PP1/R2QR1K1 b -' => {
			eco => 'C99m',
			# TRANSLATORS: C99m: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 cxd4 13. cxd4 Nc6 14. Nb3 a5 15. Be3 a4 16. Nbd2
			variation => N__('Spanish: Closed, Chigorin, 13... Nc6 14. Nb3 a5 15. Be3 a4'),
			moves => {
				'c6b4' => 1,
				'c8d7' => 1,
			},
		},
		'r1b2rk1/2q1bppp/3p1n2/1p2p3/pn1PP3/4BN1P/PPBN1PP1/R2QR1K1 w -' => {
			eco => 'C99n',
			# TRANSLATORS: C99n: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 cxd4 13. cxd4 Nc6 14. Nb3 a5 15. Be3 a4 16. Nbd2 Nb4
			variation => N__('Spanish: Closed, Chigorin, 13... Nc6 14. Nb3 a5 15. Be3 a4 16.Nbd2 Nb4'),
			moves => {
			},
		},
		'r4rk1/2qbbppp/2np1n2/1p2p3/p2PP3/4BN1P/PPBN1PP1/R2QR1K1 w -' => {
			eco => 'C99o',
			# TRANSLATORS: C99o: 1. e4 e5 2. Nf3 Nc6 3. Bb5 a6 4. Ba4 Nf6 5. O-O Be7 6. Re1 b5 7. Bb3 O-O 8. c3 d6 9. h3 Na5 10. Bc2 c5 11. d4 Qc7 12. Nbd2 cxd4 13. cxd4 Nc6 14. Nb3 a5 15. Be3 a4 16. Nbd2 Bd7
			variation => N__('Spanish: Closed, Chigorin, 13... Nc6 14. Nb3 a5 15. Be3 a4 16.Nbd2 Bd7'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/3P4/8/PPP1PPPP/RNBQKBNR w KQkq' => {
			eco => 'D00a',
			# TRANSLATORS: D00a: 1. d4 d5
			variation => N__('Queen\'s Pawn Game'),
			moves => {
				'b1c3' => 1,
				'c1f4' => 1,
				'c1g5' => 1,
				'c2c3' => 1,
				'c2c4' => 1,
				'e2e3' => 1,
				'e2e4' => 1,
				'f2f4' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/3P1P2/8/PPP1P1PP/RNBQKBNR b KQkq' => {
			eco => 'D00a',
			# TRANSLATORS: D00a: 1. d4 d5 2. f4
			variation => N__('Queen\'s Pawn: 2. f4'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/3P4/6P1/PPP1PP1P/RNBQKBNR b KQkq' => {
			eco => 'D00a',
			# TRANSLATORS: D00a: 1. d4 d5 2. g3
			variation => N__('Queen\'s Pawn: 2. g3'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/3P4/2P5/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'D00b',
			# TRANSLATORS: D00b: 1. d4 d5 2. c3
			variation => N__('Queen\'s Pawn: 2. c3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/3P4/2P5/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'D00b',
			# TRANSLATORS: D00b: 1. d4 d5 2. c3 Nf6
			variation => N__('Queen\'s Pawn: 2. c3 Nf6'),
			moves => {
				'c1f4' => 1,
				'c1g5' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/3P1B2/2P5/PP2PPPP/RN1QKBNR b KQkq' => {
			eco => 'D00b',
			# TRANSLATORS: D00b: 1. d4 d5 2. c3 Nf6 3. Bf4
			variation => N__('Queen\'s Pawn: 2. c3 Nf6 3. Bf4'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p2B1/3P4/2P5/PP2PPPP/RN1QKBNR b KQkq' => {
			eco => 'D00b',
			# TRANSLATORS: D00b: 1. d4 d5 2. c3 Nf6 3. Bg5
			variation => N__('Queen\'s Pawn: 2. c3 Nf6 3. Bg5'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/3P1B2/8/PPP1PPPP/RN1QKBNR b KQkq' => {
			eco => 'D00c',
			# TRANSLATORS: D00c: 1. d4 d5 2. Bf4
			variation => N__('Queen\'s Pawn: Mason Variation'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/8/2pp4/3P1B2/8/PPP1PPPP/RN1QKBNR w KQkq' => {
			eco => 'D00c',
			# TRANSLATORS: D00c: 1. d4 d5 2. Bf4 c5
			variation => N__('Queen\'s Pawn, Mason, Steinitz Countergambit'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/3P4/4P3/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'D00d',
			# TRANSLATORS: D00d: 1. d4 d5 2. e3
			variation => N__('Queen\'s Pawn: 2. e3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/3P4/4P3/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'D00d',
			# TRANSLATORS: D00d: 1. d4 d5 2. e3 Nf6
			variation => N__('Queen\'s Pawn: 2. e3 Nf6'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/3P4/3BP3/PPP2PPP/RNBQK1NR b KQkq' => {
			eco => 'D00e',
			# TRANSLATORS: D00e: 1. d4 d5 2. e3 Nf6 3. Bd3
			variation => N__('Queen\'s Pawn: Stonewall Attack'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p2B1/3P4/8/PPP1PPPP/RN1QKBNR b KQkq' => {
			eco => 'D00f',
			# TRANSLATORS: D00f: 1. d4 d5 2. Bg5
			variation => N__('Hodgson Attack (Trompowsky vs. 1... d5)'),
			moves => {
				'c7c6' => 1,
				'c8g4' => 1,
				'f7f6' => 1,
				'g7g6' => 1,
				'h7h6' => 1,
			},
		},
		'rn1qkbnr/ppp1pppp/8/3p2B1/3P2b1/8/PPP1PPPP/RN1QKBNR w KQkq' => {
			eco => 'D00f',
			# TRANSLATORS: D00f: 1. d4 d5 2. Bg5 Bg4
			variation => N__('Hodgson Attack: Welling Variation'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1p1pp/5p2/3p2B1/3P4/8/PPP1PPPP/RN1QKBNR w KQkq' => {
			eco => 'D00f',
			# TRANSLATORS: D00f: 1. d4 d5 2. Bg5 f6
			variation => N__('Hodgson Attack: 2... f6'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pp1p/6p1/3p2B1/3P4/8/PPP1PPPP/RN1QKBNR w KQkq' => {
			eco => 'D00f',
			# TRANSLATORS: D00f: 1. d4 d5 2. Bg5 g6
			variation => N__('Hodgson Attack: 2... g6'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3p2B1/3P4/8/PPP1PPPP/RN1QKBNR w KQkq' => {
			eco => 'D00g',
			# TRANSLATORS: D00g: 1. d4 d5 2. Bg5 c6
			variation => N__('Hodgson Attack: 2... c6'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1ppp1/7p/3p2B1/3P4/8/PPP1PPPP/RN1QKBNR w KQkq' => {
			eco => 'D00h',
			# TRANSLATORS: D00h: 1. d4 d5 2. Bg5 h6
			variation => N__('Hodgson Attack, 2... h6'),
			moves => {
				'g5h4' => 1,
			},
		},
		'rnbqkbnr/ppp1ppp1/7p/3p4/3P3B/8/PPP1PPPP/RN1QKBNR b KQkq' => {
			eco => 'D00h',
			# TRANSLATORS: D00h: 1. d4 d5 2. Bg5 h6 3. Bh4
			variation => N__('Hodgson Attack, 2... h6'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rnbqkbnr/pp2ppp1/2p4p/3p4/3P3B/8/PPP1PPPP/RN1QKBNR w KQkq' => {
			eco => 'D00h',
			# TRANSLATORS: D00h: 1. d4 d5 2. Bg5 h6 3. Bh4 c6
			variation => N__('Hodgson Attack: 2... h6 3. Bh4 c6'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbqkbnr/pp2ppp1/2p4p/3p4/3P3B/4P3/PPP2PPP/RN1QKBNR b KQkq' => {
			eco => 'D00h',
			# TRANSLATORS: D00h: 1. d4 d5 2. Bg5 h6 3. Bh4 c6 4. e3
			variation => N__('Hodgson Attack: 2... h6 3. Bh4 c6 4. e3'),
			moves => {
				'd8b6' => 1,
			},
		},
		'rnb1kbnr/pp2ppp1/1qp4p/3p4/3P3B/4P3/PPP2PPP/RN1QKBNR w KQkq' => {
			eco => 'D00h',
			# TRANSLATORS: D00h: 1. d4 d5 2. Bg5 h6 3. Bh4 c6 4. e3 Qb6
			variation => N__('Hodgson Attack: 2... h6 3. Bh4 c6 4. e3 Qb6'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p2B1/3P4/8/PPP1PPPP/RN1QKBNR w KQkq' => {
			eco => 'D00i',
			# TRANSLATORS: D00i: 1. d4 Nf6 2. Bg5 d5
			variation => N__('Trompowsky: 2... d5'),
			moves => {
				'b1d2' => 1,
				'e2e3' => 1,
				'g5f6' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p2B1/3P4/8/PPPNPPPP/R2QKBNR b KQkq' => {
			eco => 'D00i',
			# TRANSLATORS: D00i: 1. d4 Nf6 2. Bg5 d5 3. Nd2
			variation => N__('Trompowsky: 2... d5 3. Nd2'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p2B1/3P4/4P3/PPP2PPP/RN1QKBNR b KQkq' => {
			eco => 'D00i',
			# TRANSLATORS: D00i: 1. d4 Nf6 2. Bg5 d5 3. e3
			variation => N__('Trompowsky: 2... d5 3. e3'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p2B1/3P4/4P3/PPP2PPP/RN1QKBNR w KQkq' => {
			eco => 'D00i',
			# TRANSLATORS: D00i: 1. d4 Nf6 2. Bg5 d5 3. e3 e6
			variation => N__('Trompowsky: 2... d5 3. e3 e6'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5B2/3p4/3P4/8/PPP1PPPP/RN1QKBNR b KQkq' => {
			eco => 'D00j',
			# TRANSLATORS: D00j: 1. d4 Nf6 2. Bg5 d5 3. Bxf6
			variation => N__('Trompowsky: 2... d5 3.Bxf6'),
			moves => {
				'e7f6' => 1,
				'g7f6' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/5p2/3p4/3P4/8/PPP1PPPP/RN1QKBNR w KQkq' => {
			eco => 'D00j',
			# TRANSLATORS: D00j: 1. d4 Nf6 2. Bg5 d5 3. Bxf6 gxf6
			variation => N__('Trompowsky: 2... d5 3.Bxf6 gxf6'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/5p2/3p4/3P4/4P3/PPP2PPP/RN1QKBNR b KQkq' => {
			eco => 'D00j',
			# TRANSLATORS: D00j: 1. d4 Nf6 2. Bg5 d5 3. Bxf6 gxf6 4. e3
			variation => N__('Trompowsky: 2... d5 3.Bxf6 gxf6 4. e3'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqkb1r/pp2pp1p/5p2/2pp4/3P4/4P3/PPP2PPP/RN1QKBNR w KQkq' => {
			eco => 'D00j',
			# TRANSLATORS: D00j: 1. d4 Nf6 2. Bg5 d5 3. Bxf6 gxf6 4. e3 c5
			variation => N__('Trompowsky: 2... d5 3.Bxf6 gxf6 4. e3 c5'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/5p2/3p4/3P4/8/PPP1PPPP/RN1QKBNR w KQkq' => {
			eco => 'D00k',
			# TRANSLATORS: D00k: 1. d4 Nf6 2. Bg5 d5 3. Bxf6 exf6
			variation => N__('Trompowsky: 2... d5 3.Bxf6 exf6'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/5p2/3p4/3P4/4P3/PPP2PPP/RN1QKBNR b KQkq' => {
			eco => 'D00k',
			# TRANSLATORS: D00k: 1. d4 Nf6 2. Bg5 d5 3. Bxf6 exf6 4. e3
			variation => N__('Trompowsky: 2... d5 3.Bxf6 exf6 4. e3'),
			moves => {
				'c7c6' => 1,
				'c8e6' => 1,
				'c8f5' => 1,
				'f8d6' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/2p2p2/3p4/3P4/4P3/PPP2PPP/RN1QKBNR w KQkq' => {
			eco => 'D00k',
			# TRANSLATORS: D00k: 1. d4 Nf6 2. Bg5 d5 3. Bxf6 exf6 4. e3 c6
			variation => N__('Trompowsky: 2... d5 3.Bxf6 exf6 4. e3 c6'),
			moves => {
			},
		},
		'rn1qkb1r/ppp2ppp/4bp2/3p4/3P4/4P3/PPP2PPP/RN1QKBNR w KQkq' => {
			eco => 'D00k',
			# TRANSLATORS: D00k: 1. d4 Nf6 2. Bg5 d5 3. Bxf6 exf6 4. e3 Be6
			variation => N__('Trompowsky: 2... d5 3.Bxf6 exf6 4. e3 Be6'),
			moves => {
			},
		},
		'rn1qkb1r/ppp2ppp/5p2/3p1b2/3P4/4P3/PPP2PPP/RN1QKBNR w KQkq' => {
			eco => 'D00k',
			# TRANSLATORS: D00k: 1. d4 Nf6 2. Bg5 d5 3. Bxf6 exf6 4. e3 Bf5
			variation => N__('Trompowsky: 2... d5 3.Bxf6 exf6 4. e3 Bf5'),
			moves => {
			},
		},
		'rnbqk2r/ppp2ppp/3b1p2/3p4/3P4/4P3/PPP2PPP/RN1QKBNR w KQkq' => {
			eco => 'D00k',
			# TRANSLATORS: D00k: 1. d4 Nf6 2. Bg5 d5 3. Bxf6 exf6 4. e3 Bd6
			variation => N__('Trompowsky: 2... d5 3.Bxf6 exf6 4. e3 Bd6'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/3PP3/8/PPP2PPP/RNBQKBNR b KQkq' => {
			eco => 'D00l',
			# TRANSLATORS: D00l: 1. d4 d5 2. e4
			variation => N__('Blackmar-Diemer Gambit (BDG): 2. e4'),
			moves => {
				'd5e4' => 1,
				'e7e5' => 1,
			},
		},
		'rnbqkbnr/ppp1pppp/8/8/3Pp3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'D00l',
			# TRANSLATORS: D00l: 1. d4 d5 2. e4 dxe4
			variation => N__('Blackmar-Diemer Gambit (BDG): 2. e4 dxe4'),
			moves => {
				'b1c3' => 1,
				'f1c4' => 1,
				'f2f3' => 1,
			},
		},
		'rnbqkbnr/ppp1pppp/8/8/3Pp3/2N5/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'D00l',
			# TRANSLATORS: D00l: 1. d4 d5 2. e4 dxe4 3. Nc3
			variation => N__('Blackmar-Diemer: 2. e4 dxe4 3. Nc3'),
			moves => {
				'c8d7' => 1,
				'c8f5' => 1,
				'e7e5' => 1,
				'f7f5' => 1,
			},
		},
		'rn1qkbnr/pppbpppp/8/8/3Pp3/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'D00l',
			# TRANSLATORS: D00l: 1. d4 d5 2. e4 dxe4 3. Nc3 Bd7
			variation => N__('Blackmar-Diemer: Grosshans Defence'),
			moves => {
			},
		},
		'rn1qkbnr/ppp1pppp/8/5b2/3Pp3/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'D00l',
			# TRANSLATORS: D00l: 1. d4 d5 2. e4 dxe4 3. Nc3 Bf5
			variation => N__('Blackmar-Diemer: Zeller Defence'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1p1pp/8/5p2/3Pp3/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'D00l',
			# TRANSLATORS: D00l: 1. d4 d5 2. e4 dxe4 3. Nc3 f5
			variation => N__('Blackmar-Diemer: Pohmlann Defence'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/8/2BPp3/8/PPP2PPP/RNBQK1NR b KQkq' => {
			eco => 'D00l',
			# TRANSLATORS: D00l: 1. d4 d5 2. e4 dxe4 3. Bc4
			variation => N__('Blackmar-Diemer: Fritz Attack'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/8/3Pp3/5P2/PPP3PP/RNBQKBNR b KQkq' => {
			eco => 'D00l',
			# TRANSLATORS: D00l: 1. d4 d5 2. e4 dxe4 3. f3
			variation => N__('Blackmar-Diemer: Gedult Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/8/3pp3/3PP3/8/PPP2PPP/RNBQKBNR w KQkq' => {
			eco => 'D00l',
			# TRANSLATORS: D00l: 1. d4 d5 2. e4 e5
			variation => N__('Blackmar-Diemer: Beyer Countergambit'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/8/4p3/3Pp3/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'D00m',
			# TRANSLATORS: D00m: 1. d4 d5 2. e4 dxe4 3. Nc3 e5
			variation => N__('Blackmar-Diemer: Lemberger Countergambit'),
			moves => {
				'd1h5' => 1,
				'g1e2' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/8/4p2Q/3Pp3/2N5/PPP2PPP/R1B1KBNR b KQkq' => {
			eco => 'D00m',
			# TRANSLATORS: D00m: 1. d4 d5 2. e4 dxe4 3. Nc3 e5 4. Qh5
			variation => N__('Blackmar-Diemer: Lemberger Countergambit, Sneider Attack'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/8/4p3/3Pp3/2N5/PPP1NPPP/R1BQKB1R b KQkq' => {
			eco => 'D00m',
			# TRANSLATORS: D00m: 1. d4 d5 2. e4 dxe4 3. Nc3 e5 4. Nge2
			variation => N__('Blackmar-Diemer: Lemberger Countergambit, Rassmussen Attack'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/3P4/2N5/PPP1PPPP/R1BQKBNR b KQkq' => {
			eco => 'D00n',
			# TRANSLATORS: D00n: 1. d4 d5 2. Nc3
			variation => N__('Queen\'s Pawn: Veresov Attack'),
			moves => {
				'c8f5' => 1,
				'g8f6' => 1,
			},
		},
		'rn1qkbnr/ppp1pppp/8/3p1b2/3P4/2N5/PPP1PPPP/R1BQKBNR w KQkq' => {
			eco => 'D00n',
			# TRANSLATORS: D00n: 1. d4 d5 2. Nc3 Bf5
			variation => N__('Queen\'s Pawn: Veresov Attack'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/3P4/2N5/PPP1PPPP/R1BQKBNR w KQkq' => {
			eco => 'D00n',
			# TRANSLATORS: D00n: 1. d4 d5 2. Nc3 Nf6
			variation => N__('Queen\'s Pawn: Veresov Attack'),
			moves => {
				'c1f4' => 1,
				'c1g5' => 1,
				'e2e4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/3P1B2/2N5/PPP1PPPP/R2QKBNR b KQkq' => {
			eco => 'D00o',
			# TRANSLATORS: D00o: 1. d4 d5 2. Nc3 Nf6 3. Bf4
			variation => N__('Queen\'s Pawn: Veresov, 3. Bf4'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/3P4/2N2N2/PPP1PPPP/R1BQKB1R b KQkq' => {
			eco => 'D00p',
			# TRANSLATORS: D00p: 1. d4 d5 2. Nc3 Nf6 3. Nf3
			variation => N__('Queen\'s Pawn: Veresov, 3. Nf3'),
			moves => {
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/3p4/3P4/2N2N2/PPP1PPPP/R1BQKB1R w KQkq' => {
			eco => 'D00p',
			# TRANSLATORS: D00p: 1. d4 d5 2. Nc3 Nf6 3. Nf3 g6
			variation => N__('Queen\'s Pawn: Veresov, 3. Nf3 g6'),
			moves => {
				'c1f4' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/3p4/3P1B2/2N2N2/PPP1PPPP/R2QKB1R b KQkq' => {
			eco => 'D00q',
			# TRANSLATORS: D00q: 1. d4 d5 2. Nc3 Nf6 3. Nf3 g6 4. Bf4
			variation => N__('Queen\'s Pawn: Anti-King\'s Indian'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/3p4/3P1B2/2N2N2/PPP1PPPP/R2QKB1R w KQkq' => {
			eco => 'D00q',
			# TRANSLATORS: D00q: 1. d4 d5 2. Nc3 Nf6 3. Nf3 g6 4. Bf4 Bg7
			variation => N__('Queen\'s Pawn: Anti-King\'s Indian'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/3p4/3P1B2/2N1PN2/PPP2PPP/R2QKB1R b KQkq' => {
			eco => 'D00q',
			# TRANSLATORS: D00q: 1. d4 d5 2. Nc3 Nf6 3. Nf3 g6 4. Bf4 Bg7 5. e3
			variation => N__('Queen\'s Pawn: Anti-King\'s Indian'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/3p4/3P1B2/2N1PN2/PPP2PPP/R2QKB1R w KQ' => {
			eco => 'D00q',
			# TRANSLATORS: D00q: 1. d4 d5 2. Nc3 Nf6 3. Nf3 g6 4. Bf4 Bg7 5. e3 O-O
			variation => N__('Queen\'s Pawn: Anti-King\'s Indian'),
			moves => {
				'f1e2' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/3p4/3P1B2/2N1PN2/PPP1BPPP/R2QK2R b KQ' => {
			eco => 'D00r',
			# TRANSLATORS: D00r: 1. d4 d5 2. Nc3 Nf6 3. Nf3 g6 4. Bf4 Bg7 5. e3 O-O 6. Be2
			variation => N__('Queen\'s Pawn: Anti-King\'s Indian, Main Line'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/3PP3/2N5/PPP2PPP/R1BQKBNR b KQkq' => {
			eco => 'D00s',
			# TRANSLATORS: D00s: 1. d4 d5 2. Nc3 Nf6 3. e4
			variation => N__('Blackmar-Diemer Gambit (BDG)'),
			moves => {
				'd5e4' => 1,
				'f6e4' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/8/3p4/3Pn3/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'D00s',
			# TRANSLATORS: D00s: 1. d4 d5 2. Nc3 Nf6 3. e4 Nxe4
			variation => N__('Blackmar-Diemer: Hubsch Gambit'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/8/3Pp3/2N5/PPP2PPP/R1BQKBNR w KQkq' => {
			eco => 'D00t',
			# TRANSLATORS: D00t: 1. d4 d5 2. Nc3 Nf6 3. e4 dxe4
			variation => N__('Blackmar-Diemer: 3...dxe4'),
			moves => {
				'c1g5' => 1,
				'f2f3' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/6B1/3Pp3/2N5/PPP2PPP/R2QKBNR b KQkq' => {
			eco => 'D00t',
			# TRANSLATORS: D00t: 1. d4 d5 2. Nc3 Nf6 3. e4 dxe4 4. Bg5
			variation => N__('Blackmar-Diemer: von Popiel Attack'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/8/3Pp3/2N2P2/PPP3PP/R1BQKBNR b KQkq' => {
			eco => 'D00u',
			# TRANSLATORS: D00u: 1. d4 d5 2. Nc3 Nf6 3. e4 dxe4 4. f3
			variation => N__('Blackmar-Diemer: 4. f3'),
			moves => {
				'b8c6' => 1,
				'c7c6' => 1,
				'c8f5' => 1,
				'e4e3' => 1,
				'e4f3' => 1,
				'e7e5' => 1,
				'e7e6' => 1,
			},
		},
		'r1bqkb1r/ppp1pppp/2n2n2/8/3Pp3/2N2P2/PPP3PP/R1BQKBNR w KQkq' => {
			eco => 'D00u',
			# TRANSLATORS: D00u: 1. d4 d5 2. Nc3 Nf6 3. e4 dxe4 4. f3 Nc6
			variation => N__('Blackmar-Diemer: Lamb Defence'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/8/3Pp3/2N2P2/PPP3PP/R1BQKBNR w KQkq' => {
			eco => 'D00u',
			# TRANSLATORS: D00u: 1. d4 d5 2. Nc3 Nf6 3. e4 dxe4 4. f3 c6
			variation => N__('Blackmar-Diemer: O\'Kelly Defence'),
			moves => {
			},
		},
		'rn1qkb1r/ppp1pppp/5n2/5b2/3Pp3/2N2P2/PPP3PP/R1BQKBNR w KQkq' => {
			eco => 'D00u',
			# TRANSLATORS: D00u: 1. d4 d5 2. Nc3 Nf6 3. e4 dxe4 4. f3 Bf5
			variation => N__('Blackmar-Diemer: Vienna Defence'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/8/3P4/2N1pP2/PPP3PP/R1BQKBNR w KQkq' => {
			eco => 'D00u',
			# TRANSLATORS: D00u: 1. d4 d5 2. Nc3 Nf6 3. e4 dxe4 4. f3 e3
			variation => N__('Blackmar-Diemer: Langeheinecke Defence'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/4p3/3Pp3/2N2P2/PPP3PP/R1BQKBNR w KQkq' => {
			eco => 'D00u',
			# TRANSLATORS: D00u: 1. d4 d5 2. Nc3 Nf6 3. e4 dxe4 4. f3 e5
			variation => N__('Blackmar-Diemer: Elbert Countergambit'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/8/3Pp3/2N2P2/PPP3PP/R1BQKBNR w KQkq' => {
			eco => 'D00u',
			# TRANSLATORS: D00u: 1. d4 d5 2. Nc3 Nf6 3. e4 dxe4 4. f3 e6
			variation => N__('Blackmar-Diemer: Weinspach Defence'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/8/3P4/2N2p2/PPP3PP/R1BQKBNR w KQkq' => {
			eco => 'D00v',
			# TRANSLATORS: D00v: 1. d4 d5 2. Nc3 Nf6 3. e4 dxe4 4. f3 exf3
			variation => N__('Blackmar-Diemer: Accepted'),
			moves => {
				'd1f3' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/8/3P4/2N2Q2/PPP3PP/R1B1KBNR b KQkq' => {
			eco => 'D00v',
			# TRANSLATORS: D00v: 1. d4 d5 2. Nc3 Nf6 3. e4 dxe4 4. f3 exf3 5. Qxf3
			variation => N__('Blackmar-Diemer: Ryder Gambit'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/8/3P4/2N2N2/PPP3PP/R1BQKB1R b KQkq' => {
			eco => 'D00w',
			# TRANSLATORS: D00w: 1. d4 d5 2. Nc3 Nf6 3. e4 dxe4 4. f3 exf3 5. Nxf3
			variation => N__('Blackmar-Diemer: 4. f3 exf3 5.Nxf3'),
			moves => {
				'c7c6' => 1,
				'c8f5' => 1,
				'c8g4' => 1,
				'e7e6' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/8/3P4/2N2N2/PPP3PP/R1BQKB1R w KQkq' => {
			eco => 'D00w',
			# TRANSLATORS: D00w: 1. d4 d5 2. Nc3 Nf6 3. e4 dxe4 4. f3 exf3 5. Nxf3 c6
			variation => N__('Blackmar-Diemer: Ziegler Defence'),
			moves => {
			},
		},
		'rn1qkb1r/ppp1pppp/5n2/5b2/3P4/2N2N2/PPP3PP/R1BQKB1R w KQkq' => {
			eco => 'D00w',
			# TRANSLATORS: D00w: 1. d4 d5 2. Nc3 Nf6 3. e4 dxe4 4. f3 exf3 5. Nxf3 Bf5
			variation => N__('Blackmar-Diemer: Gunderam Defence'),
			moves => {
			},
		},
		'rn1qkb1r/ppp1pppp/5n2/8/3P2b1/2N2N2/PPP3PP/R1BQKB1R w KQkq' => {
			eco => 'D00w',
			# TRANSLATORS: D00w: 1. d4 d5 2. Nc3 Nf6 3. e4 dxe4 4. f3 exf3 5. Nxf3 Bg4
			variation => N__('Blackmar-Diemer: Tartakower Defence'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/8/3P4/2N2N2/PPP3PP/R1BQKB1R w KQkq' => {
			eco => 'D00x',
			# TRANSLATORS: D00x: 1. d4 d5 2. Nc3 Nf6 3. e4 dxe4 4. f3 exf3 5. Nxf3 e6
			variation => N__('Blackmar-Diemer: Euwe Defence'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/8/3P4/2N2N2/PPP3PP/R1BQKB1R w KQkq' => {
			eco => 'D00y',
			# TRANSLATORS: D00y: 1. d4 d5 2. Nc3 Nf6 3. e4 dxe4 4. f3 exf3 5. Nxf3 g6
			variation => N__('Blackmar-Diemer: Bogoljubow Defence'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p2B1/3P4/2N5/PPP1PPPP/R2QKBNR b KQkq' => {
			eco => 'D01a',
			# TRANSLATORS: D01a: 1. d4 d5 2. Nc3 Nf6 3. Bg5
			variation => N__('Richter-Veresov Attack'),
			moves => {
				'b8d7' => 1,
				'c7c5' => 1,
				'c7c6' => 1,
				'c8f5' => 1,
				'e7e6' => 1,
				'f6e4' => 1,
				'g7g6' => 1,
				'h7h6' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/8/3p2B1/3Pn3/2N5/PPP1PPPP/R2QKBNR w KQkq' => {
			eco => 'D01b',
			# TRANSLATORS: D01b: 1. d4 d5 2. Nc3 Nf6 3. Bg5 Ne4
			variation => N__('Richter-Veresov: 3... Ne4'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p2B1/3P4/2N5/PPP1PPPP/R2QKBNR w KQkq' => {
			eco => 'D01c',
			# TRANSLATORS: D01c: 1. d4 d5 2. Nc3 Nf6 3. Bg5 e6
			variation => N__('Richter-Veresov: 3... e6'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1ppp1/5n1p/3p2B1/3P4/2N5/PPP1PPPP/R2QKBNR w KQkq' => {
			eco => 'D01d',
			# TRANSLATORS: D01d: 1. d4 d5 2. Nc3 Nf6 3. Bg5 h6
			variation => N__('Richter-Veresov: 3... h6'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/3p2B1/3P4/2N5/PPP1PPPP/R2QKBNR w KQkq' => {
			eco => 'D01e',
			# TRANSLATORS: D01e: 1. d4 d5 2. Nc3 Nf6 3. Bg5 g6
			variation => N__('Richter-Veresov: 3... g6'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/3p2B1/3P4/2N5/PPP1PPPP/R2QKBNR w KQkq' => {
			eco => 'D01f',
			# TRANSLATORS: D01f: 1. d4 d5 2. Nc3 Nf6 3. Bg5 c6
			variation => N__('Richter-Veresov: 3... c6'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/5n2/2pp2B1/3P4/2N5/PPP1PPPP/R2QKBNR w KQkq' => {
			eco => 'D01g',
			# TRANSLATORS: D01g: 1. d4 d5 2. Nc3 Nf6 3. Bg5 c5
			variation => N__('Richter-Veresov: 3... c5'),
			moves => {
			},
		},
		'rn1qkb1r/ppp1pppp/5n2/3p1bB1/3P4/2N5/PPP1PPPP/R2QKBNR w KQkq' => {
			eco => 'D01h',
			# TRANSLATORS: D01h: 1. d4 d5 2. Nc3 Nf6 3. Bg5 Bf5
			variation => N__('Richter-Veresov: 3... Bf5'),
			moves => {
				'f2f3' => 1,
				'g1f3' => 1,
				'g5f6' => 1,
			},
		},
		'rn1qkb1r/ppp1pppp/5n2/3p1bB1/3P4/2N2P2/PPP1P1PP/R2QKBNR b KQkq' => {
			eco => 'D01i',
			# TRANSLATORS: D01i: 1. d4 d5 2. Nc3 Nf6 3. Bg5 Bf5 4. f3
			variation => N__('Richter-Veresov: 3... Bf5 4. f3'),
			moves => {
			},
		},
		'rn1qkb1r/ppp1pppp/5n2/3p1bB1/3P4/2N2N2/PPP1PPPP/R2QKB1R b KQkq' => {
			eco => 'D01j',
			# TRANSLATORS: D01j: 1. d4 d5 2. Nc3 Nf6 3. Bg5 Bf5 4. Nf3
			variation => N__('Richter-Veresov: 3... Bf5 4. Nf3'),
			moves => {
			},
		},
		'rn1qkb1r/ppp1pppp/5B2/3p1b2/3P4/2N5/PPP1PPPP/R2QKBNR b KQkq' => {
			eco => 'D01k',
			# TRANSLATORS: D01k: 1. d4 d5 2. Nc3 Nf6 3. Bg5 Bf5 4. Bxf6
			variation => N__('Richter-Veresov: 3... Bf5 4.Bxf6'),
			moves => {
			},
		},
		'r1bqkb1r/pppnpppp/5n2/3p2B1/3P4/2N5/PPP1PPPP/R2QKBNR w KQkq' => {
			eco => 'D01l',
			# TRANSLATORS: D01l: 1. d4 d5 2. Nc3 Nf6 3. Bg5 Nbd7
			variation => N__('Richter-Veresov: 3...Nbd7'),
			moves => {
				'f2f3' => 1,
				'g1f3' => 1,
			},
		},
		'r1bqkb1r/pppnpppp/5n2/3p2B1/3P4/2N2P2/PPP1P1PP/R2QKBNR b KQkq' => {
			eco => 'D01m',
			# TRANSLATORS: D01m: 1. d4 d5 2. Nc3 Nf6 3. Bg5 Nbd7 4. f3
			variation => N__('Richter-Veresov: 3...Nbd7 4. f3'),
			moves => {
			},
		},
		'r1bqkb1r/pppnpppp/5n2/3p2B1/3P4/2N2N2/PPP1PPPP/R2QKB1R b KQkq' => {
			eco => 'D01n',
			# TRANSLATORS: D01n: 1. d4 d5 2. Nc3 Nf6 3. Bg5 Nbd7 4. Nf3
			variation => N__('Richter-Veresov: 3...Nbd7 4. Nf3'),
			moves => {
				'g7g6' => 1,
				'h7h6' => 1,
			},
		},
		'r1bqkb1r/pppnppp1/5n1p/3p2B1/3P4/2N2N2/PPP1PPPP/R2QKB1R w KQkq' => {
			eco => 'D01o',
			# TRANSLATORS: D01o: 1. d4 d5 2. Nc3 Nf6 3. Bg5 Nbd7 4. Nf3 h6
			variation => N__('Richter-Veresov: 3...Nbd7 4. Nf3 h6'),
			moves => {
			},
		},
		'r1bqkb1r/pppnpp1p/5np1/3p2B1/3P4/2N2N2/PPP1PPPP/R2QKB1R w KQkq' => {
			eco => 'D01p',
			# TRANSLATORS: D01p: 1. d4 d5 2. Nc3 Nf6 3. Bg5 Nbd7 4. Nf3 g6
			variation => N__('Richter-Veresov: 3...Nbd7 4. Nf3 g6'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/3P4/5N2/PPP1PPPP/RNBQKB1R b KQkq' => {
			eco => 'D02a',
			# TRANSLATORS: D02a: 1. d4 d5 2. Nf3
			variation => N__('Queen\'s Pawn: 2. Nf3'),
			moves => {
				'b8c6' => 1,
				'c7c5' => 1,
				'c7c6' => 1,
				'c8f5' => 1,
				'c8g4' => 1,
				'e7e6' => 1,
				'g7g6' => 1,
				'g8f6' => 1,
			},
		},
		'rn1qkbnr/ppp1pppp/8/3p4/3P2b1/5N2/PPP1PPPP/RNBQKB1R w KQkq' => {
			eco => 'D02a',
			# TRANSLATORS: D02a: 1. d4 d5 2. Nf3 Bg4
			variation => N__('Queen\'s Pawn: 2. Nf3 Bg4'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pp1p/6p1/3p4/3P4/5N2/PPP1PPPP/RNBQKB1R w KQkq' => {
			eco => 'D02a',
			# TRANSLATORS: D02a: 1. d4 d5 2. Nf3 g6
			variation => N__('Queen\'s Pawn: 2. Nf3 g6'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3p4/3P4/5N2/PPP1PPPP/RNBQKB1R w KQkq' => {
			eco => 'D02b',
			# TRANSLATORS: D02b: 1. d4 d5 2. Nf3 c6
			variation => N__('Queen\'s Pawn: 2. Nf3 c6'),
			moves => {
				'c1f4' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3p4/3P1B2/5N2/PPP1PPPP/RN1QKB1R b KQkq' => {
			eco => 'D02c',
			# TRANSLATORS: D02c: 1. d4 d5 2. Nf3 c6 3. Bf4
			variation => N__('Queen\'s Pawn: London'),
			moves => {
				'd8b6' => 1,
			},
		},
		'rnb1kbnr/pp2pppp/1qp5/3p4/3P1B2/5N2/PPP1PPPP/RN1QKB1R w KQkq' => {
			eco => 'D02c',
			# TRANSLATORS: D02c: 1. d4 d5 2. Nf3 c6 3. Bf4 Qb6
			variation => N__('Queen\'s Pawn: London, Alapin Variation'),
			moves => {
			},
		},
		'rn1qkbnr/ppp1pppp/8/3p1b2/3P4/5N2/PPP1PPPP/RNBQKB1R w KQkq' => {
			eco => 'D02d',
			# TRANSLATORS: D02d: 1. d4 d5 2. Nf3 Bf5
			variation => N__('Queen\'s Pawn: 2. Nf3 Bf5'),
			moves => {
				'c1f4' => 1,
				'e2e3' => 1,
			},
		},
		'rn1qkbnr/ppp1pppp/8/3p1b2/3P1B2/5N2/PPP1PPPP/RN1QKB1R b KQkq' => {
			eco => 'D02d',
			# TRANSLATORS: D02d: 1. d4 d5 2. Nf3 Bf5 3. Bf4
			variation => N__('Queen\'s Pawn: 2. Nf3 Bf5 3. Bf4'),
			moves => {
				'c7c6' => 1,
				'e7e6' => 1,
			},
		},
		'rn1qkbnr/pp2pppp/2p5/3p1b2/3P1B2/5N2/PPP1PPPP/RN1QKB1R w KQkq' => {
			eco => 'D02d',
			# TRANSLATORS: D02d: 1. d4 d5 2. Nf3 Bf5 3. Bf4 c6
			variation => N__('Queen\'s Pawn: 2. Nf3 Bf5 3. Bf4 c6'),
			moves => {
			},
		},
		'rn1qkbnr/ppp2ppp/4p3/3p1b2/3P1B2/5N2/PPP1PPPP/RN1QKB1R w KQkq' => {
			eco => 'D02d',
			# TRANSLATORS: D02d: 1. d4 d5 2. Nf3 Bf5 3. Bf4 e6
			variation => N__('Queen\'s Pawn: 2. Nf3 Bf5 3. Bf4 e6'),
			moves => {
			},
		},
		'rn1qkbnr/ppp1pppp/8/3p1b2/3P4/4PN2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'D02d',
			# TRANSLATORS: D02d: 1. d4 d5 2. Nf3 Bf5 3. e3
			variation => N__('Queen\'s Pawn: 2. Nf3 Bf5 3. e3'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rn1qkbnr/pp2pppp/2p5/3p1b2/3P4/4PN2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'D02d',
			# TRANSLATORS: D02d: 1. d4 d5 2. Nf3 Bf5 3. e3 c6
			variation => N__('Queen\'s Pawn: 2. Nf3 Bf5 3. e3 c6'),
			moves => {
			},
		},
		'r1bqkbnr/ppp1pppp/2n5/3p4/3P4/5N2/PPP1PPPP/RNBQKB1R w KQkq' => {
			eco => 'D02e',
			# TRANSLATORS: D02e: 1. d4 d5 2. Nf3 Nc6
			variation => N__('Queen\'s Pawn: 2. Nf3 Nc6'),
			moves => {
				'c1f4' => 1,
				'g2g3' => 1,
			},
		},
		'r1bqkbnr/ppp1pppp/2n5/3p4/3P1B2/5N2/PPP1PPPP/RN1QKB1R b KQkq' => {
			eco => 'D02f',
			# TRANSLATORS: D02f: 1. d4 d5 2. Nf3 Nc6 3. Bf4
			variation => N__('Queen\'s Pawn: 2. Nf3 Nc6 3. Bf4'),
			moves => {
			},
		},
		'r1bqkbnr/ppp1pppp/2n5/3p4/3P4/5NP1/PPP1PP1P/RNBQKB1R b KQkq' => {
			eco => 'D02g',
			# TRANSLATORS: D02g: 1. d4 d5 2. Nf3 Nc6 3. g3
			variation => N__('Queen\'s Pawn: 2. Nf3 Nc6 3. g3'),
			moves => {
				'c8g4' => 1,
			},
		},
		'r2qkbnr/ppp1pppp/2n5/3p4/3P2b1/5NP1/PPP1PP1P/RNBQKB1R w KQkq' => {
			eco => 'D02g',
			# TRANSLATORS: D02g: 1. d4 d5 2. Nf3 Nc6 3. g3 Bg4
			variation => N__('Queen\'s Pawn: 2. Nf3 Nc6 3. g3 Bg4'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/3p4/3P4/5N2/PPP1PPPP/RNBQKB1R w KQkq' => {
			eco => 'D02h',
			# TRANSLATORS: D02h: 1. d4 d5 2. Nf3 e6
			variation => N__('Queen\'s Pawn: 2. Nf3 e6'),
			moves => {
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/3p4/3P4/5NP1/PPP1PP1P/RNBQKB1R b KQkq' => {
			eco => 'D02i',
			# TRANSLATORS: D02i: 1. d4 d5 2. Nf3 e6 3. g3
			variation => N__('Queen\'s Pawn: 2. Nf3 e6 3. g3'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/4p3/2pp4/3P4/5NP1/PPP1PP1P/RNBQKB1R w KQkq' => {
			eco => 'D02i',
			# TRANSLATORS: D02i: 1. d4 d5 2. Nf3 e6 3. g3 c5
			variation => N__('Queen\'s Pawn: 2. Nf3 e6 3. g3 c5'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/4p3/2pp4/3P4/5NP1/PPP1PPBP/RNBQK2R b KQkq' => {
			eco => 'D02i',
			# TRANSLATORS: D02i: 1. d4 d5 2. Nf3 e6 3. g3 c5 4. Bg2
			variation => N__('Queen\'s Pawn: 2. Nf3 e6 3. g3 c5'),
			moves => {
				'c5d4' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/4p3/3p4/3p4/5NP1/PPP1PPBP/RNBQK2R w KQkq' => {
			eco => 'D02i',
			# TRANSLATORS: D02i: 1. d4 d5 2. Nf3 e6 3. g3 c5 4. Bg2 cxd4
			variation => N__('Queen\'s Pawn: 2. Nf3 e6 3. g3 c5'),
			moves => {
				'f3d4' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/4p3/3p4/3N4/6P1/PPP1PPBP/RNBQK2R b KQkq' => {
			eco => 'D02i',
			# TRANSLATORS: D02i: 1. d4 d5 2. Nf3 e6 3. g3 c5 4. Bg2 cxd4 5. Nxd4
			variation => N__('Queen\'s Pawn: 2. Nf3 e6 3. g3 c5'),
			moves => {
				'e6e5' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/8/3pp3/3N4/6P1/PPP1PPBP/RNBQK2R w KQkq' => {
			eco => 'D02i',
			# TRANSLATORS: D02i: 1. d4 d5 2. Nf3 e6 3. g3 c5 4. Bg2 cxd4 5. Nxd4 e5
			variation => N__('Queen\'s Pawn: 2. Nf3 e6 3. g3 c5'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/8/2pp4/3P4/5N2/PPP1PPPP/RNBQKB1R w KQkq' => {
			eco => 'D02j',
			# TRANSLATORS: D02j: 1. d4 d5 2. Nf3 c5
			variation => N__('Queen\'s Pawn: Krause Variation'),
			moves => {
				'c2c3' => 1,
				'c2c4' => 1,
				'd4c5' => 1,
				'e2e3' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/8/2pp4/3P4/2P2N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'D02j',
			# TRANSLATORS: D02j: 1. d4 d5 2. Nf3 c5 3. c3
			variation => N__('Queen\'s Pawn: Krause, Reversed Slav'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/8/2pp4/2PP4/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'D02j',
			# TRANSLATORS: D02j: 1. d4 d5 2. Nf3 c5 3. c4
			variation => N__('Queen\'s Pawn: Krause, 3. c4'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/8/2Pp4/8/5N2/PPP1PPPP/RNBQKB1R b KQkq' => {
			eco => 'D02j',
			# TRANSLATORS: D02j: 1. d4 d5 2. Nf3 c5 3. dxc5
			variation => N__('Queen\'s Pawn: Krause, Reversed QGA'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/8/2pp4/3P4/4PN2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'D02j',
			# TRANSLATORS: D02j: 1. d4 d5 2. Nf3 c5 3. e3
			variation => N__('Queen\'s Pawn: Krause, Reversed QGD'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/3P4/5N2/PPP1PPPP/RNBQKB1R w KQkq' => {
			eco => 'D02k',
			# TRANSLATORS: D02k: 1. d4 d5 2. Nf3 Nf6
			variation => N__('Queen\'s Pawn: 2. Nf3 Nf6'),
			moves => {
				'c1f4' => 1,
				'c1g5' => 1,
				'c2c3' => 1,
				'e2e3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/3P4/2P2N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'D02k',
			# TRANSLATORS: D02k: 1. d4 d5 2. Nf3 Nf6 3. c3
			variation => N__('Queen\'s Pawn: 3. c3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/3P1B2/5N2/PPP1PPPP/RN1QKB1R b KQkq' => {
			eco => 'D02l',
			# TRANSLATORS: D02l: 1. d4 d5 2. Nf3 Nf6 3. Bf4
			variation => N__('Queen\'s Pawn: London'),
			moves => {
				'c7c5' => 1,
				'c8f5' => 1,
				'e7e6' => 1,
			},
		},
		'rn1qkb1r/ppp1pppp/5n2/3p1b2/3P1B2/5N2/PPP1PPPP/RN1QKB1R w KQkq' => {
			eco => 'D02m',
			# TRANSLATORS: D02m: 1. d4 d5 2. Nf3 Nf6 3. Bf4 Bf5
			variation => N__('Queen\'s Pawn: London'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p4/3P1B2/5N2/PPP1PPPP/RN1QKB1R w KQkq' => {
			eco => 'D02n',
			# TRANSLATORS: D02n: 1. d4 d5 2. Nf3 Nf6 3. Bf4 e6
			variation => N__('Queen\'s Pawn: London'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p4/3P1B2/4PN2/PPP2PPP/RN1QKB1R b KQkq' => {
			eco => 'D02n',
			# TRANSLATORS: D02n: 1. d4 d5 2. Nf3 Nf6 3. Bf4 e6 4. e3
			variation => N__('Queen\'s Pawn: London'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/5n2/2pp4/3P1B2/5N2/PPP1PPPP/RN1QKB1R w KQkq' => {
			eco => 'D02o',
			# TRANSLATORS: D02o: 1. d4 d5 2. Nf3 Nf6 3. Bf4 c5
			variation => N__('Queen\'s Pawn: London'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/5n2/2pp4/3P1B2/4PN2/PPP2PPP/RN1QKB1R b KQkq' => {
			eco => 'D02o',
			# TRANSLATORS: D02o: 1. d4 d5 2. Nf3 Nf6 3. Bf4 c5 4. e3
			variation => N__('Queen\'s Pawn: London'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2pp4/3P1B2/4PN2/PPP2PPP/RN1QKB1R w KQkq' => {
			eco => 'D02p',
			# TRANSLATORS: D02p: 1. d4 d5 2. Nf3 Nf6 3. Bf4 e6 4. e3 c5
			variation => N__('Queen\'s Pawn: London'),
			moves => {
				'c2c3' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2pp4/3P1B2/2P1PN2/PP3PPP/RN1QKB1R b KQkq' => {
			eco => 'D02p',
			# TRANSLATORS: D02p: 1. d4 d5 2. Nf3 Nf6 3. Bf4 e6 4. e3 c5 5. c3
			variation => N__('Queen\'s Pawn: London'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2n1pn2/2pp4/3P1B2/2P1PN2/PP3PPP/RN1QKB1R w KQkq' => {
			eco => 'D02p',
			# TRANSLATORS: D02p: 1. d4 d5 2. Nf3 Nf6 3. Bf4 e6 4. e3 c5 5. c3 Nc6
			variation => N__('Queen\'s Pawn: London'),
			moves => {
				'f1d3' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2n1pn2/2pp4/3P1B2/2PBPN2/PP3PPP/RN1QK2R b KQkq' => {
			eco => 'D02p',
			# TRANSLATORS: D02p: 1. d4 d5 2. Nf3 Nf6 3. Bf4 e6 4. e3 c5 5. c3 Nc6 6. Bd3
			variation => N__('Queen\'s Pawn: London'),
			moves => {
				'f8d6' => 1,
			},
		},
		'r1bqk2r/pp3ppp/2nbpn2/2pp4/3P1B2/2PBPN2/PP3PPP/RN1QK2R w KQkq' => {
			eco => 'D02q',
			# TRANSLATORS: D02q: 1. d4 d5 2. Nf3 Nf6 3. Bf4 e6 4. e3 c5 5. c3 Nc6 6. Bd3 Bd6
			variation => N__('Queen\'s Pawn: London'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/3P4/5NP1/PPP1PP1P/RNBQKB1R b KQkq' => {
			eco => 'D02r',
			# TRANSLATORS: D02r: 1. d4 d5 2. Nf3 Nf6 3. g3
			variation => N__('Queen\'s Pawn: 3. g3'),
			moves => {
				'c7c6' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/3p4/3P4/5NP1/PPP1PP1P/RNBQKB1R w KQkq' => {
			eco => 'D02s',
			# TRANSLATORS: D02s: 1. d4 d5 2. Nf3 Nf6 3. g3 c6
			variation => N__('Queen\'s Pawn: 3. g3 c6'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/3p4/3P4/5NP1/PPP1PPBP/RNBQK2R b KQkq' => {
			eco => 'D02s',
			# TRANSLATORS: D02s: 1. d4 d5 2. Nf3 Nf6 3. g3 c6 4. Bg2
			variation => N__('Queen\'s Pawn: 3. g3 c6'),
			moves => {
				'c8g4' => 1,
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/3p4/3P2b1/5NP1/PPP1PPBP/RNBQK2R w KQkq' => {
			eco => 'D02t',
			# TRANSLATORS: D02t: 1. d4 d5 2. Nf3 Nf6 3. g3 c6 4. Bg2 Bg4
			variation => N__('Queen\'s Pawn: 3. g3 c6 4. Bg2 Bg4'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/3p4/3P2b1/5NP1/PPP1PPBP/RNBQ1RK1 b kq' => {
			eco => 'D02t',
			# TRANSLATORS: D02t: 1. d4 d5 2. Nf3 Nf6 3. g3 c6 4. Bg2 Bg4 5. O-O
			variation => N__('Queen\'s Pawn: 3. g3 c6 4. Bg2 Bg4'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r2qkb1r/pp1npppp/2p2n2/3p4/3P2b1/5NP1/PPP1PPBP/RNBQ1RK1 w kq' => {
			eco => 'D02t',
			# TRANSLATORS: D02t: 1. d4 d5 2. Nf3 Nf6 3. g3 c6 4. Bg2 Bg4 5. O-O Nbd7
			variation => N__('Queen\'s Pawn: 3. g3 c6 4. Bg2 Bg4'),
			moves => {
				'b1d2' => 1,
			},
		},
		'r2qkb1r/pp1npppp/2p2n2/3p4/3P2b1/5NP1/PPPNPPBP/R1BQ1RK1 b kq' => {
			eco => 'D02t',
			# TRANSLATORS: D02t: 1. d4 d5 2. Nf3 Nf6 3. g3 c6 4. Bg2 Bg4 5. O-O Nbd7 6. Nbd2
			variation => N__('Queen\'s Pawn: 3. g3 c6 4. Bg2 Bg4'),
			moves => {
				'e7e6' => 1,
			},
		},
		'r2qkb1r/pp1n1ppp/2p1pn2/3p4/3P2b1/5NP1/PPPNPPBP/R1BQ1RK1 w kq' => {
			eco => 'D02t',
			# TRANSLATORS: D02t: 1. d4 d5 2. Nf3 Nf6 3. g3 c6 4. Bg2 Bg4 5. O-O Nbd7 6. Nbd2 e6
			variation => N__('Queen\'s Pawn: 3. g3 c6 4. Bg2 Bg4'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/3p4/3P4/5NP1/PPP1PP1P/RNBQKB1R w KQkq' => {
			eco => 'D02u',
			# TRANSLATORS: D02u: 1. d4 d5 2. Nf3 Nf6 3. g3 g6
			variation => N__('Queen\'s Pawn: 3. g3 g6'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/3p4/3P4/5NP1/PPP1PPBP/RNBQK2R b KQkq' => {
			eco => 'D02u',
			# TRANSLATORS: D02u: 1. d4 d5 2. Nf3 Nf6 3. g3 g6 4. Bg2
			variation => N__('Queen\'s Pawn: 3. g3 g6'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/3p4/3P4/5NP1/PPP1PPBP/RNBQK2R w KQkq' => {
			eco => 'D02u',
			# TRANSLATORS: D02u: 1. d4 d5 2. Nf3 Nf6 3. g3 g6 4. Bg2 Bg7
			variation => N__('Queen\'s Pawn: 3. g3 g6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/3p4/3P4/5NP1/PPP1PPBP/RNBQ1RK1 b kq' => {
			eco => 'D02u',
			# TRANSLATORS: D02u: 1. d4 d5 2. Nf3 Nf6 3. g3 g6 4. Bg2 Bg7 5. O-O
			variation => N__('Queen\'s Pawn: 3. g3 g6'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/3p4/3P4/5NP1/PPP1PPBP/RNBQ1RK1 w -' => {
			eco => 'D02u',
			# TRANSLATORS: D02u: 1. d4 d5 2. Nf3 Nf6 3. g3 g6 4. Bg2 Bg7 5. O-O O-O
			variation => N__('Queen\'s Pawn: 3. g3 g6'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p2B1/3P4/5N2/PPP1PPPP/RN1QKB1R b KQkq' => {
			eco => 'D03a',
			# TRANSLATORS: D03a: 1. d4 d5 2. Nf3 Nf6 3. Bg5
			variation => N__('Torre Attack (Tartakower)'),
			moves => {
				'e7e6' => 1,
				'f6e4' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/8/3p2B1/3Pn3/5N2/PPP1PPPP/RN1QKB1R w KQkq' => {
			eco => 'D03b',
			# TRANSLATORS: D03b: 1. d4 d5 2. Nf3 Nf6 3. Bg5 Ne4
			variation => N__('Torre Attack: 3... Ne4'),
			moves => {
				'g5f4' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/8/3p4/3PnB2/5N2/PPP1PPPP/RN1QKB1R b KQkq' => {
			eco => 'D03c',
			# TRANSLATORS: D03c: 1. d4 d5 2. Nf3 Nf6 3. Bg5 Ne4 4. Bf4
			variation => N__('Torre Attack: 3... Ne4 4. Bf4'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p2B1/3P4/5N2/PPP1PPPP/RN1QKB1R w KQkq' => {
			eco => 'D03d',
			# TRANSLATORS: D03d: 1. d4 d5 2. Nf3 Nf6 3. Bg5 e6
			variation => N__('Torre Attack: 3... e6'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p2B1/3P4/4PN2/PPP2PPP/RN1QKB1R b KQkq' => {
			eco => 'D03e',
			# TRANSLATORS: D03e: 1. d4 d5 2. Nf3 Nf6 3. Bg5 e6 4. e3
			variation => N__('Torre Attack: 3... e6 4. e3'),
			moves => {
				'b8d7' => 1,
				'c7c5' => 1,
			},
		},
		'r1bqkb1r/pppn1ppp/4pn2/3p2B1/3P4/4PN2/PPP2PPP/RN1QKB1R w KQkq' => {
			eco => 'D03f',
			# TRANSLATORS: D03f: 1. d4 d5 2. Nf3 Nf6 3. Bg5 e6 4. e3 Nbd7
			variation => N__('Torre Attack: 3... e6 4. e3 Nbd7'),
			moves => {
				'b1d2' => 1,
			},
		},
		'r1bqkb1r/pppn1ppp/4pn2/3p2B1/3P4/4PN2/PPPN1PPP/R2QKB1R b KQkq' => {
			eco => 'D03f',
			# TRANSLATORS: D03f: 1. d4 d5 2. Nf3 Nf6 3. Bg5 e6 4. e3 Nbd7 5. Nbd2
			variation => N__('Torre Attack: 3... e6 4. e3 Nbd7'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r1bqk2r/pppnbppp/4pn2/3p2B1/3P4/4PN2/PPPN1PPP/R2QKB1R w KQkq' => {
			eco => 'D03f',
			# TRANSLATORS: D03f: 1. d4 d5 2. Nf3 Nf6 3. Bg5 e6 4. e3 Nbd7 5. Nbd2 Be7
			variation => N__('Torre Attack: 3... e6 4. e3 Nbd7'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2pp2B1/3P4/4PN2/PPP2PPP/RN1QKB1R w KQkq' => {
			eco => 'D03g',
			# TRANSLATORS: D03g: 1. d4 d5 2. Nf3 Nf6 3. Bg5 e6 4. e3 c5
			variation => N__('Torre Attack: 3... e6 4. e3 c5'),
			moves => {
				'b1d2' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2pp2B1/3P4/4PN2/PPPN1PPP/R2QKB1R b KQkq' => {
			eco => 'D03g',
			# TRANSLATORS: D03g: 1. d4 d5 2. Nf3 Nf6 3. Bg5 e6 4. e3 c5 5. Nbd2
			variation => N__('Torre Attack: 3... e6 4. e3 c5'),
			moves => {
				'b8d7' => 1,
				'f8e7' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/4pn2/2pp2B1/3P4/4PN2/PPPN1PPP/R2QKB1R w KQkq' => {
			eco => 'D03h',
			# TRANSLATORS: D03h: 1. d4 d5 2. Nf3 Nf6 3. Bg5 e6 4. e3 c5 5. Nbd2 Nbd7
			variation => N__('Torre Attack: 3... e6 4. e3 c5'),
			moves => {
			},
		},
		'rnbqk2r/pp2bppp/4pn2/2pp2B1/3P4/4PN2/PPPN1PPP/R2QKB1R w KQkq' => {
			eco => 'D03i',
			# TRANSLATORS: D03i: 1. d4 d5 2. Nf3 Nf6 3. Bg5 e6 4. e3 c5 5. Nbd2 Be7
			variation => N__('Torre Attack: 3... e6 4. e3 c5'),
			moves => {
				'c2c3' => 1,
			},
		},
		'rnbqk2r/pp2bppp/4pn2/2pp2B1/3P4/2P1PN2/PP1N1PPP/R2QKB1R b KQkq' => {
			eco => 'D03i',
			# TRANSLATORS: D03i: 1. d4 d5 2. Nf3 Nf6 3. Bg5 e6 4. e3 c5 5. Nbd2 Be7 6. c3
			variation => N__('Torre Attack: 3... e6 4. e3 c5'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r1bqk2r/pp1nbppp/4pn2/2pp2B1/3P4/2P1PN2/PP1N1PPP/R2QKB1R w KQkq' => {
			eco => 'D03j',
			# TRANSLATORS: D03j: 1. d4 d5 2. Nf3 Nf6 3. Bg5 e6 4. e3 c5 5. Nbd2 Be7 6. c3 Nbd7
			variation => N__('Torre Attack: 3... e6 4. e3 c5'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/3p2B1/3P4/5N2/PPP1PPPP/RN1QKB1R w KQkq' => {
			eco => 'D03k',
			# TRANSLATORS: D03k: 1. d4 d5 2. Nf3 Nf6 3. Bg5 g6
			variation => N__('Torre Attack: 3... g6'),
			moves => {
				'b1d2' => 1,
				'c2c3' => 1,
				'e2e3' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/3p2B1/3P4/2P2N2/PP2PPPP/RN1QKB1R b KQkq' => {
			eco => 'D03k',
			# TRANSLATORS: D03k: 1. d4 d5 2. Nf3 Nf6 3. Bg5 g6 4. c3
			variation => N__('Torre Attack: 3... g6'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/3p2B1/3P4/2P2N2/PP2PPPP/RN1QKB1R w KQkq' => {
			eco => 'D03k',
			# TRANSLATORS: D03k: 1. d4 d5 2. Nf3 Nf6 3. Bg5 g6 4. c3 Bg7
			variation => N__('Torre Attack: 3... g6'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/3p2B1/3P4/5N2/PPPNPPPP/R2QKB1R b KQkq' => {
			eco => 'D03l',
			# TRANSLATORS: D03l: 1. d4 d5 2. Nf3 Nf6 3. Bg5 g6 4. Nbd2
			variation => N__('Torre Attack: 3... g6'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/3p2B1/3P4/5N2/PPPNPPPP/R2QKB1R w KQkq' => {
			eco => 'D03l',
			# TRANSLATORS: D03l: 1. d4 d5 2. Nf3 Nf6 3. Bg5 g6 4. Nbd2 Bg7
			variation => N__('Torre Attack: 3... g6'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/3p2B1/3P4/4PN2/PPP2PPP/RN1QKB1R b KQkq' => {
			eco => 'D03m',
			# TRANSLATORS: D03m: 1. d4 d5 2. Nf3 Nf6 3. Bg5 g6 4. e3
			variation => N__('Torre Attack: 3... g6 4. e3'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/3p2B1/3P4/4PN2/PPP2PPP/RN1QKB1R w KQkq' => {
			eco => 'D03m',
			# TRANSLATORS: D03m: 1. d4 d5 2. Nf3 Nf6 3. Bg5 g6 4. e3 Bg7
			variation => N__('Torre Attack: 3... g6 4. e3'),
			moves => {
				'b1d2' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/3p2B1/3P4/4PN2/PPPN1PPP/R2QKB1R b KQkq' => {
			eco => 'D03n',
			# TRANSLATORS: D03n: 1. d4 d5 2. Nf3 Nf6 3. Bg5 g6 4. Nbd2 Bg7 5. e3
			variation => N__('Torre Attack: 3... g6 4. e3 Bg7 5.Nbd2'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/3p2B1/3P4/4PN2/PPPN1PPP/R2QKB1R w KQ' => {
			eco => 'D03o',
			# TRANSLATORS: D03o: 1. d4 d5 2. Nf3 Nf6 3. Bg5 g6 4. Nbd2 Bg7 5. e3 O-O
			variation => N__('Torre Attack: 3... g6 4. e3 Bg7 5.Nbd2 O-O'),
			moves => {
				'c2c3' => 1,
				'f1d3' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/3p2B1/3P4/2P1PN2/PP1N1PPP/R2QKB1R b KQ' => {
			eco => 'D03p',
			# TRANSLATORS: D03p: 1. d4 d5 2. Nf3 Nf6 3. Bg5 g6 4. Nbd2 Bg7 5. e3 O-O 6. c3
			variation => N__('Torre Attack: 3... g6 4. e3 Bg7 5.Nbd2 O-O 6. c3'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r1bq1rk1/pppnppbp/5np1/3p2B1/3P4/2P1PN2/PP1N1PPP/R2QKB1R w KQ' => {
			eco => 'D03q',
			# TRANSLATORS: D03q: 1. d4 d5 2. Nf3 Nf6 3. Bg5 g6 4. Nbd2 Bg7 5. e3 O-O 6. c3 Nbd7
			variation => N__('Torre Attack: 3... g6 4. e3 Bg7 5.Nbd2 O-O 6. c3 Nbd7'),
			moves => {
				'f1e2' => 1,
			},
		},
		'r1bq1rk1/pppnppbp/5np1/3p2B1/3P4/2P1PN2/PP1NBPPP/R2QK2R b KQ' => {
			eco => 'D03r',
			# TRANSLATORS: D03r: 1. d4 d5 2. Nf3 Nf6 3. Bg5 g6 4. Nbd2 Bg7 5. e3 O-O 6. c3 Nbd7 7. Be2
			variation => N__('Torre Attack: 3... g6 4. e3 Bg7 5.Nbd2 O-O 6. c3 Nbd7 7. Be2'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/3p2B1/3P4/3BPN2/PPPN1PPP/R2QK2R b KQ' => {
			eco => 'D03s',
			# TRANSLATORS: D03s: 1. d4 d5 2. Nf3 Nf6 3. Bg5 g6 4. Nbd2 Bg7 5. e3 O-O 6. Bd3
			variation => N__('Torre Attack: 3... g6 4. e3 Bg7 5.Nbd2 O-O 6. Bd3'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/5np1/2pp2B1/3P4/3BPN2/PPPN1PPP/R2QK2R w KQ' => {
			eco => 'D03t',
			# TRANSLATORS: D03t: 1. d4 d5 2. Nf3 Nf6 3. Bg5 g6 4. Nbd2 Bg7 5. e3 O-O 6. Bd3 c5
			variation => N__('Torre Attack: 3... g6 4. e3 Bg7 5.Nbd2 O-O 6. Bd3 c5'),
			moves => {
				'c2c3' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/5np1/2pp2B1/3P4/2PBPN2/PP1N1PPP/R2QK2R b KQ' => {
			eco => 'D03t',
			# TRANSLATORS: D03t: 1. d4 d5 2. Nf3 Nf6 3. Bg5 g6 4. Nbd2 Bg7 5. e3 O-O 6. Bd3 c5 7. c3
			variation => N__('Torre Attack: 3... g6 4. e3 Bg7 5.Nbd2 O-O 6. Bd3 c5'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r1bq1rk1/pp1nppbp/5np1/2pp2B1/3P4/2PBPN2/PP1N1PPP/R2QK2R w KQ' => {
			eco => 'D03u',
			# TRANSLATORS: D03u: 1. d4 d5 2. Nf3 Nf6 3. Bg5 g6 4. Nbd2 Bg7 5. e3 O-O 6. Bd3 c5 7. c3 Nbd7
			variation => N__('Torre Attack: 3... g6 4. e3 Bg7 5.Nbd2 O-O 6. Bd3 c5 7. c3 Nbd7'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/3P4/4PN2/PPP2PPP/RNBQKB1R b KQkq' => {
			eco => 'D04a',
			# TRANSLATORS: D04a: 1. d4 d5 2. Nf3 Nf6 3. e3
			variation => N__('Queen\'s Pawn: Colle'),
			moves => {
				'c7c5' => 1,
				'c7c6' => 1,
				'c8f5' => 1,
				'c8g4' => 1,
				'e7e6' => 1,
				'g7g6' => 1,
			},
		},
		'rn1qkb1r/ppp1pppp/5n2/3p4/3P2b1/4PN2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'D04b',
			# TRANSLATORS: D04b: 1. d4 d5 2. Nf3 Nf6 3. e3 Bg4
			variation => N__('Colle: 3... Bg4'),
			moves => {
			},
		},
		'rn1qkb1r/ppp1pppp/5n2/3p1b2/3P4/4PN2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'D04c',
			# TRANSLATORS: D04c: 1. d4 d5 2. Nf3 Nf6 3. e3 Bf5
			variation => N__('Colle: 3... Bf5'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rn1qkb1r/ppp1pppp/5n2/3p1b2/3P4/3BPN2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'D04c',
			# TRANSLATORS: D04c: 1. d4 d5 2. Nf3 Nf6 3. e3 Bf5 4. Bd3
			variation => N__('Colle: 3... Bf5'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rn1qkb1r/ppp2ppp/4pn2/3p1b2/3P4/3BPN2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'D04d',
			# TRANSLATORS: D04d: 1. d4 d5 2. Nf3 Nf6 3. e3 Bf5 4. Bd3 e6
			variation => N__('Colle: 3... Bf5, Alekhine Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/3p4/3P4/4PN2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'D04e',
			# TRANSLATORS: D04e: 1. d4 d5 2. Nf3 Nf6 3. e3 g6
			variation => N__('Colle: 3... g6'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/3p4/3P4/4PN2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'D04f',
			# TRANSLATORS: D04f: 1. d4 d5 2. Nf3 Nf6 3. e3 c6
			variation => N__('Colle: 3... c6'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/5n2/2pp4/3P4/4PN2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'D04g',
			# TRANSLATORS: D04g: 1. d4 d5 2. Nf3 Nf6 3. e3 c5
			variation => N__('Colle: 3... c5'),
			moves => {
				'c2c3' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/5n2/2pp4/3P4/2P1PN2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'D04h',
			# TRANSLATORS: D04h: 1. d4 d5 2. Nf3 Nf6 3. e3 c5 4. c3
			variation => N__('Colle: 3... c5 4. c3'),
			moves => {
				'b8c6' => 1,
				'b8d7' => 1,
			},
		},
		'r1bqkb1r/pp2pppp/2n2n2/2pp4/3P4/2P1PN2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'D04i',
			# TRANSLATORS: D04i: 1. d4 d5 2. Nf3 Nf6 3. e3 c5 4. c3 Nc6
			variation => N__('Colle: 3... c5 4. c3 Nc6'),
			moves => {
			},
		},
		'r1bqkb1r/pp1npppp/5n2/2pp4/3P4/2P1PN2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'D04j',
			# TRANSLATORS: D04j: 1. d4 d5 2. Nf3 Nf6 3. e3 c5 4. c3 Nbd7
			variation => N__('Colle: 3... c5 4. c3 Nbd7'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p4/3P4/4PN2/PPP2PPP/RNBQKB1R w KQkq' => {
			eco => 'D05a',
			# TRANSLATORS: D05a: 1. d4 d5 2. Nf3 Nf6 3. e3 e6
			variation => N__('Colle: 3... e6'),
			moves => {
				'b1d2' => 1,
				'f1d3' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p4/3P4/4PN2/PPPN1PPP/R1BQKB1R b KQkq' => {
			eco => 'D05b',
			# TRANSLATORS: D05b: 1. d4 d5 2. Nf3 Nf6 3. e3 e6 4. Nbd2
			variation => N__('Colle: 3... e6 4.Nbd2'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2pp4/3P4/4PN2/PPPN1PPP/R1BQKB1R w KQkq' => {
			eco => 'D05b',
			# TRANSLATORS: D05b: 1. d4 d5 2. Nf3 Nf6 3. e3 e6 4. Nbd2 c5
			variation => N__('Colle: 3... e6 4.Nbd2'),
			moves => {
				'b2b3' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2pp4/3P4/1P2PN2/P1PN1PPP/R1BQKB1R b KQkq' => {
			eco => 'D05c',
			# TRANSLATORS: D05c: 1. d4 d5 2. Nf3 Nf6 3. e3 e6 4. Nbd2 c5 5. b3
			variation => N__('Colle: Zukertort Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p4/3P4/3BPN2/PPP2PPP/RNBQK2R b KQkq' => {
			eco => 'D05d',
			# TRANSLATORS: D05d: 1. d4 d5 2. Nf3 Nf6 3. e3 e6 4. Bd3
			variation => N__('Colle: 3... e6 4. Bd3'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2pp4/3P4/3BPN2/PPP2PPP/RNBQK2R w KQkq' => {
			eco => 'D05e',
			# TRANSLATORS: D05e: 1. d4 d5 2. Nf3 Nf6 3. e3 e6 4. Bd3 c5
			variation => N__('Colle: 3... e6 4. Bd3 c5'),
			moves => {
				'b2b3' => 1,
				'c2c3' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2pp4/3P4/1P1BPN2/P1P2PPP/RNBQK2R b KQkq' => {
			eco => 'D05f',
			# TRANSLATORS: D05f: 1. d4 d5 2. Nf3 Nf6 3. e3 e6 4. Bd3 c5 5. b3
			variation => N__('Colle: Rubinstein\'s Attack'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2n1pn2/2pp4/3P4/1P1BPN2/P1P2PPP/RNBQK2R w KQkq' => {
			eco => 'D05g',
			# TRANSLATORS: D05g: 1. d4 d5 2. Nf3 Nf6 3. e3 e6 4. Bd3 c5 5. b3 Nc6
			variation => N__('Colle: Rubinstein\'s Attack, 5... Nc6'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2pp4/3P4/2PBPN2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'D05h',
			# TRANSLATORS: D05h: 1. d4 d5 2. Nf3 Nf6 3. e3 e6 4. Bd3 c5 5. c3
			variation => N__('Colle: 5. c3'),
			moves => {
				'b8c6' => 1,
				'b8d7' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/4pn2/2pp4/3P4/2PBPN2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'D05i',
			# TRANSLATORS: D05i: 1. d4 d5 2. Nf3 Nf6 3. e3 e6 4. Bd3 c5 5. c3 Nbd7
			variation => N__('Colle: 5. c3 Nbd7'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2n1pn2/2pp4/3P4/2PBPN2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'D05j',
			# TRANSLATORS: D05j: 1. d4 d5 2. Nf3 Nf6 3. e3 e6 4. Bd3 c5 5. c3 Nc6
			variation => N__('Colle: 5. c3 Nc6'),
			moves => {
				'b1d2' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2n1pn2/2pp4/3P4/2PBPN2/PP1N1PPP/R1BQK2R b KQkq' => {
			eco => 'D05k',
			# TRANSLATORS: D05k: 1. d4 d5 2. Nf3 Nf6 3. e3 e6 4. Bd3 c5 5. c3 Nc6 6. Nbd2
			variation => N__('Colle: 5. c3 Nc6 6.Nbd2'),
			moves => {
				'f8d6' => 1,
			},
		},
		'r1bqk2r/pp3ppp/2nbpn2/2pp4/3P4/2PBPN2/PP1N1PPP/R1BQK2R w KQkq' => {
			eco => 'D05l',
			# TRANSLATORS: D05l: 1. d4 d5 2. Nf3 Nf6 3. e3 e6 4. Bd3 c5 5. c3 Nc6 6. Nbd2 Bd6
			variation => N__('Colle: 5. c3 Nc6 6.Nbd2 Bd6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqk2r/pp3ppp/2nbpn2/2pp4/3P4/2PBPN2/PP1N1PPP/R1BQ1RK1 b kq' => {
			eco => 'D05l',
			# TRANSLATORS: D05l: 1. d4 d5 2. Nf3 Nf6 3. e3 e6 4. Bd3 c5 5. c3 Nc6 6. Nbd2 Bd6 7. O-O
			variation => N__('Colle: 5. c3 Nc6 6.Nbd2 Bd6'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp3ppp/2nbpn2/2pp4/3P4/2PBPN2/PP1N1PPP/R1BQ1RK1 w -' => {
			eco => 'D05m',
			# TRANSLATORS: D05m: 1. d4 d5 2. Nf3 Nf6 3. e3 e6 4. Bd3 c5 5. c3 Nc6 6. Nbd2 Bd6 7. O-O O-O
			variation => N__('Colle: 5. c3 Nc6 6.Nbd2 Bd6 7.O-O O-O'),
			moves => {
				'd4c5' => 1,
			},
		},
		'r1bq1rk1/pp3ppp/2nbpn2/2Pp4/8/2PBPN2/PP1N1PPP/R1BQ1RK1 b -' => {
			eco => 'D05m',
			# TRANSLATORS: D05m: 1. d4 d5 2. Nf3 Nf6 3. e3 e6 4. Bd3 c5 5. c3 Nc6 6. Nbd2 Bd6 7. O-O O-O 8. dxc5
			variation => N__('Colle: 5. c3 Nc6 6.Nbd2 Bd6 7.O-O O-O'),
			moves => {
				'd6c5' => 1,
			},
		},
		'r1bq1rk1/pp3ppp/2n1pn2/2bp4/8/2PBPN2/PP1N1PPP/R1BQ1RK1 w -' => {
			eco => 'D05n',
			# TRANSLATORS: D05n: 1. d4 d5 2. Nf3 Nf6 3. e3 e6 4. Bd3 c5 5. c3 Nc6 6. Nbd2 Bd6 7. O-O O-O 8. dxc5 Bxc5
			variation => N__('Colle: 5. c3 Nc6 6.Nbd2 Bd6 7.O-O O-O 8.dxc5 Bxc5'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/3p4/2PP4/8/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'D06a',
			# TRANSLATORS: D06a: 1. d4 d5 2. c4
			variation => N__('Queen\'s Gambit'),
			moves => {
				'b8c6' => 1,
				'c7c5' => 1,
				'c7c6' => 1,
				'c8f5' => 1,
				'd5c4' => 1,
				'e7e5' => 1,
				'e7e6' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/8/2pp4/2PP4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'D06b',
			# TRANSLATORS: D06b: 1. d4 d5 2. c4 c5
			variation => N__('QGD: Austrian Defence'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/8/2pP4/3P4/8/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'D06b',
			# TRANSLATORS: D06b: 1. d4 d5 2. c4 c5 3. cxd5
			variation => N__('QGD: Austrian Defence'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/5n2/2pP4/3P4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'D06b',
			# TRANSLATORS: D06b: 1. d4 d5 2. c4 c5 3. cxd5 Nf6
			variation => N__('QGD: Austrian, Rubinstein Variation'),
			moves => {
				'd4c5' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/5n2/2PP4/8/8/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'D06b',
			# TRANSLATORS: D06b: 1. d4 d5 2. c4 c5 3. cxd5 Nf6 4. dxc5
			variation => N__('QGD: Austrian, Rubinstein, 4.dxc5'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/5n2/2pP4/3P4/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'D06c',
			# TRANSLATORS: D06c: 1. d4 d5 2. c4 c5 3. cxd5 Nf6 4. Nf3
			variation => N__('QGD: Austrian, Rubinstein, 4. Nf3'),
			moves => {
				'c5d4' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/5n2/3P4/3p4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'D06d',
			# TRANSLATORS: D06d: 1. d4 d5 2. c4 c5 3. cxd5 Nf6 4. Nf3 cxd4
			variation => N__('QGD: Austrian, Rubinstein, 4. Nf3 cxd4'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/2PP4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'D06e',
			# TRANSLATORS: D06e: 1. d4 d5 2. c4 Nf6
			variation => N__('QGD: Marshall Defence'),
			moves => {
				'b1c3' => 1,
				'c4d5' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/2PP4/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'D06f',
			# TRANSLATORS: D06f: 1. d4 d5 2. c4 Nf6 3. Nc3
			variation => N__('QGD: Marshall Defence, 3. Nc3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3p4/2PP4/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'D06g',
			# TRANSLATORS: D06g: 1. d4 d5 2. c4 Nf6 3. Nf3
			variation => N__('QGD: Marshall Defence, 3. Nf3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/3P4/3P4/8/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'D06h',
			# TRANSLATORS: D06h: 1. d4 d5 2. c4 Nf6 3. cxd5
			variation => N__('QGD: Marshall Defence, 3.cxd5'),
			moves => {
				'f6d5' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/8/3n4/3P4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'D06i',
			# TRANSLATORS: D06i: 1. d4 d5 2. c4 Nf6 3. cxd5 Nxd5
			variation => N__('QGD: Marshall Defence, 3.cxd5 Nxd5'),
			moves => {
				'e2e4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/8/3n4/3P4/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'D06j',
			# TRANSLATORS: D06j: 1. d4 d5 2. c4 Nf6 3. cxd5 Nxd5 4. Nf3
			variation => N__('QGD: Marshall Defence, 3.cxd5 Nxd5 4. Nf3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/8/3n4/3PP3/8/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'D06k',
			# TRANSLATORS: D06k: 1. d4 d5 2. c4 Nf6 3. cxd5 Nxd5 4. e4
			variation => N__('QGD: Marshall Defence, 3.cxd5 Nxd5 4. e4'),
			moves => {
			},
		},
		'rn1qkbnr/ppp1pppp/8/3p1b2/2PP4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'D06l',
			# TRANSLATORS: D06l: 1. d4 d5 2. c4 Bf5
			variation => N__('QGD: 2... Bf5'),
			moves => {
				'b1c3' => 1,
				'c4d5' => 1,
				'd1b3' => 1,
				'g1f3' => 1,
			},
		},
		'rn1qkbnr/ppp1pppp/8/3p1b2/2PP4/1Q6/PP2PPPP/RNB1KBNR b KQkq' => {
			eco => 'D06l',
			# TRANSLATORS: D06l: 1. d4 d5 2. c4 Bf5 3. Qb3
			variation => N__('QGD: 2... Bf5 3. Qb3'),
			moves => {
			},
		},
		'rn1qkbnr/ppp1pppp/8/3p1b2/2PP4/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'D06m',
			# TRANSLATORS: D06m: 1. d4 d5 2. c4 Bf5 3. Nc3
			variation => N__('QGD: 2... Bf5 3. Nc3'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rn1qkbnr/ppp2ppp/4p3/3p1b2/2PP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'D06m',
			# TRANSLATORS: D06m: 1. d4 d5 2. c4 Bf5 3. Nc3 e6
			variation => N__('QGD: 2... Bf5 3. Nc3 e6'),
			moves => {
			},
		},
		'rn1qkbnr/ppp1pppp/8/3p1b2/2PP4/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'D06n',
			# TRANSLATORS: D06n: 1. d4 d5 2. c4 Bf5 3. Nf3
			variation => N__('QGD: 2... Bf5 3. Nf3'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rn1qkbnr/ppp2ppp/4p3/3p1b2/2PP4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'D06n',
			# TRANSLATORS: D06n: 1. d4 d5 2. c4 Bf5 3. Nf3 e6
			variation => N__('QGD: 2... Bf5 3. Nf3 e6'),
			moves => {
				'b1c3' => 1,
				'd1b3' => 1,
			},
		},
		'rn1qkbnr/ppp2ppp/4p3/3p1b2/2PP4/1Q3N2/PP2PPPP/RNB1KB1R b KQkq' => {
			eco => 'D06o',
			# TRANSLATORS: D06o: 1. d4 d5 2. c4 Bf5 3. Nf3 e6 4. Qb3
			variation => N__('QGD: 2... Bf5 3. Nf3 e6 4. Qb3'),
			moves => {
			},
		},
		'rn1qkbnr/ppp2ppp/4p3/3p1b2/2PP4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D06p',
			# TRANSLATORS: D06p: 1. d4 d5 2. c4 Bf5 3. Nf3 e6 4. Nc3
			variation => N__('QGD: 2... Bf5 3. Nf3 e6 4. Nc3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rn1qkb1r/ppp2ppp/4pn2/3p1b2/2PP4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D06q',
			# TRANSLATORS: D06q: 1. d4 d5 2. c4 Bf5 3. Nf3 e6 4. Nc3 Nf6
			variation => N__('QGD: 2... Bf5 3. Nf3 e6 4. Nc3 Nf6'),
			moves => {
			},
		},
		'rn1qkbnr/ppp1pppp/8/3P1b2/3P4/8/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'D06r',
			# TRANSLATORS: D06r: 1. d4 d5 2. c4 Bf5 3. cxd5
			variation => N__('QGD: 2... Bf5 3.cxd5'),
			moves => {
				'f5b1' => 1,
			},
		},
		'rn1qkbnr/ppp1pppp/8/3P4/3P4/8/PP2PPPP/RbBQKBNR w KQkq' => {
			eco => 'D06r',
			# TRANSLATORS: D06r: 1. d4 d5 2. c4 Bf5 3. cxd5 Bxb1
			variation => N__('QGD: 2... Bf5 3.cxd5'),
			moves => {
				'a1b1' => 1,
				'd1a4' => 1,
			},
		},
		'rn1qkbnr/ppp1pppp/8/3P4/3P4/8/PP2PPPP/1RBQKBNR b Kkq' => {
			eco => 'D06s',
			# TRANSLATORS: D06s: 1. d4 d5 2. c4 Bf5 3. cxd5 Bxb1 4. Rxb1
			variation => N__('QGD: 2... Bf5 3.cxd5 Bxb1 4.Rxb1'),
			moves => {
			},
		},
		'rn1qkbnr/ppp1pppp/8/3P4/Q2P4/8/PP2PPPP/RbB1KBNR b KQkq' => {
			eco => 'D06t',
			# TRANSLATORS: D06t: 1. d4 d5 2. c4 Bf5 3. cxd5 Bxb1 4. Qa4+
			variation => N__('QGD: 2... Bf5 3.cxd5 Bxb1 4. Qa4+'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rn1qkbnr/pp2pppp/2p5/3P4/Q2P4/8/PP2PPPP/RbB1KBNR w KQkq' => {
			eco => 'D06t',
			# TRANSLATORS: D06t: 1. d4 d5 2. c4 Bf5 3. cxd5 Bxb1 4. Qa4+ c6
			variation => N__('QGD: 2... Bf5 3.cxd5 Bxb1 4. Qa4+'),
			moves => {
				'a1b1' => 1,
			},
		},
		'rn1qkbnr/pp2pppp/2p5/3P4/Q2P4/8/PP2PPPP/1RB1KBNR b Kkq' => {
			eco => 'D06u',
			# TRANSLATORS: D06u: 1. d4 d5 2. c4 Bf5 3. cxd5 Bxb1 4. Qa4+ c6 5. Rxb1
			variation => N__('QGD: 2... Bf5 3.cxd5 Bxb1 4. Qa4+ c6 5.Rxb1'),
			moves => {
			},
		},
		'r1bqkbnr/ppp1pppp/2n5/3p4/2PP4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'D07a',
			# TRANSLATORS: D07a: 1. d4 d5 2. c4 Nc6
			variation => N__('QGD: Chigorin Defence'),
			moves => {
				'b1c3' => 1,
				'c4d5' => 1,
				'e2e3' => 1,
				'g1f3' => 1,
			},
		},
		'r1bqkbnr/ppp1pppp/2n5/3p4/2PP4/4P3/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'D07b',
			# TRANSLATORS: D07b: 1. d4 d5 2. c4 Nc6 3. e3
			variation => N__('QGD: Chigorin, 3. e3'),
			moves => {
			},
		},
		'r1bqkbnr/ppp1pppp/2n5/3P4/3P4/8/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'D07c',
			# TRANSLATORS: D07c: 1. d4 d5 2. c4 Nc6 3. cxd5
			variation => N__('QGD: Chigorin, 3.cxd5'),
			moves => {
				'd8d5' => 1,
			},
		},
		'r1b1kbnr/ppp1pppp/2n5/3q4/3P4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'D07c',
			# TRANSLATORS: D07c: 1. d4 d5 2. c4 Nc6 3. cxd5 Qxd5
			variation => N__('QGD: Chigorin, 3.cxd5'),
			moves => {
				'e2e3' => 1,
			},
		},
		'r1b1kbnr/ppp1pppp/2n5/3q4/3P4/4P3/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'D07c',
			# TRANSLATORS: D07c: 1. d4 d5 2. c4 Nc6 3. cxd5 Qxd5 4. e3
			variation => N__('QGD: Chigorin, 3.cxd5'),
			moves => {
				'e7e5' => 1,
			},
		},
		'r1b1kbnr/ppp2ppp/2n5/3qp3/3P4/4P3/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'D07c',
			# TRANSLATORS: D07c: 1. d4 d5 2. c4 Nc6 3. cxd5 Qxd5 4. e3 e5
			variation => N__('QGD: Chigorin, 3.cxd5'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r1b1kbnr/ppp2ppp/2n5/3qp3/3P4/2N1P3/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'D07c',
			# TRANSLATORS: D07c: 1. d4 d5 2. c4 Nc6 3. cxd5 Qxd5 4. e3 e5 5. Nc3
			variation => N__('QGD: Chigorin, 3.cxd5'),
			moves => {
				'f8b4' => 1,
			},
		},
		'r1b1k1nr/ppp2ppp/2n5/3qp3/1b1P4/2N1P3/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'D07c',
			# TRANSLATORS: D07c: 1. d4 d5 2. c4 Nc6 3. cxd5 Qxd5 4. e3 e5 5. Nc3 Bb4
			variation => N__('QGD: Chigorin, 3.cxd5'),
			moves => {
				'c1d2' => 1,
			},
		},
		'r1b1k1nr/ppp2ppp/2n5/3qp3/1b1P4/2N1P3/PP1B1PPP/R2QKBNR b KQkq' => {
			eco => 'D07c',
			# TRANSLATORS: D07c: 1. d4 d5 2. c4 Nc6 3. cxd5 Qxd5 4. e3 e5 5. Nc3 Bb4 6. Bd2
			variation => N__('QGD: Chigorin, 3.cxd5'),
			moves => {
				'b4c3' => 1,
			},
		},
		'r1b1k1nr/ppp2ppp/2n5/3qp3/3P4/2b1P3/PP1B1PPP/R2QKBNR w KQkq' => {
			eco => 'D07c',
			# TRANSLATORS: D07c: 1. d4 d5 2. c4 Nc6 3. cxd5 Qxd5 4. e3 e5 5. Nc3 Bb4 6. Bd2 Bxc3
			variation => N__('QGD: Chigorin, 3.cxd5, Main Line'),
			moves => {
				'b2c3' => 1,
				'd2c3' => 1,
			},
		},
		'r1b1k1nr/ppp2ppp/2n5/3qp3/3P4/2P1P3/P2B1PPP/R2QKBNR b KQkq' => {
			eco => 'D07d',
			# TRANSLATORS: D07d: 1. d4 d5 2. c4 Nc6 3. cxd5 Qxd5 4. e3 e5 5. Nc3 Bb4 6. Bd2 Bxc3 7. bxc3
			variation => N__('QGD: Chigorin, 3.cxd5, Main Line, 7.bxc3'),
			moves => {
			},
		},
		'r1b1k1nr/ppp2ppp/2n5/3qp3/3P4/2B1P3/PP3PPP/R2QKBNR b KQkq' => {
			eco => 'D07e',
			# TRANSLATORS: D07e: 1. d4 d5 2. c4 Nc6 3. cxd5 Qxd5 4. e3 e5 5. Nc3 Bb4 6. Bd2 Bxc3 7. Bxc3
			variation => N__('QGD: Chigorin, 3.cxd5 Main Line, 7.Bxc3'),
			moves => {
			},
		},
		'r1bqkbnr/ppp1pppp/2n5/3p4/2PP4/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'D07f',
			# TRANSLATORS: D07f: 1. d4 d5 2. c4 Nc6 3. Nf3
			variation => N__('QGD: Chigorin, 3. Nf3'),
			moves => {
				'c8g4' => 1,
				'e7e5' => 1,
			},
		},
		'r1bqkbnr/ppp2ppp/2n5/3pp3/2PP4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'D07g',
			# TRANSLATORS: D07g: 1. d4 d5 2. c4 Nc6 3. Nf3 e5
			variation => N__('QGD: Chigorin, Lazard Gambit'),
			moves => {
			},
		},
		'r2qkbnr/ppp1pppp/2n5/3p4/2PP2b1/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'D07h',
			# TRANSLATORS: D07h: 1. d4 d5 2. c4 Nc6 3. Nf3 Bg4
			variation => N__('QGD: Chigorin, 3. Nf3 Bg4'),
			moves => {
				'b1c3' => 1,
				'c4d5' => 1,
				'e2e3' => 1,
			},
		},
		'r2qkbnr/ppp1pppp/2n5/3p4/2PP2b1/4PN2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'D07i',
			# TRANSLATORS: D07i: 1. d4 d5 2. c4 Nc6 3. Nf3 Bg4 4. e3
			variation => N__('QGD: Chigorin, 3. Nf3 Bg4 4. e3'),
			moves => {
			},
		},
		'r2qkbnr/ppp1pppp/2n5/3p4/2PP2b1/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D07j',
			# TRANSLATORS: D07j: 1. d4 d5 2. c4 Nc6 3. Nf3 Bg4 4. Nc3
			variation => N__('QGD: Chigorin, 3. Nf3 Bg4 4. Nc3'),
			moves => {
			},
		},
		'r2qkbnr/ppp1pppp/2n5/3P4/3P2b1/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'D07k',
			# TRANSLATORS: D07k: 1. d4 d5 2. c4 Nc6 3. Nf3 Bg4 4. cxd5
			variation => N__('QGD: Chigorin, 3. Nf3 Bg4 4.cxd5'),
			moves => {
				'g4f3' => 1,
			},
		},
		'r2qkbnr/ppp1pppp/2n5/3P4/3P4/5b2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'D07k',
			# TRANSLATORS: D07k: 1. d4 d5 2. c4 Nc6 3. Nf3 Bg4 4. cxd5 Bxf3
			variation => N__('QGD: Chigorin, 3. Nf3 Bg4 4.cxd5'),
			moves => {
				'd5c6' => 1,
				'g2f3' => 1,
			},
		},
		'r2qkbnr/ppp1pppp/2P5/8/3P4/5b2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'D07l',
			# TRANSLATORS: D07l: 1. d4 d5 2. c4 Nc6 3. Nf3 Bg4 4. cxd5 Bxf3 5. dxc6
			variation => N__('QGD: Chigorin, 3. Nf3 Bg4 4.cxd5 Bxf3 5.dxc6'),
			moves => {
			},
		},
		'r2qkbnr/ppp1pppp/2n5/3P4/3P4/5P2/PP2PP1P/RNBQKB1R b KQkq' => {
			eco => 'D07m',
			# TRANSLATORS: D07m: 1. d4 d5 2. c4 Nc6 3. Nf3 Bg4 4. cxd5 Bxf3 5. gxf3
			variation => N__('QGD: Chigorin, 3. Nf3 Bg4 4.cxd5 Bxf3 5.gxf3'),
			moves => {
			},
		},
		'r1bqkbnr/ppp1pppp/2n5/3p4/2PP4/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'D07n',
			# TRANSLATORS: D07n: 1. d4 d5 2. c4 Nc6 3. Nc3
			variation => N__('QGD: Chigorin, 3. Nc3'),
			moves => {
				'd5c4' => 1,
				'e7e5' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkbnr/ppp2ppp/2n5/3pp3/2PP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'D07o',
			# TRANSLATORS: D07o: 1. d4 d5 2. c4 Nc6 3. Nc3 e5
			variation => N__('QGD: Chigorin, Tartakower Gambit'),
			moves => {
			},
		},
		'r1bqkb1r/ppp1pppp/2n2n2/3p4/2PP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'D07p',
			# TRANSLATORS: D07p: 1. d4 d5 2. c4 Nc6 3. Nc3 Nf6
			variation => N__('QGD: Chigorin, 3. Nc3 Nf6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'r1bqkb1r/ppp1pppp/2n2n2/3p4/2PP4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D07q',
			# TRANSLATORS: D07q: 1. d4 d5 2. c4 Nc6 3. Nc3 Nf6 4. Nf3
			variation => N__('QGD: Chigorin, 3. Nc3 Nf6 4. Nf3'),
			moves => {
				'c8g4' => 1,
			},
		},
		'r2qkb1r/ppp1pppp/2n2n2/3p4/2PP2b1/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D07r',
			# TRANSLATORS: D07r: 1. d4 d5 2. c4 Nc6 3. Nc3 Nf6 4. Nf3 Bg4
			variation => N__('QGD: Chigorin, 3. Nc3 Nf6 4. Nf3 Bg4'),
			moves => {
			},
		},
		'r1bqkbnr/ppp1pppp/2n5/8/2pP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'D07s',
			# TRANSLATORS: D07s: 1. d4 d5 2. c4 Nc6 3. Nc3 dxc4
			variation => N__('QGD: Chigorin, 3. Nc3 dxc4'),
			moves => {
				'd4d5' => 1,
				'g1f3' => 1,
			},
		},
		'r1bqkbnr/ppp1pppp/2n5/3P4/2p5/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'D07t',
			# TRANSLATORS: D07t: 1. d4 d5 2. c4 Nc6 3. Nc3 dxc4 4. d5
			variation => N__('QGD: Chigorin, 3. Nc3 dxc4 4. d5'),
			moves => {
			},
		},
		'r1bqkbnr/ppp1pppp/2n5/8/2pP4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D07u',
			# TRANSLATORS: D07u: 1. d4 d5 2. c4 Nc6 3. Nc3 dxc4 4. Nf3
			variation => N__('QGD: Chigorin, 3. Nc3 dxc4 4. Nf3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r1bqkb1r/ppp1pppp/2n2n2/8/2pP4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D07v',
			# TRANSLATORS: D07v: 1. d4 d5 2. c4 Nc6 3. Nc3 dxc4 4. Nf3 Nf6
			variation => N__('QGD: Chigorin, 3. Nc3 dxc4 4. Nf3 Nf6'),
			moves => {
				'e2e4' => 1,
			},
		},
		'r1bqkb1r/ppp1pppp/2n2n2/8/2pPP3/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'D07w',
			# TRANSLATORS: D07w: 1. d4 d5 2. c4 Nc6 3. Nc3 dxc4 4. Nf3 Nf6 5. e4
			variation => N__('QGD: Chigorin, 3. Nc3 dxc4 4. Nf3 Nf6 5. e4'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/8/3pp3/2PP4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'D08',
			# TRANSLATORS: D08: 1. d4 d5 2. c4 e5
			variation => N__('QGD: Albin Countergambit'),
			moves => {
				'd4e5' => 1,
				'e2e3' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/8/3pP3/2P5/8/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'D08',
			# TRANSLATORS: D08: 1. d4 d5 2. c4 e5 3. dxe5
			variation => N__('QGD: Albin, 3.dxe5'),
			moves => {
				'd5d4' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/8/4P3/2Pp4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'D08',
			# TRANSLATORS: D08: 1. d4 d5 2. c4 e5 3. dxe5 d4
			variation => N__('QGD: Albin, 3.dxe5 d4'),
			moves => {
				'a2a3' => 1,
				'e2e3' => 1,
				'e2e4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/8/4P3/2Pp4/P7/1P2PPPP/RNBQKBNR b KQkq' => {
			eco => 'D08',
			# TRANSLATORS: D08: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. a3
			variation => N__('QGD: Albin, 4. a3'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/8/4P3/2Pp4/4P3/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'D08',
			# TRANSLATORS: D08: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. e3
			variation => N__('QGD: Albin, 3.dxe5 d4'),
			moves => {
				'f8b4' => 1,
			},
		},
		'rnbqk1nr/ppp2ppp/8/4P3/1bPp4/4P3/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'D08',
			# TRANSLATORS: D08: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. e3 Bb4+
			variation => N__('QGD: Albin, 3.dxe5 d4'),
			moves => {
				'c1d2' => 1,
			},
		},
		'rnbqk1nr/ppp2ppp/8/4P3/1bPp4/4P3/PP1B1PPP/RN1QKBNR b KQkq' => {
			eco => 'D08',
			# TRANSLATORS: D08: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. e3 Bb4+ 5. Bd2
			variation => N__('QGD: Albin, 3.dxe5 d4'),
			moves => {
				'd4e3' => 1,
			},
		},
		'rnbqk1nr/ppp2ppp/8/4P3/1bP5/4p3/PP1B1PPP/RN1QKBNR w KQkq' => {
			eco => 'D08',
			# TRANSLATORS: D08: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. e3 Bb4+ 5. Bd2 dxe3
			variation => N__('QGD: Albin, Lasker Trap'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/8/4P3/2PpP3/8/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'D08',
			# TRANSLATORS: D08: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. e4
			variation => N__('QGD: Albin, 4. e4'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/8/4P3/2Pp4/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'D08',
			# TRANSLATORS: D08: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. Nf3
			variation => N__('QGD: Albin, 4. Nf3'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkbnr/ppp2ppp/2n5/4P3/2Pp4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'D08',
			# TRANSLATORS: D08: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. Nf3 Nc6
			variation => N__('QGD: Albin, 4. Nf3 Nc6'),
			moves => {
				'a2a3' => 1,
				'b1d2' => 1,
				'g2g3' => 1,
			},
		},
		'r1bqkbnr/ppp2ppp/2n5/4P3/2Pp4/P4N2/1P2PPPP/RNBQKB1R b KQkq' => {
			eco => 'D08',
			# TRANSLATORS: D08: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. Nf3 Nc6 5. a3
			variation => N__('QGD: Albin, 4. Nf3 Nc6 5. a3'),
			moves => {
				'a7a5' => 1,
				'c8e6' => 1,
				'c8g4' => 1,
			},
		},
		'r1bqkbnr/1pp2ppp/2n5/p3P3/2Pp4/P4N2/1P2PPPP/RNBQKB1R w KQkq' => {
			eco => 'D08',
			# TRANSLATORS: D08: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. Nf3 Nc6 5. a3 a5
			variation => N__('QGD: Albin, 4. Nf3 Nc6 5. a3 a5'),
			moves => {
			},
		},
		'r2qkbnr/ppp2ppp/2n1b3/4P3/2Pp4/P4N2/1P2PPPP/RNBQKB1R w KQkq' => {
			eco => 'D08',
			# TRANSLATORS: D08: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. Nf3 Nc6 5. a3 Be6
			variation => N__('QGD: Albin, 4. Nf3 Nc6 5. a3 Be6'),
			moves => {
			},
		},
		'r2qkbnr/ppp2ppp/2n5/4P3/2Pp2b1/P4N2/1P2PPPP/RNBQKB1R w KQkq' => {
			eco => 'D08',
			# TRANSLATORS: D08: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. Nf3 Nc6 5. a3 Bg4
			variation => N__('QGD: Albin, 4. Nf3 Nc6 5. a3 Bg4'),
			moves => {
				'b1d2' => 1,
			},
		},
		'r2qkbnr/ppp2ppp/2n5/4P3/2Pp2b1/P4N2/1P1NPPPP/R1BQKB1R b KQkq' => {
			eco => 'D08',
			# TRANSLATORS: D08: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. Nf3 Nc6 5. a3 Bg4 6. Nbd2
			variation => N__('QGD: Albin, 4. Nf3 Nc6 5. a3 Bg4 6.Nbd2'),
			moves => {
			},
		},
		'r1bqkbnr/ppp2ppp/2n5/4P3/2Pp4/5N2/PP1NPPPP/R1BQKB1R b KQkq' => {
			eco => 'D08',
			# TRANSLATORS: D08: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. Nf3 Nc6 5. Nbd2
			variation => N__('QGD: Albin, Alapin Variation'),
			moves => {
				'c8g4' => 1,
				'd8e7' => 1,
				'f7f6' => 1,
			},
		},
		'r2qkbnr/ppp2ppp/2n5/4P3/2Pp2b1/5N2/PP1NPPPP/R1BQKB1R w KQkq' => {
			eco => 'D08',
			# TRANSLATORS: D08: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. Nf3 Nc6 5. Nbd2 Bg4
			variation => N__('QGD: Albin, Alapin, 5... Bg4'),
			moves => {
				'h2h3' => 1,
			},
		},
		'r2qkbnr/ppp2ppp/2n5/4P3/2Pp2b1/5N1P/PP1NPPP1/R1BQKB1R b KQkq' => {
			eco => 'D08',
			# TRANSLATORS: D08: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. Nf3 Nc6 5. Nbd2 Bg4 6. h3
			variation => N__('QGD: Albin, Alapin, 5... Bg4'),
			moves => {
				'g4f3' => 1,
			},
		},
		'r2qkbnr/ppp2ppp/2n5/4P3/2Pp4/5b1P/PP1NPPP1/R1BQKB1R w KQkq' => {
			eco => 'D08',
			# TRANSLATORS: D08: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. Nf3 Nc6 5. Nbd2 Bg4 6. h3 Bxf3
			variation => N__('QGD: Albin, Alapin, 5... Bg4'),
			moves => {
				'd2f3' => 1,
			},
		},
		'r2qkbnr/ppp2ppp/2n5/4P3/2Pp4/5N1P/PP2PPP1/R1BQKB1R b KQkq' => {
			eco => 'D08',
			# TRANSLATORS: D08: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. Nf3 Nc6 5. Nbd2 Bg4 6. h3 Bxf3 7. Nxf3
			variation => N__('QGD: Albin, Alapin, 5... Bg4'),
			moves => {
				'f8b4' => 1,
			},
		},
		'r2qk1nr/ppp2ppp/2n5/4P3/1bPp4/5N1P/PP2PPP1/R1BQKB1R w KQkq' => {
			eco => 'D08',
			# TRANSLATORS: D08: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. Nf3 Nc6 5. Nbd2 Bg4 6. h3 Bxf3 7. Nxf3 Bb4+
			variation => N__('QGD: Albin, Alapin, 5... Bg4'),
			moves => {
				'c1d2' => 1,
			},
		},
		'r2qk1nr/ppp2ppp/2n5/4P3/1bPp4/5N1P/PP1BPPP1/R2QKB1R b KQkq' => {
			eco => 'D08',
			# TRANSLATORS: D08: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. Nf3 Nc6 5. Nbd2 Bg4 6. h3 Bxf3 7. Nxf3 Bb4+ 8. Bd2
			variation => N__('QGD: Albin, Alapin, 5... Bg4'),
			moves => {
				'd8e7' => 1,
			},
		},
		'r3k1nr/ppp1qppp/2n5/4P3/1bPp4/5N1P/PP1BPPP1/R2QKB1R w KQkq' => {
			eco => 'D08',
			# TRANSLATORS: D08: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. Nf3 Nc6 5. Nbd2 Bg4 6. h3 Bxf3 7. Nxf3 Bb4+ 8. Bd2 Qe7
			variation => N__('QGD: Albin, Krenosz Variation'),
			moves => {
			},
		},
		'r1b1kbnr/ppp1qppp/2n5/4P3/2Pp4/5N2/PP1NPPPP/R1BQKB1R w KQkq' => {
			eco => 'D08',
			# TRANSLATORS: D08: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. Nf3 Nc6 5. Nbd2 Qe7
			variation => N__('QGD: Albin, Balogh Variation'),
			moves => {
			},
		},
		'r1bqkbnr/ppp3pp/2n2p2/4P3/2Pp4/5N2/PP1NPPPP/R1BQKB1R w KQkq' => {
			eco => 'D08',
			# TRANSLATORS: D08: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. Nf3 Nc6 5. Nbd2 f6
			variation => N__('QGD: Albin, Janowski Variation'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/8/3pp3/2PP4/4P3/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'D08',
			# TRANSLATORS: D08: 1. d4 d5 2. c4 e5 3. e3
			variation => N__('QGD: Albin, 3. e3'),
			moves => {
			},
		},
		'r1bqkbnr/ppp2ppp/2n5/4P3/2Pp4/5NP1/PP2PP1P/RNBQKB1R b KQkq' => {
			eco => 'D09',
			# TRANSLATORS: D09: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. Nf3 Nc6 5. g3
			variation => N__('QGD: Albin, 5. g3'),
			moves => {
				'c8e6' => 1,
				'c8f5' => 1,
				'c8g4' => 1,
				'g8e7' => 1,
			},
		},
		'r2qkbnr/ppp2ppp/2n1b3/4P3/2Pp4/5NP1/PP2PP1P/RNBQKB1R w KQkq' => {
			eco => 'D09',
			# TRANSLATORS: D09: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. Nf3 Nc6 5. g3 Be6
			variation => N__('QGD: Albin, 5. g3 Be6'),
			moves => {
				'b1d2' => 1,
				'b2b3' => 1,
				'f1g2' => 1,
			},
		},
		'r2qkbnr/ppp2ppp/2n1b3/4P3/2Pp4/5NP1/PP1NPP1P/R1BQKB1R b KQkq' => {
			eco => 'D09',
			# TRANSLATORS: D09: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. Nf3 Nc6 5. g3 Be6 6. Nbd2
			variation => N__('QGD: Albin, 5. g3 Be6 6.Nbd2'),
			moves => {
				'd8d7' => 1,
			},
		},
		'r3kbnr/pppq1ppp/2n1b3/4P3/2Pp4/5NP1/PP1NPP1P/R1BQKB1R w KQkq' => {
			eco => 'D09',
			# TRANSLATORS: D09: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. Nf3 Nc6 5. g3 Be6 6. Nbd2 Qd7
			variation => N__('QGD: Albin, 5. g3 Be6 6.Nbd2 Qd7'),
			moves => {
				'f1g2' => 1,
			},
		},
		'r3kbnr/pppq1ppp/2n1b3/4P3/2Pp4/5NP1/PP1NPPBP/R1BQK2R b KQkq' => {
			eco => 'D09',
			# TRANSLATORS: D09: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. Nf3 Nc6 5. g3 Be6 6. Nbd2 Qd7 7. Bg2
			variation => N__('QGD: Albin, 5. g3 Be6 6.Nbd2 Qd7 7. Bg2'),
			moves => {
				'e8c8' => 1,
				'g8e7' => 1,
			},
		},
		'2kr1bnr/pppq1ppp/2n1b3/4P3/2Pp4/5NP1/PP1NPPBP/R1BQK2R w KQ' => {
			eco => 'D09',
			# TRANSLATORS: D09: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. Nf3 Nc6 5. g3 Be6 6. Nbd2 Qd7 7. Bg2 O-O-O
			variation => N__('QGD: Albin, 5. g3 Be6 6.Nbd2 Qd7 7. Bg2 O-O-O'),
			moves => {
			},
		},
		'r3kb1r/pppqnppp/2n1b3/4P3/2Pp4/5NP1/PP1NPPBP/R1BQK2R w KQkq' => {
			eco => 'D09',
			# TRANSLATORS: D09: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. Nf3 Nc6 5. g3 Be6 6. Nbd2 Qd7 7. Bg2 Nge7
			variation => N__('QGD: Albin, 5. g3 Be6 6.Nbd2 Qd7 7. Bg2 Nge7'),
			moves => {
			},
		},
		'r2qkbnr/ppp2ppp/2n1b3/4P3/2Pp4/1P3NP1/P3PP1P/RNBQKB1R b KQkq' => {
			eco => 'D09',
			# TRANSLATORS: D09: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. Nf3 Nc6 5. g3 Be6 6. b3
			variation => N__('QGD: Albin, 5. g3 Be6 6. b3'),
			moves => {
			},
		},
		'r2qkbnr/ppp2ppp/2n1b3/4P3/2Pp4/5NP1/PP2PPBP/RNBQK2R b KQkq' => {
			eco => 'D09',
			# TRANSLATORS: D09: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. Nf3 Nc6 5. g3 Be6 6. Bg2
			variation => N__('QGD: Albin, 5. g3 Be6 6. Bg2'),
			moves => {
			},
		},
		'r2qkbnr/ppp2ppp/2n5/4Pb2/2Pp4/5NP1/PP2PP1P/RNBQKB1R w KQkq' => {
			eco => 'D09',
			# TRANSLATORS: D09: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. Nf3 Nc6 5. g3 Bf5
			variation => N__('QGD: Albin, 5. g3 Bf5'),
			moves => {
			},
		},
		'r2qkbnr/ppp2ppp/2n5/4P3/2Pp2b1/5NP1/PP2PP1P/RNBQKB1R w KQkq' => {
			eco => 'D09',
			# TRANSLATORS: D09: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. Nf3 Nc6 5. g3 Bg4
			variation => N__('QGD: Albin, 5. g3 Bg4'),
			moves => {
				'f1g2' => 1,
			},
		},
		'r2qkbnr/ppp2ppp/2n5/4P3/2Pp2b1/5NP1/PP2PPBP/RNBQK2R b KQkq' => {
			eco => 'D09',
			# TRANSLATORS: D09: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. Nf3 Nc6 5. g3 Bg4 6. Bg2
			variation => N__('QGD: Albin, 5. g3 Bg4'),
			moves => {
				'd8d7' => 1,
			},
		},
		'r3kbnr/pppq1ppp/2n5/4P3/2Pp2b1/5NP1/PP2PPBP/RNBQK2R w KQkq' => {
			eco => 'D09',
			# TRANSLATORS: D09: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. Nf3 Nc6 5. g3 Bg4 6. Bg2 Qd7
			variation => N__('QGD: Albin, 5. g3 Bg4 6. Bg2 Qd7'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r3kbnr/pppq1ppp/2n5/4P3/2Pp2b1/5NP1/PP2PPBP/RNBQ1RK1 b kq' => {
			eco => 'D09',
			# TRANSLATORS: D09: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. Nf3 Nc6 5. g3 Bg4 6. Bg2 Qd7 7. O-O
			variation => N__('QGD: Albin, 5. g3 Bg4 6. Bg2 Qd7'),
			moves => {
				'e8c8' => 1,
			},
		},
		'2kr1bnr/pppq1ppp/2n5/4P3/2Pp2b1/5NP1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'D09',
			# TRANSLATORS: D09: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. Nf3 Nc6 5. g3 Bg4 6. Bg2 Qd7 7. O-O O-O-O
			variation => N__('QGD: Albin, 5. g3 Bg4 6. Bg2 Qd7 7.O-O O-O-O'),
			moves => {
			},
		},
		'r1bqkb1r/ppp1nppp/2n5/4P3/2Pp4/5NP1/PP2PP1P/RNBQKB1R w KQkq' => {
			eco => 'D09',
			# TRANSLATORS: D09: 1. d4 d5 2. c4 e5 3. dxe5 d4 4. Nf3 Nc6 5. g3 Nge7
			variation => N__('QGD: Albin, 5. g3 Nge7'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3p4/2PP4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'D10a',
			# TRANSLATORS: D10a: 1. d4 d5 2. c4 c6
			variation => N__('Slav Defence'),
			moves => {
				'b1c3' => 1,
				'c1f4' => 1,
				'c4d5' => 1,
				'e2e3' => 1,
				'e2e4' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3p4/2PP1B2/8/PP2PPPP/RN1QKBNR b KQkq' => {
			eco => 'D10a',
			# TRANSLATORS: D10a: 1. d4 d5 2. c4 c6 3. Bf4
			variation => N__('Slav: 3. Bf4'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3p4/2PPP3/8/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'D10a',
			# TRANSLATORS: D10a: 1. d4 d5 2. c4 c6 3. e4
			variation => N__('Diemer-Duhm Gambit (DDG) vs. Slav/Caro-Kann'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3p4/2PP4/6P1/PP2PP1P/RNBQKBNR b KQkq' => {
			eco => 'D10a',
			# TRANSLATORS: D10a: 1. d4 d5 2. c4 c6 3. g3
			variation => N__('Slav: 3. g3'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3P4/3P4/8/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'D10b',
			# TRANSLATORS: D10b: 1. d4 d5 2. c4 c6 3. cxd5
			variation => N__('Slav: Exchange'),
			moves => {
				'c6d5' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/8/3p4/3P4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'D10b',
			# TRANSLATORS: D10b: 1. d4 d5 2. c4 c6 3. cxd5 cxd5
			variation => N__('Slav: Exchange'),
			moves => {
				'b1c3' => 1,
				'c1f4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/8/3p4/3P1B2/8/PP2PPPP/RN1QKBNR b KQkq' => {
			eco => 'D10c',
			# TRANSLATORS: D10c: 1. d4 d5 2. c4 c6 3. cxd5 cxd5 4. Bf4
			variation => N__('Slav: Exchange, 4. Bf4'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/8/3p4/3P4/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'D10d',
			# TRANSLATORS: D10d: 1. d4 d5 2. c4 c6 3. cxd5 cxd5 4. Nf3
			variation => N__('Slav: Exchange, 4. Nf3'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/8/3p4/3P4/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'D10e',
			# TRANSLATORS: D10e: 1. d4 d5 2. c4 c6 3. cxd5 cxd5 4. Nc3
			variation => N__('Slav: Exchange, 4. Nc3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/5n2/3p4/3P4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'D10e',
			# TRANSLATORS: D10e: 1. d4 d5 2. c4 c6 3. cxd5 cxd5 4. Nc3 Nf6
			variation => N__('Slav: Exchange, 4. Nc3 Nf6'),
			moves => {
				'c1f4' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/5n2/3p4/3P1B2/2N5/PP2PPPP/R2QKBNR b KQkq' => {
			eco => 'D10e',
			# TRANSLATORS: D10e: 1. d4 d5 2. c4 c6 3. cxd5 cxd5 4. Nc3 Nf6 5. Bf4
			variation => N__('Slav: Exchange, 4. Nc3 Nf6 5. Bf4'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkb1r/pp2pppp/2n2n2/3p4/3P1B2/2N5/PP2PPPP/R2QKBNR w KQkq' => {
			eco => 'D10f',
			# TRANSLATORS: D10f: 1. d4 d5 2. c4 c6 3. cxd5 cxd5 4. Nc3 Nf6 5. Bf4 Nc6
			variation => N__('Slav: Exchange, 4. Nc3 Nf6 5. Bf4 Nc6'),
			moves => {
				'e2e3' => 1,
			},
		},
		'r1bqkb1r/pp2pppp/2n2n2/3p4/3P1B2/2N1P3/PP3PPP/R2QKBNR b KQkq' => {
			eco => 'D10f',
			# TRANSLATORS: D10f: 1. d4 d5 2. c4 c6 3. cxd5 cxd5 4. Nc3 Nf6 5. Bf4 Nc6 6. e3
			variation => N__('Slav: Exchange, 4. Nc3 Nf6 5. Bf4 Nc6 6. e3'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r1bqkb1r/1p2pppp/p1n2n2/3p4/3P1B2/2N1P3/PP3PPP/R2QKBNR w KQkq' => {
			eco => 'D10g',
			# TRANSLATORS: D10g: 1. d4 d5 2. c4 c6 3. cxd5 cxd5 4. Nc3 Nf6 5. Bf4 Nc6 6. e3 a6
			variation => N__('Slav: Exchange, 4. Nc3 Nf6 5. Bf4 Nc6 6. e3 a6'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3p4/2PP4/4P3/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'D10h',
			# TRANSLATORS: D10h: 1. d4 d5 2. c4 c6 3. e3
			variation => N__('Slav: 3. e3'),
			moves => {
				'c8f5' => 1,
				'g8f6' => 1,
			},
		},
		'rn1qkbnr/pp2pppp/2p5/3p1b2/2PP4/4P3/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'D10h',
			# TRANSLATORS: D10h: 1. d4 d5 2. c4 c6 3. e3 Bf5
			variation => N__('Slav: 3. e3 Bf5'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/3p4/2PP4/4P3/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'D10h',
			# TRANSLATORS: D10h: 1. d4 d5 2. c4 c6 3. e3 Nf6
			variation => N__('Slav: 3. e3 Nf6'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3p4/2PP4/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'D10i',
			# TRANSLATORS: D10i: 1. d4 d5 2. c4 c6 3. Nc3
			variation => N__('Slav: 3. Nc3'),
			moves => {
				'd5c4' => 1,
				'e7e5' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/2p5/3pp3/2PP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'D10j',
			# TRANSLATORS: D10j: 1. d4 d5 2. c4 c6 3. Nc3 e5
			variation => N__('Slav: Winawer Countergambit'),
			moves => {
				'c4d5' => 1,
				'd4e5' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/2p5/3Pp3/3P4/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'D10k',
			# TRANSLATORS: D10k: 1. d4 d5 2. c4 c6 3. Nc3 e5 4. cxd5
			variation => N__('Slav: Winawer Countergambit, 4.cxd5'),
			moves => {
				'c6d5' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/8/3pp3/3P4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'D10k',
			# TRANSLATORS: D10k: 1. d4 d5 2. c4 c6 3. Nc3 e5 4. cxd5 cxd5
			variation => N__('Slav: Winawer Countergambit, 4.cxd5'),
			moves => {
				'd4e5' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/8/3pP3/8/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'D10k',
			# TRANSLATORS: D10k: 1. d4 d5 2. c4 c6 3. Nc3 e5 4. cxd5 cxd5 5. dxe5
			variation => N__('Slav: Winawer Countergambit, 4.cxd5 cxd5 5.dxe5'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/8/3pp3/3P4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D10l',
			# TRANSLATORS: D10l: 1. d4 d5 2. c4 c6 3. Nc3 e5 4. cxd5 cxd5 5. Nf3
			variation => N__('Slav: Winawer Countergambit, 4.cxd5 cxd5 5. Nf3'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/2p5/3pP3/2P5/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'D10m',
			# TRANSLATORS: D10m: 1. d4 d5 2. c4 c6 3. Nc3 e5 4. dxe5
			variation => N__('Slav: Winawer Countergambit Accepted'),
			moves => {
				'd5d4' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/2p5/4P3/2Pp4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'D10m',
			# TRANSLATORS: D10m: 1. d4 d5 2. c4 c6 3. Nc3 e5 4. dxe5 d4
			variation => N__('Slav: Winawer Countergambit Accepted'),
			moves => {
				'c3e4' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/2p5/4P3/2PpN3/8/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'D10m',
			# TRANSLATORS: D10m: 1. d4 d5 2. c4 c6 3. Nc3 e5 4. dxe5 d4 5. Ne4
			variation => N__('Slav: Winawer Countergambit Accepted'),
			moves => {
				'd8a5' => 1,
			},
		},
		'rnb1kbnr/pp3ppp/2p5/q3P3/2PpN3/8/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'D10m',
			# TRANSLATORS: D10m: 1. d4 d5 2. c4 c6 3. Nc3 e5 4. dxe5 d4 5. Ne4 Qa5+
			variation => N__('Slav: Winawer Countergambit Accepted'),
			moves => {
				'c1d2' => 1,
				'e4d2' => 1,
			},
		},
		'rnb1kbnr/pp3ppp/2p5/q3P3/2Pp4/8/PP1NPPPP/R1BQKBNR b KQkq' => {
			eco => 'D10m',
			# TRANSLATORS: D10m: 1. d4 d5 2. c4 c6 3. Nc3 e5 4. dxe5 d4 5. Ne4 Qa5+ 6. Nd2
			variation => N__('Slav: Winawer Countergambit Accepted, 6. Nd2'),
			moves => {
			},
		},
		'rnb1kbnr/pp3ppp/2p5/q3P3/2PpN3/8/PP1BPPPP/R2QKBNR b KQkq' => {
			eco => 'D10n',
			# TRANSLATORS: D10n: 1. d4 d5 2. c4 c6 3. Nc3 e5 4. dxe5 d4 5. Ne4 Qa5+ 6. Bd2
			variation => N__('Slav: Winawer Countergambit Accepted, 6. Bd2'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/2p5/8/2pP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'D10o',
			# TRANSLATORS: D10o: 1. d4 d5 2. c4 c6 3. Nc3 dxc4
			variation => N__('Slav: 3. Nc3 dxc4'),
			moves => {
				'a2a4' => 1,
				'e2e3' => 1,
				'e2e4' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/2p5/8/P1pP4/2N5/1P2PPPP/R1BQKBNR b KQkq' => {
			eco => 'D10o',
			# TRANSLATORS: D10o: 1. d4 d5 2. c4 c6 3. Nc3 dxc4 4. a4
			variation => N__('Slav: 3. Nc3 dxc4 4. a4'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/2p5/8/2pP4/2N1P3/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'D10o',
			# TRANSLATORS: D10o: 1. d4 d5 2. c4 c6 3. Nc3 dxc4 4. e3
			variation => N__('Slav: 3. Nc3 dxc4 4. e3'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/2p5/8/2pPP3/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'D10p',
			# TRANSLATORS: D10p: 1. d4 d5 2. c4 c6 3. Nc3 dxc4 4. e4
			variation => N__('Slav: 3. Nc3 dxc4 4. e4'),
			moves => {
				'b7b5' => 1,
			},
		},
		'rnbqkbnr/p3pppp/2p5/1p6/2pPP3/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'D10q',
			# TRANSLATORS: D10q: 1. d4 d5 2. c4 c6 3. Nc3 dxc4 4. e4 b5
			variation => N__('Slav: 3. Nc3 dxc4 4. e4 b5'),
			moves => {
				'a2a4' => 1,
			},
		},
		'rnbqkbnr/p3pppp/2p5/1p6/P1pPP3/2N5/1P3PPP/R1BQKBNR b KQkq' => {
			eco => 'D10r',
			# TRANSLATORS: D10r: 1. d4 d5 2. c4 c6 3. Nc3 dxc4 4. e4 b5 5. a4
			variation => N__('Slav: 3. Nc3 dxc4 4. e4 b5 5. a4'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/3p4/2PP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'D10r',
			# TRANSLATORS: D10r: 1. d4 d5 2. c4 c6 3. Nc3 Nf6
			variation => N__('Slav: 3. Nc3 Nf6'),
			moves => {
				'c1g5' => 1,
				'e2e3' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/3p2B1/2PP4/2N5/PP2PPPP/R2QKBNR b KQkq' => {
			eco => 'D10s',
			# TRANSLATORS: D10s: 1. d4 d5 2. c4 c6 3. Nc3 Nf6 4. Bg5
			variation => N__('Slav: 3. Nc3 Nf6 4. Bg5'),
			moves => {
				'd5c4' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/6B1/2pP4/2N5/PP2PPPP/R2QKBNR w KQkq' => {
			eco => 'D10t',
			# TRANSLATORS: D10t: 1. d4 d5 2. c4 c6 3. Nc3 Nf6 4. Bg5 dxc4
			variation => N__('Slav: 3. Nc3 Nf6 4. Bg5 dxc4'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/3p4/2PP4/2N1P3/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'D10u',
			# TRANSLATORS: D10u: 1. d4 d5 2. c4 c6 3. Nc3 Nf6 4. e3
			variation => N__('Slav: 3. Nc3 Nf6 4. e3'),
			moves => {
				'a7a6' => 1,
				'c8f5' => 1,
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/3p1b2/2PP4/2N1P3/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'D10v',
			# TRANSLATORS: D10v: 1. d4 d5 2. c4 c6 3. Nc3 Nf6 4. e3 Bf5
			variation => N__('Slav: 3. Nc3 Nf6 4. e3 Bf5'),
			moves => {
			},
		},
		'rnbqkb1r/1p2pppp/p1p2n2/3p4/2PP4/2N1P3/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'D10w',
			# TRANSLATORS: D10w: 1. d4 d5 2. c4 c6 3. Nc3 Nf6 4. e3 a6
			variation => N__('Slav: 3. Nc3 Nf6 4. e3 a6'),
			moves => {
				'd1c2' => 1,
				'f1d3' => 1,
			},
		},
		'rnbqkb1r/1p2pppp/p1p2n2/3p4/2PP4/2NBP3/PP3PPP/R1BQK1NR b KQkq' => {
			eco => 'D10w',
			# TRANSLATORS: D10w: 1. d4 d5 2. c4 c6 3. Nc3 Nf6 4. e3 a6 5. Bd3
			variation => N__('Slav: 3. Nc3 Nf6 4. e3 a6 5. Bd3'),
			moves => {
			},
		},
		'rnbqkb1r/1p2pppp/p1p2n2/3p4/2PP4/2N1P3/PPQ2PPP/R1B1KBNR b KQkq' => {
			eco => 'D10x',
			# TRANSLATORS: D10x: 1. d4 d5 2. c4 c6 3. Nc3 Nf6 4. e3 a6 5. Qc2
			variation => N__('Slav: 3. Nc3 Nf6 4. e3 a6 5. Qc2'),
			moves => {
				'b7b5' => 1,
			},
		},
		'rnbqkb1r/4pppp/p1p2n2/1p1p4/2PP4/2N1P3/PPQ2PPP/R1B1KBNR w KQkq' => {
			eco => 'D10y',
			# TRANSLATORS: D10y: 1. d4 d5 2. c4 c6 3. Nc3 Nf6 4. e3 a6 5. Qc2 b5
			variation => N__('Slav: 3. Nc3 Nf6 4. e3 a6 5. Qc2 b5'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/2p5/3p4/2PP4/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'D11a',
			# TRANSLATORS: D11a: 1. d4 d5 2. c4 c6 3. Nf3
			variation => N__('Slav: 3. Nf3'),
			moves => {
				'c8f5' => 1,
				'c8g4' => 1,
				'd5c4' => 1,
				'g8f6' => 1,
			},
		},
		'rn1qkbnr/pp2pppp/2p5/3p4/2PP2b1/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'D11b',
			# TRANSLATORS: D11b: 1. d4 d5 2. c4 c6 3. Nf3 Bg4
			variation => N__('Slav: 3. Nf3 Bg4'),
			moves => {
			},
		},
		'rn1qkbnr/pp2pppp/2p5/3p1b2/2PP4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'D11c',
			# TRANSLATORS: D11c: 1. d4 d5 2. c4 c6 3. Nf3 Bf5
			variation => N__('Slav: 3. Nf3 Bf5'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rn1qkbnr/pp2pppp/2p5/3p1b2/2PP4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D11c',
			# TRANSLATORS: D11c: 1. d4 d5 2. c4 c6 3. Nf3 Bf5 4. Nc3
			variation => N__('Slav: 3. Nf3 Bf5 4. Nc3'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rn1qkbnr/pp3ppp/2p1p3/3p1b2/2PP4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D11c',
			# TRANSLATORS: D11c: 1. d4 d5 2. c4 c6 3. Nf3 Bf5 4. Nc3 e6
			variation => N__('Slav: 3. Nf3 Bf5 4. Nc3 e6'),
			moves => {
				'd1b3' => 1,
			},
		},
		'rn1qkbnr/pp3ppp/2p1p3/3p1b2/2PP4/1QN2N2/PP2PPPP/R1B1KB1R b KQkq' => {
			eco => 'D11d',
			# TRANSLATORS: D11d: 1. d4 d5 2. c4 c6 3. Nf3 Bf5 4. Nc3 e6 5. Qb3
			variation => N__('Slav: 3. Nf3 Bf5 4. Nc3 e6 5. Qb3'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/2p5/8/2pP4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'D11e',
			# TRANSLATORS: D11e: 1. d4 d5 2. c4 c6 3. Nf3 dxc4
			variation => N__('Slav: 3. Nf3 dxc4'),
			moves => {
				'b1c3' => 1,
				'e2e3' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/2p5/8/2pP4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D11e',
			# TRANSLATORS: D11e: 1. d4 d5 2. c4 c6 3. Nf3 dxc4 4. Nc3
			variation => N__('Slav: 3. Nf3 dxc4 4. Nc3'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/2p5/8/2pP4/4PN2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'D11e',
			# TRANSLATORS: D11e: 1. d4 d5 2. c4 c6 3. Nf3 dxc4 4. e3
			variation => N__('Slav: 3. Nf3 dxc4 4. e3'),
			moves => {
				'b7b5' => 1,
				'c8e6' => 1,
			},
		},
		'rn1qkbnr/pp2pppp/2p1b3/8/2pP4/4PN2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'D11e',
			# TRANSLATORS: D11e: 1. d4 d5 2. c4 c6 3. Nf3 dxc4 4. e3 Be6
			variation => N__('Slav: 3. Nf3 dxc4 4. e3 Be6'),
			moves => {
			},
		},
		'rnbqkbnr/p3pppp/2p5/1p6/2pP4/4PN2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'D11f',
			# TRANSLATORS: D11f: 1. d4 d5 2. c4 c6 3. Nf3 dxc4 4. e3 b5
			variation => N__('Slav: 3. Nf3 dxc4 4. e3 b5'),
			moves => {
				'a2a4' => 1,
			},
		},
		'rnbqkbnr/p3pppp/2p5/1p6/P1pP4/4PN2/1P3PPP/RNBQKB1R b KQkq' => {
			eco => 'D11f',
			# TRANSLATORS: D11f: 1. d4 d5 2. c4 c6 3. Nf3 dxc4 4. e3 b5 5. a4
			variation => N__('Slav: 3. Nf3 dxc4 4. e3 b5 5. a4'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rnbqkbnr/p4ppp/2p1p3/1p6/P1pP4/4PN2/1P3PPP/RNBQKB1R w KQkq' => {
			eco => 'D11f',
			# TRANSLATORS: D11f: 1. d4 d5 2. c4 c6 3. Nf3 dxc4 4. e3 b5 5. a4 e6
			variation => N__('Slav: 3. Nf3 dxc4 4. e3 b5 5. a4 e6'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/3p4/2PP4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'D11g',
			# TRANSLATORS: D11g: 1. d4 d5 2. c4 c6 3. Nf3 Nf6
			variation => N__('Slav: 3. Nf3 Nf6'),
			moves => {
				'b1c3' => 1,
				'b1d2' => 1,
				'c4d5' => 1,
				'd1b3' => 1,
				'd1c2' => 1,
				'e2e3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/3p4/2PP4/1Q3N2/PP2PPPP/RNB1KB1R b KQkq' => {
			eco => 'D11h',
			# TRANSLATORS: D11h: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Qb3
			variation => N__('Slav: 4. Qb3'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/3p4/2PP4/5N2/PPQ1PPPP/RNB1KB1R b KQkq' => {
			eco => 'D11i',
			# TRANSLATORS: D11i: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Qc2
			variation => N__('Slav: 4. Qc2'),
			moves => {
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/pp2pp1p/2p2np1/3p4/2PP4/5N2/PPQ1PPPP/RNB1KB1R w KQkq' => {
			eco => 'D11i',
			# TRANSLATORS: D11i: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Qc2 g6
			variation => N__('Slav: 4. Qc2'),
			moves => {
				'c1f4' => 1,
			},
		},
		'rnbqkb1r/pp2pp1p/2p2np1/3p4/2PP1B2/5N2/PPQ1PPPP/RN2KB1R b KQkq' => {
			eco => 'D11j',
			# TRANSLATORS: D11j: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Qc2 g6 5. Bf4
			variation => N__('Slav: 4. Qc2 g6 5. Bf4'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/3p4/2PP4/5N2/PP1NPPPP/R1BQKB1R b KQkq' => {
			eco => 'D11k',
			# TRANSLATORS: D11k: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nbd2
			variation => N__('Slav: Breyer Variation'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/3p4/2PP4/5NP1/PP2PP1P/RNBQKB1R b KQkq' => {
			eco => 'D11l',
			# TRANSLATORS: D11l: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. g3
			variation => N__('Slav: Slav-Reti System'),
			moves => {
				'c8f5' => 1,
				'c8g4' => 1,
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/3p4/2PP2b1/5NP1/PP2PP1P/RNBQKB1R w KQkq' => {
			eco => 'D11m',
			# TRANSLATORS: D11m: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. g3 Bg4
			variation => N__('Slav: Slav-Reti System'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/3p4/2PP2b1/5NP1/PP2PPBP/RNBQK2R b KQkq' => {
			eco => 'D11m',
			# TRANSLATORS: D11m: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. g3 Bg4 5. Bg2
			variation => N__('Slav: Slav-Reti System'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rn1qkb1r/pp3ppp/2p1pn2/3p4/2PP2b1/5NP1/PP2PPBP/RNBQK2R w KQkq' => {
			eco => 'D11m',
			# TRANSLATORS: D11m: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. g3 Bg4 5. Bg2 e6
			variation => N__('Slav: Slav-Reti System'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rn1qkb1r/pp3ppp/2p1pn2/3p4/2PP2b1/5NP1/PP2PPBP/RNBQ1RK1 b kq' => {
			eco => 'D11m',
			# TRANSLATORS: D11m: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. g3 Bg4 5. Bg2 e6 6. O-O
			variation => N__('Slav: Slav-Reti System'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r2qkb1r/pp1n1ppp/2p1pn2/3p4/2PP2b1/5NP1/PP2PPBP/RNBQ1RK1 w kq' => {
			eco => 'D11m',
			# TRANSLATORS: D11m: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. g3 Bg4 5. Bg2 e6 6. O-O Nbd7
			variation => N__('Slav: Slav-Reti System'),
			moves => {
				'b1d2' => 1,
				'b2b3' => 1,
			},
		},
		'r2qkb1r/pp1n1ppp/2p1pn2/3p4/2PP2b1/5NP1/PP1NPPBP/R1BQ1RK1 b kq' => {
			eco => 'D11m',
			# TRANSLATORS: D11m: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. g3 Bg4 5. Bg2 e6 6. O-O Nbd7 7. Nbd2
			variation => N__('Slav: Slav-Reti System'),
			moves => {
				'f8d6' => 1,
				'f8e7' => 1,
			},
		},
		'r2qk2r/pp1n1ppp/2pbpn2/3p4/2PP2b1/5NP1/PP1NPPBP/R1BQ1RK1 w kq' => {
			eco => 'D11m',
			# TRANSLATORS: D11m: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. g3 Bg4 5. Bg2 e6 6. O-O Nbd7 7. Nbd2 Bd6
			variation => N__('Slav: Slav-Reti System'),
			moves => {
			},
		},
		'r2qk2r/pp1nbppp/2p1pn2/3p4/2PP2b1/5NP1/PP1NPPBP/R1BQ1RK1 w kq' => {
			eco => 'D11m',
			# TRANSLATORS: D11m: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. g3 Bg4 5. Bg2 e6 6. O-O Nbd7 7. Nbd2 Be7
			variation => N__('Slav: Slav-Reti System'),
			moves => {
			},
		},
		'r2qkb1r/pp1n1ppp/2p1pn2/3p4/2PP2b1/1P3NP1/P3PPBP/RNBQ1RK1 b kq' => {
			eco => 'D11n',
			# TRANSLATORS: D11n: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. g3 Bg4 5. Bg2 e6 6. O-O Nbd7 7. b3
			variation => N__('Slav: Slav-Reti with b3'),
			moves => {
				'f8d6' => 1,
				'f8e7' => 1,
			},
		},
		'r2qk2r/pp1n1ppp/2pbpn2/3p4/2PP2b1/1P3NP1/P3PPBP/RNBQ1RK1 w kq' => {
			eco => 'D11n',
			# TRANSLATORS: D11n: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. g3 Bg4 5. Bg2 e6 6. O-O Nbd7 7. b3 Bd6
			variation => N__('Slav: Slav-Reti with b3'),
			moves => {
				'c1b2' => 1,
			},
		},
		'r2qk2r/pp1n1ppp/2pbpn2/3p4/2PP2b1/1P3NP1/PB2PPBP/RN1Q1RK1 b kq' => {
			eco => 'D11n',
			# TRANSLATORS: D11n: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. g3 Bg4 5. Bg2 e6 6. O-O Nbd7 7. b3 Bd6 8. Bb2
			variation => N__('Slav: Slav-Reti with b3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r2q1rk1/pp1n1ppp/2pbpn2/3p4/2PP2b1/1P3NP1/PB2PPBP/RN1Q1RK1 w -' => {
			eco => 'D11n',
			# TRANSLATORS: D11n: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. g3 Bg4 5. Bg2 e6 6. O-O Nbd7 7. b3 Bd6 8. Bb2 O-O
			variation => N__('Slav: Slav-Reti with b3'),
			moves => {
				'b1d2' => 1,
			},
		},
		'r2q1rk1/pp1n1ppp/2pbpn2/3p4/2PP2b1/1P3NP1/PB1NPPBP/R2Q1RK1 b -' => {
			eco => 'D11n',
			# TRANSLATORS: D11n: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. g3 Bg4 5. Bg2 e6 6. O-O Nbd7 7. b3 Bd6 8. Bb2 O-O 9. Nbd2
			variation => N__('Slav: Slav-Reti with b3'),
			moves => {
			},
		},
		'r2qk2r/pp1nbppp/2p1pn2/3p4/2PP2b1/1P3NP1/P3PPBP/RNBQ1RK1 w kq' => {
			eco => 'D11n',
			# TRANSLATORS: D11n: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. g3 Bg4 5. Bg2 e6 6. O-O Nbd7 7. b3 Be7
			variation => N__('Slav: Slav-Reti with b3'),
			moves => {
				'c1b2' => 1,
			},
		},
		'r2qk2r/pp1nbppp/2p1pn2/3p4/2PP2b1/1P3NP1/PB2PPBP/RN1Q1RK1 b kq' => {
			eco => 'D11n',
			# TRANSLATORS: D11n: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. g3 Bg4 5. Bg2 e6 6. O-O Nbd7 7. b3 Be7 8. Bb2
			variation => N__('Slav: Slav-Reti with b3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r2q1rk1/pp1nbppp/2p1pn2/3p4/2PP2b1/1P3NP1/PB2PPBP/RN1Q1RK1 w -' => {
			eco => 'D11n',
			# TRANSLATORS: D11n: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. g3 Bg4 5. Bg2 e6 6. O-O Nbd7 7. b3 Be7 8. Bb2 O-O
			variation => N__('Slav: Slav-Reti with b3'),
			moves => {
				'b1d2' => 1,
			},
		},
		'r2q1rk1/pp1nbppp/2p1pn2/3p4/2PP2b1/1P3NP1/PB1NPPBP/R2Q1RK1 b -' => {
			eco => 'D11n',
			# TRANSLATORS: D11n: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. g3 Bg4 5. Bg2 e6 6. O-O Nbd7 7. b3 Be7 8. Bb2 O-O 9. Nbd2
			variation => N__('Slav: Slav-Reti with b3'),
			moves => {
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/3p1b2/2PP4/5NP1/PP2PP1P/RNBQKB1R w KQkq' => {
			eco => 'D11o',
			# TRANSLATORS: D11o: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. g3 Bf5
			variation => N__('Slav: Slav-Reti System'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/3p1b2/2PP4/5NP1/PP2PPBP/RNBQK2R b KQkq' => {
			eco => 'D11o',
			# TRANSLATORS: D11o: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. g3 Bf5 5. Bg2
			variation => N__('Slav: Slav-Reti System'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rn1qkb1r/pp3ppp/2p1pn2/3p1b2/2PP4/5NP1/PP2PPBP/RNBQK2R w KQkq' => {
			eco => 'D11o',
			# TRANSLATORS: D11o: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. g3 Bf5 5. Bg2 e6
			variation => N__('Slav: Slav-Reti System'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rn1qkb1r/pp3ppp/2p1pn2/3p1b2/2PP4/5NP1/PP2PPBP/RNBQ1RK1 b kq' => {
			eco => 'D11o',
			# TRANSLATORS: D11o: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. g3 Bf5 5. Bg2 e6 6. O-O
			variation => N__('Slav: Slav-Reti System'),
			moves => {
				'b8d7' => 1,
				'f8e7' => 1,
				'h7h6' => 1,
			},
		},
		'r2qkb1r/pp1n1ppp/2p1pn2/3p1b2/2PP4/5NP1/PP2PPBP/RNBQ1RK1 w kq' => {
			eco => 'D11o',
			# TRANSLATORS: D11o: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. g3 Bf5 5. Bg2 e6 6. O-O Nbd7
			variation => N__('Slav: Slav-Reti System'),
			moves => {
			},
		},
		'rn1qk2r/pp2bppp/2p1pn2/3p1b2/2PP4/5NP1/PP2PPBP/RNBQ1RK1 w kq' => {
			eco => 'D11o',
			# TRANSLATORS: D11o: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. g3 Bf5 5. Bg2 e6 6. O-O Be7
			variation => N__('Slav: Slav-Reti System'),
			moves => {
			},
		},
		'rn1qkb1r/pp3pp1/2p1pn1p/3p1b2/2PP4/5NP1/PP2PPBP/RNBQ1RK1 w kq' => {
			eco => 'D11p',
			# TRANSLATORS: D11p: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. g3 Bf5 5. Bg2 e6 6. O-O h6
			variation => N__('Slav: Slav-Reti System'),
			moves => {
				'b1c3' => 1,
				'b1d2' => 1,
				'b2b3' => 1,
			},
		},
		'rn1qkb1r/pp3pp1/2p1pn1p/3p1b2/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 b kq' => {
			eco => 'D11p',
			# TRANSLATORS: D11p: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. g3 Bf5 5. Bg2 e6 6. O-O h6 7. Nc3
			variation => N__('Slav: Slav-Reti System'),
			moves => {
			},
		},
		'rn1qkb1r/pp3pp1/2p1pn1p/3p1b2/2PP4/5NP1/PP1NPPBP/R1BQ1RK1 b kq' => {
			eco => 'D11p',
			# TRANSLATORS: D11p: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. g3 Bf5 5. Bg2 e6 6. O-O h6 7. Nbd2
			variation => N__('Slav: Slav-Reti System'),
			moves => {
			},
		},
		'rn1qkb1r/pp3pp1/2p1pn1p/3p1b2/2PP4/1P3NP1/P3PPBP/RNBQ1RK1 b kq' => {
			eco => 'D11p',
			# TRANSLATORS: D11p: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. g3 Bf5 5. Bg2 e6 6. O-O h6 7. b3
			variation => N__('Slav: Slav-Reti System'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/3p4/2PP4/4PN2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'D11q',
			# TRANSLATORS: D11q: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. e3
			variation => N__('Slav: 4. e3'),
			moves => {
				'a7a6' => 1,
				'c8f5' => 1,
				'c8g4' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/pp2pp1p/2p2np1/3p4/2PP4/4PN2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'D11r',
			# TRANSLATORS: D11r: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. e3 g6
			variation => N__('Slav: 4. e3 g6'),
			moves => {
			},
		},
		'rnbqkb1r/1p2pppp/p1p2n2/3p4/2PP4/4PN2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'D11s',
			# TRANSLATORS: D11s: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. e3 a6
			variation => N__('Slav: 4. e3 a6'),
			moves => {
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/3p4/2PP2b1/4PN2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'D11t',
			# TRANSLATORS: D11t: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. e3 Bg4
			variation => N__('Slav: 4. e3 Bg4'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/3p4/2PP2b1/2N1PN2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'D11t',
			# TRANSLATORS: D11t: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. e3 Bg4 5. Nc3
			variation => N__('Slav: 4. e3 Bg4'),
			moves => {
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/3p1b2/2PP4/4PN2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'D12a',
			# TRANSLATORS: D12a: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. e3 Bf5
			variation => N__('Slav: 4. e3 Bf5'),
			moves => {
				'b1c3' => 1,
				'c4d5' => 1,
				'd1b3' => 1,
				'f1d3' => 1,
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/3p1b2/2PP4/1Q2PN2/PP3PPP/RNB1KB1R b KQkq' => {
			eco => 'D12b',
			# TRANSLATORS: D12b: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. e3 Bf5 5. Qb3
			variation => N__('Slav: 4. e3 Bf5 5. Qb3'),
			moves => {
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/3P1b2/3P4/4PN2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'D12c',
			# TRANSLATORS: D12c: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. e3 Bf5 5. cxd5
			variation => N__('Slav: 4. e3 Bf5 5.cxd5'),
			moves => {
				'c6d5' => 1,
			},
		},
		'rn1qkb1r/pp2pppp/5n2/3p1b2/3P4/4PN2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'D12c',
			# TRANSLATORS: D12c: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. e3 Bf5 5. cxd5 cxd5
			variation => N__('Slav: 4. e3 Bf5 5.cxd5'),
			moves => {
				'b1c3' => 1,
				'd1b3' => 1,
			},
		},
		'rn1qkb1r/pp2pppp/5n2/3p1b2/3P4/1Q2PN2/PP3PPP/RNB1KB1R b KQkq' => {
			eco => 'D12d',
			# TRANSLATORS: D12d: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. e3 Bf5 5. cxd5 cxd5 6. Qb3
			variation => N__('Slav: 4. e3 Bf5 5.cxd5 cxd5 6. Qb3'),
			moves => {
				'd8c7' => 1,
			},
		},
		'rn2kb1r/ppq1pppp/5n2/3p1b2/3P4/1Q2PN2/PP3PPP/RNB1KB1R w KQkq' => {
			eco => 'D12e',
			# TRANSLATORS: D12e: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. e3 Bf5 5. cxd5 cxd5 6. Qb3 Qc7
			variation => N__('Slav: 4. e3 Bf5 5.cxd5 cxd5 6. Qb3 Qc7'),
			moves => {
			},
		},
		'rn1qkb1r/pp2pppp/5n2/3p1b2/3P4/2N1PN2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'D12f',
			# TRANSLATORS: D12f: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. e3 Bf5 5. cxd5 cxd5 6. Nc3
			variation => N__('Slav: 4. e3 Bf5 5.cxd5 cxd5 6. Nc3'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rn1qkb1r/pp3ppp/4pn2/3p1b2/3P4/2N1PN2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'D12f',
			# TRANSLATORS: D12f: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. e3 Bf5 5. cxd5 cxd5 6. Nc3 e6
			variation => N__('Slav: 4. e3 Bf5 5.cxd5 cxd5 6. Nc3'),
			moves => {
				'f3e5' => 1,
			},
		},
		'rn1qkb1r/pp3ppp/4pn2/3pNb2/3P4/2N1P3/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'D12f',
			# TRANSLATORS: D12f: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. e3 Bf5 5. cxd5 cxd5 6. Nc3 e6 7. Ne5
			variation => N__('Slav: 4. e3 Bf5 5.cxd5 cxd5 6. Nc3'),
			moves => {
				'f6d7' => 1,
			},
		},
		'rn1qkb1r/pp1n1ppp/4p3/3pNb2/3P4/2N1P3/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'D12f',
			# TRANSLATORS: D12f: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. e3 Bf5 5. cxd5 cxd5 6. Nc3 e6 7. Ne5 Nfd7
			variation => N__('Slav: 4. e3 Bf5 5.cxd5 cxd5 6. Nc3, Amsterdam Variation'),
			moves => {
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/3p1b2/2PP4/3BPN2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'D12g',
			# TRANSLATORS: D12g: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. e3 Bf5 5. Bd3
			variation => N__('Slav: 4. e3 Bf5 5. Bd3'),
			moves => {
				'f5d3' => 1,
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/3p4/2PP4/3bPN2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'D12h',
			# TRANSLATORS: D12h: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. e3 Bf5 5. Bd3 Bxd3
			variation => N__('Slav: 4. e3 Bf5 5. Bd3 Bxd3'),
			moves => {
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/3p1b2/2PP4/2N1PN2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'D12i',
			# TRANSLATORS: D12i: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. e3 Bf5 5. Nc3
			variation => N__('Slav: 4. e3 Bf5 5. Nc3'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rn1qkb1r/pp3ppp/2p1pn2/3p1b2/2PP4/2N1PN2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'D12i',
			# TRANSLATORS: D12i: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. e3 Bf5 5. Nc3 e6
			variation => N__('Slav: 4. e3 Bf5 5. Nc3 e6'),
			moves => {
				'f1d3' => 1,
				'f1e2' => 1,
				'f3h4' => 1,
			},
		},
		'rn1qkb1r/pp3ppp/2p1pn2/3p1b2/2PP4/2N1PN2/PP2BPPP/R1BQK2R b KQkq' => {
			eco => 'D12j',
			# TRANSLATORS: D12j: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. e3 Bf5 5. Nc3 e6 6. Be2
			variation => N__('Slav: 4. e3 Bf5 5. Nc3 e6 6. Be2'),
			moves => {
			},
		},
		'rn1qkb1r/pp3ppp/2p1pn2/3p1b2/2PP4/2NBPN2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'D12k',
			# TRANSLATORS: D12k: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. e3 Bf5 5. Nc3 e6 6. Bd3
			variation => N__('Slav: 4. e3 Bf5 5. Nc3 e6 6. Bd3'),
			moves => {
				'f5d3' => 1,
			},
		},
		'rn1qkb1r/pp3ppp/2p1pn2/3p4/2PP4/2NbPN2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D12l',
			# TRANSLATORS: D12l: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. e3 Bf5 5. Nc3 e6 6. Bd3 Bxd3
			variation => N__('Slav: 4. e3 Bf5 5. Nc3 e6 6. Bd3 Bxd3'),
			moves => {
				'd1d3' => 1,
			},
		},
		'rn1qkb1r/pp3ppp/2p1pn2/3p4/2PP4/2NQPN2/PP3PPP/R1B1K2R b KQkq' => {
			eco => 'D12l',
			# TRANSLATORS: D12l: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. e3 Bf5 5. Nc3 e6 6. Bd3 Bxd3 7. Qxd3
			variation => N__('Slav: 4. e3 Bf5 5. Nc3 e6 6. Bd3 Bxd3'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r2qkb1r/pp1n1ppp/2p1pn2/3p4/2PP4/2NQPN2/PP3PPP/R1B1K2R w KQkq' => {
			eco => 'D12m',
			# TRANSLATORS: D12m: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. e3 Bf5 5. Nc3 e6 6. Bd3 Bxd3 7. Qxd3 Nbd7
			variation => N__('Slav: 4. e3 Bf5 5. Nc3 e6 6. Bd3 Bxd3 7.Qxd3 Nbd7'),
			moves => {
			},
		},
		'rn1qkb1r/pp3ppp/2p1pn2/3p1b2/2PP3N/2N1P3/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'D12n',
			# TRANSLATORS: D12n: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. e3 Bf5 5. Nc3 e6 6. Nh4
			variation => N__('Slav: 4. e3 Bf5 5. Nc3 e6 6. Nh4'),
			moves => {
				'f5e4' => 1,
				'f5g4' => 1,
			},
		},
		'rn1qkb1r/pp3ppp/2p1pn2/3p4/2PP2bN/2N1P3/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'D12o',
			# TRANSLATORS: D12o: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. e3 Bf5 5. Nc3 e6 6. Nh4 Bg4
			variation => N__('Slav: 4. e3 Bf5 5. Nc3 e6 6. Nh4 Bg4'),
			moves => {
			},
		},
		'rn1qkb1r/pp3ppp/2p1pn2/3p4/2PPb2N/2N1P3/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'D12p',
			# TRANSLATORS: D12p: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. e3 Bf5 5. Nc3 e6 6. Nh4 Be4
			variation => N__('Slav: 4. e3 Bf5 5. Nc3 e6 6. Nh4 Be4'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/3P4/3P4/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'D13a',
			# TRANSLATORS: D13a: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5
			variation => N__('Slav: Exchange'),
			moves => {
				'c6d5' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/5n2/3p4/3P4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'D13b',
			# TRANSLATORS: D13b: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5
			variation => N__('Slav: Exchange'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/5n2/3p4/3P4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D13c',
			# TRANSLATORS: D13c: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3
			variation => N__('Slav: Exchange, 5. Nc3'),
			moves => {
				'a7a6' => 1,
				'b8c6' => 1,
				'c8f5' => 1,
				'e7e6' => 1,
			},
		},
		'rn1qkb1r/pp2pppp/5n2/3p1b2/3P4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D13d',
			# TRANSLATORS: D13d: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 Bf5
			variation => N__('Slav: Exchange, 5. Nc3 Bf5'),
			moves => {
			},
		},
		'rnbqkb1r/1p2pppp/p4n2/3p4/3P4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D13e',
			# TRANSLATORS: D13e: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 a6
			variation => N__('Slav: Exchange, 5. Nc3 a6'),
			moves => {
				'c1f4' => 1,
				'f3e5' => 1,
			},
		},
		'rnbqkb1r/1p2pppp/p4n2/3pN3/3P4/2N5/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D13f',
			# TRANSLATORS: D13f: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 a6 6. Ne5
			variation => N__('Slav: Exchange, 5. Nc3 a6 6. Ne5'),
			moves => {
			},
		},
		'rnbqkb1r/1p2pppp/p4n2/3p4/3P1B2/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D13g',
			# TRANSLATORS: D13g: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 a6 6. Bf4
			variation => N__('Slav: Exchange, 5. Nc3 a6 6. Bf4'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/3p4/3P4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D13h',
			# TRANSLATORS: D13h: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 e6
			variation => N__('Slav: Exchange, 5. Nc3 e6'),
			moves => {
				'c1f4' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/3p4/3P1B2/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D13i',
			# TRANSLATORS: D13i: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 e6 6. Bf4
			variation => N__('Slav: Exchange, 5. Nc3 e6 6. Bf4'),
			moves => {
			},
		},
		'r1bqkb1r/pp2pppp/2n2n2/3p4/3P4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D13j',
			# TRANSLATORS: D13j: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 Nc6
			variation => N__('Slav: Exchange, 5. Nc3 Nc6'),
			moves => {
				'c1f4' => 1,
			},
		},
		'r1bqkb1r/pp2pppp/2n2n2/3p4/3P1B2/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D13k',
			# TRANSLATORS: D13k: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 Nc6 6. Bf4
			variation => N__('Slav: Exchange, 6. Bf4'),
			moves => {
				'a7a6' => 1,
				'c8f5' => 1,
				'e7e6' => 1,
			},
		},
		'r1bqkb1r/1p2pppp/p1n2n2/3p4/3P1B2/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'D13l',
			# TRANSLATORS: D13l: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 Nc6 6. Bf4 a6
			variation => N__('Slav: Exchange, 6. Bf4 a6'),
			moves => {
				'e2e3' => 1,
			},
		},
		'r1bqkb1r/1p2pppp/p1n2n2/3p4/3P1B2/2N1PN2/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'D13m',
			# TRANSLATORS: D13m: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 Nc6 6. Bf4 a6 7. e3
			variation => N__('Slav: Exchange, 6. Bf4 a6 7. e3'),
			moves => {
				'c8g4' => 1,
			},
		},
		'r2qkb1r/1p2pppp/p1n2n2/3p4/3P1Bb1/2N1PN2/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'D13n',
			# TRANSLATORS: D13n: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 Nc6 6. Bf4 a6 7. e3 Bg4
			variation => N__('Slav: Exchange, 6. Bf4 a6 7. e3 Bg4'),
			moves => {
				'f1e2' => 1,
			},
		},
		'r2qkb1r/1p2pppp/p1n2n2/3p4/3P1Bb1/2N1PN2/PP2BPPP/R2QK2R b KQkq' => {
			eco => 'D13o',
			# TRANSLATORS: D13o: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 Nc6 6. Bf4 a6 7. e3 Bg4 8. Be2
			variation => N__('Slav: Exchange, 6. Bf4 a6 7. e3 Bg4 8. Be2'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2n1pn2/3p4/3P1B2/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'D13p',
			# TRANSLATORS: D13p: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 Nc6 6. Bf4 e6
			variation => N__('Slav: Exchange, 6. Bf4 e6'),
			moves => {
				'e2e3' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2n1pn2/3p4/3P1B2/2N1PN2/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'D13q',
			# TRANSLATORS: D13q: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 Nc6 6. Bf4 e6 7. e3
			variation => N__('Slav: Exchange, 6. Bf4 e6 7. e3'),
			moves => {
				'f8d6' => 1,
				'f8e7' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2n1pn2/3p4/3P1B2/2N1PN2/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'D13r',
			# TRANSLATORS: D13r: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 Nc6 6. Bf4 e6 7. e3 Be7
			variation => N__('Slav: Exchange, 6. Bf4 e6 7. e3 Be7'),
			moves => {
			},
		},
		'r1bqk2r/pp3ppp/2nbpn2/3p4/3P1B2/2N1PN2/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'D13s',
			# TRANSLATORS: D13s: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 Nc6 6. Bf4 e6 7. e3 Bd6
			variation => N__('Slav: Exchange, 6. Bf4 e6 7. e3 Bd6'),
			moves => {
				'f4d6' => 1,
			},
		},
		'r1bqk2r/pp3ppp/2nBpn2/3p4/3P4/2N1PN2/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'D13s',
			# TRANSLATORS: D13s: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 Nc6 6. Bf4 e6 7. e3 Bd6 8. Bxd6
			variation => N__('Slav: Exchange, 6. Bf4 e6 7. e3 Bd6'),
			moves => {
				'd8d6' => 1,
			},
		},
		'r1b1k2r/pp3ppp/2nqpn2/3p4/3P4/2N1PN2/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'D13t',
			# TRANSLATORS: D13t: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 Nc6 6. Bf4 e6 7. e3 Bd6 8. Bxd6 Qxd6
			variation => N__('Slav: Exchange, 6. Bf4 e6 7. e3 Bd6 8.Bxd6 Qxd6'),
			moves => {
			},
		},
		'r2qkb1r/pp2pppp/2n2n2/3p1b2/3P1B2/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'D14a',
			# TRANSLATORS: D14a: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 Nc6 6. Bf4 Bf5
			variation => N__('Slav: Exchange, 6. Bf4 Bf5'),
			moves => {
				'e2e3' => 1,
			},
		},
		'r2qkb1r/pp2pppp/2n2n2/3p1b2/3P1B2/2N1PN2/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'D14b',
			# TRANSLATORS: D14b: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 Nc6 6. Bf4 Bf5 7. e3
			variation => N__('Slav: Exchange, 6. Bf4 Bf5 7. e3'),
			moves => {
				'a7a6' => 1,
				'e7e6' => 1,
			},
		},
		'r2qkb1r/1p2pppp/p1n2n2/3p1b2/3P1B2/2N1PN2/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'D14c',
			# TRANSLATORS: D14c: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 Nc6 6. Bf4 Bf5 7. e3 a6
			variation => N__('Slav: Exchange, 6. Bf4 Bf5 7. e3 a6'),
			moves => {
			},
		},
		'r2qkb1r/pp3ppp/2n1pn2/3p1b2/3P1B2/2N1PN2/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'D14d',
			# TRANSLATORS: D14d: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 Nc6 6. Bf4 Bf5 7. e3 e6
			variation => N__('Slav: Exchange, 6. Bf4 Bf5 7. e3 e6'),
			moves => {
				'd1b3' => 1,
				'f1b5' => 1,
				'f1d3' => 1,
				'f3e5' => 1,
			},
		},
		'r2qkb1r/pp3ppp/2n1pn2/3pNb2/3P1B2/2N1P3/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'D14e',
			# TRANSLATORS: D14e: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 Nc6 6. Bf4 Bf5 7. e3 e6 8. Ne5
			variation => N__('Slav: Exchange, 8. Ne5'),
			moves => {
			},
		},
		'r2qkb1r/pp3ppp/2n1pn2/3p1b2/3P1B2/1QN1PN2/PP3PPP/R3KB1R b KQkq' => {
			eco => 'D14f',
			# TRANSLATORS: D14f: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 Nc6 6. Bf4 Bf5 7. e3 e6 8. Qb3
			variation => N__('Slav: Exchange, 8. Qb3'),
			moves => {
				'f8b4' => 1,
			},
		},
		'r2qk2r/pp3ppp/2n1pn2/3p1b2/1b1P1B2/1QN1PN2/PP3PPP/R3KB1R w KQkq' => {
			eco => 'D14g',
			# TRANSLATORS: D14g: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 Nc6 6. Bf4 Bf5 7. e3 e6 8. Qb3 Bb4
			variation => N__('Slav: Exchange, Trifunovic Variation'),
			moves => {
			},
		},
		'r2qkb1r/pp3ppp/2n1pn2/3p1b2/3P1B2/2NBPN2/PP3PPP/R2QK2R b KQkq' => {
			eco => 'D14h',
			# TRANSLATORS: D14h: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 Nc6 6. Bf4 Bf5 7. e3 e6 8. Bd3
			variation => N__('Slav: Exchange, 8. Bd3'),
			moves => {
				'f5d3' => 1,
			},
		},
		'r2qkb1r/pp3ppp/2n1pn2/3p4/3P1B2/2NbPN2/PP3PPP/R2QK2R w KQkq' => {
			eco => 'D14h',
			# TRANSLATORS: D14h: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 Nc6 6. Bf4 Bf5 7. e3 e6 8. Bd3 Bxd3
			variation => N__('Slav: Exchange, 8. Bd3'),
			moves => {
				'd1d3' => 1,
			},
		},
		'r2qkb1r/pp3ppp/2n1pn2/3p4/3P1B2/2NQPN2/PP3PPP/R3K2R b KQkq' => {
			eco => 'D14h',
			# TRANSLATORS: D14h: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 Nc6 6. Bf4 Bf5 7. e3 e6 8. Bd3 Bxd3 9. Qxd3
			variation => N__('Slav: Exchange, 8. Bd3'),
			moves => {
				'f8d6' => 1,
			},
		},
		'r2qk2r/pp3ppp/2nbpn2/3p4/3P1B2/2NQPN2/PP3PPP/R3K2R w KQkq' => {
			eco => 'D14i',
			# TRANSLATORS: D14i: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 Nc6 6. Bf4 Bf5 7. e3 e6 8. Bd3 Bxd3 9. Qxd3 Bd6
			variation => N__('Slav: Exchange, 8. Bd3 Bxd3 9.Qxd3 Bd6'),
			moves => {
				'f4d6' => 1,
			},
		},
		'r2qk2r/pp3ppp/2nBpn2/3p4/3P4/2NQPN2/PP3PPP/R3K2R b KQkq' => {
			eco => 'D14i',
			# TRANSLATORS: D14i: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 Nc6 6. Bf4 Bf5 7. e3 e6 8. Bd3 Bxd3 9. Qxd3 Bd6 10. Bxd6
			variation => N__('Slav: Exchange, 8. Bd3 Bxd3 9.Qxd3 Bd6'),
			moves => {
				'd8d6' => 1,
			},
		},
		'r3k2r/pp3ppp/2nqpn2/3p4/3P4/2NQPN2/PP3PPP/R3K2R w KQkq' => {
			eco => 'D14j',
			# TRANSLATORS: D14j: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 Nc6 6. Bf4 Bf5 7. e3 e6 8. Bd3 Bxd3 9. Qxd3 Bd6 10. Bxd6 Qxd6
			variation => N__('Slav: Exchange, 8. Bd3 Bxd3 9.Qxd3 Bd6 10.Bxd6 Qxd6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r3k2r/pp3ppp/2nqpn2/3p4/3P4/2NQPN2/PP3PPP/R4RK1 b kq' => {
			eco => 'D14j',
			# TRANSLATORS: D14j: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 Nc6 6. Bf4 Bf5 7. e3 e6 8. Bd3 Bxd3 9. Qxd3 Bd6 10. Bxd6 Qxd6 11. O-O
			variation => N__('Slav: Exchange, 8. Bd3 Bxd3 9.Qxd3 Bd6 10.Bxd6 Qxd6'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r4rk1/pp3ppp/2nqpn2/3p4/3P4/2NQPN2/PP3PPP/R4RK1 w -' => {
			eco => 'D14k',
			# TRANSLATORS: D14k: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 Nc6 6. Bf4 Bf5 7. e3 e6 8. Bd3 Bxd3 9. Qxd3 Bd6 10. Bxd6 Qxd6 11. O-O O-O
			variation => N__('Slav: Exchange, 8. Bd3 Main Line'),
			moves => {
				'a1c1' => 1,
				'f1c1' => 1,
			},
		},
		'r4rk1/pp3ppp/2nqpn2/3p4/3P4/2NQPN2/PP3PPP/2R2RK1 b -' => {
			eco => 'D14l',
			# TRANSLATORS: D14l: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 Nc6 6. Bf4 Bf5 7. e3 e6 8. Bd3 Bxd3 9. Qxd3 Bd6 10. Bxd6 Qxd6 11. O-O O-O 12. Rac1
			variation => N__('Slav: Exchange, 8. Bd3 Main Line, 12.Rac1'),
			moves => {
			},
		},
		'r4rk1/pp3ppp/2nqpn2/3p4/3P4/2NQPN2/PP3PPP/R1R3K1 b -' => {
			eco => 'D14m',
			# TRANSLATORS: D14m: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 Nc6 6. Bf4 Bf5 7. e3 e6 8. Bd3 Bxd3 9. Qxd3 Bd6 10. Bxd6 Qxd6 11. O-O O-O 12. Rfc1
			variation => N__('Slav: Exchange, 8. Bd3 Main Line, 12.Rfc1'),
			moves => {
				'f8c8' => 1,
			},
		},
		'r1r3k1/pp3ppp/2nqpn2/3p4/3P4/2NQPN2/PP3PPP/R1R3K1 w -' => {
			eco => 'D14n',
			# TRANSLATORS: D14n: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 Nc6 6. Bf4 Bf5 7. e3 e6 8. Bd3 Bxd3 9. Qxd3 Bd6 10. Bxd6 Qxd6 11. O-O O-O 12. Rfc1 Rfc8
			variation => N__('Slav: Exchange, 8. Bd3 Main Line, 12.Rfc1 Rfc8'),
			moves => {
			},
		},
		'r2qkb1r/pp3ppp/2n1pn2/1B1p1b2/3P1B2/2N1PN2/PP3PPP/R2QK2R b KQkq' => {
			eco => 'D14o',
			# TRANSLATORS: D14o: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 Nc6 6. Bf4 Bf5 7. e3 e6 8. Bb5
			variation => N__('Slav: Exchange, 8. Bb5'),
			moves => {
				'f6d7' => 1,
			},
		},
		'r2qkb1r/pp1n1ppp/2n1p3/1B1p1b2/3P1B2/2N1PN2/PP3PPP/R2QK2R w KQkq' => {
			eco => 'D14p',
			# TRANSLATORS: D14p: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 Nc6 6. Bf4 Bf5 7. e3 e6 8. Bb5 Nd7
			variation => N__('Slav: Exchange, 8. Bb5 Nd7'),
			moves => {
				'd1a4' => 1,
			},
		},
		'r2qkb1r/pp1n1ppp/2n1p3/1B1p1b2/Q2P1B2/2N1PN2/PP3PPP/R3K2R b KQkq' => {
			eco => 'D14q',
			# TRANSLATORS: D14q: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. cxd5 cxd5 5. Nc3 Nc6 6. Bf4 Bf5 7. e3 e6 8. Bb5 Nd7 9. Qa4
			variation => N__('Slav: Exchange, 8. Bb5 Nd7 9. Qa4'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/3p4/2PP4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D15a',
			# TRANSLATORS: D15a: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3
			variation => N__('Slav: 4. Nc3'),
			moves => {
				'a7a6' => 1,
				'c8f5' => 1,
				'd5c4' => 1,
				'd8b6' => 1,
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/3p1b2/2PP4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D15b',
			# TRANSLATORS: D15b: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 Bf5
			variation => N__('Slav: 4. Nc3 Bf5'),
			moves => {
				'd1b3' => 1,
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/3p1b2/2PP4/1QN2N2/PP2PPPP/R1B1KB1R b KQkq' => {
			eco => 'D15b',
			# TRANSLATORS: D15b: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 Bf5 5. Qb3
			variation => N__('Slav: 4. Nc3 Bf5 5. Qb3'),
			moves => {
			},
		},
		'rnb1kb1r/pp2pppp/1qp2n2/3p4/2PP4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D15c',
			# TRANSLATORS: D15c: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 Qb6
			variation => N__('Slav: Süchting Variation'),
			moves => {
			},
		},
		'rnbqkb1r/1p2pppp/p1p2n2/3p4/2PP4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D15d',
			# TRANSLATORS: D15d: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 a6
			variation => N__('Slav: Chameleon Variation'),
			moves => {
				'a2a4' => 1,
				'c1g5' => 1,
				'c4c5' => 1,
				'e2e3' => 1,
				'f3e5' => 1,
			},
		},
		'rnbqkb1r/1p2pppp/p1p2n2/3p2B1/2PP4/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D15e',
			# TRANSLATORS: D15e: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 a6 5. Bg5
			variation => N__('Slav: Chameleon, 5. Bg5'),
			moves => {
			},
		},
		'rnbqkb1r/1p2pppp/p1p2n2/3pN3/2PP4/2N5/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D15f',
			# TRANSLATORS: D15f: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 a6 5. Ne5
			variation => N__('Slav: Chameleon, 5. Ne5'),
			moves => {
			},
		},
		'rnbqkb1r/1p2pppp/p1p2n2/3p4/2PP4/2N1PN2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'D15g',
			# TRANSLATORS: D15g: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 a6 5. e3
			variation => N__('Slav: Chameleon, 5. e3'),
			moves => {
				'b7b5' => 1,
			},
		},
		'rnbqkb1r/4pppp/p1p2n2/1p1p4/2PP4/2N1PN2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'D15h',
			# TRANSLATORS: D15h: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 a6 5. e3 b5
			variation => N__('Slav: Chameleon, 5. e3 b5'),
			moves => {
				'b2b3' => 1,
			},
		},
		'rnbqkb1r/4pppp/p1p2n2/1p1p4/2PP4/1PN1PN2/P4PPP/R1BQKB1R b KQkq' => {
			eco => 'D15i',
			# TRANSLATORS: D15i: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 a6 5. e3 b5 6. b3
			variation => N__('Slav: Chameleon, 5. e3 b5 6. b3'),
			moves => {
			},
		},
		'rnbqkb1r/1p2pppp/p1p2n2/2Pp4/3P4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D15j',
			# TRANSLATORS: D15j: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 a6 5. c5
			variation => N__('Slav: Chameleon, 5. c5'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r1bqkb1r/1p1npppp/p1p2n2/2Pp4/3P4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D15k',
			# TRANSLATORS: D15k: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 a6 5. c5 Nbd7
			variation => N__('Slav: Chameleon, 5. c5 Nbd7'),
			moves => {
			},
		},
		'rnbqkb1r/1p2pppp/p1p2n2/3p4/P1PP4/2N2N2/1P2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D15l',
			# TRANSLATORS: D15l: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 a6 5. a4
			variation => N__('Slav: Chameleon, 5. a4'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rnbqkb1r/1p3ppp/p1p1pn2/3p4/P1PP4/2N2N2/1P2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D15m',
			# TRANSLATORS: D15m: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 a6 5. a4 e6
			variation => N__('Slav: Chameleon, 5. a4 e6'),
			moves => {
				'c1g5' => 1,
			},
		},
		'rnbqkb1r/1p3ppp/p1p1pn2/3p2B1/P1PP4/2N2N2/1P2PPPP/R2QKB1R b KQkq' => {
			eco => 'D15n',
			# TRANSLATORS: D15n: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 a6 5. a4 e6 6. Bg5
			variation => N__('Slav: Chameleon, 5. a4 e6 6. Bg5'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/8/2pP4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D15o',
			# TRANSLATORS: D15o: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4
			variation => N__('Slav: Accepted'),
			moves => {
				'a2a4' => 1,
				'e2e3' => 1,
				'e2e4' => 1,
				'f3e5' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/4N3/2pP4/2N5/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D15p',
			# TRANSLATORS: D15p: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. Ne5
			variation => N__('Slav: Accepted, 5. Ne5'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/8/2pP4/2N1PN2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'D15q',
			# TRANSLATORS: D15q: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. e3
			variation => N__('Slav: Accepted, Alekhine'),
			moves => {
				'b7b5' => 1,
			},
		},
		'rnbqkb1r/p3pppp/2p2n2/1p6/2pP4/2N1PN2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'D15q',
			# TRANSLATORS: D15q: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. e3 b5
			variation => N__('Slav: Accepted, Alekhine'),
			moves => {
				'a2a4' => 1,
			},
		},
		'rnbqkb1r/p3pppp/2p2n2/1p6/P1pP4/2N1PN2/1P3PPP/R1BQKB1R b KQkq' => {
			eco => 'D15q',
			# TRANSLATORS: D15q: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. e3 b5 6. a4
			variation => N__('Slav: Accepted, Alekhine'),
			moves => {
				'b5b4' => 1,
			},
		},
		'rnbqkb1r/p3pppp/2p2n2/8/PppP4/2N1PN2/1P3PPP/R1BQKB1R w KQkq' => {
			eco => 'D15r',
			# TRANSLATORS: D15r: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. e3 b5 6. a4 b4
			variation => N__('Slav: Accepted, Alekhine: 5... b5 6. a4 b4'),
			moves => {
				'c3b1' => 1,
			},
		},
		'rnbqkb1r/p3pppp/2p2n2/8/PppP4/4PN2/1P3PPP/RNBQKB1R b KQkq' => {
			eco => 'D15s',
			# TRANSLATORS: D15s: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. e3 b5 6. a4 b4 7. Nb1
			variation => N__('Slav: Accepted, Alekhine: 5... b5 6. a4 b4 7. Nb1'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/8/2pPP3/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'D15t',
			# TRANSLATORS: D15t: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. e4
			variation => N__('Slav: Geller (Tolush) Gambit'),
			moves => {
				'b7b5' => 1,
			},
		},
		'rnbqkb1r/p3pppp/2p2n2/1p6/2pPP3/2N2N2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'D15t',
			# TRANSLATORS: D15t: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. e4 b5
			variation => N__('Slav: Geller Gambit'),
			moves => {
				'd1c2' => 1,
				'e4e5' => 1,
			},
		},
		'rnbqkb1r/p3pppp/2p2n2/1p6/2pPP3/2N2N2/PPQ2PPP/R1B1KB1R b KQkq' => {
			eco => 'D15u',
			# TRANSLATORS: D15u: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. e4 b5 6. Qc2
			variation => N__('Slav: Geller Gambit, Spassky Variation'),
			moves => {
			},
		},
		'rnbqkb1r/p3pppp/2p2n2/1p2P3/2pP4/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'D15v',
			# TRANSLATORS: D15v: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. e4 b5 6. e5
			variation => N__('Slav: Geller Gambit, 6. e5'),
			moves => {
				'f6d5' => 1,
			},
		},
		'rnbqkb1r/p3pppp/2p5/1p1nP3/2pP4/2N2N2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'D15v',
			# TRANSLATORS: D15v: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. e4 b5 6. e5 Nd5
			variation => N__('Slav: Geller Gambit, 6. e5'),
			moves => {
				'a2a4' => 1,
				'f3g5' => 1,
			},
		},
		'rnbqkb1r/p3pppp/2p5/1p1nP1N1/2pP4/2N5/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'D15w',
			# TRANSLATORS: D15w: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. e4 b5 6. e5 Nd5 7. Ng5
			variation => N__('Slav: Geller Gambit, 6. e5 Nd5 7. Ng5'),
			moves => {
			},
		},
		'rnbqkb1r/p3pppp/2p5/1p1nP3/P1pP4/2N2N2/1P3PPP/R1BQKB1R b KQkq' => {
			eco => 'D15x',
			# TRANSLATORS: D15x: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. e4 b5 6. e5 Nd5 7. a4
			variation => N__('Slav: Geller Gambit, 6. e5 Nd5 7. a4'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rnbqkb1r/p4ppp/2p1p3/1p1nP3/P1pP4/2N2N2/1P3PPP/R1BQKB1R w KQkq' => {
			eco => 'D15y',
			# TRANSLATORS: D15y: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. e4 b5 6. e5 Nd5 7. a4 e6
			variation => N__('Slav: Geller Gambit, 6. e5 Nd5 7. a4 e6'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/8/P1pP4/2N2N2/1P2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D16a',
			# TRANSLATORS: D16a: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4
			variation => N__('Slav: Alapin'),
			moves => {
				'a7a5' => 1,
				'b8a6' => 1,
				'c8f5' => 1,
				'c8g4' => 1,
				'e7e6' => 1,
				'f6d5' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/2p5/3n4/P1pP4/2N2N2/1P2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D16b',
			# TRANSLATORS: D16b: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Nd5
			variation => N__('Slav: 5. a4 Nd5'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/2p1pn2/8/P1pP4/2N2N2/1P2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D16c',
			# TRANSLATORS: D16c: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 e6
			variation => N__('Slav: Soultanbeieff Variation'),
			moves => {
			},
		},
		'rnbqkb1r/1p2pppp/2p2n2/p7/P1pP4/2N2N2/1P2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D16d',
			# TRANSLATORS: D16d: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 a5
			variation => N__('Slav: Murey Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pp2pppp/n1p2n2/8/P1pP4/2N2N2/1P2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D16e',
			# TRANSLATORS: D16e: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Na6
			variation => N__('Slav: Smyslov Variation'),
			moves => {
				'e2e3' => 1,
				'e2e4' => 1,
				'f3e5' => 1,
			},
		},
		'r1bqkb1r/pp2pppp/n1p2n2/4N3/P1pP4/2N5/1P2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D16f',
			# TRANSLATORS: D16f: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Na6 6. Ne5
			variation => N__('Slav: Smyslov, 6. Ne5'),
			moves => {
			},
		},
		'r1bqkb1r/pp2pppp/n1p2n2/8/P1pP4/2N1PN2/1P3PPP/R1BQKB1R b KQkq' => {
			eco => 'D16g',
			# TRANSLATORS: D16g: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Na6 6. e3
			variation => N__('Slav: Smyslov, 6. e3'),
			moves => {
				'c8g4' => 1,
			},
		},
		'r2qkb1r/pp2pppp/n1p2n2/8/P1pP2b1/2N1PN2/1P3PPP/R1BQKB1R w KQkq' => {
			eco => 'D16h',
			# TRANSLATORS: D16h: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Na6 6. e3 Bg4
			variation => N__('Slav: Smyslov, 6. e3 Bg4'),
			moves => {
			},
		},
		'r1bqkb1r/pp2pppp/n1p2n2/8/P1pPP3/2N2N2/1P3PPP/R1BQKB1R b KQkq' => {
			eco => 'D16i',
			# TRANSLATORS: D16i: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Na6 6. e4
			variation => N__('Slav: Smyslov, 6. e4'),
			moves => {
				'c8g4' => 1,
			},
		},
		'r2qkb1r/pp2pppp/n1p2n2/8/P1pPP1b1/2N2N2/1P3PPP/R1BQKB1R w KQkq' => {
			eco => 'D16j',
			# TRANSLATORS: D16j: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Na6 6. e4 Bg4
			variation => N__('Slav: Smyslov, 6. e4 Bg4'),
			moves => {
				'f1c4' => 1,
			},
		},
		'r2qkb1r/pp2pppp/n1p2n2/8/P1BPP1b1/2N2N2/1P3PPP/R1BQK2R b KQkq' => {
			eco => 'D16j',
			# TRANSLATORS: D16j: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Na6 6. e4 Bg4 7. Bxc4
			variation => N__('Slav: Smyslov, 6. e4 Bg4'),
			moves => {
				'e7e6' => 1,
			},
		},
		'r2qkb1r/pp3ppp/n1p1pn2/8/P1BPP1b1/2N2N2/1P3PPP/R1BQK2R w KQkq' => {
			eco => 'D16k',
			# TRANSLATORS: D16k: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Na6 6. e4 Bg4 7. Bxc4 e6
			variation => N__('Slav: Smyslov, 6. e4 Bg4 7.Bxc4 e6'),
			moves => {
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/8/P1pP2b1/2N2N2/1P2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D16l',
			# TRANSLATORS: D16l: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bg4
			variation => N__('Slav: Bronstein (Steiner) Variation'),
			moves => {
				'f3e5' => 1,
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/4N3/P1pP2b1/2N5/1P2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D16m',
			# TRANSLATORS: D16m: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bg4 6. Ne5
			variation => N__('Slav: Bronstein, 6. Ne5'),
			moves => {
				'g4h5' => 1,
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/4N2b/P1pP4/2N5/1P2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D16n',
			# TRANSLATORS: D16n: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bg4 6. Ne5 Bh5
			variation => N__('Slav: Bronstein, 6. Ne5 Bh5'),
			moves => {
				'f2f3' => 1,
				'g2g3' => 1,
				'h2h3' => 1,
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/4N2b/P1pP4/2N4P/1P2PPP1/R1BQKB1R b KQkq' => {
			eco => 'D16o',
			# TRANSLATORS: D16o: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bg4 6. Ne5 Bh5 7. h3
			variation => N__('Slav: Bronstein, 6. Ne5 Bh5 7. h3'),
			moves => {
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/4N2b/P1pP4/2N3P1/1P2PP1P/R1BQKB1R b KQkq' => {
			eco => 'D16p',
			# TRANSLATORS: D16p: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bg4 6. Ne5 Bh5 7. g3
			variation => N__('Slav: Bronstein, 6. Ne5 Bh5 7. g3'),
			moves => {
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/4N2b/P1pP4/2N2P2/1P2P1PP/R1BQKB1R b KQkq' => {
			eco => 'D16q',
			# TRANSLATORS: D16q: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bg4 6. Ne5 Bh5 7. f3
			variation => N__('Slav: Bronstein, 6. Ne5 Bh5 7. f3'),
			moves => {
				'f6d7' => 1,
			},
		},
		'rn1qkb1r/pp1npppp/2p5/4N2b/P1pP4/2N2P2/1P2P1PP/R1BQKB1R w KQkq' => {
			eco => 'D16r',
			# TRANSLATORS: D16r: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bg4 6. Ne5 Bh5 7. f3 Nfd7
			variation => N__('Slav: Bronstein, 6. Ne5 Bh5 7. f3 Nfd7'),
			moves => {
				'e5c4' => 1,
			},
		},
		'rn1qkb1r/pp1npppp/2p5/7b/P1NP4/2N2P2/1P2P1PP/R1BQKB1R b KQkq' => {
			eco => 'D16r',
			# TRANSLATORS: D16r: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bg4 6. Ne5 Bh5 7. f3 Nfd7 8. Nxc4
			variation => N__('Slav: Bronstein, 6. Ne5 Bh5 7. f3 Nfd7'),
			moves => {
				'e7e5' => 1,
			},
		},
		'rn1qkb1r/pp1n1ppp/2p5/4p2b/P1NP4/2N2P2/1P2P1PP/R1BQKB1R w KQkq' => {
			eco => 'D16r',
			# TRANSLATORS: D16r: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bg4 6. Ne5 Bh5 7. f3 Nfd7 8. Nxc4 e5
			variation => N__('Slav: Bronstein, 6. Ne5 Bh5 7. f3 Nfd7'),
			moves => {
				'c3e4' => 1,
			},
		},
		'rn1qkb1r/pp1n1ppp/2p5/4p2b/P1NPN3/5P2/1P2P1PP/R1BQKB1R b KQkq' => {
			eco => 'D16s',
			# TRANSLATORS: D16s: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bg4 6. Ne5 Bh5 7. f3 Nfd7 8. Nxc4 e5 9. Ne4
			variation => N__('Slav: Bronstein, 6. Ne5 Bh5 7. f3 Nfd7 8.Nxc4 e5 9. Ne4'),
			moves => {
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/5b2/P1pP4/2N2N2/1P2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D17a',
			# TRANSLATORS: D17a: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5
			variation => N__('Slav: Czech Defence'),
			moves => {
				'e2e3' => 1,
				'f3e5' => 1,
				'f3h4' => 1,
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/5b2/P1pP3N/2N5/1P2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D17b',
			# TRANSLATORS: D17b: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Nh4
			variation => N__('Slav: Czech, 6. Nh4'),
			moves => {
				'e7e6' => 1,
				'f5c8' => 1,
			},
		},
		'rn1qkb1r/pp3ppp/2p1pn2/5b2/P1pP3N/2N5/1P2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D17c',
			# TRANSLATORS: D17c: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Nh4 e6
			variation => N__('Slav: Czech, 6. Nh4 e6'),
			moves => {
				'h4f5' => 1,
			},
		},
		'rn1qkb1r/pp3ppp/2p1pn2/5N2/P1pP4/2N5/1P2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D17c',
			# TRANSLATORS: D17c: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Nh4 e6 7. Nxf5
			variation => N__('Slav: Czech, 6. Nh4 e6'),
			moves => {
				'e6f5' => 1,
			},
		},
		'rn1qkb1r/pp3ppp/2p2n2/5p2/P1pP4/2N5/1P2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D17c',
			# TRANSLATORS: D17c: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Nh4 e6 7. Nxf5 exf5
			variation => N__('Slav: Czech, 6. Nh4 e6'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rn1qkb1r/pp3ppp/2p2n2/5p2/P1pP4/2N1P3/1P3PPP/R1BQKB1R b KQkq' => {
			eco => 'D17d',
			# TRANSLATORS: D17d: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Nh4 e6 7. Nxf5 exf5 8. e3
			variation => N__('Slav: Czech, 6. Nh4 e6 7.Nxf5 exf5 8. e3'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/8/P1pP3N/2N5/1P2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D17e',
			# TRANSLATORS: D17e: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Nh4 Bc8
			variation => N__('Slav: Czech, 6. Nh4 Bc8'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/8/P1pP3N/2N1P3/1P3PPP/R1BQKB1R b KQkq' => {
			eco => 'D17e',
			# TRANSLATORS: D17e: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Nh4 Bc8 7. e3
			variation => N__('Slav: Czech, 6. Nh4 Bc8 7. e3'),
			moves => {
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/4Nb2/P1pP4/2N5/1P2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D17f',
			# TRANSLATORS: D17f: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5
			variation => N__('Slav: Central Variation'),
			moves => {
				'b8a6' => 1,
				'b8d7' => 1,
				'e7e6' => 1,
			},
		},
		'r2qkb1r/pp2pppp/n1p2n2/4Nb2/P1pP4/2N5/1P2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D17g',
			# TRANSLATORS: D17g: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 Na6
			variation => N__('Slav: Central, 6. Ne5 Na6'),
			moves => {
				'f2f3' => 1,
			},
		},
		'r2qkb1r/pp2pppp/n1p2n2/4Nb2/P1pP4/2N2P2/1P2P1PP/R1BQKB1R b KQkq' => {
			eco => 'D17g',
			# TRANSLATORS: D17g: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 Na6 7. f3
			variation => N__('Slav: Central, 6. Ne5 Na6 7. f3'),
			moves => {
			},
		},
		'r2qkb1r/pp1npppp/2p2n2/4Nb2/P1pP4/2N5/1P2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D17h',
			# TRANSLATORS: D17h: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 Nbd7
			variation => N__('Slav: Central, 6. Ne5 Nbd7'),
			moves => {
				'e5c4' => 1,
			},
		},
		'r2qkb1r/pp1npppp/2p2n2/5b2/P1NP4/2N5/1P2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D17h',
			# TRANSLATORS: D17h: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 Nbd7 7. Nxc4
			variation => N__('Slav: Central, 6. Ne5 Nbd7'),
			moves => {
				'd8c7' => 1,
			},
		},
		'r3kb1r/ppqnpppp/2p2n2/5b2/P1NP4/2N5/1P2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D17h',
			# TRANSLATORS: D17h: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 Nbd7 7. Nxc4 Qc7
			variation => N__('Slav: Central, 6. Ne5 Nbd7'),
			moves => {
				'g2g3' => 1,
			},
		},
		'r3kb1r/ppqnpppp/2p2n2/5b2/P1NP4/2N3P1/1P2PP1P/R1BQKB1R b KQkq' => {
			eco => 'D17h',
			# TRANSLATORS: D17h: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 Nbd7 7. Nxc4 Qc7 8. g3
			variation => N__('Slav: Central, 6. Ne5 Nbd7'),
			moves => {
				'e7e5' => 1,
			},
		},
		'r3kb1r/ppqn1ppp/2p2n2/4pb2/P1NP4/2N3P1/1P2PP1P/R1BQKB1R w KQkq' => {
			eco => 'D17i',
			# TRANSLATORS: D17i: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 Nbd7 7. Nxc4 Qc7 8. g3 e5
			variation => N__('Slav: Central, Carlsbad Variation'),
			moves => {
				'd4e5' => 1,
			},
		},
		'r3kb1r/ppqn1ppp/2p2n2/4Pb2/P1N5/2N3P1/1P2PP1P/R1BQKB1R b KQkq' => {
			eco => 'D17i',
			# TRANSLATORS: D17i: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 Nbd7 7. Nxc4 Qc7 8. g3 e5 9. dxe5
			variation => N__('Slav: Central, Carlsbad Variation'),
			moves => {
				'd7e5' => 1,
			},
		},
		'r3kb1r/ppq2ppp/2p2n2/4nb2/P1N5/2N3P1/1P2PP1P/R1BQKB1R w KQkq' => {
			eco => 'D17i',
			# TRANSLATORS: D17i: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 Nbd7 7. Nxc4 Qc7 8. g3 e5 9. dxe5 Nxe5
			variation => N__('Slav: Central, Carlsbad Variation'),
			moves => {
				'c1f4' => 1,
			},
		},
		'r3kb1r/ppq2ppp/2p2n2/4nb2/P1N2B2/2N3P1/1P2PP1P/R2QKB1R b KQkq' => {
			eco => 'D17i',
			# TRANSLATORS: D17i: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 Nbd7 7. Nxc4 Qc7 8. g3 e5 9. dxe5 Nxe5 10. Bf4
			variation => N__('Slav: Central, Carlsbad Variation'),
			moves => {
				'f6d7' => 1,
			},
		},
		'r3kb1r/ppqn1ppp/2p5/4nb2/P1N2B2/2N3P1/1P2PP1P/R2QKB1R w KQkq' => {
			eco => 'D17i',
			# TRANSLATORS: D17i: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 Nbd7 7. Nxc4 Qc7 8. g3 e5 9. dxe5 Nxe5 10. Bf4 Nfd7
			variation => N__('Slav: Central, Carlsbad Variation'),
			moves => {
				'f1g2' => 1,
			},
		},
		'r3kb1r/ppqn1ppp/2p5/4nb2/P1N2B2/2N3P1/1P2PPBP/R2QK2R b KQkq' => {
			eco => 'D17i',
			# TRANSLATORS: D17i: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 Nbd7 7. Nxc4 Qc7 8. g3 e5 9. dxe5 Nxe5 10. Bf4 Nfd7 11. Bg2
			variation => N__('Slav: Central, Carlsbad Variation'),
			moves => {
				'f7f6' => 1,
			},
		},
		'r3kb1r/ppqn2pp/2p2p2/4nb2/P1N2B2/2N3P1/1P2PPBP/R2QK2R w KQkq' => {
			eco => 'D17j',
			# TRANSLATORS: D17j: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 Nbd7 7. Nxc4 Qc7 8. g3 e5 9. dxe5 Nxe5 10. Bf4 Nfd7 11. Bg2 f6
			variation => N__('Slav: Central, Carlsbad, Main Line'),
			moves => {
			},
		},
		'rn1qkb1r/pp3ppp/2p1pn2/4Nb2/P1pP4/2N5/1P2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D17k',
			# TRANSLATORS: D17k: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 e6
			variation => N__('Slav: Central, 6. Ne5 e6'),
			moves => {
				'f2f3' => 1,
			},
		},
		'rn1qkb1r/pp3ppp/2p1pn2/4Nb2/P1pP4/2N2P2/1P2P1PP/R1BQKB1R b KQkq' => {
			eco => 'D17k',
			# TRANSLATORS: D17k: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 e6 7. f3
			variation => N__('Slav: Central, 6. Ne5 e6 7. f3'),
			moves => {
				'c6c5' => 1,
				'f8b4' => 1,
			},
		},
		'rn1qkb1r/pp3ppp/4pn2/2p1Nb2/P1pP4/2N2P2/1P2P1PP/R1BQKB1R w KQkq' => {
			eco => 'D17l',
			# TRANSLATORS: D17l: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 e6 7. f3 c5
			variation => N__('Slav: Central, Hübner (7... c5)'),
			moves => {
			},
		},
		'rn1qk2r/pp3ppp/2p1pn2/4Nb2/PbpP4/2N2P2/1P2P1PP/R1BQKB1R w KQkq' => {
			eco => 'D17m',
			# TRANSLATORS: D17m: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 e6 7. f3 Bb4
			variation => N__('Slav: Central, 7. f3 Bb4'),
			moves => {
				'c1g5' => 1,
				'e2e4' => 1,
				'e5c4' => 1,
			},
		},
		'rn1qk2r/pp3ppp/2p1pn2/4NbB1/PbpP4/2N2P2/1P2P1PP/R2QKB1R b KQkq' => {
			eco => 'D17m',
			# TRANSLATORS: D17m: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 e6 7. f3 Bb4 8. Bg5
			variation => N__('Slav: Central, 7. f3 Bb4 8. Bg5'),
			moves => {
			},
		},
		'rn1qk2r/pp3ppp/2p1pn2/5b2/PbNP4/2N2P2/1P2P1PP/R1BQKB1R b KQkq' => {
			eco => 'D17n',
			# TRANSLATORS: D17n: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 e6 7. f3 Bb4 8. Nxc4
			variation => N__('Slav: Central, 7. f3 Bb4 8.Nxc4'),
			moves => {
			},
		},
		'rn1qk2r/pp3ppp/2p1pn2/4Nb2/PbpPP3/2N2P2/1P4PP/R1BQKB1R b KQkq' => {
			eco => 'D17o',
			# TRANSLATORS: D17o: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 e6 7. f3 Bb4 8. e4
			variation => N__('Slav: Central, 7. f3 Bb4 8. e4'),
			moves => {
				'f5e4' => 1,
			},
		},
		'rn1qk2r/pp3ppp/2p1pn2/4N3/PbpPb3/2N2P2/1P4PP/R1BQKB1R w KQkq' => {
			eco => 'D17p',
			# TRANSLATORS: D17p: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 e6 7. f3 Bb4 8. e4 Bxe4
			variation => N__('Slav: Central, Piece-Sac Line'),
			moves => {
				'f3e4' => 1,
			},
		},
		'rn1qk2r/pp3ppp/2p1pn2/4N3/PbpPP3/2N5/1P4PP/R1BQKB1R b KQkq' => {
			eco => 'D17p',
			# TRANSLATORS: D17p: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 e6 7. f3 Bb4 8. e4 Bxe4 9. fxe4
			variation => N__('Slav: Central, Piece-Sac Line'),
			moves => {
				'f6e4' => 1,
			},
		},
		'rn1qk2r/pp3ppp/2p1p3/4N3/PbpPn3/2N5/1P4PP/R1BQKB1R w KQkq' => {
			eco => 'D17p',
			# TRANSLATORS: D17p: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 e6 7. f3 Bb4 8. e4 Bxe4 9. fxe4 Nxe4
			variation => N__('Slav: Central, Piece-Sac Line'),
			moves => {
				'c1d2' => 1,
			},
		},
		'rn1qk2r/pp3ppp/2p1p3/4N3/PbpPn3/2N5/1P1B2PP/R2QKB1R b KQkq' => {
			eco => 'D17p',
			# TRANSLATORS: D17p: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 e6 7. f3 Bb4 8. e4 Bxe4 9. fxe4 Nxe4 10. Bd2
			variation => N__('Slav: Central, Piece-Sac Line'),
			moves => {
				'd8d4' => 1,
			},
		},
		'rn2k2r/pp3ppp/2p1p3/4N3/Pbpqn3/2N5/1P1B2PP/R2QKB1R w KQkq' => {
			eco => 'D17p',
			# TRANSLATORS: D17p: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 e6 7. f3 Bb4 8. e4 Bxe4 9. fxe4 Nxe4 10. Bd2 Qxd4
			variation => N__('Slav: Central, Piece-Sac Line'),
			moves => {
				'c3e4' => 1,
			},
		},
		'rn2k2r/pp3ppp/2p1p3/4N3/PbpqN3/8/1P1B2PP/R2QKB1R b KQkq' => {
			eco => 'D17p',
			# TRANSLATORS: D17p: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 e6 7. f3 Bb4 8. e4 Bxe4 9. fxe4 Nxe4 10. Bd2 Qxd4 11. Nxe4
			variation => N__('Slav: Central, Piece-Sac Line'),
			moves => {
				'd4e4' => 1,
			},
		},
		'rn2k2r/pp3ppp/2p1p3/4N3/Pbp1q3/8/1P1B2PP/R2QKB1R w KQkq' => {
			eco => 'D17p',
			# TRANSLATORS: D17p: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 e6 7. f3 Bb4 8. e4 Bxe4 9. fxe4 Nxe4 10. Bd2 Qxd4 11. Nxe4 Qxe4+
			variation => N__('Slav: Central, Piece-Sac Line'),
			moves => {
				'd1e2' => 1,
			},
		},
		'rn2k2r/pp3ppp/2p1p3/4N3/Pbp1q3/8/1P1BQ1PP/R3KB1R b KQkq' => {
			eco => 'D17p',
			# TRANSLATORS: D17p: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 e6 7. f3 Bb4 8. e4 Bxe4 9. fxe4 Nxe4 10. Bd2 Qxd4 11. Nxe4 Qxe4+ 12. Qe2
			variation => N__('Slav: Central, Piece-Sac Line'),
			moves => {
				'b4d2' => 1,
			},
		},
		'rn2k2r/pp3ppp/2p1p3/4N3/P1p1q3/8/1P1bQ1PP/R3KB1R w KQkq' => {
			eco => 'D17p',
			# TRANSLATORS: D17p: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 e6 7. f3 Bb4 8. e4 Bxe4 9. fxe4 Nxe4 10. Bd2 Qxd4 11. Nxe4 Qxe4+ 12. Qe2 Bxd2+
			variation => N__('Slav: Central, Piece-Sac Line'),
			moves => {
				'e1d2' => 1,
			},
		},
		'rn2k2r/pp3ppp/2p1p3/4N3/P1p1q3/8/1P1KQ1PP/R4B1R b kq' => {
			eco => 'D17q',
			# TRANSLATORS: D17q: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 e6 7. f3 Bb4 8. e4 Bxe4 9. fxe4 Nxe4 10. Bd2 Qxd4 11. Nxe4 Qxe4+ 12. Qe2 Bxd2+ 13. Kxd2
			variation => N__('Slav: Central, Main Line'),
			moves => {
				'e4d5' => 1,
			},
		},
		'rn2k2r/pp3ppp/2p1p3/3qN3/P1p5/8/1P1KQ1PP/R4B1R w kq' => {
			eco => 'D17q',
			# TRANSLATORS: D17q: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 e6 7. f3 Bb4 8. e4 Bxe4 9. fxe4 Nxe4 10. Bd2 Qxd4 11. Nxe4 Qxe4+ 12. Qe2 Bxd2+ 13. Kxd2 Qd5+
			variation => N__('Slav: Central, Main Line'),
			moves => {
				'd2c2' => 1,
			},
		},
		'rn2k2r/pp3ppp/2p1p3/3qN3/P1p5/8/1PK1Q1PP/R4B1R b kq' => {
			eco => 'D17q',
			# TRANSLATORS: D17q: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 e6 7. f3 Bb4 8. e4 Bxe4 9. fxe4 Nxe4 10. Bd2 Qxd4 11. Nxe4 Qxe4+ 12. Qe2 Bxd2+ 13. Kxd2 Qd5+ 14. Kc2
			variation => N__('Slav: Central, Main Line'),
			moves => {
				'b8a6' => 1,
			},
		},
		'r3k2r/pp3ppp/n1p1p3/3qN3/P1p5/8/1PK1Q1PP/R4B1R w kq' => {
			eco => 'D17q',
			# TRANSLATORS: D17q: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 e6 7. f3 Bb4 8. e4 Bxe4 9. fxe4 Nxe4 10. Bd2 Qxd4 11. Nxe4 Qxe4+ 12. Qe2 Bxd2+ 13. Kxd2 Qd5+ 14. Kc2 Na6
			variation => N__('Slav: Central, Main Line'),
			moves => {
				'e5c4' => 1,
			},
		},
		'r3k2r/pp3ppp/n1p1p3/3q4/P1N5/8/1PK1Q1PP/R4B1R b kq' => {
			eco => 'D17r',
			# TRANSLATORS: D17r: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 e6 7. f3 Bb4 8. e4 Bxe4 9. fxe4 Nxe4 10. Bd2 Qxd4 11. Nxe4 Qxe4+ 12. Qe2 Bxd2+ 13. Kxd2 Qd5+ 14. Kc2 Na6 15. Nxc4
			variation => N__('Slav: Central, Main Line, 15.Nxc4'),
			moves => {
				'e8c8' => 1,
				'e8g8' => 1,
			},
		},
		'r4rk1/pp3ppp/n1p1p3/3q4/P1N5/8/1PK1Q1PP/R4B1R w -' => {
			eco => 'D17s',
			# TRANSLATORS: D17s: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 e6 7. f3 Bb4 8. e4 Bxe4 9. fxe4 Nxe4 10. Bd2 Qxd4 11. Nxe4 Qxe4+ 12. Qe2 Bxd2+ 13. Kxd2 Qd5+ 14. Kc2 Na6 15. Nxc4 O-O
			variation => N__('Slav: Central, Main Line, 15.Nxc4 O-O'),
			moves => {
			},
		},
		'2kr3r/pp3ppp/n1p1p3/3q4/P1N5/8/1PK1Q1PP/R4B1R w -' => {
			eco => 'D17t',
			# TRANSLATORS: D17t: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. Ne5 e6 7. f3 Bb4 8. e4 Bxe4 9. fxe4 Nxe4 10. Bd2 Qxd4 11. Nxe4 Qxe4+ 12. Qe2 Bxd2+ 13. Kxd2 Qd5+ 14. Kc2 Na6 15. Nxc4 O-O-O
			variation => N__('Slav: Central, Main Line, 15.Nxc4 O-O-O'),
			moves => {
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/5b2/P1pP4/2N1PN2/1P3PPP/R1BQKB1R b KQkq' => {
			eco => 'D18a',
			# TRANSLATORS: D18a: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3
			variation => N__('Slav: Dutch Variation'),
			moves => {
				'b8a6' => 1,
				'e7e6' => 1,
			},
		},
		'r2qkb1r/pp2pppp/n1p2n2/5b2/P1pP4/2N1PN2/1P3PPP/R1BQKB1R w KQkq' => {
			eco => 'D18b',
			# TRANSLATORS: D18b: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 Na6
			variation => N__('Slav: Dutch, Lasker Variation'),
			moves => {
			},
		},
		'rn1qkb1r/pp3ppp/2p1pn2/5b2/P1pP4/2N1PN2/1P3PPP/R1BQKB1R w KQkq' => {
			eco => 'D18c',
			# TRANSLATORS: D18c: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6
			variation => N__('Slav: Dutch, 6... e6'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rn1qkb1r/pp3ppp/2p1pn2/5b2/P1BP4/2N1PN2/1P3PPP/R1BQK2R b KQkq' => {
			eco => 'D18c',
			# TRANSLATORS: D18c: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4
			variation => N__('Slav: Dutch, 6... e6'),
			moves => {
				'f8b4' => 1,
			},
		},
		'rn1qk2r/pp3ppp/2p1pn2/5b2/PbBP4/2N1PN2/1P3PPP/R1BQK2R w KQkq' => {
			eco => 'D18d',
			# TRANSLATORS: D18d: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4
			variation => N__('Slav: Dutch, 6... e6 7.Bxc4 Bb4'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rn1qk2r/pp3ppp/2p1pn2/5b2/PbBP4/2N1PN2/1P3PPP/R1BQ1RK1 b kq' => {
			eco => 'D18e',
			# TRANSLATORS: D18e: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O
			variation => N__('Slav: Dutch, 8.O-O'),
			moves => {
				'b8d7' => 1,
				'e8g8' => 1,
			},
		},
		'r2qk2r/pp1n1ppp/2p1pn2/5b2/PbBP4/2N1PN2/1P3PPP/R1BQ1RK1 w kq' => {
			eco => 'D18f',
			# TRANSLATORS: D18f: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O Nbd7
			variation => N__('Slav: Dutch, 8...Nbd7'),
			moves => {
				'd1b3' => 1,
				'd1e2' => 1,
				'f3h4' => 1,
			},
		},
		'r2qk2r/pp1n1ppp/2p1pn2/5b2/PbBP3N/2N1P3/1P3PPP/R1BQ1RK1 b kq' => {
			eco => 'D18g',
			# TRANSLATORS: D18g: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O Nbd7 9. Nh4
			variation => N__('Slav: Dutch, 8...Nbd7 9. Nh4'),
			moves => {
				'f5g6' => 1,
			},
		},
		'r2qk2r/pp1n1ppp/2p1pnb1/8/PbBP3N/2N1P3/1P3PPP/R1BQ1RK1 w kq' => {
			eco => 'D18h',
			# TRANSLATORS: D18h: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O Nbd7 9. Nh4 Bg6
			variation => N__('Slav: Dutch, 8...Nbd7 9. Nh4 Bg6'),
			moves => {
			},
		},
		'r2qk2r/pp1n1ppp/2p1pn2/5b2/PbBP4/1QN1PN2/1P3PPP/R1B2RK1 b kq' => {
			eco => 'D18i',
			# TRANSLATORS: D18i: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O Nbd7 9. Qb3
			variation => N__('Slav: Dutch, 8...Nbd7 9. Qb3'),
			moves => {
				'a7a5' => 1,
			},
		},
		'r2qk2r/1p1n1ppp/2p1pn2/p4b2/PbBP4/1QN1PN2/1P3PPP/R1B2RK1 w kq' => {
			eco => 'D18j',
			# TRANSLATORS: D18j: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O Nbd7 9. Qb3 a5
			variation => N__('Slav: Dutch, 8...Nbd7 9. Qb3 a5'),
			moves => {
			},
		},
		'r2qk2r/pp1n1ppp/2p1pn2/5b2/PbBP4/2N1PN2/1P2QPPP/R1B2RK1 b kq' => {
			eco => 'D18k',
			# TRANSLATORS: D18k: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O Nbd7 9. Qe2
			variation => N__('Slav: Dutch, 8...Nbd7 9. Qe2'),
			moves => {
				'f5g6' => 1,
			},
		},
		'r2qk2r/pp1n1ppp/2p1pnb1/8/PbBP4/2N1PN2/1P2QPPP/R1B2RK1 w kq' => {
			eco => 'D18l',
			# TRANSLATORS: D18l: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O Nbd7 9. Qe2 Bg6
			variation => N__('Slav: Dutch, 8...Nbd7 9. Qe2 Bg6'),
			moves => {
				'e3e4' => 1,
			},
		},
		'r2qk2r/pp1n1ppp/2p1pnb1/8/PbBPP3/2N2N2/1P2QPPP/R1B2RK1 b kq' => {
			eco => 'D18m',
			# TRANSLATORS: D18m: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O Nbd7 9. Qe2 Bg6 10. e4
			variation => N__('Slav: Dutch, 8...Nbd7 9. Qe2 Bg6 10. e4'),
			moves => {
			},
		},
		'rn1q1rk1/pp3ppp/2p1pn2/5b2/PbBP4/2N1PN2/1P3PPP/R1BQ1RK1 w -' => {
			eco => 'D18n',
			# TRANSLATORS: D18n: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O O-O
			variation => N__('Slav: Dutch, 8...O-O'),
			moves => {
				'd1b3' => 1,
				'd1e2' => 1,
				'f3h4' => 1,
			},
		},
		'rn1q1rk1/pp3ppp/2p1pn2/5b2/PbBP4/1QN1PN2/1P3PPP/R1B2RK1 b -' => {
			eco => 'D18o',
			# TRANSLATORS: D18o: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O O-O 9. Qb3
			variation => N__('Slav: Dutch, 8...O-O 9. Qb3'),
			moves => {
			},
		},
		'rn1q1rk1/pp3ppp/2p1pn2/5b2/PbBP3N/2N1P3/1P3PPP/R1BQ1RK1 b -' => {
			eco => 'D18p',
			# TRANSLATORS: D18p: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O O-O 9. Nh4
			variation => N__('Slav: Dutch, 8...O-O 9. Nh4'),
			moves => {
				'b8d7' => 1,
				'f5g4' => 1,
				'f5g6' => 1,
			},
		},
		'rn1q1rk1/pp3ppp/2p1pnb1/8/PbBP3N/2N1P3/1P3PPP/R1BQ1RK1 w -' => {
			eco => 'D18p',
			# TRANSLATORS: D18p: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O O-O 9. Nh4 Bg6
			variation => N__('Slav: Dutch, 8...O-O 9. Nh4 Bg6'),
			moves => {
			},
		},
		'rn1q1rk1/pp3ppp/2p1pn2/8/PbBP2bN/2N1P3/1P3PPP/R1BQ1RK1 w -' => {
			eco => 'D18q',
			# TRANSLATORS: D18q: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O O-O 9. Nh4 Bg4
			variation => N__('Slav: Dutch, 8...O-O 9. Nh4 Bg4'),
			moves => {
			},
		},
		'r2q1rk1/pp1n1ppp/2p1pn2/5b2/PbBP3N/2N1P3/1P3PPP/R1BQ1RK1 w -' => {
			eco => 'D18r',
			# TRANSLATORS: D18r: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O O-O 9. Nh4 Nbd7
			variation => N__('Slav: Dutch, 8...O-O 9. Nh4 Nbd7'),
			moves => {
				'h4f5' => 1,
			},
		},
		'r2q1rk1/pp1n1ppp/2p1pn2/5N2/PbBP4/2N1P3/1P3PPP/R1BQ1RK1 b -' => {
			eco => 'D18s',
			# TRANSLATORS: D18s: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O O-O 9. Nh4 Nbd7 10. Nxf5
			variation => N__('Slav: Dutch, 8...O-O 9. Nh4 Nbd7 10.Nxf5'),
			moves => {
				'e6f5' => 1,
			},
		},
		'r2q1rk1/pp1n1ppp/2p2n2/5p2/PbBP4/2N1P3/1P3PPP/R1BQ1RK1 w -' => {
			eco => 'D18s',
			# TRANSLATORS: D18s: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O O-O 9. Nh4 Nbd7 10. Nxf5 exf5
			variation => N__('Slav: Dutch, 8...O-O 9. Nh4 Nbd7 10.Nxf5 exf5'),
			moves => {
				'd1c2' => 1,
			},
		},
		'r2q1rk1/pp1n1ppp/2p2n2/5p2/PbBP4/2N1P3/1PQ2PPP/R1B2RK1 b -' => {
			eco => 'D18t',
			# TRANSLATORS: D18t: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O O-O 9. Nh4 Nbd7 10. Nxf5 exf5 11. Qc2
			variation => N__('Slav: Dutch, 8...O-O 9. Nh4 Nbd7 10.Nxf5 exf5 11. Qc2'),
			moves => {
			},
		},
		'rn1q1rk1/pp3ppp/2p1pn2/5b2/PbBP4/2N1PN2/1P2QPPP/R1B2RK1 b -' => {
			eco => 'D19a',
			# TRANSLATORS: D19a: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O O-O 9. Qe2
			variation => N__('Slav: Dutch, 8...O-O 9. Qe2'),
			moves => {
				'b8d7' => 1,
				'f5g4' => 1,
				'f5g6' => 1,
				'f6e4' => 1,
			},
		},
		'rn1q1rk1/pp3ppp/2p1pn2/8/PbBP2b1/2N1PN2/1P2QPPP/R1B2RK1 w -' => {
			eco => 'D19b',
			# TRANSLATORS: D19b: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O O-O 9. Qe2 Bg4
			variation => N__('Slav: Dutch, 8...O-O 9. Qe2 Bg4'),
			moves => {
			},
		},
		'rn1q1rk1/pp3ppp/2p1pnb1/8/PbBP4/2N1PN2/1P2QPPP/R1B2RK1 w -' => {
			eco => 'D19c',
			# TRANSLATORS: D19c: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O O-O 9. Qe2 Bg6
			variation => N__('Slav: Dutch, 8...O-O 9. Qe2 Bg6'),
			moves => {
				'f1d1' => 1,
				'f3e5' => 1,
			},
		},
		'rn1q1rk1/pp3ppp/2p1pnb1/8/PbBP4/2N1PN2/1P2QPPP/R1BR2K1 b -' => {
			eco => 'D19d',
			# TRANSLATORS: D19d: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O O-O 9. Qe2 Bg6 10. Rd1
			variation => N__('Slav: Dutch, 8...O-O 9. Qe2 Bg6 10. Rd1'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r2q1rk1/pp1n1ppp/2p1pnb1/8/PbBP4/2N1PN2/1P2QPPP/R1BR2K1 w -' => {
			eco => 'D19d',
			# TRANSLATORS: D19d: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O O-O 9. Qe2 Bg6 10. Rd1 Nbd7
			variation => N__('Slav: Dutch, 8...O-O 9. Qe2 Bg6 10. Rd1 Nbd7'),
			moves => {
			},
		},
		'rn1q1rk1/pp3ppp/2p1pnb1/4N3/PbBP4/2N1P3/1P2QPPP/R1B2RK1 b -' => {
			eco => 'D19e',
			# TRANSLATORS: D19e: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O O-O 9. Qe2 Bg6 10. Ne5
			variation => N__('Slav: Dutch, 8...O-O 9. Qe2 Bg6 10. Ne5'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r2q1rk1/pp1n1ppp/2p1pnb1/4N3/PbBP4/2N1P3/1P2QPPP/R1B2RK1 w -' => {
			eco => 'D19e',
			# TRANSLATORS: D19e: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O O-O 9. Qe2 Bg6 10. Ne5 Nbd7
			variation => N__('Slav: Dutch, 8...O-O 9. Qe2 Bg6 10. Ne5 Nbd7, 12. Rd1'),
			moves => {
				'e5g6' => 1,
			},
		},
		'r2q1rk1/pp1n1ppp/2p1pnN1/8/PbBP4/2N1P3/1P2QPPP/R1B2RK1 b -' => {
			eco => 'D19e',
			# TRANSLATORS: D19e: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O O-O 9. Qe2 Bg6 10. Ne5 Nbd7 11. Nxg6
			variation => N__('Slav: Dutch, 8...O-O 9. Qe2 Bg6 10. Ne5 Nbd7, 12. Rd1'),
			moves => {
				'h7g6' => 1,
			},
		},
		'r2q1rk1/pp1n1pp1/2p1pnp1/8/PbBP4/2N1P3/1P2QPPP/R1B2RK1 w -' => {
			eco => 'D19e',
			# TRANSLATORS: D19e: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O O-O 9. Qe2 Bg6 10. Ne5 Nbd7 11. Nxg6 hxg6
			variation => N__('Slav: Dutch, 8...O-O 9. Qe2 Bg6 10. Ne5 Nbd7, 12. Rd1'),
			moves => {
				'f1d1' => 1,
			},
		},
		'r2q1rk1/pp1n1pp1/2p1pnp1/8/PbBP4/2N1P3/1P2QPPP/R1BR2K1 b -' => {
			eco => 'D19f',
			# TRANSLATORS: D19f: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O O-O 9. Qe2 Bg6 10. Ne5 Nbd7 11. Nxg6 hxg6 12. Rd1
			variation => N__('Slav: Dutch, 8...O-O 9. Qe2 Bg6 10. Ne5 Nbd7, 12. Rd1'),
			moves => {
			},
		},
		'rn1q1rk1/pp3ppp/2p1p3/5b2/PbBPn3/2N1PN2/1P2QPPP/R1B2RK1 w -' => {
			eco => 'D19g',
			# TRANSLATORS: D19g: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O O-O 9. Qe2 Ne4
			variation => N__('Slav: Dutch, 8...O-O 9. Qe2 Ne4'),
			moves => {
				'g2g4' => 1,
			},
		},
		'rn1q1rk1/pp3ppp/2p1p3/5b2/PbBPn1P1/2N1PN2/1P2QP1P/R1B2RK1 b -' => {
			eco => 'D19g',
			# TRANSLATORS: D19g: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O O-O 9. Qe2 Ne4 10. g4
			variation => N__('Slav: Dutch, Sämisch Variation'),
			moves => {
			},
		},
		'r2q1rk1/pp1n1ppp/2p1pn2/5b2/PbBP4/2N1PN2/1P2QPPP/R1B2RK1 w -' => {
			eco => 'D19h',
			# TRANSLATORS: D19h: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O O-O 9. Qe2 Nbd7
			variation => N__('Slav: Dutch, 8...O-O 9. Qe2 Nbd7'),
			moves => {
				'e3e4' => 1,
			},
		},
		'r2q1rk1/pp1n1ppp/2p1pn2/5b2/PbBPP3/2N2N2/1P2QPPP/R1B2RK1 b -' => {
			eco => 'D19i',
			# TRANSLATORS: D19i: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O O-O 9. Qe2 Nbd7 10. e4
			variation => N__('Slav: Dutch, 8...O-O 9. Qe2 Nbd7 10. e4'),
			moves => {
				'f5g4' => 1,
				'f5g6' => 1,
			},
		},
		'r2q1rk1/pp1n1ppp/2p1pn2/8/PbBPP1b1/2N2N2/1P2QPPP/R1B2RK1 w -' => {
			eco => 'D19i',
			# TRANSLATORS: D19i: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O O-O 9. Qe2 Nbd7 10. e4 Bg4
			variation => N__('Slav: Dutch, 8...O-O 9. Qe2 Nbd7 10. e4 Bg4'),
			moves => {
			},
		},
		'r2q1rk1/pp1n1ppp/2p1pnb1/8/PbBPP3/2N2N2/1P2QPPP/R1B2RK1 w -' => {
			eco => 'D19j',
			# TRANSLATORS: D19j: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O O-O 9. Qe2 Nbd7 10. e4 Bg6
			variation => N__('Slav: Dutch, 8...O-O 9. Qe2 Nbd7 10. e4 Bg6'),
			moves => {
				'c4d3' => 1,
			},
		},
		'r2q1rk1/pp1n1ppp/2p1pnb1/8/Pb1PP3/2NB1N2/1P2QPPP/R1B2RK1 b -' => {
			eco => 'D19k',
			# TRANSLATORS: D19k: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O O-O 9. Qe2 Nbd7 10. e4 Bg6 11. Bd3
			variation => N__('Slav: Dutch, 8...O-O 9. Qe2 Nbd7 10. e4 Bg6 11. Bd3'),
			moves => {
				'f8e8' => 1,
				'g6h5' => 1,
				'h7h6' => 1,
			},
		},
		'r2q1rk1/pp1n1pp1/2p1pnbp/8/Pb1PP3/2NB1N2/1P2QPPP/R1B2RK1 w -' => {
			eco => 'D19l',
			# TRANSLATORS: D19l: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O O-O 9. Qe2 Nbd7 10. e4 Bg6 11. Bd3 h6
			variation => N__('Slav: Dutch, 8...O-O 9. Qe2 Nbd7 10. e4 Bg6 11. Bd3 h6'),
			moves => {
			},
		},
		'r2qr1k1/pp1n1ppp/2p1pnb1/8/Pb1PP3/2NB1N2/1P2QPPP/R1B2RK1 w -' => {
			eco => 'D19m',
			# TRANSLATORS: D19m: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O O-O 9. Qe2 Nbd7 10. e4 Bg6 11. Bd3 Re8
			variation => N__('Slav: Dutch, 8...O-O 9. Qe2 Nbd7 10. e4 Bg6 11. Bd3 Re8'),
			moves => {
			},
		},
		'r2q1rk1/pp1n1ppp/2p1pn2/7b/Pb1PP3/2NB1N2/1P2QPPP/R1B2RK1 w -' => {
			eco => 'D19n',
			# TRANSLATORS: D19n: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O O-O 9. Qe2 Nbd7 10. e4 Bg6 11. Bd3 Bh5
			variation => N__('Slav: Dutch, 8...O-O 9. Qe2 Nbd7 10. e4 Bg6 11. Bd3 Bh5'),
			moves => {
				'e4e5' => 1,
			},
		},
		'r2q1rk1/pp1n1ppp/2p1pn2/4P2b/Pb1P4/2NB1N2/1P2QPPP/R1B2RK1 b -' => {
			eco => 'D19o',
			# TRANSLATORS: D19o: 1. d4 d5 2. c4 c6 3. Nf3 Nf6 4. Nc3 dxc4 5. a4 Bf5 6. e3 e6 7. Bxc4 Bb4 8. O-O O-O 9. Qe2 Nbd7 10. e4 Bg6 11. Bd3 Bh5 12. e5
			variation => N__('Slav: Dutch, 8...O-O 9. Qe2 Nbd7 10. e4 Bg6 11. Bd3 Bh5 12. e5'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/8/2pP4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'D20a',
			# TRANSLATORS: D20a: 1. d4 d5 2. c4 dxc4
			variation => N__('Queen\'s Gambit Accepted (QGA)'),
			moves => {
				'b1c3' => 1,
				'd1a4' => 1,
				'e2e3' => 1,
				'e2e4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/ppp1pppp/8/8/Q1pP4/8/PP2PPPP/RNB1KBNR b KQkq' => {
			eco => 'D20a',
			# TRANSLATORS: D20a: 1. d4 d5 2. c4 dxc4 3. Qa4+
			variation => N__('QGA: 3. Qa4+'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/8/2pP4/4P3/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'D20b',
			# TRANSLATORS: D20b: 1. d4 d5 2. c4 dxc4 3. e3
			variation => N__('QGA: 3. e3'),
			moves => {
				'c7c5' => 1,
				'e7e5' => 1,
				'e7e6' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/8/2p5/2pP4/4P3/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'D20c',
			# TRANSLATORS: D20c: 1. d4 d5 2. c4 dxc4 3. e3 c5
			variation => N__('QGA: 3. e3 c5'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/8/2p5/2BP4/4P3/PP3PPP/RNBQK1NR b KQkq' => {
			eco => 'D20c',
			# TRANSLATORS: D20c: 1. d4 d5 2. c4 dxc4 3. e3 c5 4. Bxc4
			variation => N__('QGA: 3. e3 c5 4.Bxc4'),
			moves => {
				'c5d4' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/8/8/2Bp4/4P3/PP3PPP/RNBQK1NR w KQkq' => {
			eco => 'D20c',
			# TRANSLATORS: D20c: 1. d4 d5 2. c4 dxc4 3. e3 c5 4. Bxc4 cxd4
			variation => N__('QGA: 3. e3 c5 4.Bxc4'),
			moves => {
				'e3d4' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/8/8/2BP4/8/PP3PPP/RNBQK1NR b KQkq' => {
			eco => 'D20c',
			# TRANSLATORS: D20c: 1. d4 d5 2. c4 dxc4 3. e3 c5 4. Bxc4 cxd4 5. exd4
			variation => N__('QGA: 3. e3 c5 4.Bxc4'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/8/2pP4/4P3/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'D20d',
			# TRANSLATORS: D20d: 1. d4 d5 2. c4 dxc4 3. e3 e6
			variation => N__('QGA: 3. e3 e6'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/8/2BP4/4P3/PP3PPP/RNBQK1NR b KQkq' => {
			eco => 'D20d',
			# TRANSLATORS: D20d: 1. d4 d5 2. c4 dxc4 3. e3 e6 4. Bxc4
			variation => N__('QGA: 3. e3 e6'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/8/2BP4/4P3/PP3PPP/RNBQK1NR w KQkq' => {
			eco => 'D20d',
			# TRANSLATORS: D20d: 1. d4 d5 2. c4 dxc4 3. e3 e6 4. Bxc4 Nf6
			variation => N__('QGA: 3. e3 e6'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/8/4p3/2pP4/4P3/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'D20e',
			# TRANSLATORS: D20e: 1. d4 d5 2. c4 dxc4 3. e3 e5
			variation => N__('QGA: 3. e3 e5'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/8/4p3/2BP4/4P3/PP3PPP/RNBQK1NR b KQkq' => {
			eco => 'D20e',
			# TRANSLATORS: D20e: 1. d4 d5 2. c4 dxc4 3. e3 e5 4. Bxc4
			variation => N__('QGA: 3. e3 e5'),
			moves => {
				'e5d4' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/8/8/2Bp4/4P3/PP3PPP/RNBQK1NR w KQkq' => {
			eco => 'D20e',
			# TRANSLATORS: D20e: 1. d4 d5 2. c4 dxc4 3. e3 e5 4. Bxc4 exd4
			variation => N__('QGA: 3. e3 e5'),
			moves => {
				'e3d4' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/8/8/2BP4/8/PP3PPP/RNBQK1NR b KQkq' => {
			eco => 'D20e',
			# TRANSLATORS: D20e: 1. d4 d5 2. c4 dxc4 3. e3 e5 4. Bxc4 exd4 5. exd4
			variation => N__('QGA: 3. e3 e5'),
			moves => {
				'f8b4' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqk1nr/ppp2ppp/8/8/1bBP4/8/PP3PPP/RNBQK1NR w KQkq' => {
			eco => 'D20f',
			# TRANSLATORS: D20f: 1. d4 d5 2. c4 dxc4 3. e3 e5 4. Bxc4 exd4 5. exd4 Bb4+
			variation => N__('QGA: 3. e3 e5'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqk1nr/ppp2ppp/8/8/1bBP4/2N5/PP3PPP/R1BQK1NR b KQkq' => {
			eco => 'D20f',
			# TRANSLATORS: D20f: 1. d4 d5 2. c4 dxc4 3. e3 e5 4. Bxc4 exd4 5. exd4 Bb4+ 6. Nc3
			variation => N__('QGA: 3. e3 e5'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/5n2/8/1bBP4/2N5/PP3PPP/R1BQK1NR w KQkq' => {
			eco => 'D20f',
			# TRANSLATORS: D20f: 1. d4 d5 2. c4 dxc4 3. e3 e5 4. Bxc4 exd4 5. exd4 Bb4+ 6. Nc3 Nf6
			variation => N__('QGA: 3. e3 e5'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/8/2BP4/8/PP3PPP/RNBQK1NR w KQkq' => {
			eco => 'D20g',
			# TRANSLATORS: D20g: 1. d4 d5 2. c4 dxc4 3. e3 e5 4. Bxc4 exd4 5. exd4 Nf6
			variation => N__('QGA: 3. e3 e5'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/8/2pP4/4P3/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'D20h',
			# TRANSLATORS: D20h: 1. d4 d5 2. c4 dxc4 3. e3 Nf6
			variation => N__('QGA: 3. e3 Nf6'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/8/2pP4/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'D20i',
			# TRANSLATORS: D20i: 1. d4 d5 2. c4 dxc4 3. Nc3
			variation => N__('QGA: 3. Nc3'),
			moves => {
				'a7a6' => 1,
				'c7c5' => 1,
				'e7e5' => 1,
				'e7e6' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/8/2p5/2pP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'D20i',
			# TRANSLATORS: D20i: 1. d4 d5 2. c4 dxc4 3. Nc3 c5
			variation => N__('QGA: 3. Nc3 c5'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/8/4p3/2pP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'D20i',
			# TRANSLATORS: D20i: 1. d4 d5 2. c4 dxc4 3. Nc3 e5
			variation => N__('QGA: 3. Nc3 e5'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/8/2pP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'D20i',
			# TRANSLATORS: D20i: 1. d4 d5 2. c4 dxc4 3. Nc3 Nf6
			variation => N__('QGA: 3. Nc3 Nf6'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/8/2pP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'D20j',
			# TRANSLATORS: D20j: 1. d4 d5 2. c4 dxc4 3. Nc3 e6
			variation => N__('QGA: 3. Nc3 e6'),
			moves => {
				'e2e4' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/8/2pPP3/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'D20j',
			# TRANSLATORS: D20j: 1. d4 d5 2. c4 dxc4 3. Nc3 e6 4. e4
			variation => N__('QGA: 3. Nc3 e6 4. e4'),
			moves => {
			},
		},
		'rnbqkbnr/1pp1pppp/p7/8/2pP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'D20k',
			# TRANSLATORS: D20k: 1. d4 d5 2. c4 dxc4 3. Nc3 a6
			variation => N__('QGA: 3. Nc3 a6'),
			moves => {
				'a2a4' => 1,
			},
		},
		'rnbqkbnr/1pp1pppp/p7/8/P1pP4/2N5/1P2PPPP/R1BQKBNR b KQkq' => {
			eco => 'D20k',
			# TRANSLATORS: D20k: 1. d4 d5 2. c4 dxc4 3. Nc3 a6 4. a4
			variation => N__('QGA: 3. Nc3 a6 4. a4'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/8/2pPP3/8/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'D20l',
			# TRANSLATORS: D20l: 1. d4 d5 2. c4 dxc4 3. e4
			variation => N__('QGA: 3. e4'),
			moves => {
				'b8c6' => 1,
				'c7c5' => 1,
				'e7e5' => 1,
				'f7f5' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/ppp1p1pp/8/5p2/2pPP3/8/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'D20l',
			# TRANSLATORS: D20l: 1. d4 d5 2. c4 dxc4 3. e4 f5
			variation => N__('QGA: 3. e4, Schwartz Defence'),
			moves => {
			},
		},
		'r1bqkbnr/ppp1pppp/2n5/8/2pPP3/8/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'D20m',
			# TRANSLATORS: D20m: 1. d4 d5 2. c4 dxc4 3. e4 Nc6
			variation => N__('QGA: 3. e4 Nc6'),
			moves => {
				'c1e3' => 1,
				'g1f3' => 1,
			},
		},
		'r1bqkbnr/ppp1pppp/2n5/8/2pPP3/5N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'D20m',
			# TRANSLATORS: D20m: 1. d4 d5 2. c4 dxc4 3. e4 Nc6 4. Nf3
			variation => N__('QGA: 3. e4 Nc6 4. Nf3'),
			moves => {
			},
		},
		'r1bqkbnr/ppp1pppp/2n5/8/2pPP3/4B3/PP3PPP/RN1QKBNR b KQkq' => {
			eco => 'D20n',
			# TRANSLATORS: D20n: 1. d4 d5 2. c4 dxc4 3. e4 Nc6 4. Be3
			variation => N__('QGA: 3. e4 Nc6 4. Be3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/8/2pPP3/8/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'D20o',
			# TRANSLATORS: D20o: 1. d4 d5 2. c4 dxc4 3. e4 Nf6
			variation => N__('QGA: 3. e4 Nf6'),
			moves => {
				'b1c3' => 1,
				'e4e5' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/8/2pPP3/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'D20o',
			# TRANSLATORS: D20o: 1. d4 d5 2. c4 dxc4 3. e4 Nf6 4. Nc3
			variation => N__('QGA: 3. e4 Nf6 4. Nc3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/4P3/2pP4/8/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'D20o',
			# TRANSLATORS: D20o: 1. d4 d5 2. c4 dxc4 3. e4 Nf6 4. e5
			variation => N__('QGA: 3. e4 Nf6 4. e5'),
			moves => {
				'f6d5' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/8/3nP3/2pP4/8/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'D20o',
			# TRANSLATORS: D20o: 1. d4 d5 2. c4 dxc4 3. e4 Nf6 4. e5 Nd5
			variation => N__('QGA: 3. e4 Nf6 4. e5 Nd5'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/8/3nP3/2BP4/8/PP3PPP/RNBQK1NR b KQkq' => {
			eco => 'D20o',
			# TRANSLATORS: D20o: 1. d4 d5 2. c4 dxc4 3. e4 Nf6 4. e5 Nd5 5. Bxc4
			variation => N__('QGA: 3. e4 Nf6 4. e5 Nd5'),
			moves => {
				'd5b6' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/1n6/4P3/2BP4/8/PP3PPP/RNBQK1NR w KQkq' => {
			eco => 'D20p',
			# TRANSLATORS: D20p: 1. d4 d5 2. c4 dxc4 3. e4 Nf6 4. e5 Nd5 5. Bxc4 Nb6
			variation => N__('QGA: 3. e4 Nf6 4. e5 Nd5 5.Bxc4 Nb6'),
			moves => {
				'c4b3' => 1,
				'c4d3' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/1n6/4P3/3P4/3B4/PP3PPP/RNBQK1NR b KQkq' => {
			eco => 'D20p',
			# TRANSLATORS: D20p: 1. d4 d5 2. c4 dxc4 3. e4 Nf6 4. e5 Nd5 5. Bxc4 Nb6 6. Bd3
			variation => N__('QGA: 3. e4 Nf6 4. e5 Nd5 5.Bxc4 Nb6 6. Bd3'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkb1r/ppp1pppp/1nn5/4P3/3P4/3B4/PP3PPP/RNBQK1NR w KQkq' => {
			eco => 'D20p',
			# TRANSLATORS: D20p: 1. d4 d5 2. c4 dxc4 3. e4 Nf6 4. e5 Nd5 5. Bxc4 Nb6 6. Bd3 Nc6
			variation => N__('QGA: 3. e4 Nf6 4. e5 Nd5 5.Bxc4 Nb6 6. Bd3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/1n6/4P3/3P4/1B6/PP3PPP/RNBQK1NR b KQkq' => {
			eco => 'D20q',
			# TRANSLATORS: D20q: 1. d4 d5 2. c4 dxc4 3. e4 Nf6 4. e5 Nd5 5. Bxc4 Nb6 6. Bb3
			variation => N__('QGA: 3. e4 Nf6 4. e5 Nd5 5.Bxc4 Nb6 6. Bb3'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkb1r/ppp1pppp/1nn5/4P3/3P4/1B6/PP3PPP/RNBQK1NR w KQkq' => {
			eco => 'D20q',
			# TRANSLATORS: D20q: 1. d4 d5 2. c4 dxc4 3. e4 Nf6 4. e5 Nd5 5. Bxc4 Nb6 6. Bb3 Nc6
			variation => N__('QGA: 3. e4 Nf6 4. e5 Nd5 5.Bxc4 Nb6 6. Bb3'),
			moves => {
				'g1e2' => 1,
			},
		},
		'r1bqkb1r/ppp1pppp/1nn5/4P3/3P4/1B6/PP2NPPP/RNBQK2R b KQkq' => {
			eco => 'D20r',
			# TRANSLATORS: D20r: 1. d4 d5 2. c4 dxc4 3. e4 Nf6 4. e5 Nd5 5. Bxc4 Nb6 6. Bb3 Nc6 7. Ne2
			variation => N__('QGA: 3. e4 Nf6 4. e5 Nd5 5.Bxc4 Nb6 6. Bb3 Nc6 7. Ne2'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/8/2p5/2pPP3/8/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'D20s',
			# TRANSLATORS: D20s: 1. d4 d5 2. c4 dxc4 3. e4 c5
			variation => N__('QGA: 3. e4 c5'),
			moves => {
				'd4d5' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/8/2p5/2pPP3/5N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'D20s',
			# TRANSLATORS: D20s: 1. d4 d5 2. c4 dxc4 3. e4 c5 4. Nf3
			variation => N__('QGA: 3. e4 c5'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/8/2pP4/2p1P3/8/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'D20t',
			# TRANSLATORS: D20t: 1. d4 d5 2. c4 dxc4 3. e4 c5 4. d5
			variation => N__('QGA: 3. e4 c5 4. d5'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/5n2/2pP4/2p1P3/8/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'D20t',
			# TRANSLATORS: D20t: 1. d4 d5 2. c4 dxc4 3. e4 c5 4. d5 Nf6
			variation => N__('QGA: 3. e4 c5 4. d5'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/5n2/2pP4/2p1P3/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'D20t',
			# TRANSLATORS: D20t: 1. d4 d5 2. c4 dxc4 3. e4 c5 4. d5 Nf6 5. Nc3
			variation => N__('QGA: 3. e4 c5 4. d5'),
			moves => {
				'b7b5' => 1,
			},
		},
		'rnbqkb1r/p3pppp/5n2/1ppP4/2p1P3/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'D20u',
			# TRANSLATORS: D20u: 1. d4 d5 2. c4 dxc4 3. e4 c5 4. d5 Nf6 5. Nc3 b5
			variation => N__('QGA: Linares Variation'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/8/4p3/2pPP3/8/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'D20v',
			# TRANSLATORS: D20v: 1. d4 d5 2. c4 dxc4 3. e4 e5
			variation => N__('QGA: 3. e4 e5'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/8/4p3/2pPP3/5N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'D20v',
			# TRANSLATORS: D20v: 1. d4 d5 2. c4 dxc4 3. e4 e5 4. Nf3
			variation => N__('QGA: 3. e4 e5'),
			moves => {
				'e5d4' => 1,
				'f8b4' => 1,
			},
		},
		'rnbqk1nr/ppp2ppp/8/4p3/1bpPP3/5N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'D20w',
			# TRANSLATORS: D20w: 1. d4 d5 2. c4 dxc4 3. e4 e5 4. Nf3 Bb4+
			variation => N__('QGA: 3. e4 e5 4. Nf3 Bb4+'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/8/8/2ppP3/5N2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'D20x',
			# TRANSLATORS: D20x: 1. d4 d5 2. c4 dxc4 3. e4 e5 4. Nf3 exd4
			variation => N__('QGA: 3. e4 e5 4. Nf3 exd4'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/8/8/2BpP3/5N2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'D20x',
			# TRANSLATORS: D20x: 1. d4 d5 2. c4 dxc4 3. e4 e5 4. Nf3 exd4 5. Bxc4
			variation => N__('QGA: 3. e4 e5 4. Nf3 exd4'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkbnr/ppp2ppp/2n5/8/2BpP3/5N2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'D20y',
			# TRANSLATORS: D20y: 1. d4 d5 2. c4 dxc4 3. e4 e5 4. Nf3 exd4 5. Bxc4 Nc6
			variation => N__('QGA: 3. e4 e5 4. Nf3 exd4 5.Bxc4 Nc6'),
			moves => {
			},
		},
		'rnbqkbnr/ppp1pppp/8/8/2pP4/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'D21a',
			# TRANSLATORS: D21a: 1. d4 d5 2. c4 dxc4 3. Nf3
			variation => N__('QGA: 3. Nf3'),
			moves => {
				'a7a6' => 1,
				'b7b5' => 1,
				'b8d7' => 1,
				'c7c5' => 1,
				'c8g4' => 1,
				'e7e6' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/p1p1pppp/8/1p6/2pP4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'D21a',
			# TRANSLATORS: D21a: 1. d4 d5 2. c4 dxc4 3. Nf3 b5
			variation => N__('QGA: Ericson Variation'),
			moves => {
			},
		},
		'r1bqkbnr/pppnpppp/8/8/2pP4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'D21b',
			# TRANSLATORS: D21b: 1. d4 d5 2. c4 dxc4 3. Nf3 Nd7
			variation => N__('QGA: 3. Nf3 Nd7'),
			moves => {
			},
		},
		'rn1qkbnr/ppp1pppp/8/8/2pP2b1/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'D21c',
			# TRANSLATORS: D21c: 1. d4 d5 2. c4 dxc4 3. Nf3 Bg4
			variation => N__('QGA: 3. Nf3 Bg4'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/8/2pP4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'D21d',
			# TRANSLATORS: D21d: 1. d4 d5 2. c4 dxc4 3. Nf3 e6
			variation => N__('QGA: 3. Nf3 e6'),
			moves => {
				'd1a4' => 1,
				'e2e3' => 1,
				'e2e4' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/8/Q1pP4/5N2/PP2PPPP/RNB1KB1R b KQkq' => {
			eco => 'D21e',
			# TRANSLATORS: D21e: 1. d4 d5 2. c4 dxc4 3. Nf3 e6 4. Qa4+
			variation => N__('QGA: 3. Nf3 e6 4. Qa4+'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/8/2pPP3/5N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'D21f',
			# TRANSLATORS: D21f: 1. d4 d5 2. c4 dxc4 3. Nf3 e6 4. e4
			variation => N__('QGA: 3. Nf3 e6 4. e4'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/8/2pP4/4PN2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'D21g',
			# TRANSLATORS: D21g: 1. d4 d5 2. c4 dxc4 3. Nf3 e6 4. e3
			variation => N__('QGA: 3. Nf3 e6 4. e3'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/4p3/2p5/2pP4/4PN2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'D21g',
			# TRANSLATORS: D21g: 1. d4 d5 2. c4 dxc4 3. Nf3 e6 4. e3 c5
			variation => N__('QGA: 3. Nf3 e6 4. e3 c5'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/8/2p5/2pP4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'D21h',
			# TRANSLATORS: D21h: 1. d4 d5 2. c4 dxc4 3. Nf3 c5
			variation => N__('QGA: 3. Nf3 c5'),
			moves => {
				'b1c3' => 1,
				'd4d5' => 1,
				'e2e3' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/8/2p5/2pP4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D21i',
			# TRANSLATORS: D21i: 1. d4 d5 2. c4 dxc4 3. Nf3 c5 4. Nc3
			variation => N__('QGA: 3. Nf3 c5 4. Nc3'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/8/2p5/2pP4/4PN2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'D21j',
			# TRANSLATORS: D21j: 1. d4 d5 2. c4 dxc4 3. Nf3 c5 4. e3
			variation => N__('QGA: 3. Nf3 c5 4. e3'),
			moves => {
				'c5d4' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/8/8/2pp4/4PN2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'D21j',
			# TRANSLATORS: D21j: 1. d4 d5 2. c4 dxc4 3. Nf3 c5 4. e3 cxd4
			variation => N__('QGA: 3. Nf3 c5 4. e3 cxd4'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnbqkbnr/pp2pppp/8/8/2Bp4/4PN2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'D21k',
			# TRANSLATORS: D21k: 1. d4 d5 2. c4 dxc4 3. Nf3 c5 4. e3 cxd4 5. Bxc4
			variation => N__('QGA: 3. Nf3 c5 4. e3 cxd4 5.Bxc4'),
			moves => {
			},
		},
		'rnbqkbnr/pp2pppp/8/2pP4/2p5/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'D21l',
			# TRANSLATORS: D21l: 1. d4 d5 2. c4 dxc4 3. Nf3 c5 4. d5
			variation => N__('QGA: 3. Nf3 c5 4. d5'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/4p3/2pP4/2p5/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'D21m',
			# TRANSLATORS: D21m: 1. d4 d5 2. c4 dxc4 3. Nf3 c5 4. d5 e6
			variation => N__('QGA: 3. Nf3 c5 4. d5 e6'),
			moves => {
				'b1c3' => 1,
				'e2e4' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/4p3/2pP4/2p1P3/5N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'D21m',
			# TRANSLATORS: D21m: 1. d4 d5 2. c4 dxc4 3. Nf3 c5 4. d5 e6 5. e4
			variation => N__('QGA: 3. Nf3 c5 4. d5 e6 5. e4'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/4p3/2pP4/2p5/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D21n',
			# TRANSLATORS: D21n: 1. d4 d5 2. c4 dxc4 3. Nf3 c5 4. d5 e6 5. Nc3
			variation => N__('QGA: 3. Nf3 c5 4. d5 e6 5. Nc3'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/8/2pp4/2p5/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D21o',
			# TRANSLATORS: D21o: 1. d4 d5 2. c4 dxc4 3. Nf3 c5 4. d5 e6 5. Nc3 exd5
			variation => N__('QGA: 3. Nf3 c5 4. d5 e6 5. Nc3 exd5'),
			moves => {
				'd1d5' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/8/2pQ4/2p5/2N2N2/PP2PPPP/R1B1KB1R b KQkq' => {
			eco => 'D21o',
			# TRANSLATORS: D21o: 1. d4 d5 2. c4 dxc4 3. Nf3 c5 4. d5 e6 5. Nc3 exd5 6. Qxd5
			variation => N__('QGA: 3. Nf3 c5 4. d5 e6 5. Nc3 exd5'),
			moves => {
				'd8d5' => 1,
			},
		},
		'rnb1kbnr/pp3ppp/8/2pq4/2p5/2N2N2/PP2PPPP/R1B1KB1R w KQkq' => {
			eco => 'D21o',
			# TRANSLATORS: D21o: 1. d4 d5 2. c4 dxc4 3. Nf3 c5 4. d5 e6 5. Nc3 exd5 6. Qxd5 Qxd5
			variation => N__('QGA: 3. Nf3 c5 4. d5 e6 5. Nc3 exd5'),
			moves => {
				'c3d5' => 1,
			},
		},
		'rnb1kbnr/pp3ppp/8/2pN4/2p5/5N2/PP2PPPP/R1B1KB1R b KQkq' => {
			eco => 'D21p',
			# TRANSLATORS: D21p: 1. d4 d5 2. c4 dxc4 3. Nf3 c5 4. d5 e6 5. Nc3 exd5 6. Qxd5 Qxd5 7. Nxd5
			variation => N__('QGA: 3. Nf3 c5 4. d5 e6 5. Nc3 exd5 6.Qxd5 Qxd5 7.Nxd5'),
			moves => {
				'f8d6' => 1,
			},
		},
		'rnb1k1nr/pp3ppp/3b4/2pN4/2p5/5N2/PP2PPPP/R1B1KB1R w KQkq' => {
			eco => 'D21q',
			# TRANSLATORS: D21q: 1. d4 d5 2. c4 dxc4 3. Nf3 c5 4. d5 e6 5. Nc3 exd5 6. Qxd5 Qxd5 7. Nxd5 Bd6
			variation => N__('QGA: 3. Nf3 c5 4. d5 e6 5. Nc3 exd5 6.Qxd5 Qxd5 7.Nxd5 Bd6'),
			moves => {
				'f3d2' => 1,
			},
		},
		'rnb1k1nr/pp3ppp/3b4/2pN4/2p5/8/PP1NPPPP/R1B1KB1R b KQkq' => {
			eco => 'D21r',
			# TRANSLATORS: D21r: 1. d4 d5 2. c4 dxc4 3. Nf3 c5 4. d5 e6 5. Nc3 exd5 6. Qxd5 Qxd5 7. Nxd5 Bd6 8. Nd2
			variation => N__('QGA: 3. Nf3 c5 4. d5 e6 5. Nc3 exd5 6.Qxd5 Qxd5 7.Nxd5 Bd6 8. Nd2'),
			moves => {
				'g8e7' => 1,
			},
		},
		'rnb1k2r/pp2nppp/3b4/2pN4/2p5/8/PP1NPPPP/R1B1KB1R w KQkq' => {
			eco => 'D21s',
			# TRANSLATORS: D21s: 1. d4 d5 2. c4 dxc4 3. Nf3 c5 4. d5 e6 5. Nc3 exd5 6. Qxd5 Qxd5 7. Nxd5 Bd6 8. Nd2 Ne7
			variation => N__('QGA: Seirawan Variation'),
			moves => {
			},
		},
		'rnbqkbnr/1pp1pppp/p7/8/2pP4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'D21t',
			# TRANSLATORS: D21t: 1. d4 d5 2. c4 dxc4 3. Nf3 a6
			variation => N__('QGA: Alekhine Defence'),
			moves => {
				'a2a4' => 1,
				'e2e3' => 1,
				'e2e4' => 1,
			},
		},
		'rnbqkbnr/1pp1pppp/p7/8/2pPP3/5N2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'D21u',
			# TRANSLATORS: D21u: 1. d4 d5 2. c4 dxc4 3. Nf3 a6 4. e4
			variation => N__('QGA: Alekhine, Borisenko-Furman Variation'),
			moves => {
			},
		},
		'rnbqkbnr/1pp1pppp/p7/8/P1pP4/5N2/1P2PPPP/RNBQKB1R b KQkq' => {
			eco => 'D21v',
			# TRANSLATORS: D21v: 1. d4 d5 2. c4 dxc4 3. Nf3 a6 4. a4
			variation => N__('QGA: Alekhine, 4. a4'),
			moves => {
			},
		},
		'rnbqkbnr/1pp1pppp/p7/8/2pP4/4PN2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'D22a',
			# TRANSLATORS: D22a: 1. d4 d5 2. c4 dxc4 3. Nf3 a6 4. e3
			variation => N__('QGA: Alekhine, 4. e3'),
			moves => {
				'b7b5' => 1,
				'c8g4' => 1,
				'e7e6' => 1,
			},
		},
		'rnbqkbnr/2p1pppp/p7/1p6/2pP4/4PN2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'D22b',
			# TRANSLATORS: D22b: 1. d4 d5 2. c4 dxc4 3. Nf3 a6 4. e3 b5
			variation => N__('QGA: Alekhine, Haberditz Variation'),
			moves => {
			},
		},
		'rnbqkbnr/1pp2ppp/p3p3/8/2pP4/4PN2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'D22c',
			# TRANSLATORS: D22c: 1. d4 d5 2. c4 dxc4 3. Nf3 a6 4. e3 e6
			variation => N__('QGA: Alekhine, 4. e3 e6'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnbqkbnr/1pp2ppp/p3p3/8/2BP4/4PN2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'D22d',
			# TRANSLATORS: D22d: 1. d4 d5 2. c4 dxc4 3. Nf3 a6 4. e3 e6 5. Bxc4
			variation => N__('QGA: Alekhine, 4. e3 e6 5.Bxc4'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqkbnr/1p3ppp/p3p3/2p5/2BP4/4PN2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'D22e',
			# TRANSLATORS: D22e: 1. d4 d5 2. c4 dxc4 3. Nf3 a6 4. e3 e6 5. Bxc4 c5
			variation => N__('QGA: Alekhine, 4. e3 e6 5.Bxc4 c5'),
			moves => {
				'd1e2' => 1,
			},
		},
		'rnbqkbnr/1p3ppp/p3p3/2p5/2BP4/4PN2/PP2QPPP/RNB1K2R b KQkq' => {
			eco => 'D22f',
			# TRANSLATORS: D22f: 1. d4 d5 2. c4 dxc4 3. Nf3 a6 4. e3 e6 5. Bxc4 c5 6. Qe2
			variation => N__('QGA: Alekhine, 4. e3 e6 5.Bxc4 c5 6. Qe2'),
			moves => {
			},
		},
		'rn1qkbnr/1pp1pppp/p7/8/2pP2b1/4PN2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'D22g',
			# TRANSLATORS: D22g: 1. d4 d5 2. c4 dxc4 3. Nf3 a6 4. e3 Bg4
			variation => N__('QGA: Alekhine, 4. e3 Bg4'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rn1qkbnr/1pp1pppp/p7/8/2BP2b1/4PN2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'D22g',
			# TRANSLATORS: D22g: 1. d4 d5 2. c4 dxc4 3. Nf3 a6 4. e3 Bg4 5. Bxc4
			variation => N__('QGA: Alekhine, 4. e3 Bg4'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rn1qkbnr/1pp2ppp/p3p3/8/2BP2b1/4PN2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'D22h',
			# TRANSLATORS: D22h: 1. d4 d5 2. c4 dxc4 3. Nf3 a6 4. e3 Bg4 5. Bxc4 e6
			variation => N__('QGA: Alekhine, 4. e3 Bg4 5.Bxc4 e6'),
			moves => {
				'b1c3' => 1,
				'd1b3' => 1,
				'd4d5' => 1,
				'h2h3' => 1,
			},
		},
		'rn1qkbnr/1pp2ppp/p3p3/3P4/2B3b1/4PN2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'D22i',
			# TRANSLATORS: D22i: 1. d4 d5 2. c4 dxc4 3. Nf3 a6 4. e3 Bg4 5. Bxc4 e6 6. d5
			variation => N__('QGA: Alekhine, Alatortsev Variation'),
			moves => {
			},
		},
		'rn1qkbnr/1pp2ppp/p3p3/8/2BP2b1/1Q2PN2/PP3PPP/RNB1K2R b KQkq' => {
			eco => 'D22j',
			# TRANSLATORS: D22j: 1. d4 d5 2. c4 dxc4 3. Nf3 a6 4. e3 Bg4 5. Bxc4 e6 6. Qb3
			variation => N__('QGA: Alekhine, 4. e3 Bg4 5.Bxc4 e6 6. Qb3'),
			moves => {
			},
		},
		'rn1qkbnr/1pp2ppp/p3p3/8/2BP2b1/2N1PN2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'D22k',
			# TRANSLATORS: D22k: 1. d4 d5 2. c4 dxc4 3. Nf3 a6 4. e3 Bg4 5. Bxc4 e6 6. Nc3
			variation => N__('QGA: Alekhine, 4. e3 Bg4 5.Bxc4 e6 6. Nc3'),
			moves => {
			},
		},
		'rn1qkbnr/1pp2ppp/p3p3/8/2BP2b1/4PN1P/PP3PP1/RNBQK2R b KQkq' => {
			eco => 'D22l',
			# TRANSLATORS: D22l: 1. d4 d5 2. c4 dxc4 3. Nf3 a6 4. e3 Bg4 5. Bxc4 e6 6. h3
			variation => N__('QGA: Alekhine, 4. e3 Bg4 5.Bxc4 e6 6. h3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/8/2pP4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'D23a',
			# TRANSLATORS: D23a: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6
			variation => N__('QGA: 3. Nf3 Nf6'),
			moves => {
				'b1c3' => 1,
				'd1a4' => 1,
				'e2e3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/8/2pP4/5NP1/PP2PP1P/RNBQKB1R b KQkq' => {
			eco => 'D23b',
			# TRANSLATORS: D23b: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. g3
			variation => N__('QGA: 3. Nf3 Nf6 4. g3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/8/Q1pP4/5N2/PP2PPPP/RNB1KB1R b KQkq' => {
			eco => 'D23c',
			# TRANSLATORS: D23c: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Qa4+
			variation => N__('QGA: Mannheim Variation'),
			moves => {
				'b8c6' => 1,
				'b8d7' => 1,
				'c7c6' => 1,
			},
		},
		'r1bqkb1r/ppp1pppp/2n2n2/8/Q1pP4/5N2/PP2PPPP/RNB1KB1R w KQkq' => {
			eco => 'D23d',
			# TRANSLATORS: D23d: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Qa4+ Nc6
			variation => N__('QGA: Mannheim, 4... Nc6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r1bqkb1r/ppp1pppp/2n2n2/8/Q1pP4/2N2N2/PP2PPPP/R1B1KB1R b KQkq' => {
			eco => 'D23e',
			# TRANSLATORS: D23e: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Qa4+ Nc6 5. Nc3
			variation => N__('QGA: Mannheim, 4... Nc6'),
			moves => {
			},
		},
		'r1bqkb1r/pppnpppp/5n2/8/Q1pP4/5N2/PP2PPPP/RNB1KB1R w KQkq' => {
			eco => 'D23f',
			# TRANSLATORS: D23f: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Qa4+ Nbd7
			variation => N__('QGA: Mannheim, 4...Nbd7'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r1bqkb1r/pppnpppp/5n2/8/Q1pP4/2N2N2/PP2PPPP/R1B1KB1R b KQkq' => {
			eco => 'D23f',
			# TRANSLATORS: D23f: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Qa4+ Nbd7 5. Nc3
			variation => N__('QGA: Mannheim, 4...Nbd7'),
			moves => {
				'e7e6' => 1,
			},
		},
		'r1bqkb1r/pppn1ppp/4pn2/8/Q1pP4/2N2N2/PP2PPPP/R1B1KB1R w KQkq' => {
			eco => 'D23g',
			# TRANSLATORS: D23g: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Qa4+ Nbd7 5. Nc3 e6
			variation => N__('QGA: Mannheim, 4...Nbd7 5. Nc3 e6'),
			moves => {
				'e2e4' => 1,
			},
		},
		'r1bqkb1r/pppn1ppp/4pn2/8/Q1pPP3/2N2N2/PP3PPP/R1B1KB1R b KQkq' => {
			eco => 'D23h',
			# TRANSLATORS: D23h: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Qa4+ Nbd7 5. Nc3 e6 6. e4
			variation => N__('QGA: Mannheim, 4...Nbd7 5. Nc3 e6 6. e4'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/8/Q1pP4/5N2/PP2PPPP/RNB1KB1R w KQkq' => {
			eco => 'D23i',
			# TRANSLATORS: D23i: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Qa4+ c6
			variation => N__('QGA: Mannheim, 4... c6'),
			moves => {
				'a4c4' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/2p2n2/8/2QP4/5N2/PP2PPPP/RNB1KB1R b KQkq' => {
			eco => 'D23i',
			# TRANSLATORS: D23i: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Qa4+ c6 5. Qxc4
			variation => N__('QGA: Mannheim, 4... c6 5.Qxc4'),
			moves => {
				'c8f5' => 1,
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/5b2/2QP4/5N2/PP2PPPP/RNB1KB1R w KQkq' => {
			eco => 'D23j',
			# TRANSLATORS: D23j: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Qa4+ c6 5. Qxc4 Bf5
			variation => N__('QGA: Mannheim, 4... c6, 5.Qxc4 Bf5'),
			moves => {
				'b1c3' => 1,
				'g2g3' => 1,
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/5b2/2QP4/2N2N2/PP2PPPP/R1B1KB1R b KQkq' => {
			eco => 'D23k',
			# TRANSLATORS: D23k: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Qa4+ c6 5. Qxc4 Bf5 6. Nc3
			variation => N__('QGA: Mannheim, 4... c6, 5.Qxc4 Bf5 6. Nc3'),
			moves => {
			},
		},
		'rn1qkb1r/pp2pppp/2p2n2/5b2/2QP4/5NP1/PP2PP1P/RNB1KB1R b KQkq' => {
			eco => 'D23l',
			# TRANSLATORS: D23l: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Qa4+ c6 5. Qxc4 Bf5 6. g3
			variation => N__('QGA: Mannheim, 4... c6, 5.Qxc4 Bf5 6. g3'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rn1qkb1r/pp3ppp/2p1pn2/5b2/2QP4/5NP1/PP2PP1P/RNB1KB1R w KQkq' => {
			eco => 'D23m',
			# TRANSLATORS: D23m: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Qa4+ c6 5. Qxc4 Bf5 6. g3 e6
			variation => N__('QGA: Mannheim, 4... c6, 5.Qxc4 Bf5 6. g3 e6'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rn1qkb1r/pp3ppp/2p1pn2/5b2/2QP4/5NP1/PP2PPBP/RNB1K2R b KQkq' => {
			eco => 'D23m',
			# TRANSLATORS: D23m: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Qa4+ c6 5. Qxc4 Bf5 6. g3 e6 7. Bg2
			variation => N__('QGA: Mannheim, 4... c6, 5.Qxc4 Bf5 6. g3 e6 7. Bg2'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r2qkb1r/pp1n1ppp/2p1pn2/5b2/2QP4/5NP1/PP2PPBP/RNB1K2R w KQkq' => {
			eco => 'D23n',
			# TRANSLATORS: D23n: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Qa4+ c6 5. Qxc4 Bf5 6. g3 e6 7. Bg2 Nbd7
			variation => N__('QGA: Mannheim, 4... c6, 5.Qxc4 Bf5 6. g3 e6 7. Bg2 Nbd7'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r2qkb1r/pp1n1ppp/2p1pn2/5b2/2QP4/5NP1/PP2PPBP/RNB2RK1 b kq' => {
			eco => 'D23n',
			# TRANSLATORS: D23n: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Qa4+ c6 5. Qxc4 Bf5 6. g3 e6 7. Bg2 Nbd7 8. O-O
			variation => N__('QGA: Mannheim, 4... c6, 5.Qxc4 Bf5 6. g3 e6 7. Bg2 Nbd7'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r2qk2r/pp1nbppp/2p1pn2/5b2/2QP4/5NP1/PP2PPBP/RNB2RK1 w kq' => {
			eco => 'D23n',
			# TRANSLATORS: D23n: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Qa4+ c6 5. Qxc4 Bf5 6. g3 e6 7. Bg2 Nbd7 8. O-O Be7
			variation => N__('QGA: Mannheim, 4... c6, 5.Qxc4 Bf5 6. g3 e6 7. Bg2 Nbd7'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r2qk2r/pp1nbppp/2p1pn2/5b2/2QP4/2N2NP1/PP2PPBP/R1B2RK1 b kq' => {
			eco => 'D23o',
			# TRANSLATORS: D23o: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Qa4+ c6 5. Qxc4 Bf5 6. g3 e6 7. Bg2 Nbd7 8. O-O Be7 9. Nc3
			variation => N__('QGA: Mannheim, Main Line'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r2q1rk1/pp1nbppp/2p1pn2/5b2/2QP4/2N2NP1/PP2PPBP/R1B2RK1 w -' => {
			eco => 'D23p',
			# TRANSLATORS: D23p: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Qa4+ c6 5. Qxc4 Bf5 6. g3 e6 7. Bg2 Nbd7 8. O-O Be7 9. Nc3 O-O
			variation => N__('QGA: Mannheim, Main Line, 9...O-O'),
			moves => {
				'c1g5' => 1,
				'e2e3' => 1,
			},
		},
		'r2q1rk1/pp1nbppp/2p1pn2/5bB1/2QP4/2N2NP1/PP2PPBP/R4RK1 b -' => {
			eco => 'D23q',
			# TRANSLATORS: D23q: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Qa4+ c6 5. Qxc4 Bf5 6. g3 e6 7. Bg2 Nbd7 8. O-O Be7 9. Nc3 O-O 10. Bg5
			variation => N__('QGA: Mannheim, Main Line, 10. Bg5'),
			moves => {
			},
		},
		'r2q1rk1/pp1nbppp/2p1pn2/5b2/2QP4/2N1PNP1/PP3PBP/R1B2RK1 b -' => {
			eco => 'D23r',
			# TRANSLATORS: D23r: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Qa4+ c6 5. Qxc4 Bf5 6. g3 e6 7. Bg2 Nbd7 8. O-O Be7 9. Nc3 O-O 10. e3
			variation => N__('QGA: Mannheim, Main Line, 10. e3'),
			moves => {
				'f6e4' => 1,
			},
		},
		'r2q1rk1/pp1nbppp/2p1p3/5b2/2QPn3/2N1PNP1/PP3PBP/R1B2RK1 w -' => {
			eco => 'D23s',
			# TRANSLATORS: D23s: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Qa4+ c6 5. Qxc4 Bf5 6. g3 e6 7. Bg2 Nbd7 8. O-O Be7 9. Nc3 O-O 10. e3 Ne4
			variation => N__('QGA: Mannheim, Main Line, 10. e3 Ne4'),
			moves => {
				'c4e2' => 1,
			},
		},
		'r2q1rk1/pp1nbppp/2p1p3/5b2/3Pn3/2N1PNP1/PP2QPBP/R1B2RK1 b -' => {
			eco => 'D23t',
			# TRANSLATORS: D23t: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Qa4+ c6 5. Qxc4 Bf5 6. g3 e6 7. Bg2 Nbd7 8. O-O Be7 9. Nc3 O-O 10. e3 Ne4 11. Qe2
			variation => N__('QGA: Mannheim, Main Line, 10. e3 Ne4 11. Qe2'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/8/2pP4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D24a',
			# TRANSLATORS: D24a: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Nc3
			variation => N__('QGA: 4. Nc3'),
			moves => {
				'a7a6' => 1,
				'c7c5' => 1,
				'e7e6' => 1,
				'f6d5' => 1,
			},
		},
		'rnbqkb1r/ppp1pppp/8/3n4/2pP4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D24a',
			# TRANSLATORS: D24a: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Nc3 Nd5
			variation => N__('QGA: 4. Nc3 Nd5'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/8/2pP4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D24b',
			# TRANSLATORS: D24b: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Nc3 e6
			variation => N__('QGA: 4. Nc3 e6'),
			moves => {
				'c1g5' => 1,
				'e2e3' => 1,
				'e2e4' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/6B1/2pP4/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D24b',
			# TRANSLATORS: D24b: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Nc3 e6 5. Bg5
			variation => N__('QGA: 4. Nc3 e6 5. Bg5'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/8/2pPP3/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'D24b',
			# TRANSLATORS: D24b: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Nc3 e6 5. e4
			variation => N__('QGA: 4. Nc3 e6 5. e4'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/8/2pP4/2N1PN2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'D24c',
			# TRANSLATORS: D24c: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Nc3 e6 5. e3
			variation => N__('QGA: 4. Nc3 e6 5. e3'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pppp/5n2/2p5/2pP4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D24d',
			# TRANSLATORS: D24d: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Nc3 c5
			variation => N__('QGA: 4. Nc3 c5'),
			moves => {
				'd4d5' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/5n2/2pP4/2p5/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D24e',
			# TRANSLATORS: D24e: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Nc3 c5 5. d5
			variation => N__('QGA: 4. Nc3 c5 5. d5'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2pP4/2p5/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D24e',
			# TRANSLATORS: D24e: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Nc3 c5 5. d5 e6
			variation => N__('QGA: 4. Nc3 c5 5. d5'),
			moves => {
				'e2e4' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2pP4/2p1P3/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'D24f',
			# TRANSLATORS: D24f: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Nc3 c5 5. d5 e6 6. e4
			variation => N__('QGA: 4. Nc3 c5 5. d5 e6 6. e4'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/5n2/2pp4/2p1P3/2N2N2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'D24f',
			# TRANSLATORS: D24f: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Nc3 c5 5. d5 e6 6. e4 exd5
			variation => N__('QGA: 4. Nc3 c5 5. d5 e6 6. e4'),
			moves => {
				'e4e5' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/5n2/2ppP3/2p5/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'D24f',
			# TRANSLATORS: D24f: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Nc3 c5 5. d5 e6 6. e4 exd5 7. e5
			variation => N__('QGA: 4. Nc3 c5 5. d5 e6 6. e4'),
			moves => {
				'f6d7' => 1,
			},
		},
		'rnbqkb1r/pp1n1ppp/8/2ppP3/2p5/2N2N2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'D24g',
			# TRANSLATORS: D24g: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Nc3 c5 5. d5 e6 6. e4 exd5 7. e5 Nfd7
			variation => N__('QGA: 4. Nc3 c5 5. d5 e6 6. e4'),
			moves => {
				'c1g5' => 1,
			},
		},
		'rnbqkb1r/pp1n1ppp/8/2ppP1B1/2p5/2N2N2/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'D24g',
			# TRANSLATORS: D24g: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Nc3 c5 5. d5 e6 6. e4 exd5 7. e5 Nfd7 8. Bg5
			variation => N__('QGA: 4. Nc3 c5 5. d5 e6 6. e4'),
			moves => {
				'f8e7' => 1,
			},
		},
		'rnbqk2r/pp1nbppp/8/2ppP1B1/2p5/2N2N2/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'D24g',
			# TRANSLATORS: D24g: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Nc3 c5 5. d5 e6 6. e4 exd5 7. e5 Nfd7 8. Bg5 Be7
			variation => N__('QGA: 4. Nc3 c5 5. d5 e6 6. e4'),
			moves => {
			},
		},
		'rnbqkb1r/1pp1pppp/p4n2/8/2pP4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D24h',
			# TRANSLATORS: D24h: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Nc3 a6
			variation => N__('QGA: 4. Nc3 a6'),
			moves => {
				'a2a4' => 1,
				'e2e4' => 1,
			},
		},
		'rnbqkb1r/1pp1pppp/p4n2/8/P1pP4/2N2N2/1P2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D24i',
			# TRANSLATORS: D24i: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Nc3 a6 5. a4
			variation => N__('QGA: 4. Nc3 a6 5. a4'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkb1r/1pp1pppp/p1n2n2/8/P1pP4/2N2N2/1P2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D24j',
			# TRANSLATORS: D24j: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Nc3 a6 5. a4 Nc6
			variation => N__('QGA: 4. Nc3 a6 5. a4 Nc6'),
			moves => {
				'e2e4' => 1,
			},
		},
		'r1bqkb1r/1pp1pppp/p1n2n2/8/P1pPP3/2N2N2/1P3PPP/R1BQKB1R b KQkq' => {
			eco => 'D24j',
			# TRANSLATORS: D24j: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Nc3 a6 5. a4 Nc6 6. e4
			variation => N__('QGA: 4. Nc3 a6 5. a4 Nc6 5. e4'),
			moves => {
			},
		},
		'rnbqkb1r/1pp1pppp/p4n2/8/2pPP3/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'D24k',
			# TRANSLATORS: D24k: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Nc3 a6 5. e4
			variation => N__('QGA: Bogoljubow'),
			moves => {
				'b7b5' => 1,
			},
		},
		'rnbqkb1r/2p1pppp/p4n2/1p6/2pPP3/2N2N2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'D24k',
			# TRANSLATORS: D24k: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Nc3 a6 5. e4 b5
			variation => N__('QGA: Bogoljubow'),
			moves => {
				'e4e5' => 1,
			},
		},
		'rnbqkb1r/2p1pppp/p4n2/1p2P3/2pP4/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'D24k',
			# TRANSLATORS: D24k: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Nc3 a6 5. e4 b5 6. e5
			variation => N__('QGA: Bogoljubow'),
			moves => {
				'f6d5' => 1,
			},
		},
		'rnbqkb1r/2p1pppp/p7/1p1nP3/2pP4/2N2N2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'D24k',
			# TRANSLATORS: D24k: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Nc3 a6 5. e4 b5 6. e5 Nd5
			variation => N__('QGA: Bogoljubow'),
			moves => {
				'a2a4' => 1,
			},
		},
		'rnbqkb1r/2p1pppp/p7/1p1nP3/P1pP4/2N2N2/1P3PPP/R1BQKB1R b KQkq' => {
			eco => 'D24l',
			# TRANSLATORS: D24l: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Nc3 a6 5. e4 b5 6. e5 Nd5 7. a4
			variation => N__('QGA: Bogoljubow, 7. a4'),
			moves => {
				'c7c6' => 1,
				'c8b7' => 1,
				'd5b4' => 1,
				'd5c3' => 1,
				'e7e6' => 1,
			},
		},
		'rnbqkb1r/2p2ppp/p3p3/1p1nP3/P1pP4/2N2N2/1P3PPP/R1BQKB1R w KQkq' => {
			eco => 'D24m',
			# TRANSLATORS: D24m: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Nc3 a6 5. e4 b5 6. e5 Nd5 7. a4 e6
			variation => N__('QGA: Bogoljubow, 7. a4 e6'),
			moves => {
			},
		},
		'rnbqkb1r/4pppp/p1p5/1p1nP3/P1pP4/2N2N2/1P3PPP/R1BQKB1R w KQkq' => {
			eco => 'D24n',
			# TRANSLATORS: D24n: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Nc3 a6 5. e4 b5 6. e5 Nd5 7. a4 c6
			variation => N__('QGA: Bogoljubow, 7. a4 c6'),
			moves => {
			},
		},
		'rn1qkb1r/1bp1pppp/p7/1p1nP3/P1pP4/2N2N2/1P3PPP/R1BQKB1R w KQkq' => {
			eco => 'D24o',
			# TRANSLATORS: D24o: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Nc3 a6 5. e4 b5 6. e5 Nd5 7. a4 Bb7
			variation => N__('QGA: Bogoljubow, 7. a4 Bb7'),
			moves => {
			},
		},
		'rnbqkb1r/2p1pppp/p7/1p2P3/PnpP4/2N2N2/1P3PPP/R1BQKB1R w KQkq' => {
			eco => 'D24p',
			# TRANSLATORS: D24p: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Nc3 a6 5. e4 b5 6. e5 Nd5 7. a4 Nb4
			variation => N__('QGA: Bogoljubow, 7. a4 Nb4'),
			moves => {
			},
		},
		'rnbqkb1r/2p1pppp/p7/1p2P3/P1pP4/2n2N2/1P3PPP/R1BQKB1R w KQkq' => {
			eco => 'D24q',
			# TRANSLATORS: D24q: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Nc3 a6 5. e4 b5 6. e5 Nd5 7. a4 Nxc3
			variation => N__('QGA: Bogoljubow, 7. a4 Nxc3'),
			moves => {
				'b2c3' => 1,
			},
		},
		'rnbqkb1r/2p1pppp/p7/1p2P3/P1pP4/2P2N2/5PPP/R1BQKB1R b KQkq' => {
			eco => 'D24q',
			# TRANSLATORS: D24q: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Nc3 a6 5. e4 b5 6. e5 Nd5 7. a4 Nxc3 8. bxc3
			variation => N__('QGA: Bogoljubow, 7. a4 Nxc3'),
			moves => {
				'c8b7' => 1,
				'd8d5' => 1,
			},
		},
		'rn1qkb1r/1bp1pppp/p7/1p2P3/P1pP4/2P2N2/5PPP/R1BQKB1R w KQkq' => {
			eco => 'D24r',
			# TRANSLATORS: D24r: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Nc3 a6 5. e4 b5 6. e5 Nd5 7. a4 Nxc3 8. bxc3 Bb7
			variation => N__('QGA: Bogoljubow, 7. a4 Nxc3'),
			moves => {
			},
		},
		'rnb1kb1r/2p1pppp/p7/1p1qP3/P1pP4/2P2N2/5PPP/R1BQKB1R w KQkq' => {
			eco => 'D24s',
			# TRANSLATORS: D24s: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Nc3 a6 5. e4 b5 6. e5 Nd5 7. a4 Nxc3 8. bxc3 Qd5
			variation => N__('QGA: Bogoljubow, 7. a4 Nxc3'),
			moves => {
				'g2g3' => 1,
			},
		},
		'rnb1kb1r/2p1pppp/p7/1p1qP3/P1pP4/2P2NP1/5P1P/R1BQKB1R b KQkq' => {
			eco => 'D24s',
			# TRANSLATORS: D24s: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Nc3 a6 5. e4 b5 6. e5 Nd5 7. a4 Nxc3 8. bxc3 Qd5 9. g3
			variation => N__('QGA: Bogoljubow, 7. a4 Nxc3'),
			moves => {
				'c8b7' => 1,
			},
		},
		'rn2kb1r/1bp1pppp/p7/1p1qP3/P1pP4/2P2NP1/5P1P/R1BQKB1R w KQkq' => {
			eco => 'D24t',
			# TRANSLATORS: D24t: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. Nc3 a6 5. e4 b5 6. e5 Nd5 7. a4 Nxc3 8. bxc3 Qd5 9. g3 Bb7
			variation => N__('QGA: Bogoljubow, 7. a4 Nxc3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pppp/5n2/8/2pP4/4PN2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'D25a',
			# TRANSLATORS: D25a: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3
			variation => N__('QGA: 4. e3'),
			moves => {
				'a7a6' => 1,
				'c7c5' => 1,
				'c8e6' => 1,
				'c8g4' => 1,
				'e7e6' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/pp2pppp/5n2/2p5/2pP4/4PN2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'D25b',
			# TRANSLATORS: D25b: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 c5
			variation => N__('QGA: 4. e3 c5'),
			moves => {
			},
		},
		'rnbqkb1r/1pp1pppp/p4n2/8/2pP4/4PN2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'D25c',
			# TRANSLATORS: D25c: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 a6
			variation => N__('QGA: 4. e3 a6'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/8/2pP4/4PN2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'D25d',
			# TRANSLATORS: D25d: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 g6
			variation => N__('QGA: Smyslov Variation'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/8/2BP4/4PN2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'D25d',
			# TRANSLATORS: D25d: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 g6 5. Bxc4
			variation => N__('QGA: Smyslov Variation'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/8/2BP4/4PN2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'D25d',
			# TRANSLATORS: D25d: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 g6 5. Bxc4 Bg7
			variation => N__('QGA: Smyslov, 5.Bxc4 Bg7'),
			moves => {
				'b1c3' => 1,
				'e1g1' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/8/2BP4/2N1PN2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'D25d',
			# TRANSLATORS: D25d: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 g6 5. Bxc4 Bg7 6. Nc3
			variation => N__('QGA: Smyslov, 5.Bxc4 Bg7 6. Nc3'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/8/2BP4/4PN2/PP3PPP/RNBQ1RK1 b kq' => {
			eco => 'D25e',
			# TRANSLATORS: D25e: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 g6 5. Bxc4 Bg7 6. O-O
			variation => N__('QGA: Smyslov, 5.Bxc4 Bg7 6.O-O'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/8/2BP4/4PN2/PP3PPP/RNBQ1RK1 w -' => {
			eco => 'D25e',
			# TRANSLATORS: D25e: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 g6 5. Bxc4 Bg7 6. O-O O-O
			variation => N__('QGA: Smyslov, 5.Bxc4 Bg7 6.O-O O-O'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/8/2BP4/2N1PN2/PP3PPP/R1BQ1RK1 b -' => {
			eco => 'D25e',
			# TRANSLATORS: D25e: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 g6 5. Bxc4 Bg7 6. O-O O-O 7. Nc3
			variation => N__('QGA: Smyslov, 5.Bxc4 Bg7 6.O-O O-O 7. Nc3'),
			moves => {
			},
		},
		'rn1qkb1r/ppp1pppp/4bn2/8/2pP4/4PN2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'D25f',
			# TRANSLATORS: D25f: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 Be6
			variation => N__('QGA: Flohr Variation'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rn1qkb1r/ppp1pppp/4bn2/8/2pP4/2N1PN2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'D25f',
			# TRANSLATORS: D25f: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 Be6 5. Nc3
			variation => N__('QGA: Flohr, 5. Nc3'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rn1qkb1r/pp2pppp/2p1bn2/8/2pP4/2N1PN2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'D25f',
			# TRANSLATORS: D25f: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 Be6 5. Nc3 c6
			variation => N__('QGA: Flohr, 5. Nc3 c6'),
			moves => {
			},
		},
		'rn1qkb1r/ppp1pppp/5n2/8/2pP2b1/4PN2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'D25g',
			# TRANSLATORS: D25g: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 Bg4
			variation => N__('QGA: Janowski-Larsen Variation'),
			moves => {
				'f1c4' => 1,
				'h2h3' => 1,
			},
		},
		'rn1qkb1r/ppp1pppp/5n2/8/2BP2b1/4PN2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'D25g',
			# TRANSLATORS: D25g: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 Bg4 5. Bxc4
			variation => N__('QGA: Janowski-Larsen Variation'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rn1qkb1r/ppp1pppp/5n2/8/2pP2b1/4PN1P/PP3PP1/RNBQKB1R b KQkq' => {
			eco => 'D25g',
			# TRANSLATORS: D25g: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 Bg4 5. h3
			variation => N__('QGA: Janowski-Larsen, 5. h3'),
			moves => {
			},
		},
		'rn1qkb1r/ppp2ppp/4pn2/8/2BP2b1/4PN2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'D25h',
			# TRANSLATORS: D25h: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 Bg4 5. Bxc4 e6
			variation => N__('QGA: Janowski-Larsen, 5.Bxc4 e6'),
			moves => {
				'b1c3' => 1,
				'd1b3' => 1,
				'e1g1' => 1,
				'h2h3' => 1,
			},
		},
		'rn1qkb1r/ppp2ppp/4pn2/8/2BP2b1/1Q2PN2/PP3PPP/RNB1K2R b KQkq' => {
			eco => 'D25i',
			# TRANSLATORS: D25i: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 Bg4 5. Bxc4 e6 6. Qb3
			variation => N__('QGA: Janowski-Larsen, 6. Qb3'),
			moves => {
			},
		},
		'rn1qkb1r/ppp2ppp/4pn2/8/2BP2b1/4PN2/PP3PPP/RNBQ1RK1 b kq' => {
			eco => 'D25j',
			# TRANSLATORS: D25j: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 Bg4 5. Bxc4 e6 6. O-O
			variation => N__('QGA: Janowski-Larsen, 6.O-O'),
			moves => {
			},
		},
		'rn1qkb1r/ppp2ppp/4pn2/8/2BP2b1/2N1PN2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'D25k',
			# TRANSLATORS: D25k: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 Bg4 5. Bxc4 e6 6. Nc3
			variation => N__('QGA: Janowski-Larsen, 6. Nc3'),
			moves => {
			},
		},
		'rn1qkb1r/ppp2ppp/4pn2/8/2BP2b1/4PN1P/PP3PP1/RNBQK2R b KQkq' => {
			eco => 'D25l',
			# TRANSLATORS: D25l: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 Bg4 5. Bxc4 e6 6. h3
			variation => N__('QGA: Janowski-Larsen, 6. h3'),
			moves => {
				'g4h5' => 1,
			},
		},
		'rn1qkb1r/ppp2ppp/4pn2/7b/2BP4/4PN1P/PP3PP1/RNBQK2R w KQkq' => {
			eco => 'D25l',
			# TRANSLATORS: D25l: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 Bg4 5. Bxc4 e6 6. h3 Bh5
			variation => N__('QGA: Janowski-Larsen, 6. h3'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rn1qkb1r/ppp2ppp/4pn2/7b/2BP4/2N1PN1P/PP3PP1/R1BQK2R b KQkq' => {
			eco => 'D25m',
			# TRANSLATORS: D25m: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 Bg4 5. Bxc4 e6 6. h3 Bh5 7. Nc3
			variation => N__('QGA: Janowski-Larsen, 6. h3 Bh5 7. Nc3'),
			moves => {
				'a7a6' => 1,
				'b8d7' => 1,
			},
		},
		'rn1qkb1r/1pp2ppp/p3pn2/7b/2BP4/2N1PN1P/PP3PP1/R1BQK2R w KQkq' => {
			eco => 'D25n',
			# TRANSLATORS: D25n: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 Bg4 5. Bxc4 e6 6. h3 Bh5 7. Nc3 a6
			variation => N__('QGA: Janowski-Larsen, 6. h3 Bh5 7. Nc3 a6'),
			moves => {
				'g2g4' => 1,
			},
		},
		'rn1qkb1r/1pp2ppp/p3pn2/7b/2BP2P1/2N1PN1P/PP3P2/R1BQK2R b KQkq' => {
			eco => 'D25o',
			# TRANSLATORS: D25o: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 Bg4 5. Bxc4 e6 6. h3 Bh5 7. Nc3 a6 8. g4
			variation => N__('QGA: Janowski-Larsen, 6. h3 Bh5 7. Nc3 a6 8. g4'),
			moves => {
			},
		},
		'r2qkb1r/pppn1ppp/4pn2/7b/2BP4/2N1PN1P/PP3PP1/R1BQK2R w KQkq' => {
			eco => 'D25p',
			# TRANSLATORS: D25p: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 Bg4 5. Bxc4 e6 6. h3 Bh5 7. Nc3 Nbd7
			variation => N__('QGA: Janowski-Larsen, 6. h3 Bh5 7. Nc3 Nbd7'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r2qkb1r/pppn1ppp/4pn2/7b/2BP4/2N1PN1P/PP3PP1/R1BQ1RK1 b kq' => {
			eco => 'D25q',
			# TRANSLATORS: D25q: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 Bg4 5. Bxc4 e6 6. h3 Bh5 7. Nc3 Nbd7 8. O-O
			variation => N__('QGA: Janowski-Larsen, 6. h3 Bh5 7. Nc3 Nbd7 8.O-O'),
			moves => {
				'f8d6' => 1,
			},
		},
		'r2qk2r/pppn1ppp/3bpn2/7b/2BP4/2N1PN1P/PP3PP1/R1BQ1RK1 w kq' => {
			eco => 'D25r',
			# TRANSLATORS: D25r: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 Bg4 5. Bxc4 e6 6. h3 Bh5 7. Nc3 Nbd7 8. O-O Bd6
			variation => N__('QGA: Janowski-Larsen, 6. h3 Bh5 7. Nc3 Nbd7 8.O-O Bd6'),
			moves => {
				'c4e2' => 1,
				'e3e4' => 1,
			},
		},
		'r2qk2r/pppn1ppp/3bpn2/7b/3P4/2N1PN1P/PP2BPP1/R1BQ1RK1 b kq' => {
			eco => 'D25r',
			# TRANSLATORS: D25r: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 Bg4 5. Bxc4 e6 6. h3 Bh5 7. Nc3 Nbd7 8. O-O Bd6 9. Be2
			variation => N__('QGA: Janowski-Larsen, 6. h3 Bh5 7. Nc3 Nbd7 8.O-O Bd6 9. Be2'),
			moves => {
			},
		},
		'r2qk2r/pppn1ppp/3bpn2/7b/2BPP3/2N2N1P/PP3PP1/R1BQ1RK1 b kq' => {
			eco => 'D25s',
			# TRANSLATORS: D25s: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 Bg4 5. Bxc4 e6 6. h3 Bh5 7. Nc3 Nbd7 8. O-O Bd6 9. e4
			variation => N__('QGA: Janowski-Larsen, 6. h3 Bh5 7. Nc3 Nbd7 8.O-O Bd6 9. e4'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/8/2pP4/4PN2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'D26a',
			# TRANSLATORS: D26a: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6
			variation => N__('QGA: 4. e3 e6'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/8/2BP4/4PN2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'D26b',
			# TRANSLATORS: D26b: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4
			variation => N__('QGA: 4. e3 e6 5.Bxc4'),
			moves => {
				'a7a6' => 1,
				'c7c5' => 1,
			},
		},
		'rnbqkb1r/1pp2ppp/p3pn2/8/2BP4/4PN2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'D26c',
			# TRANSLATORS: D26c: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 a6
			variation => N__('QGA: 4. e3 e6 5.Bxc4 a6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbqkb1r/1pp2ppp/p3pn2/8/2BP4/4PN2/PP3PPP/RNBQ1RK1 b kq' => {
			eco => 'D26d',
			# TRANSLATORS: D26d: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 a6 6. O-O
			variation => N__('QGA: 4. e3 e6 5.Bxc4 a6 6.O-O'),
			moves => {
				'b7b5' => 1,
			},
		},
		'rnbqkb1r/2p2ppp/p3pn2/1p6/2BP4/4PN2/PP3PPP/RNBQ1RK1 w kq' => {
			eco => 'D26e',
			# TRANSLATORS: D26e: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 a6 6. O-O b5
			variation => N__('QGA: 4. e3 e6 5.Bxc4 a6 6.O-O b5'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2p5/2BP4/4PN2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'D26f',
			# TRANSLATORS: D26f: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5
			variation => N__('QGA: Classical Variation'),
			moves => {
				'b1c3' => 1,
				'd1e2' => 1,
				'd4c5' => 1,
				'e1g1' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2P5/2B5/4PN2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'D26g',
			# TRANSLATORS: D26g: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. dxc5
			variation => N__('QGA: Classical, Early Queenswap'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2p5/2BP4/2N1PN2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'D26h',
			# TRANSLATORS: D26h: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. Nc3
			variation => N__('QGA: Classical, 6. Nc3'),
			moves => {
				'a7a6' => 1,
			},
		},
		'rnbqkb1r/1p3ppp/p3pn2/2p5/2BP4/2N1PN2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D26i',
			# TRANSLATORS: D26i: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. Nc3 a6
			variation => N__('QGA: Classical, 6. Nc3 a6'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2p5/2BP4/4PN2/PP2QPPP/RNB1K2R b KQkq' => {
			eco => 'D26j',
			# TRANSLATORS: D26j: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. Qe2
			variation => N__('QGA: Classical, Furman Variation'),
			moves => {
				'a7a6' => 1,
				'c5d4' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/8/2Bp4/4PN2/PP2QPPP/RNB1K2R w KQkq' => {
			eco => 'D26k',
			# TRANSLATORS: D26k: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. Qe2 cxd4
			variation => N__('QGA: Classical, Furman, 6...cxd4'),
			moves => {
			},
		},
		'rnbqkb1r/1p3ppp/p3pn2/2p5/2BP4/4PN2/PP2QPPP/RNB1K2R w KQkq' => {
			eco => 'D26l',
			# TRANSLATORS: D26l: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. Qe2 a6
			variation => N__('QGA: Classical, Furman, 6... a6'),
			moves => {
				'd4c5' => 1,
			},
		},
		'rnbqkb1r/1p3ppp/p3pn2/2P5/2B5/4PN2/PP2QPPP/RNB1K2R b KQkq' => {
			eco => 'D26l',
			# TRANSLATORS: D26l: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. Qe2 a6 7. dxc5
			variation => N__('QGA: Classical, Furman, 6... a6'),
			moves => {
				'f8c5' => 1,
			},
		},
		'rnbqk2r/1p3ppp/p3pn2/2b5/2B5/4PN2/PP2QPPP/RNB1K2R w KQkq' => {
			eco => 'D26l',
			# TRANSLATORS: D26l: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. Qe2 a6 7. dxc5 Bxc5
			variation => N__('QGA: Classical, Furman, 6... a6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbqk2r/1p3ppp/p3pn2/2b5/2B5/4PN2/PP2QPPP/RNB2RK1 b kq' => {
			eco => 'D26m',
			# TRANSLATORS: D26m: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. Qe2 a6 7. dxc5 Bxc5 8. O-O
			variation => N__('QGA: Classical, Furman, 6... a6 7.dxc5 Bxc5 8.O-O'),
			moves => {
				'b7b5' => 1,
				'b8c6' => 1,
			},
		},
		'r1bqk2r/1p3ppp/p1n1pn2/2b5/2B5/4PN2/PP2QPPP/RNB2RK1 w kq' => {
			eco => 'D26n',
			# TRANSLATORS: D26n: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. Qe2 a6 7. dxc5 Bxc5 8. O-O Nc6
			variation => N__('QGA: Classical, Furman, 6... a6 7.dxc5 Bxc5 8.O-O Nc6'),
			moves => {
			},
		},
		'rnbqk2r/5ppp/p3pn2/1pb5/2B5/4PN2/PP2QPPP/RNB2RK1 w kq' => {
			eco => 'D26o',
			# TRANSLATORS: D26o: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. Qe2 a6 7. dxc5 Bxc5 8. O-O b5
			variation => N__('QGA: Classical, Furman, 6... a6 7.dxc5 Bxc5 8.O-O b5'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2p5/2BP4/4PN2/PP3PPP/RNBQ1RK1 b kq' => {
			eco => 'D26p',
			# TRANSLATORS: D26p: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O
			variation => N__('QGA: Classical, 6.O-O'),
			moves => {
				'a7a6' => 1,
				'b8c6' => 1,
				'c5d4' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/8/2Bp4/4PN2/PP3PPP/RNBQ1RK1 w kq' => {
			eco => 'D26q',
			# TRANSLATORS: D26q: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O cxd4
			variation => N__('QGA: Classical, Steinitz Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2n1pn2/2p5/2BP4/4PN2/PP3PPP/RNBQ1RK1 w kq' => {
			eco => 'D26r',
			# TRANSLATORS: D26r: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O Nc6
			variation => N__('QGA: Classical, 6.O-O Nc6'),
			moves => {
				'b1c3' => 1,
				'd1e2' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2n1pn2/2p5/2BP4/2N1PN2/PP3PPP/R1BQ1RK1 b kq' => {
			eco => 'D26s',
			# TRANSLATORS: D26s: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O Nc6 7. Nc3
			variation => N__('QGA: Classical, 6.O-O Nc6 7. Nc3'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2n1pn2/2p5/2BP4/4PN2/PP2QPPP/RNB2RK1 b kq' => {
			eco => 'D26t',
			# TRANSLATORS: D26t: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O Nc6 7. Qe2
			variation => N__('QGA: Classical, 6.O-O Nc6 7. Qe2'),
			moves => {
			},
		},
		'rnbqkb1r/1p3ppp/p3pn2/2p5/2BP4/4PN2/PP3PPP/RNBQ1RK1 w kq' => {
			eco => 'D27a',
			# TRANSLATORS: D27a: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6
			variation => N__('QGA: Classical, 6... a6'),
			moves => {
				'a2a3' => 1,
				'a2a4' => 1,
				'b1c3' => 1,
				'b2b3' => 1,
				'c4b3' => 1,
				'c4d3' => 1,
				'd1e2' => 1,
				'd4c5' => 1,
				'e3e4' => 1,
			},
		},
		'rnbqkb1r/1p3ppp/p3pn2/2p5/2BP4/P3PN2/1P3PPP/RNBQ1RK1 b kq' => {
			eco => 'D27a',
			# TRANSLATORS: D27a: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. a3
			variation => N__('QGA: Classical, 6... a6 7. a3'),
			moves => {
			},
		},
		'rnbqkb1r/1p3ppp/p3pn2/2p5/2BP4/1P2PN2/P4PPP/RNBQ1RK1 b kq' => {
			eco => 'D27b',
			# TRANSLATORS: D27b: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. b3
			variation => N__('QGA: Classical, 6... a6 7. b3'),
			moves => {
			},
		},
		'rnbqkb1r/1p3ppp/p3pn2/2p5/2BP4/2N1PN2/PP3PPP/R1BQ1RK1 b kq' => {
			eco => 'D27c',
			# TRANSLATORS: D27c: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Nc3
			variation => N__('QGA: Classical, 6... a6 7. Nc3'),
			moves => {
			},
		},
		'rnbqkb1r/1p3ppp/p3pn2/2p5/3P4/3BPN2/PP3PPP/RNBQ1RK1 b kq' => {
			eco => 'D27d',
			# TRANSLATORS: D27d: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Bd3
			variation => N__('QGA: Classical, 6... a6 7. Bd3'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r1bqkb1r/1p1n1ppp/p3pn2/2p5/3P4/3BPN2/PP3PPP/RNBQ1RK1 w kq' => {
			eco => 'D27e',
			# TRANSLATORS: D27e: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Bd3 Nbd7
			variation => N__('QGA: Classical, 6... a6 7. Bd3 Nbd7'),
			moves => {
			},
		},
		'rnbqkb1r/1p3ppp/p3pn2/2p5/3P4/1B2PN2/PP3PPP/RNBQ1RK1 b kq' => {
			eco => 'D27f',
			# TRANSLATORS: D27f: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Bb3
			variation => N__('QGA: Classical, 6... a6 7. Bb3'),
			moves => {
				'b7b5' => 1,
				'b8c6' => 1,
				'c5d4' => 1,
			},
		},
		'rnbqkb1r/5ppp/p3pn2/1pp5/3P4/1B2PN2/PP3PPP/RNBQ1RK1 w kq' => {
			eco => 'D27g',
			# TRANSLATORS: D27g: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Bb3 b5
			variation => N__('QGA: Classical, 6... a6 7. Bb3 b5'),
			moves => {
			},
		},
		'rnbqkb1r/1p3ppp/p3pn2/8/3p4/1B2PN2/PP3PPP/RNBQ1RK1 w kq' => {
			eco => 'D27h',
			# TRANSLATORS: D27h: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Bb3 cxd4
			variation => N__('QGA: Classical, 6... a6 7. Bb3 cxd4'),
			moves => {
			},
		},
		'r1bqkb1r/1p3ppp/p1n1pn2/2p5/3P4/1B2PN2/PP3PPP/RNBQ1RK1 w kq' => {
			eco => 'D27i',
			# TRANSLATORS: D27i: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Bb3 Nc6
			variation => N__('QGA: Classical, 6... a6 7. Bb3 Nc6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r1bqkb1r/1p3ppp/p1n1pn2/2p5/3P4/1BN1PN2/PP3PPP/R1BQ1RK1 b kq' => {
			eco => 'D27j',
			# TRANSLATORS: D27j: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Bb3 Nc6 8. Nc3
			variation => N__('QGA: Classical, 6... a6 7. Bb3 Nc6 8. Nc3'),
			moves => {
			},
		},
		'rnbqkb1r/1p3ppp/p3pn2/2p5/2BPP3/5N2/PP3PPP/RNBQ1RK1 b kq' => {
			eco => 'D27k',
			# TRANSLATORS: D27k: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. e4
			variation => N__('QGA: Classical, Geller Variation'),
			moves => {
			},
		},
		'rnbqkb1r/1p3ppp/p3pn2/2P5/2B5/4PN2/PP3PPP/RNBQ1RK1 b kq' => {
			eco => 'D27l',
			# TRANSLATORS: D27l: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. dxc5
			variation => N__('QGA: Classical, Spassky Variation'),
			moves => {
				'd8d1' => 1,
			},
		},
		'rnb1kb1r/1p3ppp/p3pn2/2P5/2B5/4PN2/PP3PPP/RNBq1RK1 w kq' => {
			eco => 'D27m',
			# TRANSLATORS: D27m: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. dxc5 Qxd1
			variation => N__('QGA: Classical, Spassky, 7...Qxd1'),
			moves => {
				'f1d1' => 1,
			},
		},
		'rnb1kb1r/1p3ppp/p3pn2/2P5/2B5/4PN2/PP3PPP/RNBR2K1 b kq' => {
			eco => 'D27m',
			# TRANSLATORS: D27m: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. dxc5 Qxd1 8. Rxd1
			variation => N__('QGA: Classical, Spassky, 7...Qxd1'),
			moves => {
				'f8c5' => 1,
			},
		},
		'rnb1k2r/1p3ppp/p3pn2/2b5/2B5/4PN2/PP3PPP/RNBR2K1 w kq' => {
			eco => 'D27m',
			# TRANSLATORS: D27m: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. dxc5 Qxd1 8. Rxd1 Bxc5
			variation => N__('QGA: Classical, Spassky, 7...Qxd1'),
			moves => {
				'b1d2' => 1,
				'b2b3' => 1,
			},
		},
		'rnb1k2r/1p3ppp/p3pn2/2b5/2B5/4PN2/PP1N1PPP/R1BR2K1 b kq' => {
			eco => 'D27n',
			# TRANSLATORS: D27n: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. dxc5 Qxd1 8. Rxd1 Bxc5 9. Nbd2
			variation => N__('QGA: Classical, Spassky, 9.Nbd2'),
			moves => {
			},
		},
		'rnb1k2r/1p3ppp/p3pn2/2b5/2B5/1P2PN2/P4PPP/RNBR2K1 b kq' => {
			eco => 'D27o',
			# TRANSLATORS: D27o: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. dxc5 Qxd1 8. Rxd1 Bxc5 9. b3
			variation => N__('QGA: Classical, Spassky, 9. b3'),
			moves => {
			},
		},
		'rnbqkb1r/1p3ppp/p3pn2/2p5/P1BP4/4PN2/1P3PPP/RNBQ1RK1 b kq' => {
			eco => 'D27p',
			# TRANSLATORS: D27p: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. a4
			variation => N__('QGA: Classical, Rubinstein Variation'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkb1r/1p3ppp/p1n1pn2/2p5/P1BP4/4PN2/1P3PPP/RNBQ1RK1 w kq' => {
			eco => 'D27p',
			# TRANSLATORS: D27p: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. a4 Nc6
			variation => N__('QGA: Classical, Rubinstein, 7... Nc6'),
			moves => {
				'b1c3' => 1,
				'd1e2' => 1,
			},
		},
		'r1bqkb1r/1p3ppp/p1n1pn2/2p5/P1BP4/2N1PN2/1P3PPP/R1BQ1RK1 b kq' => {
			eco => 'D27q',
			# TRANSLATORS: D27q: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. a4 Nc6 8. Nc3
			variation => N__('QGA: Classical, Rubinstein, 8. Nc3'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r1bqk2r/1p2bppp/p1n1pn2/2p5/P1BP4/2N1PN2/1P3PPP/R1BQ1RK1 w kq' => {
			eco => 'D27r',
			# TRANSLATORS: D27r: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. a4 Nc6 8. Nc3 Be7
			variation => N__('QGA: Classical, Rubinstein, 8. Nc3 Be7'),
			moves => {
				'd1e2' => 1,
			},
		},
		'r1bqk2r/1p2bppp/p1n1pn2/2p5/P1BP4/2N1PN2/1P2QPPP/R1B2RK1 b kq' => {
			eco => 'D27s',
			# TRANSLATORS: D27s: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. a4 Nc6 8. Nc3 Be7 9. Qe2
			variation => N__('QGA: Classical, Rubinstein, 8. Nc3 Be7 9. Qe2'),
			moves => {
			},
		},
		'r1bqkb1r/1p3ppp/p1n1pn2/2p5/P1BP4/4PN2/1P2QPPP/RNB2RK1 b kq' => {
			eco => 'D27t',
			# TRANSLATORS: D27t: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. a4 Nc6 8. Qe2
			variation => N__('QGA: Classical, Rubinstein, 8. Qe2'),
			moves => {
				'c5d4' => 1,
				'd8c7' => 1,
			},
		},
		'r1b1kb1r/1pq2ppp/p1n1pn2/2p5/P1BP4/4PN2/1P2QPPP/RNB2RK1 w kq' => {
			eco => 'D27u',
			# TRANSLATORS: D27u: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. a4 Nc6 8. Qe2 Qc7
			variation => N__('QGA: Classical, Rubinstein, 8. Qe2 Qc7'),
			moves => {
			},
		},
		'r1bqkb1r/1p3ppp/p1n1pn2/8/P1Bp4/4PN2/1P2QPPP/RNB2RK1 w kq' => {
			eco => 'D27v',
			# TRANSLATORS: D27v: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. a4 Nc6 8. Qe2 cxd4
			variation => N__('QGA: Classical, Rubinstein, 8. Qe2 cxd4'),
			moves => {
				'f1d1' => 1,
			},
		},
		'r1bqkb1r/1p3ppp/p1n1pn2/8/P1Bp4/4PN2/1P2QPPP/RNBR2K1 b kq' => {
			eco => 'D27v',
			# TRANSLATORS: D27v: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. a4 Nc6 8. Qe2 cxd4 9. Rd1
			variation => N__('QGA: Classical, Rubinstein, 8. Qe2 cxd4'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r1bqk2r/1p2bppp/p1n1pn2/8/P1Bp4/4PN2/1P2QPPP/RNBR2K1 w kq' => {
			eco => 'D27v',
			# TRANSLATORS: D27v: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. a4 Nc6 8. Qe2 cxd4 9. Rd1 Be7
			variation => N__('QGA: Classical, Rubinstein, 8. Qe2 cxd4'),
			moves => {
				'e3d4' => 1,
			},
		},
		'r1bqk2r/1p2bppp/p1n1pn2/8/P1BP4/5N2/1P2QPPP/RNBR2K1 b kq' => {
			eco => 'D27v',
			# TRANSLATORS: D27v: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. a4 Nc6 8. Qe2 cxd4 9. Rd1 Be7 10. exd4
			variation => N__('QGA: Classical, Rubinstein, 8. Qe2 cxd4'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/1p2bppp/p1n1pn2/8/P1BP4/5N2/1P2QPPP/RNBR2K1 w -' => {
			eco => 'D27v',
			# TRANSLATORS: D27v: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. a4 Nc6 8. Qe2 cxd4 9. Rd1 Be7 10. exd4 O-O
			variation => N__('QGA: Classical, Rubinstein, 8. Qe2 cxd4'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r1bq1rk1/1p2bppp/p1n1pn2/8/P1BP4/2N2N2/1P2QPPP/R1BR2K1 b -' => {
			eco => 'D27v',
			# TRANSLATORS: D27v: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. a4 Nc6 8. Qe2 cxd4 9. Rd1 Be7 10. exd4 O-O 11. Nc3
			variation => N__('QGA: Classical, Rubinstein, 8. Qe2 cxd4, 11. Nc3'),
			moves => {
				'f6d5' => 1,
			},
		},
		'r1bq1rk1/1p2bppp/p1n1p3/3n4/P1BP4/2N2N2/1P2QPPP/R1BR2K1 w -' => {
			eco => 'D27w',
			# TRANSLATORS: D27w: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. a4 Nc6 8. Qe2 cxd4 9. Rd1 Be7 10. exd4 O-O 11. Nc3 Nd5
			variation => N__('QGA: Classical, Rubinstein, 8. Qe2 cxd4, 11. Nc3 Nd5'),
			moves => {
			},
		},
		'rnbqkb1r/1p3ppp/p3pn2/2p5/2BP4/4PN2/PP2QPPP/RNB2RK1 b kq' => {
			eco => 'D28a',
			# TRANSLATORS: D28a: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Qe2
			variation => N__('QGA: Classical, 7. Qe2'),
			moves => {
				'b7b5' => 1,
				'b8c6' => 1,
				'c5d4' => 1,
			},
		},
		'rnbqkb1r/1p3ppp/p3pn2/8/2Bp4/4PN2/PP2QPPP/RNB2RK1 w kq' => {
			eco => 'D28b',
			# TRANSLATORS: D28b: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Qe2 cxd4
			variation => N__('QGA: Classical, 7. Qe2 cxd4'),
			moves => {
			},
		},
		'r1bqkb1r/1p3ppp/p1n1pn2/2p5/2BP4/4PN2/PP2QPPP/RNB2RK1 w kq' => {
			eco => 'D28c',
			# TRANSLATORS: D28c: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Qe2 Nc6
			variation => N__('QGA: Classical, 7. Qe2 Nc6'),
			moves => {
			},
		},
		'rnbqkb1r/5ppp/p3pn2/1pp5/2BP4/4PN2/PP2QPPP/RNB2RK1 w kq' => {
			eco => 'D28d',
			# TRANSLATORS: D28d: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Qe2 b5
			variation => N__('QGA: Classical, 7. Qe2 b5'),
			moves => {
				'c4b3' => 1,
				'c4d3' => 1,
			},
		},
		'rnbqkb1r/5ppp/p3pn2/1pp5/3P4/3BPN2/PP2QPPP/RNB2RK1 b kq' => {
			eco => 'D28e',
			# TRANSLATORS: D28e: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Qe2 b5 8. Bd3
			variation => N__('QGA: Classical, 7. Qe2 b5 8. Bd3'),
			moves => {
				'c5d4' => 1,
			},
		},
		'rnbqkb1r/5ppp/p3pn2/1p6/3p4/3BPN2/PP2QPPP/RNB2RK1 w kq' => {
			eco => 'D28f',
			# TRANSLATORS: D28f: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Qe2 b5 8. Bd3 cxd4
			variation => N__('QGA: Classical, 7. Qe2 b5 8. Bd3 cxd4'),
			moves => {
				'e3d4' => 1,
			},
		},
		'rnbqkb1r/5ppp/p3pn2/1p6/3P4/3B1N2/PP2QPPP/RNB2RK1 b kq' => {
			eco => 'D28g',
			# TRANSLATORS: D28g: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Qe2 b5 8. Bd3 cxd4 9. exd4
			variation => N__('QGA: Classical, 7. Qe2 b5 8. Bd3 cxd4 9.exd4'),
			moves => {
			},
		},
		'rnbqkb1r/5ppp/p3pn2/1pp5/3P4/1B2PN2/PP2QPPP/RNB2RK1 b kq' => {
			eco => 'D28h',
			# TRANSLATORS: D28h: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Qe2 b5 8. Bb3
			variation => N__('QGA: Classical, 7. Qe2 b5 8. Bb3'),
			moves => {
				'b8c6' => 1,
				'c8b7' => 1,
			},
		},
		'r1bqkb1r/5ppp/p1n1pn2/1pp5/3P4/1B2PN2/PP2QPPP/RNB2RK1 w kq' => {
			eco => 'D28i',
			# TRANSLATORS: D28i: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Qe2 b5 8. Bb3 Nc6
			variation => N__('QGA: Classical, 7. Qe2 b5 8. Bb3 Nc6'),
			moves => {
				'b1c3' => 1,
				'f1d1' => 1,
			},
		},
		'r1bqkb1r/5ppp/p1n1pn2/1pp5/3P4/1B2PN2/PP2QPPP/RNBR2K1 b kq' => {
			eco => 'D28j',
			# TRANSLATORS: D28j: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Qe2 b5 8. Bb3 Nc6 9. Rd1
			variation => N__('QGA: Classical, 7. Qe2 b5 8. Bb3 Nc6 9. Rd1'),
			moves => {
				'c5c4' => 1,
			},
		},
		'r1bqkb1r/5ppp/p1n1pn2/1p6/2pP4/1B2PN2/PP2QPPP/RNBR2K1 w kq' => {
			eco => 'D28k',
			# TRANSLATORS: D28k: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Qe2 b5 8. Bb3 Nc6 9. Rd1 c4
			variation => N__('QGA: Classical, 7. Qe2 b5 8. Bb3 Nc6 9. Rd1 c4'),
			moves => {
			},
		},
		'r1bqkb1r/5ppp/p1n1pn2/1pp5/3P4/1BN1PN2/PP2QPPP/R1B2RK1 b kq' => {
			eco => 'D28l',
			# TRANSLATORS: D28l: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Qe2 b5 8. Bb3 Nc6 9. Nc3
			variation => N__('QGA: Classical, 7. Qe2 b5 8. Bb3 Nc6 9. Nc3'),
			moves => {
				'c8b7' => 1,
				'f8e7' => 1,
			},
		},
		'r2qkb1r/1b3ppp/p1n1pn2/1pp5/3P4/1BN1PN2/PP2QPPP/R1B2RK1 w kq' => {
			eco => 'D28m',
			# TRANSLATORS: D28m: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Qe2 b5 8. Bb3 Nc6 9. Nc3 Bb7
			variation => N__('QGA: Classical, 7. Qe2 b5 8. Bb3 Nc6 9. Nc3 Bb7'),
			moves => {
			},
		},
		'r1bqk2r/4bppp/p1n1pn2/1pp5/3P4/1BN1PN2/PP2QPPP/R1B2RK1 w kq' => {
			eco => 'D28n',
			# TRANSLATORS: D28n: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Qe2 b5 8. Bb3 Nc6 9. Nc3 Be7
			variation => N__('QGA: Classical, 7. Qe2 b5 8. Bb3 Nc6 9. Nc3 Be7'),
			moves => {
			},
		},
		'rn1qkb1r/1b3ppp/p3pn2/1pp5/3P4/1B2PN2/PP2QPPP/RNB2RK1 w kq' => {
			eco => 'D29a',
			# TRANSLATORS: D29a: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Qe2 b5 8. Bb3 Bb7
			variation => N__('QGA: Classical, 8... Bb7'),
			moves => {
				'a2a4' => 1,
				'b1c3' => 1,
				'f1d1' => 1,
			},
		},
		'rn1qkb1r/1b3ppp/p3pn2/1pp5/3P4/1BN1PN2/PP2QPPP/R1B2RK1 b kq' => {
			eco => 'D29b',
			# TRANSLATORS: D29b: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Qe2 b5 8. Bb3 Bb7 9. Nc3
			variation => N__('QGA: Classical, 8... Bb7 9. Nc3'),
			moves => {
			},
		},
		'rn1qkb1r/1b3ppp/p3pn2/1pp5/P2P4/1B2PN2/1P2QPPP/RNB2RK1 b kq' => {
			eco => 'D29c',
			# TRANSLATORS: D29c: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Qe2 b5 8. Bb3 Bb7 9. a4
			variation => N__('QGA: Classical, 8... Bb7 9. a4'),
			moves => {
				'b5b4' => 1,
				'b8d7' => 1,
			},
		},
		'rn1qkb1r/1b3ppp/p3pn2/2p5/Pp1P4/1B2PN2/1P2QPPP/RNB2RK1 w kq' => {
			eco => 'D29d',
			# TRANSLATORS: D29d: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Qe2 b5 8. Bb3 Bb7 9. a4 b4
			variation => N__('QGA: Classical, 8... Bb7 9. a4 b4'),
			moves => {
			},
		},
		'r2qkb1r/1b1n1ppp/p3pn2/1pp5/P2P4/1B2PN2/1P2QPPP/RNB2RK1 w kq' => {
			eco => 'D29e',
			# TRANSLATORS: D29e: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Qe2 b5 8. Bb3 Bb7 9. a4 Nbd7
			variation => N__('QGA: Classical, 8... Bb7 9. a4 Nbd7'),
			moves => {
			},
		},
		'rn1qkb1r/1b3ppp/p3pn2/1pp5/3P4/1B2PN2/PP2QPPP/RNBR2K1 b kq' => {
			eco => 'D29f',
			# TRANSLATORS: D29f: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Qe2 b5 8. Bb3 Bb7 9. Rd1
			variation => N__('QGA: Classical, 8... Bb7 9. Rd1'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r2qkb1r/1b1n1ppp/p3pn2/1pp5/3P4/1B2PN2/PP2QPPP/RNBR2K1 w kq' => {
			eco => 'D29g',
			# TRANSLATORS: D29g: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Qe2 b5 8. Bb3 Bb7 9. Rd1 Nbd7
			variation => N__('QGA: Classical, 8... Bb7 9. Rd1 Nbd7'),
			moves => {
				'a2a4' => 1,
				'b1c3' => 1,
				'e3e4' => 1,
			},
		},
		'r2qkb1r/1b1n1ppp/p3pn2/1pp5/3PP3/1B3N2/PP2QPPP/RNBR2K1 b kq' => {
			eco => 'D29g',
			# TRANSLATORS: D29g: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Qe2 b5 8. Bb3 Bb7 9. Rd1 Nbd7 10. e4
			variation => N__('QGA: Classical, 8... Bb7 9. Rd1 Nbd7 10. e4'),
			moves => {
			},
		},
		'r2qkb1r/1b1n1ppp/p3pn2/1pp5/P2P4/1B2PN2/1P2QPPP/RNBR2K1 b kq' => {
			eco => 'D29h',
			# TRANSLATORS: D29h: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Qe2 b5 8. Bb3 Bb7 9. Rd1 Nbd7 10. a4
			variation => N__('QGA: Classical, 8... Bb7 9. Rd1 Nbd7 10. a4'),
			moves => {
				'b5b4' => 1,
			},
		},
		'r2qkb1r/1b1n1ppp/p3pn2/2p5/Pp1P4/1B2PN2/1P2QPPP/RNBR2K1 w kq' => {
			eco => 'D29i',
			# TRANSLATORS: D29i: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Qe2 b5 8. Bb3 Bb7 9. Rd1 Nbd7 10. a4 b4
			variation => N__('QGA: Classical, 8... Bb7 9. Rd1 Nbd7 10. a4 b4'),
			moves => {
			},
		},
		'r2qkb1r/1b1n1ppp/p3pn2/1pp5/3P4/1BN1PN2/PP2QPPP/R1BR2K1 b kq' => {
			eco => 'D29j',
			# TRANSLATORS: D29j: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Qe2 b5 8. Bb3 Bb7 9. Rd1 Nbd7 10. Nc3
			variation => N__('QGA: Classical, 8... Bb7 9. Rd1 Nbd7 10. Nc3'),
			moves => {
				'd8b6' => 1,
				'd8b8' => 1,
				'd8c7' => 1,
				'f8d6' => 1,
			},
		},
		'r2qk2r/1b1n1ppp/p2bpn2/1pp5/3P4/1BN1PN2/PP2QPPP/R1BR2K1 w kq' => {
			eco => 'D29k',
			# TRANSLATORS: D29k: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Qe2 b5 8. Bb3 Bb7 9. Rd1 Nbd7 10. Nc3 Bd6
			variation => N__('QGA: Classical, Smyslov Variation'),
			moves => {
			},
		},
		'r3kb1r/1bqn1ppp/p3pn2/1pp5/3P4/1BN1PN2/PP2QPPP/R1BR2K1 w kq' => {
			eco => 'D29l',
			# TRANSLATORS: D29l: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Qe2 b5 8. Bb3 Bb7 9. Rd1 Nbd7 10. Nc3 Qc7
			variation => N__('QGA: Classical, 8... Bb7 9. Rd1 Nbd7 10. Nc3 Qc7'),
			moves => {
			},
		},
		'rq2kb1r/1b1n1ppp/p3pn2/1pp5/3P4/1BN1PN2/PP2QPPP/R1BR2K1 w kq' => {
			eco => 'D29m',
			# TRANSLATORS: D29m: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Qe2 b5 8. Bb3 Bb7 9. Rd1 Nbd7 10. Nc3 Qb8
			variation => N__('QGA: Classical, 8... Bb7 9. Rd1 Nbd7 10. Nc3 Qb8'),
			moves => {
			},
		},
		'r3kb1r/1b1n1ppp/pq2pn2/1pp5/3P4/1BN1PN2/PP2QPPP/R1BR2K1 w kq' => {
			eco => 'D29n',
			# TRANSLATORS: D29n: 1. d4 d5 2. c4 dxc4 3. Nf3 Nf6 4. e3 e6 5. Bxc4 c5 6. O-O a6 7. Qe2 b5 8. Bb3 Bb7 9. Rd1 Nbd7 10. Nc3 Qb6
			variation => N__('QGA: Classical, 8... Bb7 9. Rd1 Nbd7 10. Nc3 Qb6'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/3p4/2PP4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'D30a',
			# TRANSLATORS: D30a: 1. d4 d5 2. c4 e6
			variation => N__('Queen\'s Gambit Declined (QGD)'),
			moves => {
				'b1c3' => 1,
				'c1f4' => 1,
				'c4d5' => 1,
				'e2e3' => 1,
				'e2e4' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/3p4/2PP4/4P3/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'D30a',
			# TRANSLATORS: D30a: 1. d4 d5 2. c4 e6 3. e3
			variation => N__('QGD: 3. e3'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/3p4/2PPP3/8/PP3PPP/RNBQKBNR b KQkq' => {
			eco => 'D30b',
			# TRANSLATORS: D30b: 1. e4 e6 2. d4 d5 3. c4
			variation => N__('Diemer-Duhm Gambit (DDG)'),
			moves => {
				'd5e4' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/8/2PPp3/8/PP3PPP/RNBQKBNR w KQkq' => {
			eco => 'D30b',
			# TRANSLATORS: D30b: 1. e4 e6 2. d4 d5 3. c4 dxe4
			variation => N__('Diemer-Duhm Gambit (DDG) Accepted'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/8/2PPp3/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'D30b',
			# TRANSLATORS: D30b: 1. e4 e6 2. d4 d5 3. c4 dxe4 4. Nc3
			variation => N__('Diemer-Duhm Gambit (DDG) Accepted'),
			moves => {
				'f7f5' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/ppp3pp/4p3/5p2/2PPp3/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'D30b',
			# TRANSLATORS: D30b: 1. e4 e6 2. d4 d5 3. c4 dxe4 4. Nc3 f5
			variation => N__('Diemer-Duhm Gambit (DDG): 4... f5'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/8/2PPp3/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'D30b',
			# TRANSLATORS: D30b: 1. e4 e6 2. d4 d5 3. c4 dxe4 4. Nc3 Nf6
			variation => N__('Diemer-Duhm Gambit (DDG) Accepted'),
			moves => {
				'a2a3' => 1,
				'c1e3' => 1,
				'f2f3' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/8/2PPp3/P1N5/1P3PPP/R1BQKBNR b KQkq' => {
			eco => 'D30b',
			# TRANSLATORS: D30b: 1. e4 e6 2. d4 d5 3. c4 dxe4 4. Nc3 Nf6 5. a3
			variation => N__('Diemer-Duhm Gambit (DDG): Duhm Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/8/2PPp3/2N1B3/PP3PPP/R2QKBNR b KQkq' => {
			eco => 'D30b',
			# TRANSLATORS: D30b: 1. e4 e6 2. d4 d5 3. c4 dxe4 4. Nc3 Nf6 5. Be3
			variation => N__('Diemer-Duhm Gambit (DDG): Alapin Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/8/2PPp3/2N2P2/PP4PP/R1BQKBNR b KQkq' => {
			eco => 'D30b',
			# TRANSLATORS: D30b: 1. e4 e6 2. d4 d5 3. c4 dxe4 4. Nc3 Nf6 5. f3
			variation => N__('Diemer-Duhm Gambit (DDG): 5. f3'),
			moves => {
				'c7c5' => 1,
				'e4f3' => 1,
				'f8b4' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2p5/2PPp3/2N2P2/PP4PP/R1BQKBNR w KQkq' => {
			eco => 'D30b',
			# TRANSLATORS: D30b: 1. e4 e6 2. d4 d5 3. c4 dxe4 4. Nc3 Nf6 5. f3 c5
			variation => N__('Diemer-Duhm Gambit (DDG): Keres Defence'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/8/2PP4/2N2p2/PP4PP/R1BQKBNR w KQkq' => {
			eco => 'D30b',
			# TRANSLATORS: D30b: 1. e4 e6 2. d4 d5 3. c4 dxe4 4. Nc3 Nf6 5. f3 exf3
			variation => N__('Diemer-Duhm Gambit (DDG): Exchange Variation'),
			moves => {
			},
		},
		'rnbqk2r/ppp2ppp/4pn2/8/1bPPp3/2N2P2/PP4PP/R1BQKBNR w KQkq' => {
			eco => 'D30b',
			# TRANSLATORS: D30b: 1. e4 e6 2. d4 d5 3. c4 dxe4 4. Nc3 Nf6 5. f3 Bb4
			variation => N__('Diemer-Duhm Gambit (DDG): Main Line'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/3p4/2PP4/6P1/PP2PP1P/RNBQKBNR b KQkq' => {
			eco => 'D30c',
			# TRANSLATORS: D30c: 1. d4 d5 2. c4 e6 3. g3
			variation => N__('QGD: 3. g3'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/3P4/3P4/8/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'D30d',
			# TRANSLATORS: D30d: 1. d4 d5 2. c4 e6 3. cxd5
			variation => N__('QGD: 3.cxd5'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/8/3p4/3P4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'D30d',
			# TRANSLATORS: D30d: 1. d4 d5 2. c4 e6 3. cxd5 exd5
			variation => N__('QGD: 3.cxd5'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkbnr/ppp2ppp/8/3p4/3P4/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'D30d',
			# TRANSLATORS: D30d: 1. d4 d5 2. c4 e6 3. cxd5 exd5 4. Nc3
			variation => N__('QGD: 3.cxd5'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/3p4/2PP1B2/8/PP2PPPP/RN1QKBNR b KQkq' => {
			eco => 'D30e',
			# TRANSLATORS: D30e: 1. d4 d5 2. c4 e6 3. Bf4
			variation => N__('QGD: 3. Bf4'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/3p4/2PP4/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'D30f',
			# TRANSLATORS: D30f: 1. d4 d5 2. c4 e6 3. Nf3
			variation => N__('QGD: 3. Nf3'),
			moves => {
				'b8d7' => 1,
				'c7c5' => 1,
				'c7c6' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkbnr/pppn1ppp/4p3/3p4/2PP4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'D30g',
			# TRANSLATORS: D30g: 1. d4 d5 2. c4 e6 3. Nf3 Nd7
			variation => N__('QGD: 3. Nf3 Nbd7 (Westphalia)'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/4p3/2pp4/2PP4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'D30h',
			# TRANSLATORS: D30h: 1. d4 d5 2. c4 e6 3. Nf3 c5
			variation => N__('QGD: Tarrasch without Nc3'),
			moves => {
				'c4d5' => 1,
				'e2e3' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/4p3/2pP4/3P4/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'D30h',
			# TRANSLATORS: D30h: 1. d4 d5 2. c4 e6 3. Nf3 c5 4. cxd5
			variation => N__('QGD: Tarrasch without Nc3'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/8/2pp4/3P4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'D30h',
			# TRANSLATORS: D30h: 1. d4 d5 2. c4 e6 3. Nf3 c5 4. cxd5 exd5
			variation => N__('QGD: Tarrasch without Nc3'),
			moves => {
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/4p3/2pp4/2PP4/4PN2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'D30h',
			# TRANSLATORS: D30h: 1. d4 d5 2. c4 e6 3. Nf3 c5 4. e3
			variation => N__('QGD: Tarrasch without Nc3: 4. e3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2pp4/2PP4/4PN2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'D30h',
			# TRANSLATORS: D30h: 1. d4 d5 2. c4 e6 3. Nf3 c5 4. e3 Nf6
			variation => N__('QGD: Tarrasch without Nc3: 4. e3 Nf6'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/8/2pp4/3P4/5NP1/PP2PP1P/RNBQKB1R b KQkq' => {
			eco => 'D30i',
			# TRANSLATORS: D30i: 1. d4 d5 2. c4 e6 3. Nf3 c5 4. cxd5 exd5 5. g3
			variation => N__('QGD: Tarrasch without Nc3: 5. g3'),
			moves => {
				'b8c6' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkbnr/pp3ppp/2n5/2pp4/3P4/5NP1/PP2PP1P/RNBQKB1R w KQkq' => {
			eco => 'D30i',
			# TRANSLATORS: D30i: 1. d4 d5 2. c4 e6 3. Nf3 c5 4. cxd5 exd5 5. g3 Nc6
			variation => N__('QGD: Tarrasch without Nc3: 5. g3 Nc6'),
			moves => {
				'f1g2' => 1,
			},
		},
		'r1bqkbnr/pp3ppp/2n5/2pp4/3P4/5NP1/PP2PPBP/RNBQK2R b KQkq' => {
			eco => 'D30i',
			# TRANSLATORS: D30i: 1. d4 d5 2. c4 e6 3. Nf3 c5 4. cxd5 exd5 5. g3 Nc6 6. Bg2
			variation => N__('QGD: Tarrasch without Nc3: 5. g3 Nc6 6. Bg2'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2n2n2/2pp4/3P4/5NP1/PP2PPBP/RNBQK2R w KQkq' => {
			eco => 'D30i',
			# TRANSLATORS: D30i: 1. d4 d5 2. c4 e6 3. Nf3 c5 4. cxd5 exd5 5. g3 Nc6 6. Bg2 Nf6
			variation => N__('QGD: Tarrasch without Nc3: 5. g3 Nc6 6. Bg2 Nf6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2n2n2/2pp4/3P4/5NP1/PP2PPBP/RNBQ1RK1 b kq' => {
			eco => 'D30i',
			# TRANSLATORS: D30i: 1. d4 d5 2. c4 e6 3. Nf3 c5 4. cxd5 exd5 5. g3 Nc6 6. Bg2 Nf6 7. O-O
			variation => N__('QGD: Tarrasch without Nc3: 5. g3 Nc6 6. Bg2 Nf6 7.O-O'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2n2n2/2pp4/3P4/5NP1/PP2PPBP/RNBQ1RK1 w kq' => {
			eco => 'D30i',
			# TRANSLATORS: D30i: 1. d4 d5 2. c4 e6 3. Nf3 c5 4. cxd5 exd5 5. g3 Nc6 6. Bg2 Nf6 7. O-O Be7
			variation => N__('QGD: Tarrasch without Nc3: Main Line'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/5n2/2pp4/3P4/5NP1/PP2PP1P/RNBQKB1R w KQkq' => {
			eco => 'D30i',
			# TRANSLATORS: D30i: 1. d4 d5 2. c4 e6 3. Nf3 c5 4. cxd5 exd5 5. g3 Nf6
			variation => N__('QGD: Tarrasch without Nc3: 5. g3'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/5n2/2pp4/3P4/5NP1/PP2PPBP/RNBQK2R b KQkq' => {
			eco => 'D30i',
			# TRANSLATORS: D30i: 1. d4 d5 2. c4 e6 3. Nf3 c5 4. cxd5 exd5 5. g3 Nf6 6. Bg2
			variation => N__('QGD: Tarrasch without Nc3: 5. g3'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/2p1p3/3p4/2PP4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'D30j',
			# TRANSLATORS: D30j: 1. d4 d5 2. c4 e6 3. Nf3 c6
			variation => N__('QGD: 3. Nf3 c6'),
			moves => {
				'b1d2' => 1,
				'd1c2' => 1,
				'e2e3' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/2p1p3/3p4/2PP4/4PN2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'D30k',
			# TRANSLATORS: D30k: 1. d4 d5 2. c4 e6 3. Nf3 c6 4. e3
			variation => N__('QGD: 3. Nf3 c6 4. e3'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/2p1p3/3p4/2PP4/5N2/PP1NPPPP/R1BQKB1R b KQkq' => {
			eco => 'D30l',
			# TRANSLATORS: D30l: 1. d4 d5 2. c4 e6 3. Nf3 c6 4. Nbd2
			variation => N__('QGD: 3. Nf3 c6 4.Nbd2'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/2p1p3/3p4/2PP4/5N2/PPQ1PPPP/RNB1KB1R b KQkq' => {
			eco => 'D30m',
			# TRANSLATORS: D30m: 1. d4 d5 2. c4 e6 3. Nf3 c6 4. Qc2
			variation => N__('QGD: 3. Nf3 c6 4. Qc2'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/2p1pn2/3p4/2PP4/5N2/PPQ1PPPP/RNB1KB1R w KQkq' => {
			eco => 'D30n',
			# TRANSLATORS: D30n: 1. d4 d5 2. c4 e6 3. Nf3 c6 4. Qc2 Nf6
			variation => N__('QGD: 3. Nf3 c6 4. Qc2 Nf6'),
			moves => {
				'c1g5' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/2p1pn2/3p2B1/2PP4/5N2/PPQ1PPPP/RN2KB1R b KQkq' => {
			eco => 'D30o',
			# TRANSLATORS: D30o: 1. d4 d5 2. c4 e6 3. Nf3 c6 4. Qc2 Nf6 5. Bg5
			variation => N__('QGD: 3. Nf3 c6 4. Qc2 Nf6 5. Bg5'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/2p1pn2/3p4/2PP4/5NP1/PPQ1PP1P/RNB1KB1R b KQkq' => {
			eco => 'D30p',
			# TRANSLATORS: D30p: 1. d4 d5 2. c4 e6 3. Nf3 c6 4. Qc2 Nf6 5. g3
			variation => N__('QGD: 3. Nf3 c6 4. Qc2 Nf6 5. g3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p4/2PP4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'D30q',
			# TRANSLATORS: D30q: 1. d4 d5 2. c4 e6 3. Nf3 Nf6
			variation => N__('QGD: 3. Nf3 Nf6'),
			moves => {
				'c1g5' => 1,
				'e2e3' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p4/2PP4/4PN2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'D30r',
			# TRANSLATORS: D30r: 1. d4 d5 2. c4 e6 3. Nf3 Nf6 4. e3
			variation => N__('QGD: 3. Nf3 Nf6 4. e3'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/2p1pn2/3p4/2PP4/4PN2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'D30s',
			# TRANSLATORS: D30s: 1. d4 d5 2. c4 e6 3. Nf3 Nf6 4. e3 c6
			variation => N__('QGD: 3. Nf3 Nf6 4. e3 c6'),
			moves => {
				'b1d2' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/2p1pn2/3p4/2PP4/4PN2/PP1N1PPP/R1BQKB1R b KQkq' => {
			eco => 'D30t',
			# TRANSLATORS: D30t: 1. d4 d5 2. c4 e6 3. Nf3 Nf6 4. e3 c6 5. Nbd2
			variation => N__('QGD: 3. Nf3 Nf6 4. e3 c6 5.Nbd2'),
			moves => {
				'b8d7' => 1,
				'f6e4' => 1,
				'g7g6' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/2p1pn2/3p4/2PP4/4PN2/PP1N1PPP/R1BQKB1R w KQkq' => {
			eco => 'D30t',
			# TRANSLATORS: D30t: 1. d4 d5 2. c4 e6 3. Nf3 Nf6 4. e3 c6 5. Nbd2 Nbd7
			variation => N__('QGD: 3. Nf3 Nf6 4. e3 c6 5.Nbd2 Nbd7'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/2p1p3/3p4/2PPn3/4PN2/PP1N1PPP/R1BQKB1R w KQkq' => {
			eco => 'D30t',
			# TRANSLATORS: D30t: 1. d4 d5 2. c4 e6 3. Nf3 Nf6 4. e3 c6 5. Nbd2 Ne4
			variation => N__('QGD: 3. Nf3 Nf6 4. e3 c6 5.Nbd2'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/2p1p3/3p4/2PPn3/3BPN2/PP1N1PPP/R1BQK2R b KQkq' => {
			eco => 'D30t',
			# TRANSLATORS: D30t: 1. d4 d5 2. c4 e6 3. Nf3 Nf6 4. e3 c6 5. Nbd2 Ne4 6. Bd3
			variation => N__('QGD: 3. Nf3 Nf6 4. e3 c6 5.Nbd2'),
			moves => {
				'f7f5' => 1,
			},
		},
		'rnbqkb1r/pp4pp/2p1p3/3p1p2/2PPn3/3BPN2/PP1N1PPP/R1BQK2R w KQkq' => {
			eco => 'D30t',
			# TRANSLATORS: D30t: 1. d4 d5 2. c4 e6 3. Nf3 Nf6 4. e3 c6 5. Nbd2 Ne4 6. Bd3 f5
			variation => N__('QGD: Stonewall Formation'),
			moves => {
			},
		},
		'rnbqkb1r/pp3p1p/2p1pnp1/3p4/2PP4/4PN2/PP1N1PPP/R1BQKB1R w KQkq' => {
			eco => 'D30t',
			# TRANSLATORS: D30t: 1. d4 d5 2. c4 e6 3. Nf3 Nf6 4. e3 c6 5. Nbd2 g6
			variation => N__('QGD: Spielmann Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pp1n1ppp/2p1pn2/3p4/2PP4/3BPN2/PP1N1PPP/R1BQK2R b KQkq' => {
			eco => 'D30u',
			# TRANSLATORS: D30u: 1. d4 d5 2. c4 e6 3. Nf3 Nf6 4. e3 c6 5. Nbd2 Nbd7 6. Bd3
			variation => N__('QGD: 3. Nf3 Nf6 4. e3 c6 5.Nbd2 Nbd7 6. Bd3'),
			moves => {
				'c6c5' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/4pn2/2pp4/2PP4/3BPN2/PP1N1PPP/R1BQK2R w KQkq' => {
			eco => 'D30u',
			# TRANSLATORS: D30u: 1. d4 d5 2. c4 e6 3. Nf3 Nf6 4. e3 c6 5. Nbd2 Nbd7 6. Bd3 c5
			variation => N__('QGD: Semmering Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p2B1/2PP4/5N2/PP2PPPP/RN1QKB1R b KQkq' => {
			eco => 'D30v',
			# TRANSLATORS: D30v: 1. d4 d5 2. c4 e6 3. Nf3 Nf6 4. Bg5
			variation => N__('QGD: 3. Nf3 Nf6 4. Bg5'),
			moves => {
				'b8d7' => 1,
				'd5c4' => 1,
				'f8b4' => 1,
				'f8e7' => 1,
				'h7h6' => 1,
			},
		},
		'r1bqkb1r/pppn1ppp/4pn2/3p2B1/2PP4/5N2/PP2PPPP/RN1QKB1R w KQkq' => {
			eco => 'D30v',
			# TRANSLATORS: D30v: 1. d4 d5 2. c4 e6 3. Nf3 Nf6 4. Bg5 Nbd7
			variation => N__('QGD: 3. Nf3 Nf6 4. Bg5 Nbd7'),
			moves => {
				'e2e3' => 1,
			},
		},
		'r1bqkb1r/pppn1ppp/4pn2/3p2B1/2PP4/4PN2/PP3PPP/RN1QKB1R b KQkq' => {
			eco => 'D30v',
			# TRANSLATORS: D30v: 1. d4 d5 2. c4 e6 3. Nf3 Nf6 4. Bg5 Nbd7 5. e3
			variation => N__('QGD: 3. Nf3 Nf6 4. Bg5 Nbd7'),
			moves => {
				'c7c6' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/2p1pn2/3p2B1/2PP4/4PN2/PP3PPP/RN1QKB1R w KQkq' => {
			eco => 'D30v',
			# TRANSLATORS: D30v: 1. d4 d5 2. c4 e6 3. Nf3 Nf6 4. Bg5 Nbd7 5. e3 c6
			variation => N__('QGD: 3. Nf3 Nf6 4. Bg5 Nbd7'),
			moves => {
				'b1d2' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/2p1pn2/3p2B1/2PP4/4PN2/PP1N1PPP/R2QKB1R b KQkq' => {
			eco => 'D30v',
			# TRANSLATORS: D30v: 1. d4 d5 2. c4 e6 3. Nf3 Nf6 4. Bg5 Nbd7 5. e3 c6 6. Nbd2
			variation => N__('QGD: 3. Nf3 Nf6 4. Bg5, Capablanca Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/6B1/2pP4/5N2/PP2PPPP/RN1QKB1R w KQkq' => {
			eco => 'D30v',
			# TRANSLATORS: D30v: 1. d4 d5 2. c4 e6 3. Nf3 Nf6 4. Bg5 dxc4
			variation => N__('QGD: 3. Nf3 Nf6 4. Bg5 dxc4'),
			moves => {
			},
		},
		'rnbqk2r/ppp2ppp/4pn2/3p2B1/1bPP4/5N2/PP2PPPP/RN1QKB1R w KQkq' => {
			eco => 'D30v',
			# TRANSLATORS: D30v: 1. d4 d5 2. c4 e6 3. Nf3 Nf6 4. Bg5 Bb4+
			variation => N__('QGD: Vienna Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2pp1/4pn1p/3p2B1/2PP4/5N2/PP2PPPP/RN1QKB1R w KQkq' => {
			eco => 'D30w',
			# TRANSLATORS: D30w: 1. d4 d5 2. c4 e6 3. Nf3 Nf6 4. Bg5 h6
			variation => N__('QGD: Capablanca-Duras Variation'),
			moves => {
			},
		},
		'rnbqk2r/ppp1bppp/4pn2/3p2B1/2PP4/5N2/PP2PPPP/RN1QKB1R w KQkq' => {
			eco => 'D30x',
			# TRANSLATORS: D30x: 1. d4 d5 2. c4 e6 3. Nf3 Nf6 4. Bg5 Be7
			variation => N__('QGD: 3. Nf3 Nf6 4. Bg5 Be7'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbqk2r/ppp1bppp/4pn2/3p2B1/2PP4/4PN2/PP3PPP/RN1QKB1R b KQkq' => {
			eco => 'D30x',
			# TRANSLATORS: D30x: 1. d4 d5 2. c4 e6 3. Nf3 Nf6 4. Bg5 Be7 5. e3
			variation => N__('QGD: 3. Nf3 Nf6 4. Bg5 Be7 5. e3'),
			moves => {
			},
		},
		'rnbqkbnr/ppp2ppp/4p3/3p4/2PP4/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'D31a',
			# TRANSLATORS: D31a: 1. d4 d5 2. c4 e6 3. Nc3
			variation => N__('QGD: 3. Nc3'),
			moves => {
				'a7a6' => 1,
				'b7b6' => 1,
				'b8c6' => 1,
				'c7c5' => 1,
				'c7c6' => 1,
				'f8b4' => 1,
				'f8e7' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkbnr/p1p2ppp/1p2p3/3p4/2PP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'D31a',
			# TRANSLATORS: D31a: 1. d4 d5 2. c4 e6 3. Nc3 b6
			variation => N__('QGD: Alapin Variation'),
			moves => {
			},
		},
		'r1bqkbnr/ppp2ppp/2n1p3/3p4/2PP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'D31a',
			# TRANSLATORS: D31a: 1. d4 d5 2. c4 e6 3. Nc3 Nc6
			variation => N__('QGD: 3. Nc3 Nc6'),
			moves => {
			},
		},
		'rnbqkbnr/1pp2ppp/p3p3/3p4/2PP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'D31b',
			# TRANSLATORS: D31b: 1. d4 d5 2. c4 e6 3. Nc3 a6
			variation => N__('QGD: Janowski Variation'),
			moves => {
			},
		},
		'rnbqk1nr/ppp2ppp/4p3/3p4/1bPP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'D31c',
			# TRANSLATORS: D31c: 1. d4 d5 2. c4 e6 3. Nc3 Bb4
			variation => N__('QGD: 3. Nc3 Bb4'),
			moves => {
				'a2a3' => 1,
			},
		},
		'rnbqk1nr/ppp2ppp/4p3/3p4/1bPP4/P1N5/1P2PPPP/R1BQKBNR b KQkq' => {
			eco => 'D31c',
			# TRANSLATORS: D31c: 1. d4 d5 2. c4 e6 3. Nc3 Bb4 4. a3
			variation => N__('QGD: 3. Nc3 Bb4 4. a3'),
			moves => {
			},
		},
		'rnbqk1nr/ppp1bppp/4p3/3p4/2PP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'D31d',
			# TRANSLATORS: D31d: 1. d4 d5 2. c4 e6 3. Nc3 Be7
			variation => N__('QGD: Alatortsev Variation'),
			moves => {
				'c1f4' => 1,
				'c4d5' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqk1nr/ppp1bppp/4p3/3p4/2PP1B2/2N5/PP2PPPP/R2QKBNR b KQkq' => {
			eco => 'D31d',
			# TRANSLATORS: D31d: 1. d4 d5 2. c4 e6 3. Nc3 Be7 4. Bf4
			variation => N__('QGD: Alatortsev, 4. Bf4'),
			moves => {
			},
		},
		'rnbqk1nr/ppp1bppp/4p3/3p4/2PP4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D31d',
			# TRANSLATORS: D31d: 1. d4 d5 2. c4 e6 3. Nc3 Be7 4. Nf3
			variation => N__('QGD: Alatortsev, 4. Nf3'),
			moves => {
			},
		},
		'rnbqk1nr/ppp1bppp/4p3/3P4/3P4/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'D31e',
			# TRANSLATORS: D31e: 1. d4 d5 2. c4 e6 3. Nc3 Be7 4. cxd5
			variation => N__('QGD: Alatortsev, Exchange'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rnbqk1nr/ppp1bppp/8/3p4/3P4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'D31e',
			# TRANSLATORS: D31e: 1. d4 d5 2. c4 e6 3. Nc3 Be7 4. cxd5 exd5
			variation => N__('QGD: Alatortsev, Exchange'),
			moves => {
				'c1f4' => 1,
			},
		},
		'rnbqk1nr/ppp1bppp/8/3p4/3P1B2/2N5/PP2PPPP/R2QKBNR b KQkq' => {
			eco => 'D31e',
			# TRANSLATORS: D31e: 1. d4 d5 2. c4 e6 3. Nc3 Be7 4. cxd5 exd5 5. Bf4
			variation => N__('QGD: Alatortsev, 5. Bf4'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rnbqk1nr/pp2bppp/2p5/3p4/3P1B2/2N5/PP2PPPP/R2QKBNR w KQkq' => {
			eco => 'D31f',
			# TRANSLATORS: D31f: 1. d4 d5 2. c4 e6 3. Nc3 Be7 4. cxd5 exd5 5. Bf4 c6
			variation => N__('QGD: Alatortsev, 5. Bf4 c6'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbqk1nr/pp2bppp/2p5/3p4/3P1B2/2N1P3/PP3PPP/R2QKBNR b KQkq' => {
			eco => 'D31f',
			# TRANSLATORS: D31f: 1. d4 d5 2. c4 e6 3. Nc3 Be7 4. cxd5 exd5 5. Bf4 c6 6. e3
			variation => N__('QGD: Alatortsev, 5. Bf4 c6'),
			moves => {
				'c8f5' => 1,
			},
		},
		'rn1qk1nr/pp2bppp/2p5/3p1b2/3P1B2/2N1P3/PP3PPP/R2QKBNR w KQkq' => {
			eco => 'D31g',
			# TRANSLATORS: D31g: 1. d4 d5 2. c4 e6 3. Nc3 Be7 4. cxd5 exd5 5. Bf4 c6 6. e3 Bf5
			variation => N__('QGD: Alatortsev, 5. Bf4 c6 6. e3 Bf5'),
			moves => {
				'g2g4' => 1,
			},
		},
		'rn1qk1nr/pp2bppp/2p5/3p1b2/3P1BP1/2N1P3/PP3P1P/R2QKBNR b KQkq' => {
			eco => 'D31h',
			# TRANSLATORS: D31h: 1. d4 d5 2. c4 e6 3. Nc3 Be7 4. cxd5 exd5 5. Bf4 c6 6. e3 Bf5 7. g4
			variation => N__('QGD: Alatortsev, 5. Bf4 c6 6. e3 Bf5 7. g4'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/2p1p3/3p4/2PP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'D31i',
			# TRANSLATORS: D31i: 1. d4 d5 2. c4 e6 3. Nc3 c6
			variation => N__('Semi-Slav'),
			moves => {
				'c4d5' => 1,
				'e2e3' => 1,
				'e2e4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/2p1p3/3P4/3P4/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'D31j',
			# TRANSLATORS: D31j: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. cxd5
			variation => N__('Semi-Slav: 4.cxd5'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/2p5/3p4/3P4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'D31j',
			# TRANSLATORS: D31j: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. cxd5 exd5
			variation => N__('Semi-Slav: 4.cxd5'),
			moves => {
				'c1f4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/2p5/3p4/3P4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D31k',
			# TRANSLATORS: D31k: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. cxd5 exd5 5. Nf3
			variation => N__('Semi-Slav: 4.cxd5 exd5 5. Nf3'),
			moves => {
				'c8f5' => 1,
			},
		},
		'rn1qkbnr/pp3ppp/2p5/3p1b2/3P4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D31l',
			# TRANSLATORS: D31l: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. cxd5 exd5 5. Nf3 Bf5
			variation => N__('Semi-Slav: 4.cxd5 exd5 5. Nf3 Bf5'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/2p5/3p4/3P1B2/2N5/PP2PPPP/R2QKBNR b KQkq' => {
			eco => 'D31m',
			# TRANSLATORS: D31m: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. cxd5 exd5 5. Bf4
			variation => N__('Semi-Slav: 4.cxd5 exd5 5. Bf4'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/2p1p3/3p4/2PP4/2N1P3/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'D31n',
			# TRANSLATORS: D31n: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. e3
			variation => N__('Semi-Slav: 4. e3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/2p1pn2/3p4/2PP4/2N1P3/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'D31o',
			# TRANSLATORS: D31o: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. e3 Nf6
			variation => N__('Semi-Slav: 4. e3 Nf6'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/2p1p3/3p4/2PP4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D31p',
			# TRANSLATORS: D31p: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. Nf3
			variation => N__('Semi-Slav: 4. Nf3'),
			moves => {
				'd5c4' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/2p1p3/8/2pP4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D31q',
			# TRANSLATORS: D31q: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. Nf3 dxc4
			variation => N__('Semi-Slav: Noteboom Variation'),
			moves => {
				'a2a4' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/2p1p3/8/P1pP4/2N2N2/1P2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D31r',
			# TRANSLATORS: D31r: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. Nf3 dxc4 5. a4
			variation => N__('Semi-Slav: Noteboom, 5. a4'),
			moves => {
				'f8b4' => 1,
			},
		},
		'rnbqk1nr/pp3ppp/2p1p3/8/PbpP4/2N2N2/1P2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D31r',
			# TRANSLATORS: D31r: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. Nf3 dxc4 5. a4 Bb4
			variation => N__('Semi-Slav: Noteboom, 5. a4'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbqk1nr/pp3ppp/2p1p3/8/PbpP4/2N1PN2/1P3PPP/R1BQKB1R b KQkq' => {
			eco => 'D31r',
			# TRANSLATORS: D31r: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. Nf3 dxc4 5. a4 Bb4 6. e3
			variation => N__('Semi-Slav: Noteboom, 5. a4'),
			moves => {
				'b7b5' => 1,
			},
		},
		'rnbqk1nr/p4ppp/2p1p3/1p6/PbpP4/2N1PN2/1P3PPP/R1BQKB1R w KQkq' => {
			eco => 'D31s',
			# TRANSLATORS: D31s: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. Nf3 dxc4 5. a4 Bb4 6. e3 b5
			variation => N__('Semi-Slav: Noteboom, 5. a4 Bb4 6. e3 b5'),
			moves => {
				'c1d2' => 1,
			},
		},
		'rnbqk1nr/p4ppp/2p1p3/1p6/PbpP4/2N1PN2/1P1B1PPP/R2QKB1R b KQkq' => {
			eco => 'D31s',
			# TRANSLATORS: D31s: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. Nf3 dxc4 5. a4 Bb4 6. e3 b5 7. Bd2
			variation => N__('Semi-Slav: Noteboom, 5. a4 Bb4 6. e3 b5'),
			moves => {
				'a7a5' => 1,
				'd8b6' => 1,
				'd8e7' => 1,
			},
		},
		'rnb1k1nr/p4ppp/1qp1p3/1p6/PbpP4/2N1PN2/1P1B1PPP/R2QKB1R w KQkq' => {
			eco => 'D31s',
			# TRANSLATORS: D31s: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. Nf3 dxc4 5. a4 Bb4 6. e3 b5 7. Bd2 Qb6
			variation => N__('Semi-Slav: Noteboom, Junge Variation'),
			moves => {
			},
		},
		'rnb1k1nr/p3qppp/2p1p3/1p6/PbpP4/2N1PN2/1P1B1PPP/R2QKB1R w KQkq' => {
			eco => 'D31s',
			# TRANSLATORS: D31s: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. Nf3 dxc4 5. a4 Bb4 6. e3 b5 7. Bd2 Qe7
			variation => N__('Semi-Slav: Noteboom, Koomen Variation'),
			moves => {
			},
		},
		'rnbqk1nr/5ppp/2p1p3/pp6/PbpP4/2N1PN2/1P1B1PPP/R2QKB1R w KQkq' => {
			eco => 'D31t',
			# TRANSLATORS: D31t: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. Nf3 dxc4 5. a4 Bb4 6. e3 b5 7. Bd2 a5
			variation => N__('Semi-Slav: Noteboom, Abrahams Variation'),
			moves => {
				'a4b5' => 1,
			},
		},
		'rnbqk1nr/5ppp/2p1p3/pP6/1bpP4/2N1PN2/1P1B1PPP/R2QKB1R b KQkq' => {
			eco => 'D31t',
			# TRANSLATORS: D31t: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. Nf3 dxc4 5. a4 Bb4 6. e3 b5 7. Bd2 a5 8. axb5
			variation => N__('Semi-Slav: Noteboom, Abrahams Variation'),
			moves => {
				'b4c3' => 1,
			},
		},
		'rnbqk1nr/5ppp/2p1p3/pP6/2pP4/2b1PN2/1P1B1PPP/R2QKB1R w KQkq' => {
			eco => 'D31t',
			# TRANSLATORS: D31t: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. Nf3 dxc4 5. a4 Bb4 6. e3 b5 7. Bd2 a5 8. axb5 Bxc3
			variation => N__('Semi-Slav: Noteboom, Abrahams Variation'),
			moves => {
				'd2c3' => 1,
			},
		},
		'rnbqk1nr/5ppp/2p1p3/pP6/2pP4/2B1PN2/1P3PPP/R2QKB1R b KQkq' => {
			eco => 'D31t',
			# TRANSLATORS: D31t: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. Nf3 dxc4 5. a4 Bb4 6. e3 b5 7. Bd2 a5 8. axb5 Bxc3 9. Bxc3
			variation => N__('Semi-Slav: Noteboom, Abrahams Variation'),
			moves => {
				'c6b5' => 1,
			},
		},
		'rnbqk1nr/5ppp/4p3/pp6/2pP4/2B1PN2/1P3PPP/R2QKB1R w KQkq' => {
			eco => 'D31t',
			# TRANSLATORS: D31t: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. Nf3 dxc4 5. a4 Bb4 6. e3 b5 7. Bd2 a5 8. axb5 Bxc3 9. Bxc3 cxb5
			variation => N__('Semi-Slav: Noteboom, Abrahams Variation'),
			moves => {
				'b2b3' => 1,
			},
		},
		'rnbqk1nr/5ppp/4p3/pp6/2pP4/1PB1PN2/5PPP/R2QKB1R b KQkq' => {
			eco => 'D31t',
			# TRANSLATORS: D31t: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. Nf3 dxc4 5. a4 Bb4 6. e3 b5 7. Bd2 a5 8. axb5 Bxc3 9. Bxc3 cxb5 10. b3
			variation => N__('Semi-Slav: Noteboom, Abrahams Variation'),
			moves => {
				'c8b7' => 1,
			},
		},
		'rn1qk1nr/1b3ppp/4p3/pp6/2pP4/1PB1PN2/5PPP/R2QKB1R w KQkq' => {
			eco => 'D31u',
			# TRANSLATORS: D31u: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. Nf3 dxc4 5. a4 Bb4 6. e3 b5 7. Bd2 a5 8. axb5 Bxc3 9. Bxc3 cxb5 10. b3 Bb7
			variation => N__('Semi-Slav: Noteboom, Abrahams, Main Line'),
			moves => {
				'b3c4' => 1,
			},
		},
		'rn1qk1nr/1b3ppp/4p3/pp6/2PP4/2B1PN2/5PPP/R2QKB1R b KQkq' => {
			eco => 'D31u',
			# TRANSLATORS: D31u: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. Nf3 dxc4 5. a4 Bb4 6. e3 b5 7. Bd2 a5 8. axb5 Bxc3 9. Bxc3 cxb5 10. b3 Bb7 11. bxc4
			variation => N__('Semi-Slav: Noteboom, Abrahams, Main Line'),
			moves => {
				'b5b4' => 1,
			},
		},
		'rn1qk1nr/1b3ppp/4p3/p7/1pPP4/2B1PN2/5PPP/R2QKB1R w KQkq' => {
			eco => 'D31u',
			# TRANSLATORS: D31u: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. Nf3 dxc4 5. a4 Bb4 6. e3 b5 7. Bd2 a5 8. axb5 Bxc3 9. Bxc3 cxb5 10. b3 Bb7 11. bxc4 b4
			variation => N__('Semi-Slav: Noteboom, Abrahams, Main Line'),
			moves => {
				'c3b2' => 1,
			},
		},
		'rn1qk1nr/1b3ppp/4p3/p7/1pPP4/4PN2/1B3PPP/R2QKB1R b KQkq' => {
			eco => 'D31u',
			# TRANSLATORS: D31u: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. Nf3 dxc4 5. a4 Bb4 6. e3 b5 7. Bd2 a5 8. axb5 Bxc3 9. Bxc3 cxb5 10. b3 Bb7 11. bxc4 b4 12. Bb2
			variation => N__('Semi-Slav: Noteboom, Abrahams, Main Line'),
			moves => {
				'g8f6' => 1,
			},
		},
		'rn1qk2r/1b3ppp/4pn2/p7/1pPP4/4PN2/1B3PPP/R2QKB1R w KQkq' => {
			eco => 'D31u',
			# TRANSLATORS: D31u: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. Nf3 dxc4 5. a4 Bb4 6. e3 b5 7. Bd2 a5 8. axb5 Bxc3 9. Bxc3 cxb5 10. b3 Bb7 11. bxc4 b4 12. Bb2 Nf6
			variation => N__('Semi-Slav: Noteboom, Abrahams, Main Line'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rn1qk2r/1b3ppp/4pn2/p7/1pPP4/3BPN2/1B3PPP/R2QK2R b KQkq' => {
			eco => 'D31u',
			# TRANSLATORS: D31u: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. Nf3 dxc4 5. a4 Bb4 6. e3 b5 7. Bd2 a5 8. axb5 Bxc3 9. Bxc3 cxb5 10. b3 Bb7 11. bxc4 b4 12. Bb2 Nf6 13. Bd3
			variation => N__('Semi-Slav: Noteboom, Abrahams, Main Line'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r2qk2r/1b1n1ppp/4pn2/p7/1pPP4/3BPN2/1B3PPP/R2QK2R w KQkq' => {
			eco => 'D31u',
			# TRANSLATORS: D31u: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. Nf3 dxc4 5. a4 Bb4 6. e3 b5 7. Bd2 a5 8. axb5 Bxc3 9. Bxc3 cxb5 10. b3 Bb7 11. bxc4 b4 12. Bb2 Nf6 13. Bd3 Nbd7
			variation => N__('Semi-Slav: Noteboom, Abrahams, Main Line'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r2qk2r/1b1n1ppp/4pn2/p7/1pPP4/3BPN2/1B3PPP/R2Q1RK1 b kq' => {
			eco => 'D31u',
			# TRANSLATORS: D31u: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. Nf3 dxc4 5. a4 Bb4 6. e3 b5 7. Bd2 a5 8. axb5 Bxc3 9. Bxc3 cxb5 10. b3 Bb7 11. bxc4 b4 12. Bb2 Nf6 13. Bd3 Nbd7 14. O-O
			variation => N__('Semi-Slav: Noteboom, Abrahams, Main Line'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r2q1rk1/1b1n1ppp/4pn2/p7/1pPP4/3BPN2/1B3PPP/R2Q1RK1 w -' => {
			eco => 'D31v',
			# TRANSLATORS: D31v: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. Nf3 dxc4 5. a4 Bb4 6. e3 b5 7. Bd2 a5 8. axb5 Bxc3 9. Bxc3 cxb5 10. b3 Bb7 11. bxc4 b4 12. Bb2 Nf6 13. Bd3 Nbd7 14. O-O O-O
			variation => N__('Semi-Slav: Noteboom, Abrahams, Main Line, 14.O-O O-O'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/2p1p3/3p4/2PPP3/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'D31w',
			# TRANSLATORS: D31w: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. e4
			variation => N__('Semi-Slav: Marshall Gambit'),
			moves => {
				'd5e4' => 1,
				'f8b4' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/2p1p3/8/2PPp3/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'D31w',
			# TRANSLATORS: D31w: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. e4 dxe4
			variation => N__('Semi-Slav: Marshall Gambit, 4...dxe4'),
			moves => {
				'c3e4' => 1,
				'f2f3' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/2p1p3/8/2PPN3/8/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'D31w',
			# TRANSLATORS: D31w: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. e4 dxe4 5. Nxe4
			variation => N__('Semi-Slav: Marshall Gambit, 5.Nxe4'),
			moves => {
				'f8b4' => 1,
				'g8f6' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/2p1pn2/8/2PPN3/8/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'D31w',
			# TRANSLATORS: D31w: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. e4 dxe4 5. Nxe4 Nf6
			variation => N__('Semi-Slav: Marshall Gambit, 5.Nxe4 Nf6'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/2p1p3/8/2PPp3/2N2P2/PP4PP/R1BQKBNR b KQkq' => {
			eco => 'D31w',
			# TRANSLATORS: D31w: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. e4 dxe4 5. f3
			variation => N__('Semi-Slav: Marshall Gambit, Gunderam Gambit'),
			moves => {
			},
		},
		'rnbqk1nr/pp3ppp/2p1p3/3p4/1bPPP3/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'D31w',
			# TRANSLATORS: D31w: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. e4 Bb4
			variation => N__('Semi-Slav: Marshall Gambit, 4... Bb4'),
			moves => {
			},
		},
		'rnbqk1nr/pp3ppp/2p1p3/8/1bPPN3/8/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'D31x',
			# TRANSLATORS: D31x: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. e4 dxe4 5. Nxe4 Bb4+
			variation => N__('Semi-Slav: Marshall Gambit, 5.Nxe4 Bb4+'),
			moves => {
				'c1d2' => 1,
				'e4c3' => 1,
			},
		},
		'rnbqk1nr/pp3ppp/2p1p3/8/1bPPN3/8/PP1B1PPP/R2QKBNR b KQkq' => {
			eco => 'D31x',
			# TRANSLATORS: D31x: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. e4 dxe4 5. Nxe4 Bb4+ 6. Bd2
			variation => N__('Semi-Slav: Marshall Gambit, 5.Nxe4 Bb4+ 6. Bd2'),
			moves => {
				'd8d4' => 1,
			},
		},
		'rnb1k1nr/pp3ppp/2p1p3/8/1bPqN3/8/PP1B1PPP/R2QKBNR w KQkq' => {
			eco => 'D31x',
			# TRANSLATORS: D31x: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. e4 dxe4 5. Nxe4 Bb4+ 6. Bd2 Qxd4
			variation => N__('Semi-Slav: Marshall Gambit, 5.Nxe4 Bb4+ 6. Bd2'),
			moves => {
				'd2b4' => 1,
			},
		},
		'rnb1k1nr/pp3ppp/2p1p3/8/1BPqN3/8/PP3PPP/R2QKBNR b KQkq' => {
			eco => 'D31x',
			# TRANSLATORS: D31x: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. e4 dxe4 5. Nxe4 Bb4+ 6. Bd2 Qxd4 7. Bxb4
			variation => N__('Semi-Slav: Marshall Gambit, 5.Nxe4 Bb4+ 6. Bd2'),
			moves => {
				'd4e4' => 1,
			},
		},
		'rnb1k1nr/pp3ppp/2p1p3/8/1BP1q3/8/PP3PPP/R2QKBNR w KQkq' => {
			eco => 'D31x',
			# TRANSLATORS: D31x: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. e4 dxe4 5. Nxe4 Bb4+ 6. Bd2 Qxd4 7. Bxb4 Qxe4+
			variation => N__('Semi-Slav: Marshall Gambit, 5.Nxe4 Bb4+ 6. Bd2'),
			moves => {
				'f1e2' => 1,
				'g1e2' => 1,
			},
		},
		'rnb1k1nr/pp3ppp/2p1p3/8/1BP1q3/8/PP2NPPP/R2QKB1R b KQkq' => {
			eco => 'D31x',
			# TRANSLATORS: D31x: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. e4 dxe4 5. Nxe4 Bb4+ 6. Bd2 Qxd4 7. Bxb4 Qxe4+ 8. Ne2
			variation => N__('Semi-Slav: Marshall Gambit, 8. Ne2'),
			moves => {
			},
		},
		'rnbqk1nr/pp3ppp/2p1p3/8/1bPP4/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'D31x',
			# TRANSLATORS: D31x: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. e4 dxe4 5. Nxe4 Bb4+ 6. Nc3
			variation => N__('Semi-Slav: Marshall Gambit, 5.Nxe4 Bb4+ 6. Nc3'),
			moves => {
			},
		},
		'rnb1k1nr/pp3ppp/2p1p3/8/1BP1q3/8/PP2BPPP/R2QK1NR b KQkq' => {
			eco => 'D31y',
			# TRANSLATORS: D31y: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. e4 dxe4 5. Nxe4 Bb4+ 6. Bd2 Qxd4 7. Bxb4 Qxe4+ 8. Be2
			variation => N__('Semi-Slav: Marshall Gambit, 8. Be2'),
			moves => {
				'b8a6' => 1,
			},
		},
		'r1b1k1nr/pp3ppp/n1p1p3/8/1BP1q3/8/PP2BPPP/R2QK1NR w KQkq' => {
			eco => 'D31z',
			# TRANSLATORS: D31z: 1. d4 d5 2. c4 e6 3. Nc3 c6 4. e4 dxe4 5. Nxe4 Bb4+ 6. Bd2 Qxd4 7. Bxb4 Qxe4+ 8. Be2 Na6
			variation => N__('Semi-Slav: Marshall Gambit, 8. Be2 Na6'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/4p3/2pp4/2PP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'D32a',
			# TRANSLATORS: D32a: 1. d4 d5 2. c4 e6 3. Nc3 c5
			variation => N__('QGD Tarrasch'),
			moves => {
				'c4d5' => 1,
				'e2e3' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/4p3/2pp4/2PP4/2N1P3/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'D32a',
			# TRANSLATORS: D32a: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. e3
			variation => N__('QGD Tarrasch: 4. e3'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/4p3/2pp4/2PP4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D32b',
			# TRANSLATORS: D32b: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. Nf3
			variation => N__('QGD Tarrasch: 4. Nf3'),
			moves => {
				'c5d4' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/4p3/3p4/2Pp4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D32b',
			# TRANSLATORS: D32b: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. Nf3 cxd4
			variation => N__('QGD Tarrasch: 4. Nf3'),
			moves => {
				'f3d4' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/4p3/3p4/2PN4/2N5/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D32b',
			# TRANSLATORS: D32b: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. Nf3 cxd4 5. Nxd4
			variation => N__('QGD Tarrasch: 4. Nf3'),
			moves => {
				'e6e5' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/8/3pp3/2PN4/2N5/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D32c',
			# TRANSLATORS: D32c: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. Nf3 cxd4 5. Nxd4 e5
			variation => N__('QGD Tarrasch: 4. Nf3 cxd4 5.Nxd4 e5'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/4p3/2pP4/3P4/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'D32d',
			# TRANSLATORS: D32d: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5
			variation => N__('QGD Tarrasch: 4.cxd5'),
			moves => {
				'c5d4' => 1,
				'e6d5' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/4p3/3P4/3p4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'D32d',
			# TRANSLATORS: D32d: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 cxd4
			variation => N__('QGD Tarrasch: von Hennig-Schara Gambit'),
			moves => {
				'd1a4' => 1,
				'd1d4' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/4p3/3P4/3Q4/2N5/PP2PPPP/R1B1KBNR b KQkq' => {
			eco => 'D32d',
			# TRANSLATORS: D32d: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 cxd4 5. Qxd4
			variation => N__('QGD Tarrasch: von Hennig-Schara Gambit, 5.Qxd4'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkbnr/pp3ppp/2n1p3/3P4/3Q4/2N5/PP2PPPP/R1B1KBNR w KQkq' => {
			eco => 'D32d',
			# TRANSLATORS: D32d: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 cxd4 5. Qxd4 Nc6
			variation => N__('QGD Tarrasch: von Hennig-Schara Gambit, 5.Qxd4'),
			moves => {
				'd4d1' => 1,
			},
		},
		'r1bqkbnr/pp3ppp/2n1p3/3P4/8/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'D32d',
			# TRANSLATORS: D32d: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 cxd4 5. Qxd4 Nc6 6. Qd1
			variation => N__('QGD Tarrasch: von Hennig-Schara Gambit, 5.Qxd4'),
			moves => {
				'e6d5' => 1,
			},
		},
		'r1bqkbnr/pp3ppp/2n5/3p4/8/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'D32d',
			# TRANSLATORS: D32d: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 cxd4 5. Qxd4 Nc6 6. Qd1 exd5
			variation => N__('QGD Tarrasch: von Hennig-Schara Gambit, 5.Qxd4'),
			moves => {
				'e2e3' => 1,
			},
		},
		'r1bqkbnr/pp3ppp/2n5/3p4/8/2N1P3/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'D32e',
			# TRANSLATORS: D32e: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 cxd4 5. Qxd4 Nc6 6. Qd1 exd5 7. e3
			variation => N__('QGD Tarrasch: von Hennig-Schara Gambit, 5.Qxd4 Nc6 6. Qd1 exd5 7. e3'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/4p3/3P4/Q2p4/2N5/PP2PPPP/R1B1KBNR b KQkq' => {
			eco => 'D32f',
			# TRANSLATORS: D32f: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 cxd4 5. Qa4+
			variation => N__('QGD Tarrasch: von Hennig-Schara Gambit, 5. Qa4+'),
			moves => {
				'c8d7' => 1,
			},
		},
		'rn1qkbnr/pp1b1ppp/4p3/3P4/Q2p4/2N5/PP2PPPP/R1B1KBNR w KQkq' => {
			eco => 'D32f',
			# TRANSLATORS: D32f: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 cxd4 5. Qa4+ Bd7
			variation => N__('QGD Tarrasch: von Hennig-Schara Gambit, 5. Qa4+'),
			moves => {
				'a4d4' => 1,
			},
		},
		'rn1qkbnr/pp1b1ppp/4p3/3P4/3Q4/2N5/PP2PPPP/R1B1KBNR b KQkq' => {
			eco => 'D32f',
			# TRANSLATORS: D32f: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 cxd4 5. Qa4+ Bd7 6. Qxd4
			variation => N__('QGD Tarrasch: von Hennig-Schara Gambit, 5. Qa4+'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rn1qkbnr/pp1b1ppp/8/3p4/3Q4/2N5/PP2PPPP/R1B1KBNR w KQkq' => {
			eco => 'D32f',
			# TRANSLATORS: D32f: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 cxd4 5. Qa4+ Bd7 6. Qxd4 exd5
			variation => N__('QGD Tarrasch: von Hennig-Schara Gambit, 5. Qa4+'),
			moves => {
				'd4d5' => 1,
			},
		},
		'rn1qkbnr/pp1b1ppp/8/3Q4/8/2N5/PP2PPPP/R1B1KBNR b KQkq' => {
			eco => 'D32f',
			# TRANSLATORS: D32f: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 cxd4 5. Qa4+ Bd7 6. Qxd4 exd5 7. Qxd5
			variation => N__('QGD Tarrasch: von Hennig-Schara Gambit, 5. Qa4+'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r2qkbnr/pp1b1ppp/2n5/3Q4/8/2N5/PP2PPPP/R1B1KBNR w KQkq' => {
			eco => 'D32f',
			# TRANSLATORS: D32f: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 cxd4 5. Qa4+ Bd7 6. Qxd4 exd5 7. Qxd5 Nc6
			variation => N__('QGD Tarrasch: von Hennig-Schara Gambit, 7.Qxd5 Nc6'),
			moves => {
				'c1g5' => 1,
				'g1f3' => 1,
			},
		},
		'r2qkbnr/pp1b1ppp/2n5/3Q2B1/8/2N5/PP2PPPP/R3KBNR b KQkq' => {
			eco => 'D32g',
			# TRANSLATORS: D32g: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 cxd4 5. Qa4+ Bd7 6. Qxd4 exd5 7. Qxd5 Nc6 8. Bg5
			variation => N__('QGD Tarrasch: von Hennig-Schara Gambit, 7.Qxd5 Nc6 8. Bg5'),
			moves => {
			},
		},
		'r2qkbnr/pp1b1ppp/2n5/3Q4/8/2N2N2/PP2PPPP/R1B1KB1R b KQkq' => {
			eco => 'D32h',
			# TRANSLATORS: D32h: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 cxd4 5. Qa4+ Bd7 6. Qxd4 exd5 7. Qxd5 Nc6 8. Nf3
			variation => N__('QGD Tarrasch: von Hennig-Schara Gambit, 7.Qxd5 Nc6 8. Nf3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r2qkb1r/pp1b1ppp/2n2n2/3Q4/8/2N2N2/PP2PPPP/R1B1KB1R w KQkq' => {
			eco => 'D32h',
			# TRANSLATORS: D32h: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 cxd4 5. Qa4+ Bd7 6. Qxd4 exd5 7. Qxd5 Nc6 8. Nf3 Nf6
			variation => N__('QGD Tarrasch: von Hennig-Schara Gambit, 7.Qxd5 Nc6 8. Nf3'),
			moves => {
				'd5d1' => 1,
			},
		},
		'r2qkb1r/pp1b1ppp/2n2n2/8/8/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D32h',
			# TRANSLATORS: D32h: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 cxd4 5. Qa4+ Bd7 6. Qxd4 exd5 7. Qxd5 Nc6 8. Nf3 Nf6 9. Qd1
			variation => N__('QGD Tarrasch: von Hennig-Schara Gambit, 7.Qxd5 Nc6 8. Nf3'),
			moves => {
				'f8c5' => 1,
			},
		},
		'r2qk2r/pp1b1ppp/2n2n2/2b5/8/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D32h',
			# TRANSLATORS: D32h: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 cxd4 5. Qa4+ Bd7 6. Qxd4 exd5 7. Qxd5 Nc6 8. Nf3 Nf6 9. Qd1 Bc5
			variation => N__('QGD Tarrasch: von Hennig-Schara Gambit, 7.Qxd5 Nc6 8. Nf3'),
			moves => {
				'e2e3' => 1,
			},
		},
		'r2qk2r/pp1b1ppp/2n2n2/2b5/8/2N1PN2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'D32h',
			# TRANSLATORS: D32h: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 cxd4 5. Qa4+ Bd7 6. Qxd4 exd5 7. Qxd5 Nc6 8. Nf3 Nf6 9. Qd1 Bc5 10. e3
			variation => N__('QGD Tarrasch: von Hennig-Schara Gambit, 7.Qxd5 Nc6 8. Nf3'),
			moves => {
				'd8e7' => 1,
			},
		},
		'r3k2r/pp1bqppp/2n2n2/2b5/8/2N1PN2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'D32h',
			# TRANSLATORS: D32h: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 cxd4 5. Qa4+ Bd7 6. Qxd4 exd5 7. Qxd5 Nc6 8. Nf3 Nf6 9. Qd1 Bc5 10. e3 Qe7
			variation => N__('QGD Tarrasch: von Hennig-Schara Gambit, 7.Qxd5 Nc6 8. Nf3'),
			moves => {
				'f1e2' => 1,
			},
		},
		'r3k2r/pp1bqppp/2n2n2/2b5/8/2N1PN2/PP2BPPP/R1BQK2R b KQkq' => {
			eco => 'D32h',
			# TRANSLATORS: D32h: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 cxd4 5. Qa4+ Bd7 6. Qxd4 exd5 7. Qxd5 Nc6 8. Nf3 Nf6 9. Qd1 Bc5 10. e3 Qe7 11. Be2
			variation => N__('QGD Tarrasch: von Hennig-Schara Gambit, 7.Qxd5 Nc6 8. Nf3'),
			moves => {
				'e8c8' => 1,
			},
		},
		'2kr3r/pp1bqppp/2n2n2/2b5/8/2N1PN2/PP2BPPP/R1BQK2R w KQ' => {
			eco => 'D32i',
			# TRANSLATORS: D32i: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 cxd4 5. Qa4+ Bd7 6. Qxd4 exd5 7. Qxd5 Nc6 8. Nf3 Nf6 9. Qd1 Bc5 10. e3 Qe7 11. Be2 O-O-O
			variation => N__('QGD Tarrasch: von Hennig-Schara Gambit, Main Line (11. Be2 O-O-O)'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/8/2pp4/3P4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'D32j',
			# TRANSLATORS: D32j: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5
			variation => N__('QGD Tarrasch: 4.cxd5 exd5'),
			moves => {
				'd4c5' => 1,
				'e2e4' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/8/2pp4/3P4/2N3P1/PP2PP1P/R1BQKBNR b KQkq' => {
			eco => 'D32j',
			# TRANSLATORS: D32j: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. g3
			variation => N__('QGD Tarrasch: 5. g3'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/8/2Pp4/8/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'D32k',
			# TRANSLATORS: D32k: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. dxc5
			variation => N__('QGD Tarrasch: 5.dxc5'),
			moves => {
				'd5d4' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/8/2P5/3p4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'D32k',
			# TRANSLATORS: D32k: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. dxc5 d4
			variation => N__('QGD Tarrasch: 5.dxc5'),
			moves => {
				'c3a4' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/8/2P5/N2p4/8/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'D32k',
			# TRANSLATORS: D32k: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. dxc5 d4 6. Na4
			variation => N__('QGD Tarrasch: 5.dxc5'),
			moves => {
				'b7b5' => 1,
			},
		},
		'rnbqkbnr/p4ppp/8/1pP5/N2p4/8/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'D32k',
			# TRANSLATORS: D32k: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. dxc5 d4 6. Na4 b5
			variation => N__('QGD Tarrasch: 5.dxc5, Tarrasch Gambit'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/8/2pp4/3PP3/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'D32l',
			# TRANSLATORS: D32l: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. e4
			variation => N__('QGD Tarrasch: Marshall Gambit'),
			moves => {
				'd5e4' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/8/2p5/3Pp3/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'D32l',
			# TRANSLATORS: D32l: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. e4 dxe4
			variation => N__('QGD Tarrasch: Marshall Gambit'),
			moves => {
				'd4d5' => 1,
				'f1c4' => 1,
			},
		},
		'rnbqkbnr/pp3ppp/8/2pP4/4p3/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'D32l',
			# TRANSLATORS: D32l: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. e4 dxe4 6. d5
			variation => N__('QGD Tarrasch: Marshall Gambit, 6. d5'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/8/2p5/2BPp3/2N5/PP3PPP/R1BQK1NR b KQkq' => {
			eco => 'D32l',
			# TRANSLATORS: D32l: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. e4 dxe4 6. Bc4
			variation => N__('QGD Tarrasch: Marshall Gambit, Modern 6. Bc4'),
			moves => {
			},
		},
		'rnbqkbnr/pp3ppp/8/2pp4/3P4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D32m',
			# TRANSLATORS: D32m: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3
			variation => N__('QGD Tarrasch: 5. Nf3'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkbnr/pp3ppp/2n5/2pp4/3P4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D32n',
			# TRANSLATORS: D32n: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6
			variation => N__('QGD Tarrasch: 5. Nf3 Nc6'),
			moves => {
				'c1f4' => 1,
				'c1g5' => 1,
				'e2e3' => 1,
				'g2g3' => 1,
			},
		},
		'r1bqkbnr/pp3ppp/2n5/2pp4/3P1B2/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D32o',
			# TRANSLATORS: D32o: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. Bf4
			variation => N__('QGD Tarrasch: 5. Nf3 Nc6 6. Bf4'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2n2n2/2pp4/3P1B2/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'D32o',
			# TRANSLATORS: D32o: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. Bf4 Nf6
			variation => N__('QGD Tarrasch: 5. Nf3 Nc6 6. Bf4 Nf6'),
			moves => {
			},
		},
		'r1bqkbnr/pp3ppp/2n5/2pp2B1/3P4/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D32p',
			# TRANSLATORS: D32p: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. Bg5
			variation => N__('QGD Tarrasch: 5. Nf3 Nc6 6. Bg5'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r1bqk1nr/pp2bppp/2n5/2pp2B1/3P4/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'D32q',
			# TRANSLATORS: D32q: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. Bg5 Be7
			variation => N__('QGD Tarrasch: 5. Nf3 Nc6 6. Bg5 Be7'),
			moves => {
			},
		},
		'r1bqkbnr/pp3ppp/2n5/2pp4/3P4/2N1PN2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'D32r',
			# TRANSLATORS: D32r: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. e3
			variation => N__('QGD Tarrasch: 5. Nf3 Nc6 6. e3'),
			moves => {
				'g8f6' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2n2n2/2pp4/3P4/2N1PN2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'D32r',
			# TRANSLATORS: D32r: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. e3 Nf6
			variation => N__('QGD Tarrasch: 5. Nf3 Nc6 6. e3 Nf6'),
			moves => {
				'f1b5' => 1,
				'f1e2' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2n2n2/1Bpp4/3P4/2N1PN2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'D32s',
			# TRANSLATORS: D32s: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. e3 Nf6 7. Bb5
			variation => N__('QGD Tarrasch: 5. Nf3 Nc6 6. e3 Nf6 7. Bb5'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2n2n2/2pp4/3P4/2N1PN2/PP2BPPP/R1BQK2R b KQkq' => {
			eco => 'D32t',
			# TRANSLATORS: D32t: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. e3 Nf6 7. Be2
			variation => N__('QGD Tarrasch: 5. Nf3 Nc6 6. e3 Nf6 7. Be2'),
			moves => {
				'c5d4' => 1,
				'f8e7' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2n2n2/2pp4/3P4/2N1PN2/PP2BPPP/R1BQK2R w KQkq' => {
			eco => 'D32u',
			# TRANSLATORS: D32u: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. e3 Nf6 7. Be2 Be7
			variation => N__('QGD Tarrasch: 5. Nf3 Nc6 6. e3 Nf6 7. Be2 Be7'),
			moves => {
				'd4c5' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2n2n2/2Pp4/8/2N1PN2/PP2BPPP/R1BQK2R b KQkq' => {
			eco => 'D32u',
			# TRANSLATORS: D32u: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. e3 Nf6 7. Be2 Be7 8. dxc5
			variation => N__('QGD Tarrasch: 5. Nf3 Nc6 6. e3 Nf6 7. Be2 Be7'),
			moves => {
				'e7c5' => 1,
			},
		},
		'r1bqk2r/pp3ppp/2n2n2/2bp4/8/2N1PN2/PP2BPPP/R1BQK2R w KQkq' => {
			eco => 'D32u',
			# TRANSLATORS: D32u: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. e3 Nf6 7. Be2 Be7 8. dxc5 Bxc5
			variation => N__('QGD Tarrasch: 5. Nf3 Nc6 6. e3 Nf6 7. Be2 Be7 8.dxc5 Bxc5'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2n2n2/3p4/3p4/2N1PN2/PP2BPPP/R1BQK2R w KQkq' => {
			eco => 'D32v',
			# TRANSLATORS: D32v: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. e3 Nf6 7. Be2 cxd4
			variation => N__('QGD Tarrasch: 5. Nf3 Nc6 6. e3 Nf6 7. Be2 cxd4'),
			moves => {
				'f3d4' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2n2n2/3p4/3N4/2N1P3/PP2BPPP/R1BQK2R b KQkq' => {
			eco => 'D32v',
			# TRANSLATORS: D32v: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. e3 Nf6 7. Be2 cxd4 8. Nxd4
			variation => N__('QGD Tarrasch: 5. Nf3 Nc6 6. e3 Nf6 7. Be2 cxd4'),
			moves => {
				'f8d6' => 1,
			},
		},
		'r1bqk2r/pp3ppp/2nb1n2/3p4/3N4/2N1P3/PP2BPPP/R1BQK2R w KQkq' => {
			eco => 'D32v',
			# TRANSLATORS: D32v: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. e3 Nf6 7. Be2 cxd4 8. Nxd4 Bd6
			variation => N__('QGD Tarrasch: 5. Nf3 Nc6 6. e3 Nf6 7. Be2 cxd4 8.Nxd4 Bd6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqk2r/pp3ppp/2nb1n2/3p4/3N4/2N1P3/PP2BPPP/R1BQ1RK1 b kq' => {
			eco => 'D32v',
			# TRANSLATORS: D32v: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. e3 Nf6 7. Be2 cxd4 8. Nxd4 Bd6 9. O-O
			variation => N__('QGD Tarrasch: 5. Nf3 Nc6 6. e3 Nf6 7. Be2 cxd4 8.Nxd4 Bd6 9.O-O'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp3ppp/2nb1n2/3p4/3N4/2N1P3/PP2BPPP/R1BQ1RK1 w -' => {
			eco => 'D32w',
			# TRANSLATORS: D32w: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. e3 Nf6 7. Be2 cxd4 8. Nxd4 Bd6 9. O-O O-O
			variation => N__('QGD Tarrasch: 5. Nf3 Nc6 6. e3 Nf6 7. Be2 cxd4 8.Nxd4 Bd6 9.O-O O-O'),
			moves => {
				'b2b3' => 1,
			},
		},
		'r1bq1rk1/pp3ppp/2nb1n2/3p4/3N4/1PN1P3/P3BPPP/R1BQ1RK1 b -' => {
			eco => 'D32x',
			# TRANSLATORS: D32x: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. e3 Nf6 7. Be2 cxd4 8. Nxd4 Bd6 9. O-O O-O 10. b3
			variation => N__('QGD Tarrasch: 5. Nf3 Nc6 6. e3 Nf6 7. Be2 cxd4 8.Nxd4 Bd6 9.O-O O-O 10. b3'),
			moves => {
			},
		},
		'r1bqkbnr/pp3ppp/2n5/2pp4/3P4/2N2NP1/PP2PP1P/R1BQKB1R b KQkq' => {
			eco => 'D33a',
			# TRANSLATORS: D33a: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3
			variation => N__('QGD Tarrasch: 6. g3 (Schlecter/Rubinstein)'),
			moves => {
				'c5c4' => 1,
				'c5d4' => 1,
				'g8f6' => 1,
			},
		},
		'r1bqkbnr/pp3ppp/2n5/3p4/3p4/2N2NP1/PP2PP1P/R1BQKB1R w KQkq' => {
			eco => 'D33b',
			# TRANSLATORS: D33b: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 cxd4
			variation => N__('QGD Tarrasch: 6. g3 cxd4'),
			moves => {
			},
		},
		'r1bqkbnr/pp3ppp/2n5/3p4/2pP4/2N2NP1/PP2PP1P/R1BQKB1R w KQkq' => {
			eco => 'D33c',
			# TRANSLATORS: D33c: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 c4
			variation => N__('QGD Tarrasch: Swedish Variation'),
			moves => {
				'e2e4' => 1,
				'f1g2' => 1,
			},
		},
		'r1bqkbnr/pp3ppp/2n5/3p4/2pPP3/2N2NP1/PP3P1P/R1BQKB1R b KQkq' => {
			eco => 'D33d',
			# TRANSLATORS: D33d: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 c4 7. e4
			variation => N__('QGD Tarrasch: Swedish, Rey Ardid Variation'),
			moves => {
			},
		},
		'r1bqkbnr/pp3ppp/2n5/3p4/2pP4/2N2NP1/PP2PPBP/R1BQK2R b KQkq' => {
			eco => 'D33e',
			# TRANSLATORS: D33e: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 c4 7. Bg2
			variation => N__('QGD Tarrasch: Swedish, 7. Bg2'),
			moves => {
				'f8b4' => 1,
			},
		},
		'r1bqk1nr/pp3ppp/2n5/3p4/1bpP4/2N2NP1/PP2PPBP/R1BQK2R w KQkq' => {
			eco => 'D33e',
			# TRANSLATORS: D33e: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 c4 7. Bg2 Bb4
			variation => N__('QGD Tarrasch: Swedish, 7. Bg2'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqk1nr/pp3ppp/2n5/3p4/1bpP4/2N2NP1/PP2PPBP/R1BQ1RK1 b kq' => {
			eco => 'D33e',
			# TRANSLATORS: D33e: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 c4 7. Bg2 Bb4 8. O-O
			variation => N__('QGD Tarrasch: Swedish, 7. Bg2'),
			moves => {
				'g8e7' => 1,
			},
		},
		'r1bqk2r/pp2nppp/2n5/3p4/1bpP4/2N2NP1/PP2PPBP/R1BQ1RK1 w kq' => {
			eco => 'D33f',
			# TRANSLATORS: D33f: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 c4 7. Bg2 Bb4 8. O-O Nge7
			variation => N__('QGD Tarrasch: Swedish, 7. Bg2 Bb4 8.O-O Nge7'),
			moves => {
				'a2a3' => 1,
				'c1d2' => 1,
				'e2e4' => 1,
				'f3e5' => 1,
			},
		},
		'r1bqk2r/pp2nppp/2n5/3p4/1bpP4/P1N2NP1/1P2PPBP/R1BQ1RK1 b kq' => {
			eco => 'D33g',
			# TRANSLATORS: D33g: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 c4 7. Bg2 Bb4 8. O-O Nge7 9. a3
			variation => N__('QGD Tarrasch: Swedish, 9. a3'),
			moves => {
			},
		},
		'r1bqk2r/pp2nppp/2n5/3p4/1bpP4/2N2NP1/PP1BPPBP/R2Q1RK1 b kq' => {
			eco => 'D33h',
			# TRANSLATORS: D33h: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 c4 7. Bg2 Bb4 8. O-O Nge7 9. Bd2
			variation => N__('QGD Tarrasch: Swedish, 9. Bd2'),
			moves => {
			},
		},
		'r1bqk2r/pp2nppp/2n5/3pN3/1bpP4/2N3P1/PP2PPBP/R1BQ1RK1 b kq' => {
			eco => 'D33i',
			# TRANSLATORS: D33i: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 c4 7. Bg2 Bb4 8. O-O Nge7 9. Ne5
			variation => N__('QGD Tarrasch: Swedish, 9. Ne5'),
			moves => {
			},
		},
		'r1bqk2r/pp2nppp/2n5/3p4/1bpPP3/2N2NP1/PP3PBP/R1BQ1RK1 b kq' => {
			eco => 'D33j',
			# TRANSLATORS: D33j: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 c4 7. Bg2 Bb4 8. O-O Nge7 9. e4
			variation => N__('QGD Tarrasch: Swedish, 9. e4'),
			moves => {
				'd5e4' => 1,
			},
		},
		'r1bqk2r/pp2nppp/2n5/8/1bpPp3/2N2NP1/PP3PBP/R1BQ1RK1 w kq' => {
			eco => 'D33k',
			# TRANSLATORS: D33k: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 c4 7. Bg2 Bb4 8. O-O Nge7 9. e4 dxe4
			variation => N__('QGD Tarrasch: Swedish, 9. e4 dxe4'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2n2n2/2pp4/3P4/2N2NP1/PP2PP1P/R1BQKB1R w KQkq' => {
			eco => 'D33l',
			# TRANSLATORS: D33l: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6
			variation => N__('QGD Tarrasch: 6. g3 Nf6 (Prague)'),
			moves => {
				'f1g2' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2n2n2/2pp4/3P4/2N2NP1/PP2PPBP/R1BQK2R b KQkq' => {
			eco => 'D33l',
			# TRANSLATORS: D33l: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2
			variation => N__('QGD Tarrasch: 6. g3 Nf6 (Prague)'),
			moves => {
				'c5d4' => 1,
				'c8e6' => 1,
				'c8g4' => 1,
				'f8e7' => 1,
			},
		},
		'r2qkb1r/pp3ppp/2n1bn2/2pp4/3P4/2N2NP1/PP2PPBP/R1BQK2R w KQkq' => {
			eco => 'D33m',
			# TRANSLATORS: D33m: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be6
			variation => N__('QGD Tarrasch: 7. Bg2 Be6'),
			moves => {
			},
		},
		'r2qkb1r/pp3ppp/2n2n2/2pp4/3P2b1/2N2NP1/PP2PPBP/R1BQK2R w KQkq' => {
			eco => 'D33n',
			# TRANSLATORS: D33n: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Bg4
			variation => N__('QGD Tarrasch: Wagner Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2n2n2/3p4/3p4/2N2NP1/PP2PPBP/R1BQK2R w KQkq' => {
			eco => 'D33o',
			# TRANSLATORS: D33o: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 cxd4
			variation => N__('QGD Tarrasch: 7. Bg2 cxd4'),
			moves => {
				'f3d4' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2n2n2/3p4/3N4/2N3P1/PP2PPBP/R1BQK2R b KQkq' => {
			eco => 'D33o',
			# TRANSLATORS: D33o: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 cxd4 8. Nxd4
			variation => N__('QGD Tarrasch: 7. Bg2 cxd4 8.Nxd4'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2n2n2/3p4/3N4/2N3P1/PP2PPBP/R1BQK2R w KQkq' => {
			eco => 'D33p',
			# TRANSLATORS: D33p: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 cxd4 8. Nxd4 Be7
			variation => N__('QGD Tarrasch: 7. Bg2 cxd4 8.Nxd4 Be7'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2n2n2/3p4/3N4/2N3P1/PP2PPBP/R1BQ1RK1 b kq' => {
			eco => 'D33p',
			# TRANSLATORS: D33p: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 cxd4 8. Nxd4 Be7 9. O-O
			variation => N__('QGD Tarrasch: 7. Bg2 cxd4 8.Nxd4 Be7'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2n2n2/3p4/3N4/2N3P1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'D33p',
			# TRANSLATORS: D33p: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 cxd4 8. Nxd4 Be7 9. O-O O-O
			variation => N__('QGD Tarrasch: 7. Bg2 cxd4 8.Nxd4 Be7'),
			moves => {
				'c1e3' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2n2n2/3p4/3N4/2N1B1P1/PP2PPBP/R2Q1RK1 b -' => {
			eco => 'D33q',
			# TRANSLATORS: D33q: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 cxd4 8. Nxd4 Be7 9. O-O O-O 10. Be3
			variation => N__('QGD Tarrasch: 7. Bg2 cxd4 8.Nxd4 Be7 9.O-O O-O 10. Be3'),
			moves => {
			},
		},
		'r1bqk2r/pp2bppp/2n2n2/2pp4/3P4/2N2NP1/PP2PPBP/R1BQK2R w KQkq' => {
			eco => 'D34a',
			# TRANSLATORS: D34a: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7
			variation => N__('QGD Tarrasch: 7. Bg2 Be7'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2n2n2/2pp4/3P4/2N2NP1/PP2PPBP/R1BQ1RK1 b kq' => {
			eco => 'D34a',
			# TRANSLATORS: D34a: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O
			variation => N__('QGD Tarrasch: 7. Bg2 Be7 8.O-O'),
			moves => {
				'c8e6' => 1,
				'e8g8' => 1,
			},
		},
		'r2qk2r/pp2bppp/2n1bn2/2pp4/3P4/2N2NP1/PP2PPBP/R1BQ1RK1 w kq' => {
			eco => 'D34b',
			# TRANSLATORS: D34b: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O Be6
			variation => N__('QGD Tarrasch: 7. Bg2 Be7 8.O-O Be6'),
			moves => {
			},
		},
		'r1bq1rk1/pp2bppp/2n2n2/2pp4/3P4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'D34c',
			# TRANSLATORS: D34c: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O
			variation => N__('QGD Tarrasch: 8.O-O O-O (Main Line)'),
			moves => {
				'b2b3' => 1,
				'c1e3' => 1,
				'c1f4' => 1,
				'c1g5' => 1,
				'd4c5' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2n2n2/2pp4/3P4/1PN2NP1/P3PPBP/R1BQ1RK1 b -' => {
			eco => 'D34d',
			# TRANSLATORS: D34d: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. b3
			variation => N__('QGD Tarrasch: 9. b3'),
			moves => {
				'f6e4' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2n5/2pp4/3Pn3/1PN2NP1/P3PPBP/R1BQ1RK1 w -' => {
			eco => 'D34e',
			# TRANSLATORS: D34e: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. b3 Ne4
			variation => N__('QGD Tarrasch: 9. b3 Ne4'),
			moves => {
			},
		},
		'r1bq1rk1/pp2bppp/2n2n2/2pp4/3P1B2/2N2NP1/PP2PPBP/R2Q1RK1 b -' => {
			eco => 'D34f',
			# TRANSLATORS: D34f: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. Bf4
			variation => N__('QGD Tarrasch: 9. Bf4'),
			moves => {
			},
		},
		'r1bq1rk1/pp2bppp/2n2n2/2pp4/3P4/2N1BNP1/PP2PPBP/R2Q1RK1 b -' => {
			eco => 'D34g',
			# TRANSLATORS: D34g: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. Be3
			variation => N__('QGD Tarrasch: 9. Be3'),
			moves => {
			},
		},
		'r1bq1rk1/pp2bppp/2n2n2/2Pp4/8/2N2NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'D34h',
			# TRANSLATORS: D34h: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. dxc5
			variation => N__('QGD Tarrasch: 9.dxc5'),
			moves => {
				'd5d4' => 1,
				'e7c5' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2n2n2/2P5/3p4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'D34h',
			# TRANSLATORS: D34h: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. dxc5 d4
			variation => N__('QGD Tarrasch: Tarrasch\'s Gambit'),
			moves => {
			},
		},
		'r1bq1rk1/pp3ppp/2n2n2/2bp4/8/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'D34i',
			# TRANSLATORS: D34i: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. dxc5 Bxc5
			variation => N__('QGD Tarrasch: 9.dxc5 Bxc5'),
			moves => {
				'c1g5' => 1,
				'c3a4' => 1,
			},
		},
		'r1bq1rk1/pp3ppp/2n2n2/2bp4/N7/5NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'D34j',
			# TRANSLATORS: D34j: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. dxc5 Bxc5 10. Na4
			variation => N__('QGD Tarrasch: Reti Variation'),
			moves => {
			},
		},
		'r1bq1rk1/pp3ppp/2n2n2/2bp2B1/8/2N2NP1/PP2PPBP/R2Q1RK1 b -' => {
			eco => 'D34k',
			# TRANSLATORS: D34k: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. dxc5 Bxc5 10. Bg5
			variation => N__('QGD Tarrasch: 9.dxc5 Bxc5 10. Bg5'),
			moves => {
				'c8e6' => 1,
				'd5d4' => 1,
			},
		},
		'r2q1rk1/pp3ppp/2n1bn2/2bp2B1/8/2N2NP1/PP2PPBP/R2Q1RK1 w -' => {
			eco => 'D34k',
			# TRANSLATORS: D34k: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. dxc5 Bxc5 10. Bg5 Be6
			variation => N__('QGD Tarrasch: 9.dxc5 Bxc5 10. Bg5 Be6'),
			moves => {
				'g5f6' => 1,
			},
		},
		'r2q1rk1/pp3ppp/2n1bB2/2bp4/8/2N2NP1/PP2PPBP/R2Q1RK1 b -' => {
			eco => 'D34k',
			# TRANSLATORS: D34k: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. dxc5 Bxc5 10. Bg5 Be6 11. Bxf6
			variation => N__('QGD Tarrasch: 9.dxc5 Bxc5 10. Bg5 Be6 11.Bxf6'),
			moves => {
			},
		},
		'r1bq1rk1/pp3ppp/2n2n2/2b3B1/3p4/2N2NP1/PP2PPBP/R2Q1RK1 w -' => {
			eco => 'D34l',
			# TRANSLATORS: D34l: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. dxc5 Bxc5 10. Bg5 d4
			variation => N__('QGD Tarrasch: 9.dxc5 Bxc5 10. Bg5 d4'),
			moves => {
				'g5f6' => 1,
			},
		},
		'r1bq1rk1/pp3ppp/2n2B2/2b5/3p4/2N2NP1/PP2PPBP/R2Q1RK1 b -' => {
			eco => 'D34l',
			# TRANSLATORS: D34l: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. dxc5 Bxc5 10. Bg5 d4 11. Bxf6
			variation => N__('QGD Tarrasch: 9.dxc5 Bxc5 10. Bg5 d4'),
			moves => {
				'd8f6' => 1,
			},
		},
		'r1b2rk1/pp3ppp/2n2q2/2b5/3p4/2N2NP1/PP2PPBP/R2Q1RK1 w -' => {
			eco => 'D34l',
			# TRANSLATORS: D34l: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. dxc5 Bxc5 10. Bg5 d4 11. Bxf6 Qxf6
			variation => N__('QGD Tarrasch: 9.dxc5 Bxc5 10. Bg5 d4'),
			moves => {
				'c3d5' => 1,
			},
		},
		'r1b2rk1/pp3ppp/2n2q2/2bN4/3p4/5NP1/PP2PPBP/R2Q1RK1 b -' => {
			eco => 'D34m',
			# TRANSLATORS: D34m: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. dxc5 Bxc5 10. Bg5 d4 11. Bxf6 Qxf6 12. Nd5
			variation => N__('QGD Tarrasch: 9.dxc5 Bxc5 10. Bg5 d4 11.Bxf6 Qxf6 12. Nd5'),
			moves => {
				'f6d8' => 1,
			},
		},
		'r1bq1rk1/pp3ppp/2n5/2bN4/3p4/5NP1/PP2PPBP/R2Q1RK1 w -' => {
			eco => 'D34m',
			# TRANSLATORS: D34m: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. dxc5 Bxc5 10. Bg5 d4 11. Bxf6 Qxf6 12. Nd5 Qd8
			variation => N__('QGD Tarrasch: 9.dxc5 Bxc5 10. Bg5 d4 11.Bxf6 Qxf6 12. Nd5'),
			moves => {
				'f3d2' => 1,
			},
		},
		'r1bq1rk1/pp3ppp/2n5/2bN4/3p4/6P1/PP1NPPBP/R2Q1RK1 b -' => {
			eco => 'D34m',
			# TRANSLATORS: D34m: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. dxc5 Bxc5 10. Bg5 d4 11. Bxf6 Qxf6 12. Nd5 Qd8 13. Nd2
			variation => N__('QGD Tarrasch: 9.dxc5 Bxc5 10. Bg5 d4 11.Bxf6 Qxf6 12. Nd5'),
			moves => {
				'f8e8' => 1,
			},
		},
		'r1bqr1k1/pp3ppp/2n5/2bN4/3p4/6P1/PP1NPPBP/R2Q1RK1 w -' => {
			eco => 'D34n',
			# TRANSLATORS: D34n: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. dxc5 Bxc5 10. Bg5 d4 11. Bxf6 Qxf6 12. Nd5 Qd8 13. Nd2 Re8
			variation => N__('QGD Tarrasch: 9.dxc5 Bxc5 10. Bg5 d4 11.Bxf6: Main Line'),
			moves => {
			},
		},
		'r1bq1rk1/pp2bppp/2n2n2/2pp2B1/3P4/2N2NP1/PP2PPBP/R2Q1RK1 b -' => {
			eco => 'D34o',
			# TRANSLATORS: D34o: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. Bg5
			variation => N__('QGD Tarrasch: 9. Bg5'),
			moves => {
				'c5c4' => 1,
				'c5d4' => 1,
				'c8e6' => 1,
			},
		},
		'r2q1rk1/pp2bppp/2n1bn2/2pp2B1/3P4/2N2NP1/PP2PPBP/R2Q1RK1 w -' => {
			eco => 'D34o',
			# TRANSLATORS: D34o: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. Bg5 Be6
			variation => N__('QGD Tarrasch: 9. Bg5 Be6'),
			moves => {
				'a1c1' => 1,
			},
		},
		'r2q1rk1/pp2bppp/2n1bn2/2pp2B1/3P4/2N2NP1/PP2PPBP/2RQ1RK1 b -' => {
			eco => 'D34o',
			# TRANSLATORS: D34o: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. Bg5 Be6 10. Rc1
			variation => N__('QGD Tarrasch: 9. Bg5 Be6'),
			moves => {
				'b7b6' => 1,
				'c5c4' => 1,
			},
		},
		'r2q1rk1/p3bppp/1pn1bn2/2pp2B1/3P4/2N2NP1/PP2PPBP/2RQ1RK1 w -' => {
			eco => 'D34o',
			# TRANSLATORS: D34o: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. Bg5 Be6 10. Rc1 b6
			variation => N__('QGD Tarrasch: Stoltz Variation'),
			moves => {
			},
		},
		'r2q1rk1/pp2bppp/2n1bn2/3p2B1/2pP4/2N2NP1/PP2PPBP/2RQ1RK1 w -' => {
			eco => 'D34o',
			# TRANSLATORS: D34o: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. Bg5 Be6 10. Rc1 c4
			variation => N__('QGD Tarrasch: Bogoljubow Variation'),
			moves => {
			},
		},
		'r1bq1rk1/pp2bppp/2n2n2/3p2B1/2pP4/2N2NP1/PP2PPBP/R2Q1RK1 w -' => {
			eco => 'D34p',
			# TRANSLATORS: D34p: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. Bg5 c4
			variation => N__('QGD Tarrasch: 9. Bg5 c4'),
			moves => {
				'f3e5' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2n2n2/3pN1B1/2pP4/2N3P1/PP2PPBP/R2Q1RK1 b -' => {
			eco => 'D34p',
			# TRANSLATORS: D34p: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. Bg5 c4 10. Ne5
			variation => N__('QGD Tarrasch: 9. Bg5 c4'),
			moves => {
				'c8e6' => 1,
			},
		},
		'r2q1rk1/pp2bppp/2n1bn2/3pN1B1/2pP4/2N3P1/PP2PPBP/R2Q1RK1 w -' => {
			eco => 'D34p',
			# TRANSLATORS: D34p: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. Bg5 c4 10. Ne5 Be6
			variation => N__('QGD Tarrasch: 9. Bg5 c4'),
			moves => {
				'e5c6' => 1,
			},
		},
		'r2q1rk1/pp2bppp/2N1bn2/3p2B1/2pP4/2N3P1/PP2PPBP/R2Q1RK1 b -' => {
			eco => 'D34q',
			# TRANSLATORS: D34q: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. Bg5 c4 10. Ne5 Be6 11. Nxc6
			variation => N__('QGD Tarrasch: 9. Bg5 c4 10. Ne5 Be6 11.Nxc6'),
			moves => {
			},
		},
		'r1bq1rk1/pp2bppp/2n2n2/3p2B1/3p4/2N2NP1/PP2PPBP/R2Q1RK1 w -' => {
			eco => 'D34r',
			# TRANSLATORS: D34r: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. Bg5 cxd4
			variation => N__('QGD Tarrasch: 9. Bg5 cxd4'),
			moves => {
				'f3d4' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2n2n2/3p2B1/3N4/2N3P1/PP2PPBP/R2Q1RK1 b -' => {
			eco => 'D34r',
			# TRANSLATORS: D34r: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. Bg5 cxd4 10. Nxd4
			variation => N__('QGD Tarrasch: 9. Bg5 cxd4'),
			moves => {
				'h7h6' => 1,
			},
		},
		'r1bq1rk1/pp2bpp1/2n2n1p/3p2B1/3N4/2N3P1/PP2PPBP/R2Q1RK1 w -' => {
			eco => 'D34s',
			# TRANSLATORS: D34s: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. Bg5 cxd4 10. Nxd4 h6
			variation => N__('QGD Tarrasch: 9. Bg5 cxd4 10.Nxd4 h6'),
			moves => {
				'g5e3' => 1,
			},
		},
		'r1bq1rk1/pp2bpp1/2n2n1p/3p4/3N4/2N1B1P1/PP2PPBP/R2Q1RK1 b -' => {
			eco => 'D34t',
			# TRANSLATORS: D34t: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. Bg5 cxd4 10. Nxd4 h6 11. Be3
			variation => N__('QGD Tarrasch: 9. Bg5 cxd4 10.Nxd4 h6 11. Be3'),
			moves => {
				'f8e8' => 1,
			},
		},
		'r1bqr1k1/pp2bpp1/2n2n1p/3p4/3N4/2N1B1P1/PP2PPBP/R2Q1RK1 w -' => {
			eco => 'D34u',
			# TRANSLATORS: D34u: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. Bg5 cxd4 10. Nxd4 h6 11. Be3 Re8
			variation => N__('QGD Tarrasch: 9. Bg5 cxd4 10.Nxd4 h6 11. Be3 Re8'),
			moves => {
				'a1c1' => 1,
				'd1b3' => 1,
			},
		},
		'r1bqr1k1/pp2bpp1/2n2n1p/3p4/3N4/1QN1B1P1/PP2PPBP/R4RK1 b -' => {
			eco => 'D34v',
			# TRANSLATORS: D34v: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. Bg5 cxd4 10. Nxd4 h6 11. Be3 Re8 12. Qb3
			variation => N__('QGD Tarrasch: 9. Bg5 cxd4 10.Nxd4 h6 11. Be3 Re8 12. Qb3'),
			moves => {
			},
		},
		'r1bqr1k1/pp2bpp1/2n2n1p/3p4/3N4/2N1B1P1/PP2PPBP/2RQ1RK1 b -' => {
			eco => 'D34w',
			# TRANSLATORS: D34w: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. Bg5 cxd4 10. Nxd4 h6 11. Be3 Re8 12. Rc1
			variation => N__('QGD Tarrasch: 9. Bg5 cxd4 10.Nxd4 h6 11. Be3 Re8 12. Rc1'),
			moves => {
				'e7f8' => 1,
			},
		},
		'r1bqrbk1/pp3pp1/2n2n1p/3p4/3N4/2N1B1P1/PP2PPBP/2RQ1RK1 w -' => {
			eco => 'D34x',
			# TRANSLATORS: D34x: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. Bg5 cxd4 10. Nxd4 h6 11. Be3 Re8 12. Rc1 Bf8
			variation => N__('QGD Tarrasch: 9. Bg5 cxd4 10.Nxd4 h6 11. Be3 Re8 12. Rc1 Bf8'),
			moves => {
				'd4c6' => 1,
			},
		},
		'r1bqrbk1/pp3pp1/2N2n1p/3p4/8/2N1B1P1/PP2PPBP/2RQ1RK1 b -' => {
			eco => 'D34y',
			# TRANSLATORS: D34y: 1. d4 d5 2. c4 e6 3. Nc3 c5 4. cxd5 exd5 5. Nf3 Nc6 6. g3 Nf6 7. Bg2 Be7 8. O-O O-O 9. Bg5 cxd4 10. Nxd4 h6 11. Be3 Re8 12. Rc1 Bf8 13. Nxc6
			variation => N__('QGD Tarrasch: 9. Bg5 cxd4 10.Nxd4 h6 11. Be3 Re8 12. Rc1 Bf8 13.Nxc6'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p4/2PP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'D35a',
			# TRANSLATORS: D35a: 1. d4 d5 2. c4 e6 3. Nc3 Nf6
			variation => N__('QGD: 3. Nc3 Nf6'),
			moves => {
				'c1f4' => 1,
				'c1g5' => 1,
				'c4d5' => 1,
				'e2e3' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p4/2PP1B2/2N5/PP2PPPP/R2QKBNR b KQkq' => {
			eco => 'D35a',
			# TRANSLATORS: D35a: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bf4
			variation => N__('QGD: Harrwitz Attack'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p4/2PP4/2N1P3/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'D35a',
			# TRANSLATORS: D35a: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. e3
			variation => N__('QGD: 3. Nc3 Nf6 4. e3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p4/2PP4/2N3P1/PP2PP1P/R1BQKBNR b KQkq' => {
			eco => 'D35a',
			# TRANSLATORS: D35a: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. g3
			variation => N__('QGD: Catalan without Nf3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3P4/3P4/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'D35b',
			# TRANSLATORS: D35b: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5
			variation => N__('QGD: Exchange'),
			moves => {
				'e6d5' => 1,
				'f6d5' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3p4/3P4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'D35b',
			# TRANSLATORS: D35b: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5
			variation => N__('QGD: Exchange'),
			moves => {
				'c1f4' => 1,
				'c1g5' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4p3/3n4/3P4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'D35b',
			# TRANSLATORS: D35b: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 Nxd5
			variation => N__('QGD: Exchange, 4...Nxd5'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3p4/3P1B2/2N5/PP2PPPP/R2QKBNR b KQkq' => {
			eco => 'D35c',
			# TRANSLATORS: D35c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bf4
			variation => N__('QGD: Exchange, Sämisch Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3p4/3P4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D35d',
			# TRANSLATORS: D35d: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Nf3
			variation => N__('QGD: Exchange, 5. Nf3'),
			moves => {
				'b8d7' => 1,
				'c7c6' => 1,
				'f8e7' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/2p2n2/3p4/3P4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D35d',
			# TRANSLATORS: D35d: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Nf3 c6
			variation => N__('QGD: Exchange, 5. Nf3 c6'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/2p2n2/3p4/3P4/2N1PN2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'D35d',
			# TRANSLATORS: D35d: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Nf3 c6 6. e3
			variation => N__('QGD: Exchange, 5. Nf3 c6 6. e3'),
			moves => {
			},
		},
		'r1bqkb1r/pppn1ppp/5n2/3p4/3P4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D35e',
			# TRANSLATORS: D35e: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Nf3 Nbd7
			variation => N__('QGD: Exchange, 5. Nf3 Nbd7'),
			moves => {
				'c1f4' => 1,
				'e2e3' => 1,
			},
		},
		'r1bqkb1r/pppn1ppp/5n2/3p4/3P4/2N1PN2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'D35e',
			# TRANSLATORS: D35e: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Nf3 Nbd7 6. e3
			variation => N__('QGD: Exchange, 5. Nf3 Nbd7 6. e3'),
			moves => {
				'c7c6' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/2p2n2/3p4/3P4/2N1PN2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'D35e',
			# TRANSLATORS: D35e: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Nf3 Nbd7 6. e3 c6
			variation => N__('QGD: Exchange, 5. Nf3 Nbd7 6. e3 c6'),
			moves => {
			},
		},
		'r1bqkb1r/pppn1ppp/5n2/3p4/3P1B2/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D35f',
			# TRANSLATORS: D35f: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Nf3 Nbd7 6. Bf4
			variation => N__('QGD: Exchange, 5. Nf3 Nbd7 6. Bf4'),
			moves => {
			},
		},
		'rnbqk2r/ppp1bppp/5n2/3p4/3P4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D35g',
			# TRANSLATORS: D35g: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Nf3 Be7
			variation => N__('QGD: Exchange, 5. Nf3 Be7'),
			moves => {
				'c1f4' => 1,
			},
		},
		'rnbqk2r/ppp1bppp/5n2/3p4/3P1B2/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D35g',
			# TRANSLATORS: D35g: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Nf3 Be7 6. Bf4
			variation => N__('QGD: Exchange, 5. Nf3 Be7 6. Bf4'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rnbqk2r/pp2bppp/2p2n2/3p4/3P1B2/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'D35h',
			# TRANSLATORS: D35h: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Nf3 Be7 6. Bf4 c6
			variation => N__('QGD: Exchange, 5. Nf3 Be7 6. Bf4 c6'),
			moves => {
				'd1c2' => 1,
			},
		},
		'rnbqk2r/pp2bppp/2p2n2/3p4/3P1B2/2N2N2/PPQ1PPPP/R3KB1R b KQkq' => {
			eco => 'D35h',
			# TRANSLATORS: D35h: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Nf3 Be7 6. Bf4 c6 7. Qc2
			variation => N__('QGD: Exchange, 5. Nf3 Be7 6. Bf4 c6 7. Qc2'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r1bqk2r/pp1nbppp/2p2n2/3p4/3P1B2/2N2N2/PPQ1PPPP/R3KB1R w KQkq' => {
			eco => 'D35h',
			# TRANSLATORS: D35h: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Nf3 Be7 6. Bf4 c6 7. Qc2 Nbd7
			variation => N__('QGD: Exchange, 5. Nf3 Be7 6. Bf4 c6 7. Qc2 Nbd7'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/5n2/3p2B1/3P4/2N5/PP2PPPP/R2QKBNR b KQkq' => {
			eco => 'D35i',
			# TRANSLATORS: D35i: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5
			variation => N__('QGD: Exchange, 5. Bg5'),
			moves => {
				'b8d7' => 1,
				'c7c6' => 1,
				'f8e7' => 1,
			},
		},
		'r1bqkb1r/pppn1ppp/5n2/3p2B1/3P4/2N5/PP2PPPP/R2QKBNR w KQkq' => {
			eco => 'D35i',
			# TRANSLATORS: D35i: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 Nbd7
			variation => N__('QGD: Exchange, 5. Bg5 Nbd7'),
			moves => {
				'e2e3' => 1,
				'g1f3' => 1,
			},
		},
		'r1bqkb1r/pppn1ppp/5n2/3p2B1/3P4/2N1P3/PP3PPP/R2QKBNR b KQkq' => {
			eco => 'D35i',
			# TRANSLATORS: D35i: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 Nbd7 6. e3
			variation => N__('QGD: Exchange, 5. Bg5 Nbd7 6. e3'),
			moves => {
			},
		},
		'r1bqkb1r/pppn1ppp/5n2/3p2B1/3P4/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D35i',
			# TRANSLATORS: D35i: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 Nbd7 6. Nf3
			variation => N__('QGD: Exchange, 5. Bg5 Nbd7 6. Nf3'),
			moves => {
			},
		},
		'rnbqk2r/ppp1bppp/5n2/3p2B1/3P4/2N5/PP2PPPP/R2QKBNR w KQkq' => {
			eco => 'D35i',
			# TRANSLATORS: D35i: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 Be7
			variation => N__('QGD: Exchange, 5. Bg5 Be7'),
			moves => {
				'e2e3' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqk2r/ppp1bppp/5n2/3p2B1/3P4/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D35i',
			# TRANSLATORS: D35i: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 Be7 6. Nf3
			variation => N__('QGD: Exchange, 5. Bg5 Be7 6. Nf3'),
			moves => {
			},
		},
		'rnbqk2r/ppp1bppp/5n2/3p2B1/3P4/2N1P3/PP3PPP/R2QKBNR b KQkq' => {
			eco => 'D35j',
			# TRANSLATORS: D35j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 Be7 6. e3
			variation => N__('QGD: Exchange, 5. Bg5 Be7 6. e3'),
			moves => {
				'b8d7' => 1,
				'e8g8' => 1,
				'h7h6' => 1,
			},
		},
		'r1bqk2r/pppnbppp/5n2/3p2B1/3P4/2N1P3/PP3PPP/R2QKBNR w KQkq' => {
			eco => 'D35j',
			# TRANSLATORS: D35j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 Be7 6. e3 Nbd7
			variation => N__('QGD: Exchange, 5. Bg5 Be7 6. e3 Nbd7'),
			moves => {
			},
		},
		'rnbqk2r/ppp1bpp1/5n1p/3p2B1/3P4/2N1P3/PP3PPP/R2QKBNR w KQkq' => {
			eco => 'D35j',
			# TRANSLATORS: D35j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 Be7 6. e3 h6
			variation => N__('QGD: Exchange, 5. Bg5 Be7 6. e3 h6'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1bppp/5n2/3p2B1/3P4/2N1P3/PP3PPP/R2QKBNR w KQ' => {
			eco => 'D35k',
			# TRANSLATORS: D35k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 Be7 6. e3 O-O
			variation => N__('QGD: Exchange, 5. Bg5 Be7 6. e3 O-O'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/2p2n2/3p2B1/3P4/2N5/PP2PPPP/R2QKBNR w KQkq' => {
			eco => 'D35l',
			# TRANSLATORS: D35l: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6
			variation => N__('QGD: Exchange, 5. Bg5 c6'),
			moves => {
				'd1c2' => 1,
				'e2e3' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/2p2n2/3p2B1/3P4/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D35l',
			# TRANSLATORS: D35l: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Nf3
			variation => N__('QGD: Exchange, 5. Bg5 c6 6. Nf3'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/2p2n2/3p2B1/3P4/2N1P3/PP3PPP/R2QKBNR b KQkq' => {
			eco => 'D35m',
			# TRANSLATORS: D35m: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. e3
			variation => N__('QGD: Exchange, 5. Bg5 c6 6. e3'),
			moves => {
				'b8d7' => 1,
				'f8e7' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/2p2n2/3p2B1/3P4/2N1P3/PP3PPP/R2QKBNR w KQkq' => {
			eco => 'D35n',
			# TRANSLATORS: D35n: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. e3 Nbd7
			variation => N__('QGD: Exchange, 5. Bg5 c6 6. e3 Nbd7'),
			moves => {
			},
		},
		'rnbqk2r/pp2bppp/2p2n2/3p2B1/3P4/2N1P3/PP3PPP/R2QKBNR w KQkq' => {
			eco => 'D35o',
			# TRANSLATORS: D35o: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. e3 Be7
			variation => N__('QGD: Exchange, 5. Bg5 c6 6. e3 Be7'),
			moves => {
				'f1d3' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqk2r/pp2bppp/2p2n2/3p2B1/3P4/2N1PN2/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'D35o',
			# TRANSLATORS: D35o: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. e3 Be7 7. Nf3
			variation => N__('QGD: Exchange, 5. Bg5 c6 6. e3 Be7 7. Nf3'),
			moves => {
				'c8f5' => 1,
			},
		},
		'rn1qk2r/pp2bppp/2p2n2/3p1bB1/3P4/2N1PN2/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'D35p',
			# TRANSLATORS: D35p: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. e3 Be7 7. Nf3 Bf5
			variation => N__('QGD: Exchange, 5. Bg5 c6 6. e3 Be7 7. Nf3 Bf5'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rn1qk2r/pp2bppp/2p2n2/3p1bB1/3P4/2NBPN2/PP3PPP/R2QK2R b KQkq' => {
			eco => 'D35q',
			# TRANSLATORS: D35q: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. e3 Be7 7. Nf3 Bf5 8. Bd3
			variation => N__('QGD: Exchange, 5. Bg5 c6 6. e3 Be7 7. Nf3 Bf5 8. Bd3'),
			moves => {
			},
		},
		'rnbqk2r/pp2bppp/2p2n2/3p2B1/3P4/2NBP3/PP3PPP/R2QK1NR b KQkq' => {
			eco => 'D35r',
			# TRANSLATORS: D35r: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. e3 Be7 7. Bd3
			variation => N__('QGD: Exchange, 5. Bg5 c6 6. e3 Be7 7. Bd3'),
			moves => {
				'b8d7' => 1,
				'e8g8' => 1,
				'f6e4' => 1,
			},
		},
		'rnbqk2r/pp2bppp/2p5/3p2B1/3Pn3/2NBP3/PP3PPP/R2QK1NR w KQkq' => {
			eco => 'D35s',
			# TRANSLATORS: D35s: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. e3 Be7 7. Bd3 Ne4
			variation => N__('QGD: Exchange, 5. Bg5 c6 6. e3 Be7 7. Bd3 Ne4'),
			moves => {
			},
		},
		'r1bqk2r/pp1nbppp/2p2n2/3p2B1/3P4/2NBP3/PP3PPP/R2QK1NR w KQkq' => {
			eco => 'D35t',
			# TRANSLATORS: D35t: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. e3 Be7 7. Bd3 Nbd7
			variation => N__('QGD: Exchange, 5. Bg5 c6 6. e3 Be7 7. Bd3 Nbd7'),
			moves => {
				'g1e2' => 1,
				'g1f3' => 1,
			},
		},
		'r1bqk2r/pp1nbppp/2p2n2/3p2B1/3P4/2NBP3/PP2NPPP/R2QK2R b KQkq' => {
			eco => 'D35t',
			# TRANSLATORS: D35t: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. e3 Be7 7. Bd3 Nbd7 8. Nge2
			variation => N__('QGD: Exchange, 5. Bg5 c6 6. e3 Be7 7. Bd3 Nbd7 8.Nge2'),
			moves => {
			},
		},
		'r1bqk2r/pp1nbppp/2p2n2/3p2B1/3P4/2NBPN2/PP3PPP/R2QK2R b KQkq' => {
			eco => 'D35u',
			# TRANSLATORS: D35u: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. e3 Be7 7. Bd3 Nbd7 8. Nf3
			variation => N__('QGD: Exchange, 5. Bg5 c6 6. e3 Be7 7. Bd3 Nbd7 8. Nf3'),
			moves => {
			},
		},
		'rnbq1rk1/pp2bppp/2p2n2/3p2B1/3P4/2NBP3/PP3PPP/R2QK1NR w KQ' => {
			eco => 'D35v',
			# TRANSLATORS: D35v: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. e3 Be7 7. Bd3 O-O
			variation => N__('QGD: Exchange, 5. Bg5 c6 6. e3 Be7 7. Bd3 O-O'),
			moves => {
				'g1e2' => 1,
				'g1f3' => 1,
			},
		},
		'rnbq1rk1/pp2bppp/2p2n2/3p2B1/3P4/2NBP3/PP2NPPP/R2QK2R b KQ' => {
			eco => 'D35v',
			# TRANSLATORS: D35v: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. e3 Be7 7. Bd3 O-O 8. Nge2
			variation => N__('QGD: Exchange, 5. Bg5 c6 6. e3 Be7 7. Bd3 O-O 8.Nge2'),
			moves => {
			},
		},
		'rnbq1rk1/pp2bppp/2p2n2/3p2B1/3P4/2NBPN2/PP3PPP/R2QK2R b KQ' => {
			eco => 'D35v',
			# TRANSLATORS: D35v: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. e3 Be7 7. Bd3 O-O 8. Nf3
			variation => N__('QGD: Exchange, 5. Bg5 c6 6. e3 Be7 7. Bd3 O-O 8. Nf3'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/2p2n2/3p2B1/3P4/2N5/PPQ1PPPP/R3KBNR b KQkq' => {
			eco => 'D36a',
			# TRANSLATORS: D36a: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2
			variation => N__('QGD: Exchange, 5. Bg5 c6 6. Qc2'),
			moves => {
				'b8a6' => 1,
				'f8e7' => 1,
				'g7g6' => 1,
			},
		},
		'rnbqkb1r/pp3p1p/2p2np1/3p2B1/3P4/2N5/PPQ1PPPP/R3KBNR w KQkq' => {
			eco => 'D36a',
			# TRANSLATORS: D36a: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 g6
			variation => N__('QGD: Exchange, 5. Bg5 c6 6. Qc2 g6'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/n1p2n2/3p2B1/3P4/2N5/PPQ1PPPP/R3KBNR w KQkq' => {
			eco => 'D36b',
			# TRANSLATORS: D36b: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Na6
			variation => N__('QGD: Exchange, 5. Bg5 c6 6. Qc2 Na6'),
			moves => {
			},
		},
		'rnbqk2r/pp2bppp/2p2n2/3p2B1/3P4/2N5/PPQ1PPPP/R3KBNR w KQkq' => {
			eco => 'D36c',
			# TRANSLATORS: D36c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7
			variation => N__('QGD: Exchange, 6. Qc2 Be7'),
			moves => {
				'e2e3' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqk2r/pp2bppp/2p2n2/3p2B1/3P4/2N2N2/PPQ1PPPP/R3KB1R b KQkq' => {
			eco => 'D36c',
			# TRANSLATORS: D36c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. Nf3
			variation => N__('QGD: Exchange, 6. Qc2 Be7 7. Nf3'),
			moves => {
				'b8d7' => 1,
				'e8g8' => 1,
				'g7g6' => 1,
			},
		},
		'r1bqk2r/pp1nbppp/2p2n2/3p2B1/3P4/2N2N2/PPQ1PPPP/R3KB1R w KQkq' => {
			eco => 'D36c',
			# TRANSLATORS: D36c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. Nf3 Nbd7
			variation => N__('QGD: Exchange, 6. Qc2 Be7 7. Nf3 Nbd7'),
			moves => {
			},
		},
		'rnbq1rk1/pp2bppp/2p2n2/3p2B1/3P4/2N2N2/PPQ1PPPP/R3KB1R w KQ' => {
			eco => 'D36c',
			# TRANSLATORS: D36c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. Nf3 O-O
			variation => N__('QGD: Exchange, 6. Qc2 Be7 7. Nf3 O-O'),
			moves => {
			},
		},
		'rnbqk2r/pp2bp1p/2p2np1/3p2B1/3P4/2N2N2/PPQ1PPPP/R3KB1R w KQkq' => {
			eco => 'D36d',
			# TRANSLATORS: D36d: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. Nf3 g6
			variation => N__('QGD: Exchange, 6. Qc2 Be7 7. Nf3 g6'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbqk2r/pp2bp1p/2p2np1/3p2B1/3P4/2N1PN2/PPQ2PPP/R3KB1R b KQkq' => {
			eco => 'D36e',
			# TRANSLATORS: D36e: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. Nf3 g6 8. e3
			variation => N__('QGD: Exchange, 6. Qc2 Be7 7. Nf3 g6 8. e3'),
			moves => {
			},
		},
		'rnbqk2r/pp2bppp/2p2n2/3p2B1/3P4/2N1P3/PPQ2PPP/R3KBNR b KQkq' => {
			eco => 'D36f',
			# TRANSLATORS: D36f: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3
			variation => N__('QGD: Exchange, 6. Qc2 Be7 7. e3'),
			moves => {
				'b8d7' => 1,
				'e8g8' => 1,
				'h7h6' => 1,
			},
		},
		'rnbq1rk1/pp2bppp/2p2n2/3p2B1/3P4/2N1P3/PPQ2PPP/R3KBNR w KQ' => {
			eco => 'D36f',
			# TRANSLATORS: D36f: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 O-O
			variation => N__('QGD: Exchange, 6. Qc2 Be7 7. e3 O-O'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rnbq1rk1/pp2bppp/2p2n2/3p2B1/3P4/2NBP3/PPQ2PPP/R3K1NR b KQ' => {
			eco => 'D36f',
			# TRANSLATORS: D36f: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 O-O 8. Bd3
			variation => N__('QGD: Exchange, 6. Qc2 Be7 7. e3 O-O 8. Bd3'),
			moves => {
			},
		},
		'rnbqk2r/pp2bpp1/2p2n1p/3p2B1/3P4/2N1P3/PPQ2PPP/R3KBNR w KQkq' => {
			eco => 'D36g',
			# TRANSLATORS: D36g: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 h6
			variation => N__('QGD: Exchange, 6. Qc2 Be7 7. e3 h6'),
			moves => {
				'g5h4' => 1,
			},
		},
		'rnbqk2r/pp2bpp1/2p2n1p/3p4/3P3B/2N1P3/PPQ2PPP/R3KBNR b KQkq' => {
			eco => 'D36g',
			# TRANSLATORS: D36g: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 h6 8. Bh4
			variation => N__('QGD: Exchange, 6. Qc2 Be7 7. e3 h6'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/pp2bpp1/2p2n1p/3p4/3P3B/2N1P3/PPQ2PPP/R3KBNR w KQ' => {
			eco => 'D36g',
			# TRANSLATORS: D36g: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 h6 8. Bh4 O-O
			variation => N__('QGD: Exchange, 6. Qc2 Be7 7. e3 h6'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rnbq1rk1/pp2bpp1/2p2n1p/3p4/3P3B/2NBP3/PPQ2PPP/R3K1NR b KQ' => {
			eco => 'D36g',
			# TRANSLATORS: D36g: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 h6 8. Bh4 O-O 9. Bd3
			variation => N__('QGD: Exchange, 6. Qc2 Be7 7. e3 h6'),
			moves => {
				'f8e8' => 1,
			},
		},
		'rnbqr1k1/pp2bpp1/2p2n1p/3p4/3P3B/2NBP3/PPQ2PPP/R3K1NR w KQ' => {
			eco => 'D36g',
			# TRANSLATORS: D36g: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 h6 8. Bh4 O-O 9. Bd3 Re8
			variation => N__('QGD: Exchange, 6. Qc2 Be7 7. e3 h6'),
			moves => {
			},
		},
		'r1bqk2r/pp1nbppp/2p2n2/3p2B1/3P4/2N1P3/PPQ2PPP/R3KBNR w KQkq' => {
			eco => 'D36h',
			# TRANSLATORS: D36h: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 Nbd7
			variation => N__('QGD: Exchange, 6. Qc2 Be7 7. e3 Nbd7'),
			moves => {
				'f1d3' => 1,
				'g1f3' => 1,
			},
		},
		'r1bqk2r/pp1nbppp/2p2n2/3p2B1/3P4/2N1PN2/PPQ2PPP/R3KB1R b KQkq' => {
			eco => 'D36h',
			# TRANSLATORS: D36h: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 Nbd7 8. Nf3
			variation => N__('QGD: Exchange, 6. Qc2 Be7 7. e3 Nbd7 8. Nf3'),
			moves => {
			},
		},
		'r1bqk2r/pp1nbppp/2p2n2/3p2B1/3P4/2NBP3/PPQ2PPP/R3K1NR b KQkq' => {
			eco => 'D36i',
			# TRANSLATORS: D36i: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 Nbd7 8. Bd3
			variation => N__('QGD: Exchange, 6. Qc2 Be7 7. e3 Nbd7 8. Bd3'),
			moves => {
				'd7f8' => 1,
				'e8g8' => 1,
			},
		},
		'r1bqkn1r/pp2bppp/2p2n2/3p2B1/3P4/2NBP3/PPQ2PPP/R3K1NR w KQkq' => {
			eco => 'D36j',
			# TRANSLATORS: D36j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 Nbd7 8. Bd3 Nf8
			variation => N__('QGD: Exchange, 6. Qc2 Be7 7. e3 Nbd7 8. Bd3 Nf8'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nbppp/2p2n2/3p2B1/3P4/2NBP3/PPQ2PPP/R3K1NR w KQ' => {
			eco => 'D36k',
			# TRANSLATORS: D36k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 Nbd7 8. Bd3 O-O
			variation => N__('QGD: Exchange, Main Line'),
			moves => {
				'g1e2' => 1,
				'g1f3' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/2p2n2/3p2B1/3P4/2NBP3/PPQ1NPPP/R3K2R b KQ' => {
			eco => 'D36k',
			# TRANSLATORS: D36k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 Nbd7 8. Bd3 O-O 9. Nge2
			variation => N__('QGD: Exchange, Main Line, 9.Nge2'),
			moves => {
				'f8e8' => 1,
				'h7h6' => 1,
			},
		},
		'r1bq1rk1/pp1nbpp1/2p2n1p/3p2B1/3P4/2NBP3/PPQ1NPPP/R3K2R w KQ' => {
			eco => 'D36k',
			# TRANSLATORS: D36k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 Nbd7 8. Bd3 O-O 9. Nge2 h6
			variation => N__('QGD: Exchange, Main Line, 9.Nge2 h6'),
			moves => {
				'g5h4' => 1,
			},
		},
		'r1bq1rk1/pp1nbpp1/2p2n1p/3p4/3P3B/2NBP3/PPQ1NPPP/R3K2R b KQ' => {
			eco => 'D36k',
			# TRANSLATORS: D36k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 Nbd7 8. Bd3 O-O 9. Nge2 h6 10. Bh4
			variation => N__('QGD: Exchange, Main Line, 9.Nge2 h6 10. Bh4'),
			moves => {
			},
		},
		'r1bqr1k1/pp1nbppp/2p2n2/3p2B1/3P4/2NBP3/PPQ1NPPP/R3K2R w KQ' => {
			eco => 'D36l',
			# TRANSLATORS: D36l: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 Nbd7 8. Bd3 O-O 9. Nge2 Re8
			variation => N__('QGD: Exchange, Main Line, 9.Nge2 Re8'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqr1k1/pp1nbppp/2p2n2/3p2B1/3P4/2NBP3/PPQ1NPPP/R4RK1 b -' => {
			eco => 'D36m',
			# TRANSLATORS: D36m: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 Nbd7 8. Bd3 O-O 9. Nge2 Re8 10. O-O
			variation => N__('QGD: Exchange, Main Line, 9.Nge2 Re8 10.O-O'),
			moves => {
				'd7f8' => 1,
			},
		},
		'r1bqrnk1/pp2bppp/2p2n2/3p2B1/3P4/2NBP3/PPQ1NPPP/R4RK1 w -' => {
			eco => 'D36m',
			# TRANSLATORS: D36m: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 Nbd7 8. Bd3 O-O 9. Nge2 Re8 10. O-O Nf8
			variation => N__('QGD: Exchange, Main Line, 9.Nge2 Re8 10.O-O Nf8'),
			moves => {
				'f2f3' => 1,
			},
		},
		'r1bqrnk1/pp2bppp/2p2n2/3p2B1/3P4/2NBPP2/PPQ1N1PP/R4RK1 b -' => {
			eco => 'D36n',
			# TRANSLATORS: D36n: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 Nbd7 8. Bd3 O-O 9. Nge2 Re8 10. O-O Nf8 11. f3
			variation => N__('QGD: Exchange, Main Line, 9.Nge2 Re8 10.O-O Nf8 11. f3'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nbppp/2p2n2/3p2B1/3P4/2NBPN2/PPQ2PPP/R3K2R b KQ' => {
			eco => 'D36o',
			# TRANSLATORS: D36o: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 Nbd7 8. Bd3 O-O 9. Nf3
			variation => N__('QGD: Exchange, Main Line, 9. Nf3'),
			moves => {
				'f8e8' => 1,
				'h7h6' => 1,
			},
		},
		'r1bq1rk1/pp1nbpp1/2p2n1p/3p2B1/3P4/2NBPN2/PPQ2PPP/R3K2R w KQ' => {
			eco => 'D36o',
			# TRANSLATORS: D36o: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 Nbd7 8. Bd3 O-O 9. Nf3 h6
			variation => N__('QGD: Exchange, Main Line, 9. Nf3 h6'),
			moves => {
				'g5h4' => 1,
			},
		},
		'r1bq1rk1/pp1nbpp1/2p2n1p/3p4/3P3B/2NBPN2/PPQ2PPP/R3K2R b KQ' => {
			eco => 'D36o',
			# TRANSLATORS: D36o: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 Nbd7 8. Bd3 O-O 9. Nf3 h6 10. Bh4
			variation => N__('QGD: Exchange, Main Line, 9. Nf3 h6 10. Bh4'),
			moves => {
			},
		},
		'r1bqr1k1/pp1nbppp/2p2n2/3p2B1/3P4/2NBPN2/PPQ2PPP/R3K2R w KQ' => {
			eco => 'D36p',
			# TRANSLATORS: D36p: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 Nbd7 8. Bd3 O-O 9. Nf3 Re8
			variation => N__('QGD: Exchange, Main Line, 9. Nf3 Re8'),
			moves => {
				'e1c1' => 1,
				'e1g1' => 1,
				'h2h3' => 1,
			},
		},
		'r1bqr1k1/pp1nbppp/2p2n2/3p2B1/3P4/2NBPN1P/PPQ2PP1/R3K2R b KQ' => {
			eco => 'D36p',
			# TRANSLATORS: D36p: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 Nbd7 8. Bd3 O-O 9. Nf3 Re8 10. h3
			variation => N__('QGD: Exchange, Main Line, 9. Nf3 Re8 10. h3'),
			moves => {
				'd7f8' => 1,
			},
		},
		'r1bqrnk1/pp2bppp/2p2n2/3p2B1/3P4/2NBPN1P/PPQ2PP1/R3K2R w KQ' => {
			eco => 'D36p',
			# TRANSLATORS: D36p: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 Nbd7 8. Bd3 O-O 9. Nf3 Re8 10. h3 Nf8
			variation => N__('QGD: Exchange, Main Line, 9. Nf3 Re8 10. h3 Nf8'),
			moves => {
				'g5f4' => 1,
			},
		},
		'r1bqrnk1/pp2bppp/2p2n2/3p4/3P1B2/2NBPN1P/PPQ2PP1/R3K2R b KQ' => {
			eco => 'D36q',
			# TRANSLATORS: D36q: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 Nbd7 8. Bd3 O-O 9. Nf3 Re8 10. h3 Nf8 11. Bf4
			variation => N__('QGD: Exchange, Main Line, 9. Nf3 Re8 10. h3 Nf8 11. Bf4'),
			moves => {
			},
		},
		'r1bqr1k1/pp1nbppp/2p2n2/3p2B1/3P4/2NBPN2/PPQ2PPP/2KR3R b -' => {
			eco => 'D36r',
			# TRANSLATORS: D36r: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 Nbd7 8. Bd3 O-O 9. Nf3 Re8 10. O-O-O
			variation => N__('QGD: Exchange, Main Line, 9. Nf3 Re8 10.O-O-O'),
			moves => {
				'd7f8' => 1,
				'h7h6' => 1,
			},
		},
		'r1bqrnk1/pp2bppp/2p2n2/3p2B1/3P4/2NBPN2/PPQ2PPP/2KR3R w -' => {
			eco => 'D36r',
			# TRANSLATORS: D36r: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 Nbd7 8. Bd3 O-O 9. Nf3 Re8 10. O-O-O Nf8
			variation => N__('QGD: Exchange, Main Line, 9. Nf3 Re8 10.O-O-O Nf8'),
			moves => {
				'h2h3' => 1,
			},
		},
		'r1bqrnk1/pp2bppp/2p2n2/3p2B1/3P4/2NBPN1P/PPQ2PP1/2KR3R b -' => {
			eco => 'D36r',
			# TRANSLATORS: D36r: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 Nbd7 8. Bd3 O-O 9. Nf3 Re8 10. O-O-O Nf8 11. h3
			variation => N__('QGD: Exchange, Main Line, 9. Nf3 Re8 10.O-O-O Nf8 11. h3'),
			moves => {
			},
		},
		'r1bqr1k1/pp1nbpp1/2p2n1p/3p2B1/3P4/2NBPN2/PPQ2PPP/2KR3R w -' => {
			eco => 'D36r',
			# TRANSLATORS: D36r: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 Nbd7 8. Bd3 O-O 9. Nf3 Re8 10. O-O-O h6
			variation => N__('QGD: Exchange, Main Line, 9. Nf3 Re8 10.O-O-O'),
			moves => {
				'g5h4' => 1,
			},
		},
		'r1bqr1k1/pp1nbpp1/2p2n1p/3p4/3P3B/2NBPN2/PPQ2PPP/2KR3R b -' => {
			eco => 'D36r',
			# TRANSLATORS: D36r: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 Nbd7 8. Bd3 O-O 9. Nf3 Re8 10. O-O-O h6 11. Bh4
			variation => N__('QGD: Exchange, Main Line, 9. Nf3 Re8 10.O-O-O h6'),
			moves => {
			},
		},
		'r1bqr1k1/pp1nbppp/2p2n2/3p2B1/3P4/2NBPN2/PPQ2PPP/R4RK1 b -' => {
			eco => 'D36s',
			# TRANSLATORS: D36s: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 Nbd7 8. Bd3 O-O 9. Nf3 Re8 10. O-O
			variation => N__('QGD: Exchange, Main Line, 9. Nf3 Re8 10.O-O'),
			moves => {
				'd7f8' => 1,
				'h7h6' => 1,
			},
		},
		'r1bqr1k1/pp1nbpp1/2p2n1p/3p2B1/3P4/2NBPN2/PPQ2PPP/R4RK1 w -' => {
			eco => 'D36t',
			# TRANSLATORS: D36t: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 Nbd7 8. Bd3 O-O 9. Nf3 Re8 10. O-O h6
			variation => N__('QGD: Exchange, Main Line, 9. Nf3 Re8 10.O-O h6'),
			moves => {
				'g5f4' => 1,
				'g5h4' => 1,
			},
		},
		'r1bqr1k1/pp1nbpp1/2p2n1p/3p4/3P1B2/2NBPN2/PPQ2PPP/R4RK1 b -' => {
			eco => 'D36t',
			# TRANSLATORS: D36t: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 Nbd7 8. Bd3 O-O 9. Nf3 Re8 10. O-O h6 11. Bf4
			variation => N__('QGD: Exchange, Main Line, 9. Nf3 Re8 10.O-O h6'),
			moves => {
			},
		},
		'r1bqr1k1/pp1nbpp1/2p2n1p/3p4/3P3B/2NBPN2/PPQ2PPP/R4RK1 b -' => {
			eco => 'D36t',
			# TRANSLATORS: D36t: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 Nbd7 8. Bd3 O-O 9. Nf3 Re8 10. O-O h6 11. Bh4
			variation => N__('QGD: Exchange, Main Line, 9. Nf3 Re8 10.O-O h6'),
			moves => {
			},
		},
		'r1bqrnk1/pp2bppp/2p2n2/3p2B1/3P4/2NBPN2/PPQ2PPP/R4RK1 w -' => {
			eco => 'D36u',
			# TRANSLATORS: D36u: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 Nbd7 8. Bd3 O-O 9. Nf3 Re8 10. O-O Nf8
			variation => N__('QGD: Exchange, Main Line, 9. Nf3 Re8 10.O-O Nf8'),
			moves => {
				'a1b1' => 1,
				'a1e1' => 1,
				'h2h3' => 1,
			},
		},
		'r1bqrnk1/pp2bppp/2p2n2/3p2B1/3P4/2NBPN2/PPQ2PPP/4RRK1 b -' => {
			eco => 'D36v',
			# TRANSLATORS: D36v: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 Nbd7 8. Bd3 O-O 9. Nf3 Re8 10. O-O Nf8 11. Rae1
			variation => N__('QGD: Exchange, Main Line, 9. Nf3 Re8 10.O-O Nf8 11.Rae1'),
			moves => {
			},
		},
		'r1bqrnk1/pp2bppp/2p2n2/3p2B1/3P4/2NBPN1P/PPQ2PP1/R4RK1 b -' => {
			eco => 'D36w',
			# TRANSLATORS: D36w: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 Nbd7 8. Bd3 O-O 9. Nf3 Re8 10. O-O Nf8 11. h3
			variation => N__('QGD: Exchange, Main Line, 9. Nf3 Re8 10.O-O Nf8 11. h3'),
			moves => {
				'g7g6' => 1,
			},
		},
		'r1bqrnk1/pp2bp1p/2p2np1/3p2B1/3P4/2NBPN1P/PPQ2PP1/R4RK1 w -' => {
			eco => 'D36x',
			# TRANSLATORS: D36x: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 Nbd7 8. Bd3 O-O 9. Nf3 Re8 10. O-O Nf8 11. h3 g6
			variation => N__('QGD: Exchange, Main Line, 9. Nf3 Re8 10.O-O Nf8 11. h3 g6'),
			moves => {
			},
		},
		'r1bqrnk1/pp2bppp/2p2n2/3p2B1/3P4/2NBPN2/PPQ2PPP/1R3RK1 b -' => {
			eco => 'D36y',
			# TRANSLATORS: D36y: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 Nbd7 8. Bd3 O-O 9. Nf3 Re8 10. O-O Nf8 11. Rab1
			variation => N__('QGD: Exchange, Main Line, 9. Nf3 Re8 10.O-O Nf8 11.Rab1'),
			moves => {
				'a7a5' => 1,
			},
		},
		'r1bqrnk1/1p2bppp/2p2n2/p2p2B1/3P4/2NBPN2/PPQ2PPP/1R3RK1 w -' => {
			eco => 'D36z',
			# TRANSLATORS: D36z: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. cxd5 exd5 5. Bg5 c6 6. Qc2 Be7 7. e3 Nbd7 8. Bd3 O-O 9. Nf3 Re8 10. O-O Nf8 11. Rab1 a5
			variation => N__('QGD: Exchange, Main Line, 9. Nf3 Re8 10.O-O Nf8 11.Rab1 a5'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p4/2PP4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D37a',
			# TRANSLATORS: D37a: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3
			variation => N__('QGD: 4. Nf3'),
			moves => {
				'b8d7' => 1,
				'c7c5' => 1,
				'c7c6' => 1,
				'f8b4' => 1,
				'f8e7' => 1,
			},
		},
		'r1bqkb1r/pppn1ppp/4pn2/3p4/2PP4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D37b',
			# TRANSLATORS: D37b: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Nbd7
			variation => N__('QGD: Westphalia without Bg5'),
			moves => {
				'c1f4' => 1,
			},
		},
		'r1bqkb1r/pppn1ppp/4pn2/3p4/2PP1B2/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D37c',
			# TRANSLATORS: D37c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Nbd7 5. Bf4
			variation => N__('QGD: Westphalia: 4. Nf3 Nbd7 5. Bf4'),
			moves => {
			},
		},
		'rnbqk2r/ppp1bppp/4pn2/3p4/2PP4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D37d',
			# TRANSLATORS: D37d: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Be7
			variation => N__('QGD: 4. Nf3 Be7'),
			moves => {
				'c1f4' => 1,
				'c4d5' => 1,
				'e2e3' => 1,
			},
		},
		'rnbqk2r/ppp1bppp/4pn2/3P4/3P4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D37d',
			# TRANSLATORS: D37d: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Be7 5. cxd5
			variation => N__('QGD: 4. Nf3 Be7'),
			moves => {
				'f6d5' => 1,
			},
		},
		'rnbqk2r/ppp1bppp/4p3/3n4/3P4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D37d',
			# TRANSLATORS: D37d: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Be7 5. cxd5 Nxd5
			variation => N__('QGD: 4. Nf3 Be7 5.cxd5 Nxd5'),
			moves => {
			},
		},
		'rnbqk2r/ppp1bppp/4pn2/3p4/2PP4/2N1PN2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'D37e',
			# TRANSLATORS: D37e: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Be7 5. e3
			variation => N__('QGD: 4. Nf3 Be7 5. e3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppp1bppp/4pn2/3p4/2PP4/2N1PN2/PP3PPP/R1BQKB1R w KQ' => {
			eco => 'D37f',
			# TRANSLATORS: D37f: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Be7 5. e3 O-O
			variation => N__('QGD: 4. Nf3 Be7 5. e3 O-O'),
			moves => {
				'b2b3' => 1,
				'f1d3' => 1,
			},
		},
		'rnbq1rk1/ppp1bppp/4pn2/3p4/2PP4/1PN1PN2/P4PPP/R1BQKB1R b KQ' => {
			eco => 'D37f',
			# TRANSLATORS: D37f: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Be7 5. e3 O-O 6. b3
			variation => N__('QGD: 4. Nf3 Be7 5. e3 O-O 6. b3'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1bppp/4pn2/3p4/2PP4/2NBPN2/PP3PPP/R1BQK2R b KQ' => {
			eco => 'D37g',
			# TRANSLATORS: D37g: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Be7 5. e3 O-O 6. Bd3
			variation => N__('QGD: 4. Nf3 Be7 5. e3 O-O 6. Bd3'),
			moves => {
			},
		},
		'rnbqk2r/ppp1bppp/4pn2/3p4/2PP1B2/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D37h',
			# TRANSLATORS: D37h: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Be7 5. Bf4
			variation => N__('QGD: Classical Variation'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppp1bppp/4pn2/3p4/2PP1B2/2N2N2/PP2PPPP/R2QKB1R w KQ' => {
			eco => 'D37i',
			# TRANSLATORS: D37i: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Be7 5. Bf4 O-O
			variation => N__('QGD: Classical, 5...O-O'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbq1rk1/ppp1bppp/4pn2/3p4/2PP1B2/2N1PN2/PP3PPP/R2QKB1R b KQ' => {
			eco => 'D37i',
			# TRANSLATORS: D37i: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Be7 5. Bf4 O-O 6. e3
			variation => N__('QGD: Classical, 5...O-O'),
			moves => {
				'b7b6' => 1,
				'b8d7' => 1,
				'c7c5' => 1,
				'c7c6' => 1,
			},
		},
		'r1bq1rk1/pppnbppp/4pn2/3p4/2PP1B2/2N1PN2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'D37j',
			# TRANSLATORS: D37j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Be7 5. Bf4 O-O 6. e3 Nbd7
			variation => N__('QGD: Classical, 5...O-O 6. e3 Nbd7'),
			moves => {
			},
		},
		'rnbq1rk1/p1p1bppp/1p2pn2/3p4/2PP1B2/2N1PN2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'D37k',
			# TRANSLATORS: D37k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Be7 5. Bf4 O-O 6. e3 b6
			variation => N__('QGD: Classical, 5...O-O 6. e3 b6'),
			moves => {
			},
		},
		'rnbq1rk1/pp2bppp/2p1pn2/3p4/2PP1B2/2N1PN2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'D37l',
			# TRANSLATORS: D37l: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Be7 5. Bf4 O-O 6. e3 c6
			variation => N__('QGD: Classical, 5...O-O 6. e3 c6'),
			moves => {
			},
		},
		'rnbq1rk1/pp2bppp/4pn2/2pp4/2PP1B2/2N1PN2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'D37m',
			# TRANSLATORS: D37m: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Be7 5. Bf4 O-O 6. e3 c5
			variation => N__('QGD: Classical, 5...O-O 6. e3 c5'),
			moves => {
				'd4c5' => 1,
			},
		},
		'rnbq1rk1/pp2bppp/4pn2/2Pp4/2P2B2/2N1PN2/PP3PPP/R2QKB1R b KQ' => {
			eco => 'D37n',
			# TRANSLATORS: D37n: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Be7 5. Bf4 O-O 6. e3 c5 7. dxc5
			variation => N__('QGD: Classical, 5...O-O 6. e3 c5 7.dxc5'),
			moves => {
				'e7c5' => 1,
			},
		},
		'rnbq1rk1/pp3ppp/4pn2/2bp4/2P2B2/2N1PN2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'D37o',
			# TRANSLATORS: D37o: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Be7 5. Bf4 O-O 6. e3 c5 7. dxc5 Bxc5
			variation => N__('QGD: Classical, 5...O-O 6. e3 c5 7.dxc5 Bxc5'),
			moves => {
				'a2a3' => 1,
				'c4d5' => 1,
				'd1c2' => 1,
			},
		},
		'rnbq1rk1/pp3ppp/4pn2/2bp4/2P2B2/P1N1PN2/1P3PPP/R2QKB1R b KQ' => {
			eco => 'D37p',
			# TRANSLATORS: D37p: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Be7 5. Bf4 O-O 6. e3 c5 7. dxc5 Bxc5 8. a3
			variation => N__('QGD: Classical, 5...O-O 6. e3 c5 7.dxc5 Bxc5 8. a3'),
			moves => {
			},
		},
		'rnbq1rk1/pp3ppp/4pn2/2bP4/5B2/2N1PN2/PP3PPP/R2QKB1R b KQ' => {
			eco => 'D37q',
			# TRANSLATORS: D37q: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Be7 5. Bf4 O-O 6. e3 c5 7. dxc5 Bxc5 8. cxd5
			variation => N__('QGD: Classical, 5...O-O 6. e3 c5 7.dxc5 Bxc5 8.cxd5'),
			moves => {
			},
		},
		'rnbq1rk1/pp3ppp/4pn2/2bp4/2P2B2/2N1PN2/PPQ2PPP/R3KB1R b KQ' => {
			eco => 'D37r',
			# TRANSLATORS: D37r: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Be7 5. Bf4 O-O 6. e3 c5 7. dxc5 Bxc5 8. Qc2
			variation => N__('QGD: Classical, 5...O-O 6. e3 c5 7.dxc5 Bxc5 8. Qc2'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bq1rk1/pp3ppp/2n1pn2/2bp4/2P2B2/2N1PN2/PPQ2PPP/R3KB1R w KQ' => {
			eco => 'D37r',
			# TRANSLATORS: D37r: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Be7 5. Bf4 O-O 6. e3 c5 7. dxc5 Bxc5 8. Qc2 Nc6
			variation => N__('QGD: Classical, 5...O-O 6. e3 c5 7.dxc5 Bxc5 8. Qc2'),
			moves => {
				'a2a3' => 1,
			},
		},
		'r1bq1rk1/pp3ppp/2n1pn2/2bp4/2P2B2/P1N1PN2/1PQ2PPP/R3KB1R b KQ' => {
			eco => 'D37s',
			# TRANSLATORS: D37s: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Be7 5. Bf4 O-O 6. e3 c5 7. dxc5 Bxc5 8. Qc2 Nc6 9. a3
			variation => N__('QGD: Classical, 5...O-O 6. e3 c5 7.dxc5 Bxc5 8. Qc2 Nc6 9. a3'),
			moves => {
				'd8a5' => 1,
			},
		},
		'r1b2rk1/pp3ppp/2n1pn2/q1bp4/2P2B2/P1N1PN2/1PQ2PPP/R3KB1R w KQ' => {
			eco => 'D37t',
			# TRANSLATORS: D37t: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Be7 5. Bf4 O-O 6. e3 c5 7. dxc5 Bxc5 8. Qc2 Nc6 9. a3 Qa5
			variation => N__('QGD: Classical, 5...O-O 6. e3 c5 7.dxc5 Bxc5 8. Qc2 Nc6 9. a3 Qa5'),
			moves => {
				'a1d1' => 1,
				'e1c1' => 1,
			},
		},
		'r1b2rk1/pp3ppp/2n1pn2/q1bp4/2P2B2/P1N1PN2/1PQ2PPP/3RKB1R b K' => {
			eco => 'D37u',
			# TRANSLATORS: D37u: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Be7 5. Bf4 O-O 6. e3 c5 7. dxc5 Bxc5 8. Qc2 Nc6 9. a3 Qa5 10. Rd1
			variation => N__('QGD: Classical, 5...O-O 6. e3 c5 7.dxc5 Bxc5 8. Qc2 Nc6 9. a3 Qa5 10. Rd1'),
			moves => {
			},
		},
		'r1b2rk1/pp3ppp/2n1pn2/q1bp4/2P2B2/P1N1PN2/1PQ2PPP/2KR1B1R b -' => {
			eco => 'D37v',
			# TRANSLATORS: D37v: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Be7 5. Bf4 O-O 6. e3 c5 7. dxc5 Bxc5 8. Qc2 Nc6 9. a3 Qa5 10. O-O-O
			variation => N__('QGD: Classical, 5...O-O 6. e3 c5 7.dxc5 Bxc5 8. Qc2 Nc6 9. a3 Qa5 10.O-O-O'),
			moves => {
			},
		},
		'rnbqk2r/ppp2ppp/4pn2/3p4/1bPP4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D38a',
			# TRANSLATORS: D38a: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4
			variation => N__('QGD: Ragozin'),
			moves => {
				'c1g5' => 1,
				'c4d5' => 1,
				'd1a4' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/4pn2/3p4/QbPP4/2N2N2/PP2PPPP/R1B1KB1R b KQkq' => {
			eco => 'D38b',
			# TRANSLATORS: D38b: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Qa4+
			variation => N__('QGD: Ragozin, 5. Qa4+'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2n1pn2/3p4/QbPP4/2N2N2/PP2PPPP/R1B1KB1R w KQkq' => {
			eco => 'D38b',
			# TRANSLATORS: D38b: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Qa4+ Nc6
			variation => N__('QGD: Ragozin, 5. Qa4+'),
			moves => {
				'c4d5' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2n1pn2/3P4/Qb1P4/2N2N2/PP2PPPP/R1B1KB1R b KQkq' => {
			eco => 'D38c',
			# TRANSLATORS: D38c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Qa4+ Nc6 6. cxd5
			variation => N__('QGD: Ragozin, 5. Qa4+ Nc6 6.cxd5'),
			moves => {
				'e6d5' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2n2n2/3p4/Qb1P4/2N2N2/PP2PPPP/R1B1KB1R w KQkq' => {
			eco => 'D38c',
			# TRANSLATORS: D38c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Qa4+ Nc6 6. cxd5 exd5
			variation => N__('QGD: Ragozin, 5. Qa4+ Nc6 6.cxd5'),
			moves => {
				'c1g5' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2n2n2/3p2B1/Qb1P4/2N2N2/PP2PPPP/R3KB1R b KQkq' => {
			eco => 'D38d',
			# TRANSLATORS: D38d: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Qa4+ Nc6 6. cxd5 exd5 7. Bg5
			variation => N__('QGD: Ragozin, 5. Qa4+ Nc6 6.cxd5 exd5 7. Bg5'),
			moves => {
			},
		},
		'rnbqk2r/ppp2ppp/4pn2/3P4/1b1P4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D38e',
			# TRANSLATORS: D38e: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. cxd5
			variation => N__('QGD: Ragozin, 5.cxd5'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/5n2/3p4/1b1P4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D38e',
			# TRANSLATORS: D38e: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. cxd5 exd5
			variation => N__('QGD: Ragozin, 5.cxd5'),
			moves => {
				'c1g5' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/5n2/3p2B1/1b1P4/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D38f',
			# TRANSLATORS: D38f: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. cxd5 exd5 6. Bg5
			variation => N__('QGD: Ragozin, 5.cxd5 exd5 6. Bg5'),
			moves => {
				'h7h6' => 1,
			},
		},
		'rnbqk2r/ppp2pp1/5n1p/3p2B1/1b1P4/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'D38g',
			# TRANSLATORS: D38g: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. cxd5 exd5 6. Bg5 h6
			variation => N__('QGD: Ragozin, 5.cxd5 exd5 6. Bg5 h6'),
			moves => {
				'g5h4' => 1,
			},
		},
		'rnbqk2r/ppp2pp1/5n1p/3p4/1b1P3B/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D38g',
			# TRANSLATORS: D38g: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. cxd5 exd5 6. Bg5 h6 7. Bh4
			variation => N__('QGD: Ragozin, 5.cxd5 exd5 6. Bg5 h6'),
			moves => {
			},
		},
		'rnbqk2r/ppp2ppp/4pn2/3p2B1/1bPP4/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D38h',
			# TRANSLATORS: D38h: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Bg5
			variation => N__('QGD: Ragozin, 5. Bg5'),
			moves => {
				'b8d7' => 1,
				'd5c4' => 1,
				'h7h6' => 1,
			},
		},
		'r1bqk2r/pppn1ppp/4pn2/3p2B1/1bPP4/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'D38i',
			# TRANSLATORS: D38i: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Bg5 Nbd7
			variation => N__('QGD: Ragozin, Westphalia Variation'),
			moves => {
				'c4d5' => 1,
			},
		},
		'r1bqk2r/pppn1ppp/4pn2/3P2B1/1b1P4/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D38i',
			# TRANSLATORS: D38i: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Bg5 Nbd7 6. cxd5
			variation => N__('QGD: Ragozin, Westphalia Variation'),
			moves => {
				'e6d5' => 1,
			},
		},
		'r1bqk2r/pppn1ppp/5n2/3p2B1/1b1P4/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'D38i',
			# TRANSLATORS: D38i: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Bg5 Nbd7 6. cxd5 exd5
			variation => N__('QGD: Ragozin, Westphalia Variation'),
			moves => {
				'd1c2' => 1,
				'e2e3' => 1,
			},
		},
		'r1bqk2r/pppn1ppp/5n2/3p2B1/1b1P4/2N2N2/PPQ1PPPP/R3KB1R b KQkq' => {
			eco => 'D38j',
			# TRANSLATORS: D38j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Bg5 Nbd7 6. cxd5 exd5 7. Qc2
			variation => N__('QGD: Ragozin, Westphalia, 7. Qc2'),
			moves => {
			},
		},
		'r1bqk2r/pppn1ppp/5n2/3p2B1/1b1P4/2N1PN2/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'D38k',
			# TRANSLATORS: D38k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Bg5 Nbd7 6. cxd5 exd5 7. e3
			variation => N__('QGD: Ragozin, Westphalia, 7. e3'),
			moves => {
			},
		},
		'rnbqk2r/ppp2pp1/4pn1p/3p2B1/1bPP4/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'D38l',
			# TRANSLATORS: D38l: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Bg5 h6
			variation => N__('QGD: Ragozin, 5. Bg5 h6'),
			moves => {
				'g5f6' => 1,
			},
		},
		'rnbqk2r/ppp2pp1/4pB1p/3p4/1bPP4/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D38l',
			# TRANSLATORS: D38l: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Bg5 h6 6. Bxf6
			variation => N__('QGD: Ragozin, 5. Bg5 h6'),
			moves => {
				'd8f6' => 1,
			},
		},
		'rnb1k2r/ppp2pp1/4pq1p/3p4/1bPP4/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'D38m',
			# TRANSLATORS: D38m: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Bg5 h6 6. Bxf6 Qxf6
			variation => N__('QGD: Ragozin, 5. Bg5 h6 6.Bxf6 Qxf6'),
			moves => {
				'c4d5' => 1,
				'e2e3' => 1,
			},
		},
		'rnb1k2r/ppp2pp1/4pq1p/3P4/1b1P4/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D38n',
			# TRANSLATORS: D38n: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Bg5 h6 6. Bxf6 Qxf6 7. cxd5
			variation => N__('QGD: Ragozin, 5. Bg5 h6 6.Bxf6 Qxf6 7.cxd5'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rnb1k2r/ppp2pp1/5q1p/3p4/1b1P4/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'D38n',
			# TRANSLATORS: D38n: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Bg5 h6 6. Bxf6 Qxf6 7. cxd5 exd5
			variation => N__('QGD: Ragozin, 5. Bg5 h6 6.Bxf6 Qxf6 7.cxd5'),
			moves => {
			},
		},
		'rnb1k2r/ppp2pp1/4pq1p/3p4/1bPP4/2N1PN2/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'D38o',
			# TRANSLATORS: D38o: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Bg5 h6 6. Bxf6 Qxf6 7. e3
			variation => N__('QGD: Ragozin, 5. Bg5 h6 6.Bxf6 Qxf6 7. e3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnb2rk1/ppp2pp1/4pq1p/3p4/1bPP4/2N1PN2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'D38o',
			# TRANSLATORS: D38o: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Bg5 h6 6. Bxf6 Qxf6 7. e3 O-O
			variation => N__('QGD: Ragozin, 5. Bg5 h6 6.Bxf6 Qxf6 7. e3'),
			moves => {
				'a1c1' => 1,
			},
		},
		'rnb2rk1/ppp2pp1/4pq1p/3p4/1bPP4/2N1PN2/PP3PPP/2RQKB1R b K' => {
			eco => 'D38p',
			# TRANSLATORS: D38p: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Bg5 h6 6. Bxf6 Qxf6 7. e3 O-O 8. Rc1
			variation => N__('QGD: Ragozin, 5. Bg5 h6 6.Bxf6 Qxf6 7. e3 O-O 8. Rc1'),
			moves => {
			},
		},
		'rnbqk2r/ppp2ppp/4pn2/6B1/1bpP4/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'D39a',
			# TRANSLATORS: D39a: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Bg5 dxc4
			variation => N__('QGD: Ragozin, Vienna Variation'),
			moves => {
				'd1a4' => 1,
				'e2e4' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/4pn2/6B1/QbpP4/2N2N2/PP2PPPP/R3KB1R b KQkq' => {
			eco => 'D39b',
			# TRANSLATORS: D39b: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Bg5 dxc4 6. Qa4+
			variation => N__('QGD: Ragozin, Vienna, 6. Qa4+'),
			moves => {
			},
		},
		'rnbqk2r/ppp2ppp/4pn2/6B1/1bpPP3/2N2N2/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'D39c',
			# TRANSLATORS: D39c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Bg5 dxc4 6. e4
			variation => N__('QGD: Ragozin, Vienna, 6. e4'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqk2r/pp3ppp/4pn2/2p3B1/1bpPP3/2N2N2/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'D39d',
			# TRANSLATORS: D39d: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Bg5 dxc4 6. e4 c5
			variation => N__('QGD: Ragozin, Vienna, 6. e4 c5'),
			moves => {
				'e4e5' => 1,
				'f1c4' => 1,
			},
		},
		'rnbqk2r/pp3ppp/4pn2/2p1P1B1/1bpP4/2N2N2/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'D39e',
			# TRANSLATORS: D39e: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Bg5 dxc4 6. e4 c5 7. e5
			variation => N__('QGD: Ragozin, Vienna, 6. e4 c5 7. e5'),
			moves => {
				'c5d4' => 1,
			},
		},
		'rnbqk2r/pp3ppp/4pn2/4P1B1/1bpp4/2N2N2/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'D39f',
			# TRANSLATORS: D39f: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Bg5 dxc4 6. e4 c5 7. e5 cxd4
			variation => N__('QGD: Ragozin, Vienna, 6. e4 c5 7. e5 cxd4'),
			moves => {
				'd1a4' => 1,
			},
		},
		'rnbqk2r/pp3ppp/4pn2/4P1B1/Qbpp4/2N2N2/PP3PPP/R3KB1R b KQkq' => {
			eco => 'D39f',
			# TRANSLATORS: D39f: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Bg5 dxc4 6. e4 c5 7. e5 cxd4 8. Qa4+
			variation => N__('QGD: Ragozin, Vienna, 6. e4 c5 7. e5 cxd4'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqk2r/pp3ppp/2n1pn2/4P1B1/Qbpp4/2N2N2/PP3PPP/R3KB1R w KQkq' => {
			eco => 'D39f',
			# TRANSLATORS: D39f: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Bg5 dxc4 6. e4 c5 7. e5 cxd4 8. Qa4+ Nc6
			variation => N__('QGD: Ragozin, Vienna, 6. e4 c5 7. e5 cxd4'),
			moves => {
				'e1c1' => 1,
			},
		},
		'r1bqk2r/pp3ppp/2n1pn2/4P1B1/Qbpp4/2N2N2/PP3PPP/2KR1B1R b kq' => {
			eco => 'D39g',
			# TRANSLATORS: D39g: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Bg5 dxc4 6. e4 c5 7. e5 cxd4 8. Qa4+ Nc6 9. O-O-O
			variation => N__('QGD: Ragozin, Vienna, 6. e4 c5 7. e5 cxd4 8. Qa4+ Nc6 9.O-O-O'),
			moves => {
			},
		},
		'rnbqk2r/pp3ppp/4pn2/2p3B1/1bBPP3/2N2N2/PP3PPP/R2QK2R b KQkq' => {
			eco => 'D39h',
			# TRANSLATORS: D39h: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Bg5 dxc4 6. e4 c5 7. Bxc4
			variation => N__('QGD: Ragozin, Vienna, 6. e4 c5 7.Bxc4'),
			moves => {
				'c5d4' => 1,
			},
		},
		'rnbqk2r/pp3ppp/4pn2/6B1/1bBpP3/2N2N2/PP3PPP/R2QK2R w KQkq' => {
			eco => 'D39h',
			# TRANSLATORS: D39h: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Bg5 dxc4 6. e4 c5 7. Bxc4 cxd4
			variation => N__('QGD: Ragozin, Vienna, 6. e4 c5 7.Bxc4'),
			moves => {
				'f3d4' => 1,
			},
		},
		'rnbqk2r/pp3ppp/4pn2/6B1/1bBNP3/2N5/PP3PPP/R2QK2R b KQkq' => {
			eco => 'D39h',
			# TRANSLATORS: D39h: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Bg5 dxc4 6. e4 c5 7. Bxc4 cxd4 8. Nxd4
			variation => N__('QGD: Ragozin, Vienna, 6. e4 c5 7.Bxc4'),
			moves => {
				'b4c3' => 1,
				'd8a5' => 1,
			},
		},
		'rnb1k2r/pp3ppp/4pn2/q5B1/1bBNP3/2N5/PP3PPP/R2QK2R w KQkq' => {
			eco => 'D39i',
			# TRANSLATORS: D39i: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Bg5 dxc4 6. e4 c5 7. Bxc4 cxd4 8. Nxd4 Qa5
			variation => N__('QGD: Ragozin, Vienna, 6. e4 c5 7.Bxc4, 8... Qa5'),
			moves => {
			},
		},
		'rnbqk2r/pp3ppp/4pn2/6B1/2BNP3/2b5/PP3PPP/R2QK2R w KQkq' => {
			eco => 'D39j',
			# TRANSLATORS: D39j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Bg5 dxc4 6. e4 c5 7. Bxc4 cxd4 8. Nxd4 Bxc3+
			variation => N__('QGD: Ragozin, Vienna, 6. e4 c5 7.Bxc4, 8...Bxc3+'),
			moves => {
				'b2c3' => 1,
			},
		},
		'rnbqk2r/pp3ppp/4pn2/6B1/2BNP3/2P5/P4PPP/R2QK2R b KQkq' => {
			eco => 'D39j',
			# TRANSLATORS: D39j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Bg5 dxc4 6. e4 c5 7. Bxc4 cxd4 8. Nxd4 Bxc3+ 9. bxc3
			variation => N__('QGD: Ragozin, Vienna, 6. e4 c5 7.Bxc4, 8...Bxc3+'),
			moves => {
				'd8a5' => 1,
			},
		},
		'rnb1k2r/pp3ppp/4pn2/q5B1/2BNP3/2P5/P4PPP/R2QK2R w KQkq' => {
			eco => 'D39j',
			# TRANSLATORS: D39j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Bg5 dxc4 6. e4 c5 7. Bxc4 cxd4 8. Nxd4 Bxc3+ 9. bxc3 Qa5
			variation => N__('QGD: Ragozin, Vienna, 6. e4 c5 7.Bxc4, 8...Bxc3+'),
			moves => {
				'c4b5' => 1,
			},
		},
		'rnb1k2r/pp3ppp/4pn2/qB4B1/3NP3/2P5/P4PPP/R2QK2R b KQkq' => {
			eco => 'D39k',
			# TRANSLATORS: D39k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 Bb4 5. Bg5 dxc4 6. e4 c5 7. Bxc4 cxd4 8. Nxd4 Bxc3+ 9. bxc3 Qa5 10. Bb5+
			variation => N__('QGD: Ragozin, Vienna, 6. e4 c5 7.Bxc4, 8...Bxc3+, 10. Bb5+'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2pp4/2PP4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D40a',
			# TRANSLATORS: D40a: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5
			variation => N__('QGD: Semi-Tarrasch'),
			moves => {
				'c4d5' => 1,
				'e2e3' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2pp4/2PP4/2N1PN2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'D40a',
			# TRANSLATORS: D40a: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. e3
			variation => N__('QGD: Semi-Tarrasch, 5. e3'),
			moves => {
				'a7a6' => 1,
				'b8c6' => 1,
				'c5d4' => 1,
				'f8e7' => 1,
			},
		},
		'rnbqk2r/pp2bppp/4pn2/2pp4/2PP4/2N1PN2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'D40b',
			# TRANSLATORS: D40b: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. e3 Be7
			variation => N__('QGD: Semi-Tarrasch, 5. e3 Be7'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/3p4/2Pp4/2N1PN2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'D40c',
			# TRANSLATORS: D40c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. e3 cxd4
			variation => N__('QGD: Semi-Tarrasch, 5. e3 cxd4'),
			moves => {
			},
		},
		'rnbqkb1r/1p3ppp/p3pn2/2pp4/2PP4/2N1PN2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'D40d',
			# TRANSLATORS: D40d: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. e3 a6
			variation => N__('QGD: Semi-Tarrasch, 5. e3 a6'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rnbqkb1r/1p3ppp/p3pn2/2pP4/3P4/2N1PN2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'D40e',
			# TRANSLATORS: D40e: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. e3 a6 6. cxd5
			variation => N__('QGD: Semi-Tarrasch, 5. e3 a6 6.cxd5'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rnbqkb1r/1p3ppp/p4n2/2pp4/3P4/2N1PN2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'D40e',
			# TRANSLATORS: D40e: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. e3 a6 6. cxd5 exd5
			variation => N__('QGD: Semi-Tarrasch, 5. e3 a6 6.cxd5 exd5'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2n1pn2/2pp4/2PP4/2N1PN2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'D40f',
			# TRANSLATORS: D40f: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. e3 Nc6
			variation => N__('QGD: Semi-Tarrasch, 5. e3 Nc6'),
			moves => {
				'a2a3' => 1,
				'f1d3' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2n1pn2/2pp4/2PP4/2NBPN2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'D40g',
			# TRANSLATORS: D40g: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. e3 Nc6 6. Bd3
			variation => N__('QGD: Semi-Tarrasch, 5. e3 Nc6 6. Bd3'),
			moves => {
				'f8d6' => 1,
			},
		},
		'r1bqk2r/pp3ppp/2nbpn2/2pp4/2PP4/2NBPN2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D40g',
			# TRANSLATORS: D40g: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. e3 Nc6 6. Bd3 Bd6
			variation => N__('QGD: Semi-Tarrasch, 5. e3 Nc6 6. Bd3'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqk2r/pp3ppp/2nbpn2/2pp4/2PP4/2NBPN2/PP3PPP/R1BQ1RK1 b kq' => {
			eco => 'D40g',
			# TRANSLATORS: D40g: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. e3 Nc6 6. Bd3 Bd6 7. O-O
			variation => N__('QGD: Semi-Tarrasch, 5. e3 Nc6 6. Bd3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp3ppp/2nbpn2/2pp4/2PP4/2NBPN2/PP3PPP/R1BQ1RK1 w -' => {
			eco => 'D40h',
			# TRANSLATORS: D40h: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. e3 Nc6 6. Bd3 Bd6 7. O-O O-O
			variation => N__('QGD: Semi-Tarrasch, Symmetrical Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2n1pn2/2pp4/2PP4/P1N1PN2/1P3PPP/R1BQKB1R b KQkq' => {
			eco => 'D40i',
			# TRANSLATORS: D40i: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. e3 Nc6 6. a3
			variation => N__('QGD: Semi-Tarrasch, 5. e3 Nc6 6. a3'),
			moves => {
				'a7a6' => 1,
				'c5d4' => 1,
				'd5c4' => 1,
				'f6e4' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2n1p3/2pp4/2PPn3/P1N1PN2/1P3PPP/R1BQKB1R w KQkq' => {
			eco => 'D40j',
			# TRANSLATORS: D40j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. e3 Nc6 6. a3 Ne4
			variation => N__('QGD: Semi-Tarrasch, 5. e3 Nc6 6. a3 Ne4'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2n1pn2/2p5/2pP4/P1N1PN2/1P3PPP/R1BQKB1R w KQkq' => {
			eco => 'D40k',
			# TRANSLATORS: D40k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. e3 Nc6 6. a3 dxc4
			variation => N__('QGD: Semi-Tarrasch, 5. e3 Nc6 6. a3 dxc4'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2n1pn2/3p4/2Pp4/P1N1PN2/1P3PPP/R1BQKB1R w KQkq' => {
			eco => 'D40l',
			# TRANSLATORS: D40l: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. e3 Nc6 6. a3 cxd4
			variation => N__('QGD: Semi-Tarrasch, 5. e3 Nc6 6. a3 cxd4'),
			moves => {
				'e3d4' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2n1pn2/3p4/2PP4/P1N2N2/1P3PPP/R1BQKB1R b KQkq' => {
			eco => 'D40l',
			# TRANSLATORS: D40l: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. e3 Nc6 6. a3 cxd4 7. exd4
			variation => N__('QGD: Semi-Tarrasch, 5. e3 Nc6 6. a3 cxd4'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2n1pn2/3p4/2PP4/P1N2N2/1P3PPP/R1BQKB1R w KQkq' => {
			eco => 'D40l',
			# TRANSLATORS: D40l: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. e3 Nc6 6. a3 cxd4 7. exd4 Be7
			variation => N__('QGD: Semi-Tarrasch, 5. e3 Nc6 6. a3 cxd4 7.exd4 Be7'),
			moves => {
				'c4c5' => 1,
				'f1d3' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2n1pn2/2Pp4/3P4/P1N2N2/1P3PPP/R1BQKB1R b KQkq' => {
			eco => 'D40m',
			# TRANSLATORS: D40m: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. e3 Nc6 6. a3 cxd4 7. exd4 Be7 8. c5
			variation => N__('QGD: Semi-Tarrasch, 5. e3 Nc6 6. a3 cxd4 7.exd4 Be7 8. c5'),
			moves => {
			},
		},
		'r1bqk2r/pp2bppp/2n1pn2/3p4/2PP4/P1NB1N2/1P3PPP/R1BQK2R b KQkq' => {
			eco => 'D40n',
			# TRANSLATORS: D40n: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. e3 Nc6 6. a3 cxd4 7. exd4 Be7 8. Bd3
			variation => N__('QGD: Semi-Tarrasch, 5. e3 Nc6 6. a3 cxd4 7.exd4 Be7 8. Bd3'),
			moves => {
			},
		},
		'r1bqkb1r/1p3ppp/p1n1pn2/2pp4/2PP4/P1N1PN2/1P3PPP/R1BQKB1R w KQkq' => {
			eco => 'D40o',
			# TRANSLATORS: D40o: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. e3 Nc6 6. a3 a6
			variation => N__('QGD: Semi-Tarrasch, 5. e3 Nc6 6. a3 a6'),
			moves => {
				'b2b3' => 1,
				'd4c5' => 1,
			},
		},
		'r1bqkb1r/1p3ppp/p1n1pn2/2pp4/2PP4/PPN1PN2/5PPP/R1BQKB1R b KQkq' => {
			eco => 'D40p',
			# TRANSLATORS: D40p: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. e3 Nc6 6. a3 a6 7. b3
			variation => N__('QGD: Semi-Tarrasch, 5. e3 Nc6 6. a3 a6 7. b3'),
			moves => {
			},
		},
		'r1bqkb1r/1p3ppp/p1n1pn2/2Pp4/2P5/P1N1PN2/1P3PPP/R1BQKB1R b KQkq' => {
			eco => 'D40q',
			# TRANSLATORS: D40q: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. e3 Nc6 6. a3 a6 7. dxc5
			variation => N__('QGD: Semi-Tarrasch, 5. e3 Nc6 6. a3 a6 7.dxc5'),
			moves => {
				'f8c5' => 1,
			},
		},
		'r1bqk2r/1p3ppp/p1n1pn2/2bp4/2P5/P1N1PN2/1P3PPP/R1BQKB1R w KQkq' => {
			eco => 'D40q',
			# TRANSLATORS: D40q: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. e3 Nc6 6. a3 a6 7. dxc5 Bxc5
			variation => N__('QGD: Semi-Tarrasch, 5. e3 Nc6 6. a3 a6 7.dxc5 Bxc5'),
			moves => {
				'b2b4' => 1,
			},
		},
		'r1bqk2r/1p3ppp/p1n1pn2/2bp4/1PP5/P1N1PN2/5PPP/R1BQKB1R b KQkq' => {
			eco => 'D40q',
			# TRANSLATORS: D40q: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. e3 Nc6 6. a3 a6 7. dxc5 Bxc5 8. b4
			variation => N__('QGD: Semi-Tarrasch, 5. e3 Nc6 6. a3 a6 7.dxc5 Bxc5'),
			moves => {
				'c5a7' => 1,
			},
		},
		'r1bqk2r/bp3ppp/p1n1pn2/3p4/1PP5/P1N1PN2/5PPP/R1BQKB1R w KQkq' => {
			eco => 'D40r',
			# TRANSLATORS: D40r: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. e3 Nc6 6. a3 a6 7. dxc5 Bxc5 8. b4 Ba7
			variation => N__('QGD: Semi-Tarrasch, 5. e3 Nc6 6. a3 a6 7.dxc5 Bxc5 8. b4 Ba7'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2pP4/3P4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D41a',
			# TRANSLATORS: D41a: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5
			variation => N__('QGD: Semi-Tarrasch, 5.cxd5'),
			moves => {
				'c5d4' => 1,
				'f6d5' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/3P4/3p4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D41b',
			# TRANSLATORS: D41b: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 cxd4
			variation => N__('QGD: Semi-Tarrasch, Keres Counterattack'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/4p3/2pn4/3P4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D41c',
			# TRANSLATORS: D41c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5
			variation => N__('QGD: Semi-Tarrasch, 5.cxd5 Nxd5'),
			moves => {
				'e2e3' => 1,
				'e2e4' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4p3/2pn4/3P4/2N2NP1/PP2PP1P/R1BQKB1R b KQkq' => {
			eco => 'D41c',
			# TRANSLATORS: D41c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. g3
			variation => N__('QGD: Semi-Tarrasch, 6. g3'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2n1p3/2pn4/3P4/2N2NP1/PP2PP1P/R1BQKB1R w KQkq' => {
			eco => 'D41c',
			# TRANSLATORS: D41c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. g3 Nc6
			variation => N__('QGD: Semi-Tarrasch, 6. g3 Nc6'),
			moves => {
				'f1g2' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2n1p3/2pn4/3P4/2N2NP1/PP2PPBP/R1BQK2R b KQkq' => {
			eco => 'D41c',
			# TRANSLATORS: D41c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. g3 Nc6 7. Bg2
			variation => N__('QGD: Semi-Tarrasch, 6. g3 Nc6'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2n1p3/2pn4/3P4/2N2NP1/PP2PPBP/R1BQK2R w KQkq' => {
			eco => 'D41c',
			# TRANSLATORS: D41c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. g3 Nc6 7. Bg2 Be7
			variation => N__('QGD: Semi-Tarrasch, 6. g3 Nc6 7. Bg2 Be7'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2n1p3/2pn4/3P4/2N2NP1/PP2PPBP/R1BQ1RK1 b kq' => {
			eco => 'D41c',
			# TRANSLATORS: D41c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. g3 Nc6 7. Bg2 Be7 8. O-O
			variation => N__('QGD: Semi-Tarrasch, 6. g3 Nc6 7. Bg2 Be7'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2n1p3/2pn4/3P4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'D41d',
			# TRANSLATORS: D41d: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. g3 Nc6 7. Bg2 Be7 8. O-O O-O
			variation => N__('QGD: Semi-Tarrasch, 6. g3, Main Line'),
			moves => {
				'c3d5' => 1,
				'e2e4' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2n1p3/2pn4/3PP3/2N2NP1/PP3PBP/R1BQ1RK1 b -' => {
			eco => 'D41e',
			# TRANSLATORS: D41e: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. g3 Nc6 7. Bg2 Be7 8. O-O O-O 9. e4
			variation => N__('QGD: Semi-Tarrasch, 6. g3, Main Line, 9. e4'),
			moves => {
				'd5b4' => 1,
				'd5b6' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/1nn1p3/2p5/3PP3/2N2NP1/PP3PBP/R1BQ1RK1 w -' => {
			eco => 'D41f',
			# TRANSLATORS: D41f: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. g3 Nc6 7. Bg2 Be7 8. O-O O-O 9. e4 Nb6
			variation => N__('QGD: Semi-Tarrasch, 6. g3, Main Line, 9. e4 Nb6'),
			moves => {
			},
		},
		'r1bq1rk1/pp2bppp/2n1p3/2p5/1n1PP3/2N2NP1/PP3PBP/R1BQ1RK1 w -' => {
			eco => 'D41g',
			# TRANSLATORS: D41g: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. g3 Nc6 7. Bg2 Be7 8. O-O O-O 9. e4 Ndb4
			variation => N__('QGD: Semi-Tarrasch, 6. g3, Main Line, 9. e4 Ndb4'),
			moves => {
			},
		},
		'r1bq1rk1/pp2bppp/2n1p3/2pN4/3P4/5NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'D41h',
			# TRANSLATORS: D41h: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. g3 Nc6 7. Bg2 Be7 8. O-O O-O 9. Nxd5
			variation => N__('QGD: Semi-Tarrasch, 6. g3, Main Line, 9.Nxd5'),
			moves => {
				'e6d5' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2n5/2pp4/3P4/5NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'D41h',
			# TRANSLATORS: D41h: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. g3 Nc6 7. Bg2 Be7 8. O-O O-O 9. Nxd5 exd5
			variation => N__('QGD: Semi-Tarrasch, 6. g3, Main Line, 9.Nxd5'),
			moves => {
				'd4c5' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2n5/2Pp4/8/5NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'D41h',
			# TRANSLATORS: D41h: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. g3 Nc6 7. Bg2 Be7 8. O-O O-O 9. Nxd5 exd5 10. dxc5
			variation => N__('QGD: Semi-Tarrasch, 6. g3, Main Line, 9.Nxd5'),
			moves => {
				'e7c5' => 1,
			},
		},
		'r1bq1rk1/pp3ppp/2n5/2bp4/8/5NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'D41i',
			# TRANSLATORS: D41i: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. g3 Nc6 7. Bg2 Be7 8. O-O O-O 9. Nxd5 exd5 10. dxc5 Bxc5
			variation => N__('QGD: Semi-Tarrasch, 6. g3, Main Line, 9.Nxd5 exd5 10.dxc5 Bxc5'),
			moves => {
				'c1g5' => 1,
			},
		},
		'r1bq1rk1/pp3ppp/2n5/2bp2B1/8/5NP1/PP2PPBP/R2Q1RK1 b -' => {
			eco => 'D41j',
			# TRANSLATORS: D41j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. g3 Nc6 7. Bg2 Be7 8. O-O O-O 9. Nxd5 exd5 10. dxc5 Bxc5 11. Bg5
			variation => N__('QGD: Semi-Tarrasch, 6. g3, Main Line, 9.Nxd5 exd5 10.dxc5 Bxc5 11. Bg5'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/4p3/2pn4/3PP3/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'D41k',
			# TRANSLATORS: D41k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e4
			variation => N__('QGD: Semi-Tarrasch, 6. e4'),
			moves => {
				'd5c3' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4p3/2p5/3PP3/2n2N2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'D41k',
			# TRANSLATORS: D41k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e4 Nxc3
			variation => N__('QGD: Semi-Tarrasch, 6. e4 Nxc3'),
			moves => {
				'b2c3' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4p3/2p5/3PP3/2P2N2/P4PPP/R1BQKB1R b KQkq' => {
			eco => 'D41k',
			# TRANSLATORS: D41k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e4 Nxc3 7. bxc3
			variation => N__('QGD: Semi-Tarrasch, 6. e4 Nxc3'),
			moves => {
				'c5d4' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4p3/8/3pP3/2P2N2/P4PPP/R1BQKB1R w KQkq' => {
			eco => 'D41k',
			# TRANSLATORS: D41k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e4 Nxc3 7. bxc3 cxd4
			variation => N__('QGD: Semi-Tarrasch, 6. e4 Nxc3'),
			moves => {
				'c3d4' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4p3/8/3PP3/5N2/P4PPP/R1BQKB1R b KQkq' => {
			eco => 'D41k',
			# TRANSLATORS: D41k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e4 Nxc3 7. bxc3 cxd4 8. cxd4
			variation => N__('QGD: Semi-Tarrasch, 6. e4, 8.cxd4'),
			moves => {
				'b8c6' => 1,
				'f8b4' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2n1p3/8/3PP3/5N2/P4PPP/R1BQKB1R w KQkq' => {
			eco => 'D41l',
			# TRANSLATORS: D41l: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e4 Nxc3 7. bxc3 cxd4 8. cxd4 Nc6
			variation => N__('QGD: Semi-Tarrasch, 6. e4, 8.cxd4 Nc6'),
			moves => {
			},
		},
		'rnbqk2r/pp3ppp/4p3/8/1b1PP3/5N2/P4PPP/R1BQKB1R w KQkq' => {
			eco => 'D41m',
			# TRANSLATORS: D41m: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e4 Nxc3 7. bxc3 cxd4 8. cxd4 Bb4+
			variation => N__('QGD: Semi-Tarrasch, 6. e4, 8.cxd4 Bb4+'),
			moves => {
				'c1d2' => 1,
			},
		},
		'rnbqk2r/pp3ppp/4p3/8/1b1PP3/5N2/P2B1PPP/R2QKB1R b KQkq' => {
			eco => 'D41m',
			# TRANSLATORS: D41m: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e4 Nxc3 7. bxc3 cxd4 8. cxd4 Bb4+ 9. Bd2
			variation => N__('QGD: Semi-Tarrasch, 6. e4, 8.cxd4 Bb4+'),
			moves => {
				'b4d2' => 1,
				'd8a5' => 1,
			},
		},
		'rnbqk2r/pp3ppp/4p3/8/3PP3/5N2/P2b1PPP/R2QKB1R w KQkq' => {
			eco => 'D41m',
			# TRANSLATORS: D41m: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e4 Nxc3 7. bxc3 cxd4 8. cxd4 Bb4+ 9. Bd2 Bxd2+
			variation => N__('QGD: Semi-Tarrasch, 6. e4, 8.cxd4 Bb4+'),
			moves => {
				'd1d2' => 1,
			},
		},
		'rnbqk2r/pp3ppp/4p3/8/3PP3/5N2/P2Q1PPP/R3KB1R b KQkq' => {
			eco => 'D41m',
			# TRANSLATORS: D41m: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e4 Nxc3 7. bxc3 cxd4 8. cxd4 Bb4+ 9. Bd2 Bxd2+ 10. Qxd2
			variation => N__('QGD: Semi-Tarrasch, 6. e4, 8.cxd4 Bb4+'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/pp3ppp/4p3/8/3PP3/5N2/P2Q1PPP/R3KB1R w KQ' => {
			eco => 'D41m',
			# TRANSLATORS: D41m: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e4 Nxc3 7. bxc3 cxd4 8. cxd4 Bb4+ 9. Bd2 Bxd2+ 10. Qxd2 O-O
			variation => N__('QGD: Semi-Tarrasch, 6. e4, 8.cxd4 Bb4+'),
			moves => {
				'f1b5' => 1,
				'f1c4' => 1,
			},
		},
		'rnbq1rk1/pp3ppp/4p3/1B6/3PP3/5N2/P2Q1PPP/R3K2R b KQ' => {
			eco => 'D41m',
			# TRANSLATORS: D41m: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e4 Nxc3 7. bxc3 cxd4 8. cxd4 Bb4+ 9. Bd2 Bxd2+ 10. Qxd2 O-O 11. Bb5
			variation => N__('QGD: Semi-Tarrasch, 6. e4, Kmoch Variation'),
			moves => {
			},
		},
		'rnb1k2r/pp3ppp/4p3/q7/1b1PP3/5N2/P2B1PPP/R2QKB1R w KQkq' => {
			eco => 'D41m',
			# TRANSLATORS: D41m: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e4 Nxc3 7. bxc3 cxd4 8. cxd4 Bb4+ 9. Bd2 Qa5
			variation => N__('QGD: Semi-Tarrasch, 6. e4, San Sebastian Variation'),
			moves => {
			},
		},
		'rnbq1rk1/pp3ppp/4p3/8/2BPP3/5N2/P2Q1PPP/R3K2R b KQ' => {
			eco => 'D41n',
			# TRANSLATORS: D41n: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e4 Nxc3 7. bxc3 cxd4 8. cxd4 Bb4+ 9. Bd2 Bxd2+ 10. Qxd2 O-O 11. Bc4
			variation => N__('QGD: Semi-Tarrasch, 6. e4, Main Line'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bq1rk1/pp3ppp/2n1p3/8/2BPP3/5N2/P2Q1PPP/R3K2R w KQ' => {
			eco => 'D41n',
			# TRANSLATORS: D41n: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e4 Nxc3 7. bxc3 cxd4 8. cxd4 Bb4+ 9. Bd2 Bxd2+ 10. Qxd2 O-O 11. Bc4 Nc6
			variation => N__('QGD: Semi-Tarrasch, 6. e4, Main Line'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bq1rk1/pp3ppp/2n1p3/8/2BPP3/5N2/P2Q1PPP/R4RK1 b -' => {
			eco => 'D41n',
			# TRANSLATORS: D41n: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e4 Nxc3 7. bxc3 cxd4 8. cxd4 Bb4+ 9. Bd2 Bxd2+ 10. Qxd2 O-O 11. Bc4 Nc6 12. O-O
			variation => N__('QGD: Semi-Tarrasch, 6. e4, Main Line'),
			moves => {
				'b7b6' => 1,
			},
		},
		'r1bq1rk1/p4ppp/1pn1p3/8/2BPP3/5N2/P2Q1PPP/R4RK1 w -' => {
			eco => 'D41o',
			# TRANSLATORS: D41o: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e4 Nxc3 7. bxc3 cxd4 8. cxd4 Bb4+ 9. Bd2 Bxd2+ 10. Qxd2 O-O 11. Bc4 Nc6 12. O-O b6
			variation => N__('QGD: Semi-Tarrasch, 6. e4, Main Line, 12... b6'),
			moves => {
				'a1d1' => 1,
			},
		},
		'r1bq1rk1/p4ppp/1pn1p3/8/2BPP3/5N2/P2Q1PPP/3R1RK1 b -' => {
			eco => 'D41o',
			# TRANSLATORS: D41o: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e4 Nxc3 7. bxc3 cxd4 8. cxd4 Bb4+ 9. Bd2 Bxd2+ 10. Qxd2 O-O 11. Bc4 Nc6 12. O-O b6 13. Rad1
			variation => N__('QGD: Semi-Tarrasch, 6. e4, Main Line, 12... b6'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/4p3/2pn4/3P4/2N1PN2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'D41p',
			# TRANSLATORS: D41p: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3
			variation => N__('QGD: Semi-Tarrasch, 6. e3'),
			moves => {
				'b8c6' => 1,
				'c5d4' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4p3/3n4/3p4/2N1PN2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'D41p',
			# TRANSLATORS: D41p: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 cxd4
			variation => N__('QGD: Semi-Tarrasch, 6. e3 cxd4'),
			moves => {
				'e3d4' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4p3/3n4/3P4/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'D41p',
			# TRANSLATORS: D41p: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 cxd4 7. exd4
			variation => N__('QGD: Semi-Tarrasch, 6. e3 cxd4 7.exd4'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2n1p3/2pn4/3P4/2N1PN2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'D41q',
			# TRANSLATORS: D41q: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6
			variation => N__('QGD: Semi-Tarrasch, 6. e3 Nc6'),
			moves => {
				'f1c4' => 1,
				'f1d3' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2n1p3/2pn4/2BP4/2N1PN2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'D41r',
			# TRANSLATORS: D41r: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bc4
			variation => N__('QGD: Semi-Tarrasch, 6. e3 Nc6 7. Bc4'),
			moves => {
				'c5d4' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2n1p3/3n4/2Bp4/2N1PN2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D41r',
			# TRANSLATORS: D41r: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bc4 cxd4
			variation => N__('QGD: Semi-Tarrasch, 6. e3 Nc6 7. Bc4'),
			moves => {
				'e3d4' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2n1p3/3n4/2BP4/2N2N2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'D41r',
			# TRANSLATORS: D41r: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bc4 cxd4 8. exd4
			variation => N__('QGD: Semi-Tarrasch, 6. e3 Nc6 7. Bc4'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2n1p3/3n4/2BP4/2N2N2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D41r',
			# TRANSLATORS: D41r: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bc4 cxd4 8. exd4 Be7
			variation => N__('QGD: Semi-Tarrasch, 6. e3 Nc6 7. Bc4'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2n1p3/3n4/2BP4/2N2N2/PP3PPP/R1BQ1RK1 b kq' => {
			eco => 'D41r',
			# TRANSLATORS: D41r: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bc4 cxd4 8. exd4 Be7 9. O-O
			variation => N__('QGD: Semi-Tarrasch, 6. e3 Nc6 7. Bc4'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2n1p3/3n4/2BP4/2N2N2/PP3PPP/R1BQ1RK1 w -' => {
			eco => 'D41s',
			# TRANSLATORS: D41s: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bc4 cxd4 8. exd4 Be7 9. O-O O-O
			variation => N__('QGD: Semi-Tarrasch, 6. e3 Nc6 7. Bc4'),
			moves => {
				'f1e1' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2n1p3/3n4/2BP4/2N2N2/PP3PPP/R1BQR1K1 b -' => {
			eco => 'D41s',
			# TRANSLATORS: D41s: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bc4 cxd4 8. exd4 Be7 9. O-O O-O 10. Re1
			variation => N__('QGD: Semi-Tarrasch, 6. e3 Nc6 7. Bc4'),
			moves => {
				'd5c3' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2n1p3/8/2BP4/2n2N2/PP3PPP/R1BQR1K1 w -' => {
			eco => 'D41s',
			# TRANSLATORS: D41s: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bc4 cxd4 8. exd4 Be7 9. O-O O-O 10. Re1 Nxc3
			variation => N__('QGD: Semi-Tarrasch, 6. e3 Nc6 7. Bc4'),
			moves => {
				'b2c3' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2n1p3/8/2BP4/2P2N2/P4PPP/R1BQR1K1 b -' => {
			eco => 'D41t',
			# TRANSLATORS: D41t: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bc4 cxd4 8. exd4 Be7 9. O-O O-O 10. Re1 Nxc3 11. bxc3
			variation => N__('QGD: Semi-Tarrasch, 7. Bc4 Main Line'),
			moves => {
				'b7b6' => 1,
			},
		},
		'r1bq1rk1/p3bppp/1pn1p3/8/2BP4/2P2N2/P4PPP/R1BQR1K1 w -' => {
			eco => 'D41t',
			# TRANSLATORS: D41t: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bc4 cxd4 8. exd4 Be7 9. O-O O-O 10. Re1 Nxc3 11. bxc3 b6
			variation => N__('QGD: Semi-Tarrasch, 7. Bc4 Main Line'),
			moves => {
				'c4d3' => 1,
			},
		},
		'r1bq1rk1/p3bppp/1pn1p3/8/3P4/2PB1N2/P4PPP/R1BQR1K1 b -' => {
			eco => 'D41t',
			# TRANSLATORS: D41t: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bc4 cxd4 8. exd4 Be7 9. O-O O-O 10. Re1 Nxc3 11. bxc3 b6 12. Bd3
			variation => N__('QGD: Semi-Tarrasch, 7. Bc4 Main Line'),
			moves => {
				'c8b7' => 1,
			},
		},
		'r2q1rk1/pb2bppp/1pn1p3/8/3P4/2PB1N2/P4PPP/R1BQR1K1 w -' => {
			eco => 'D41t',
			# TRANSLATORS: D41t: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bc4 cxd4 8. exd4 Be7 9. O-O O-O 10. Re1 Nxc3 11. bxc3 b6 12. Bd3 Bb7
			variation => N__('QGD: Semi-Tarrasch, 7. Bc4 Main Line'),
			moves => {
				'd1c2' => 1,
				'h2h4' => 1,
			},
		},
		'r2q1rk1/pb2bppp/1pn1p3/8/3P4/2PB1N2/P1Q2PPP/R1B1R1K1 b -' => {
			eco => 'D41u',
			# TRANSLATORS: D41u: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bc4 cxd4 8. exd4 Be7 9. O-O O-O 10. Re1 Nxc3 11. bxc3 b6 12. Bd3 Bb7 13. Qc2
			variation => N__('QGD: Semi-Tarrasch, 7. Bc4 Main Line, 13. Qc2'),
			moves => {
			},
		},
		'r2q1rk1/pb2bppp/1pn1p3/8/3P3P/2PB1N2/P4PP1/R1BQR1K1 b -' => {
			eco => 'D41v',
			# TRANSLATORS: D41v: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bc4 cxd4 8. exd4 Be7 9. O-O O-O 10. Re1 Nxc3 11. bxc3 b6 12. Bd3 Bb7 13. h4
			variation => N__('QGD: Semi-Tarrasch, 7. Bc4 Main Line, 13. h4'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2n1p3/2pn4/3P4/2NBPN2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'D42a',
			# TRANSLATORS: D42a: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bd3
			variation => N__('QGD: Semi-Tarrasch, 6. e3 Nc6 7. Bd3'),
			moves => {
				'c5d4' => 1,
				'f8e7' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2n1p3/2pn4/3P4/2NBPN2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D42b',
			# TRANSLATORS: D42b: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bd3 Be7
			variation => N__('QGD: Semi-Tarrasch, 6. e3 Nc6 7. Bd3 Be7'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2n1p3/2pn4/3P4/2NBPN2/PP3PPP/R1BQ1RK1 b kq' => {
			eco => 'D42b',
			# TRANSLATORS: D42b: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bd3 Be7 8. O-O
			variation => N__('QGD: Semi-Tarrasch, 6. e3 Nc6 7. Bd3 Be7'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2n1p3/2pn4/3P4/2NBPN2/PP3PPP/R1BQ1RK1 w -' => {
			eco => 'D42c',
			# TRANSLATORS: D42c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bd3 Be7 8. O-O O-O
			variation => N__('QGD: Semi-Tarrasch, 6. e3 Nc6 7. Bd3 Be7 8.O-O O-O'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2n1p3/3n4/3p4/2NBPN2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D42d',
			# TRANSLATORS: D42d: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bd3 cxd4
			variation => N__('QGD: Semi-Tarrasch, 6. e3 Nc6 7. Bd3 cxd4'),
			moves => {
				'e3d4' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2n1p3/3n4/3P4/2NB1N2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'D42d',
			# TRANSLATORS: D42d: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bd3 cxd4 8. exd4
			variation => N__('QGD: Semi-Tarrasch, 6. e3 Nc6 7. Bd3 cxd4'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2n1p3/3n4/3P4/2NB1N2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D42e',
			# TRANSLATORS: D42e: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bd3 cxd4 8. exd4 Be7
			variation => N__('QGD: Semi-Tarrasch, 7. Bd3 Main Line'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2n1p3/3n4/3P4/2NB1N2/PP3PPP/R1BQ1RK1 b kq' => {
			eco => 'D42e',
			# TRANSLATORS: D42e: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bd3 cxd4 8. exd4 Be7 9. O-O
			variation => N__('QGD: Semi-Tarrasch, 7. Bd3 Main Line'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2n1p3/3n4/3P4/2NB1N2/PP3PPP/R1BQ1RK1 w -' => {
			eco => 'D42f',
			# TRANSLATORS: D42f: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bd3 cxd4 8. exd4 Be7 9. O-O O-O
			variation => N__('QGD: Semi-Tarrasch, 7. Bd3 Main Line, 9.O-O O-O'),
			moves => {
				'a2a3' => 1,
				'f1e1' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2n1p3/3n4/3P4/P1NB1N2/1P3PPP/R1BQ1RK1 b -' => {
			eco => 'D42g',
			# TRANSLATORS: D42g: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bd3 cxd4 8. exd4 Be7 9. O-O O-O 10. a3
			variation => N__('QGD: Semi-Tarrasch, 7. Bd3 Main Line, 10. a3'),
			moves => {
				'd5f6' => 1,
				'e7f6' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2n1pn2/8/3P4/P1NB1N2/1P3PPP/R1BQ1RK1 w -' => {
			eco => 'D42h',
			# TRANSLATORS: D42h: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bd3 cxd4 8. exd4 Be7 9. O-O O-O 10. a3 Nf6
			variation => N__('QGD: Semi-Tarrasch, 7. Bd3 Main Line, 10. a3 Nf6'),
			moves => {
			},
		},
		'r1bq1rk1/pp3ppp/2n1pb2/3n4/3P4/P1NB1N2/1P3PPP/R1BQ1RK1 w -' => {
			eco => 'D42i',
			# TRANSLATORS: D42i: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bd3 cxd4 8. exd4 Be7 9. O-O O-O 10. a3 Bf6
			variation => N__('QGD: Semi-Tarrasch, 7. Bd3 Main Line, 10. a3 Bf6'),
			moves => {
			},
		},
		'r1bq1rk1/pp2bppp/2n1p3/3n4/3P4/2NB1N2/PP3PPP/R1BQR1K1 b -' => {
			eco => 'D42j',
			# TRANSLATORS: D42j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bd3 cxd4 8. exd4 Be7 9. O-O O-O 10. Re1
			variation => N__('QGD: Semi-Tarrasch, 7. Bd3 Main Line, 10. Re1'),
			moves => {
				'c6b4' => 1,
				'd5f6' => 1,
				'e7f6' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/4p3/3n4/1n1P4/2NB1N2/PP3PPP/R1BQR1K1 w -' => {
			eco => 'D42k',
			# TRANSLATORS: D42k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bd3 cxd4 8. exd4 Be7 9. O-O O-O 10. Re1 Ncb4
			variation => N__('QGD: Semi-Tarrasch, 7. Bd3 Main Line, 10. Re1 Ncb4'),
			moves => {
			},
		},
		'r1bq1rk1/pp2bppp/2n1pn2/8/3P4/2NB1N2/PP3PPP/R1BQR1K1 w -' => {
			eco => 'D42l',
			# TRANSLATORS: D42l: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bd3 cxd4 8. exd4 Be7 9. O-O O-O 10. Re1 Nf6
			variation => N__('QGD: Semi-Tarrasch, 7. Bd3 Main Line, 10. Re1 Nf6'),
			moves => {
				'a2a3' => 1,
				'c1g5' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2n1pn2/6B1/3P4/2NB1N2/PP3PPP/R2QR1K1 b -' => {
			eco => 'D42l',
			# TRANSLATORS: D42l: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bd3 cxd4 8. exd4 Be7 9. O-O O-O 10. Re1 Nf6 11. Bg5
			variation => N__('QGD: Semi-Tarrasch, 7. Bd3 Main Line, 10. Re1 Nf6 11. Bg5'),
			moves => {
			},
		},
		'r1bq1rk1/pp2bppp/2n1pn2/8/3P4/P1NB1N2/1P3PPP/R1BQR1K1 b -' => {
			eco => 'D42m',
			# TRANSLATORS: D42m: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bd3 cxd4 8. exd4 Be7 9. O-O O-O 10. Re1 Nf6 11. a3
			variation => N__('QGD: Semi-Tarrasch, 7. Bd3 Main Line, 10. Re1 Nf6 11. a3'),
			moves => {
				'b7b6' => 1,
			},
		},
		'r1bq1rk1/p3bppp/1pn1pn2/8/3P4/P1NB1N2/1P3PPP/R1BQR1K1 w -' => {
			eco => 'D42m',
			# TRANSLATORS: D42m: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bd3 cxd4 8. exd4 Be7 9. O-O O-O 10. Re1 Nf6 11. a3 b6
			variation => N__('QGD: Semi-Tarrasch, 7. Bd3 Main Line, 10. Re1 Nf6 11. a3 b6'),
			moves => {
				'c1e3' => 1,
				'c1g5' => 1,
				'd3c2' => 1,
			},
		},
		'r1bq1rk1/p3bppp/1pn1pn2/8/3P4/P1NBBN2/1P3PPP/R2QR1K1 b -' => {
			eco => 'D42m',
			# TRANSLATORS: D42m: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bd3 cxd4 8. exd4 Be7 9. O-O O-O 10. Re1 Nf6 11. a3 b6 12. Be3
			variation => N__('QGD: Semi-Tarrasch, 7. Bd3 Main Line, 10. Re1 Nf6 11. a3 b6 12. Be3'),
			moves => {
			},
		},
		'r1bq1rk1/p3bppp/1pn1pn2/6B1/3P4/P1NB1N2/1P3PPP/R2QR1K1 b -' => {
			eco => 'D42n',
			# TRANSLATORS: D42n: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bd3 cxd4 8. exd4 Be7 9. O-O O-O 10. Re1 Nf6 11. a3 b6 12. Bg5
			variation => N__('QGD: Semi-Tarrasch, 7. Bd3 Main Line, 10. Re1 Nf6 11. a3 b6 12. Bg5'),
			moves => {
			},
		},
		'r1bq1rk1/p3bppp/1pn1pn2/8/3P4/P1N2N2/1PB2PPP/R1BQR1K1 b -' => {
			eco => 'D42o',
			# TRANSLATORS: D42o: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bd3 cxd4 8. exd4 Be7 9. O-O O-O 10. Re1 Nf6 11. a3 b6 12. Bc2
			variation => N__('QGD: Semi-Tarrasch, 7. Bd3 Main Line, 10. Re1 Nf6 11. a3 b6 12. Bc2'),
			moves => {
			},
		},
		'r1bq1rk1/pp3ppp/2n1pb2/3n4/3P4/2NB1N2/PP3PPP/R1BQR1K1 w -' => {
			eco => 'D42p',
			# TRANSLATORS: D42p: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bd3 cxd4 8. exd4 Be7 9. O-O O-O 10. Re1 Bf6
			variation => N__('QGD: Semi-Tarrasch, 7. Bd3 Main Line, 10. Re1 Bf6'),
			moves => {
				'd3e4' => 1,
			},
		},
		'r1bq1rk1/pp3ppp/2n1pb2/3n4/3PB3/2N2N2/PP3PPP/R1BQR1K1 b -' => {
			eco => 'D42p',
			# TRANSLATORS: D42p: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bd3 cxd4 8. exd4 Be7 9. O-O O-O 10. Re1 Bf6 11. Be4
			variation => N__('QGD: Semi-Tarrasch, 7. Bd3 Main Line, 10. Re1 Bf6 11. Be4'),
			moves => {
				'c6e7' => 1,
			},
		},
		'r1bq1rk1/pp2nppp/4pb2/3n4/3PB3/2N2N2/PP3PPP/R1BQR1K1 w -' => {
			eco => 'D42q',
			# TRANSLATORS: D42q: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bd3 cxd4 8. exd4 Be7 9. O-O O-O 10. Re1 Bf6 11. Be4 Nce7
			variation => N__('QGD: Semi-Tarrasch, 7. Bd3 Main Line, 10. Re1 Bf6 11. Be4 Nce7'),
			moves => {
				'f3e5' => 1,
			},
		},
		'r1bq1rk1/pp2nppp/4pb2/3nN3/3PB3/2N5/PP3PPP/R1BQR1K1 b -' => {
			eco => 'D42r',
			# TRANSLATORS: D42r: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c5 5. cxd5 Nxd5 6. e3 Nc6 7. Bd3 cxd4 8. exd4 Be7 9. O-O O-O 10. Re1 Bf6 11. Be4 Nce7 12. Ne5
			variation => N__('QGD: Semi-Tarrasch, 7. Bd3 Main Line, 10. Re1 Bf6 11. Be4 Nce7 12. Ne5'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/2p1pn2/3p4/2PP4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D43a',
			# TRANSLATORS: D43a: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6
			variation => N__('Semi-Slav'),
			moves => {
				'c1g5' => 1,
				'd1b3' => 1,
				'd1d3' => 1,
				'e2e3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/2p1pn2/3p4/2PP4/2N2NP1/PP2PP1P/R1BQKB1R b KQkq' => {
			eco => 'D43b',
			# TRANSLATORS: D43b: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. g3
			variation => N__('Semi-Slav: 5. g3'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/2p1pn2/3p4/2PP4/2NQ1N2/PP2PPPP/R1B1KB1R b KQkq' => {
			eco => 'D43c',
			# TRANSLATORS: D43c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Qd3
			variation => N__('Semi-Slav: 5. Qd3'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/2p1pn2/3p4/2PP4/1QN2N2/PP2PPPP/R1B1KB1R b KQkq' => {
			eco => 'D43d',
			# TRANSLATORS: D43d: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Qb3
			variation => N__('Semi-Slav: 5. Qb3'),
			moves => {
				'd5c4' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/2p1pn2/8/2pP4/1QN2N2/PP2PPPP/R1B1KB1R w KQkq' => {
			eco => 'D43d',
			# TRANSLATORS: D43d: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Qb3 dxc4
			variation => N__('Semi-Slav: 5. Qb3'),
			moves => {
				'b3c4' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/2p1pn2/8/2QP4/2N2N2/PP2PPPP/R1B1KB1R b KQkq' => {
			eco => 'D43e',
			# TRANSLATORS: D43e: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Qb3 dxc4 6. Qxc4
			variation => N__('Semi-Slav: 5. Qb3 dxc4'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/2p1pn2/3p2B1/2PP4/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D43f',
			# TRANSLATORS: D43f: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5
			variation => N__('Semi-Slav: Botvinnik (Anti-Meran)'),
			moves => {
				'd5c4' => 1,
				'f8e7' => 1,
				'h7h6' => 1,
			},
		},
		'rnbqk2r/pp2bppp/2p1pn2/3p2B1/2PP4/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'D43f',
			# TRANSLATORS: D43f: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 Be7
			variation => N__('Semi-Slav: Botvinnik, 5... Be7'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbqk2r/pp2bppp/2p1pn2/3p2B1/2PP4/2N1PN2/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'D43g',
			# TRANSLATORS: D43g: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 Be7 6. e3
			variation => N__('Semi-Slav: Botvinnik, 5... Be7 6. e3'),
			moves => {
				'b8d7' => 1,
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/pp2bppp/2p1pn2/3p2B1/2PP4/2N1PN2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'D43h',
			# TRANSLATORS: D43h: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 Be7 6. e3 O-O
			variation => N__('Semi-Slav: Botvinnik, 5... Be7 6. e3 O-O'),
			moves => {
			},
		},
		'r1bqk2r/pp1nbppp/2p1pn2/3p2B1/2PP4/2N1PN2/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'D43i',
			# TRANSLATORS: D43i: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 Be7 6. e3 Nbd7
			variation => N__('Semi-Slav: Botvinnik, 5... Be7 6. e3 Nbd7'),
			moves => {
				'f1d3' => 1,
			},
		},
		'r1bqk2r/pp1nbppp/2p1pn2/3p2B1/2PP4/2NBPN2/PP3PPP/R2QK2R b KQkq' => {
			eco => 'D43j',
			# TRANSLATORS: D43j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 Be7 6. e3 Nbd7 7. Bd3
			variation => N__('Semi-Slav: Botvinnik, 5... Be7 6. e3 Nbd7 7. Bd3'),
			moves => {
			},
		},
		'rnbqkb1r/pp3pp1/2p1pn1p/3p2B1/2PP4/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'D43k',
			# TRANSLATORS: D43k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 h6
			variation => N__('Semi-Slav: Moscow Variation'),
			moves => {
				'g5f6' => 1,
				'g5h4' => 1,
			},
		},
		'rnbqkb1r/pp3pp1/2p1pn1p/3p4/2PP3B/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D43k',
			# TRANSLATORS: D43k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 h6 6. Bh4
			variation => N__('Semi-Slav: Moscow, 6. Bh4 Gambit'),
			moves => {
				'd5c4' => 1,
				'f8e7' => 1,
			},
		},
		'rnbqkb1r/pp3pp1/2p1pn1p/8/2pP3B/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'D43k',
			# TRANSLATORS: D43k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 h6 6. Bh4 dxc4
			variation => N__('Semi-Slav: Moscow, 6. Bh4 Gambit Accepted'),
			moves => {
				'e2e4' => 1,
			},
		},
		'rnbqk2r/pp2bpp1/2p1pn1p/3p4/2PP3B/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'D43k',
			# TRANSLATORS: D43k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 h6 6. Bh4 Be7
			variation => N__('Semi-Slav: Moscow, 6. Bh4 Be7'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbqk2r/pp2bpp1/2p1pn1p/3p4/2PP3B/2N1PN2/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'D43k',
			# TRANSLATORS: D43k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 h6 6. Bh4 Be7 7. e3
			variation => N__('Semi-Slav: Moscow, 6. Bh4 Be7'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/pp2bpp1/2p1pn1p/3p4/2PP3B/2N1PN2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'D43k',
			# TRANSLATORS: D43k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 h6 6. Bh4 Be7 7. e3 O-O
			variation => N__('Semi-Slav: Moscow, 6. Bh4 Be7 7. e3 O-O'),
			moves => {
			},
		},
		'rnbqkb1r/pp3pp1/2p1pn1p/8/2pPP2B/2N2N2/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'D43l',
			# TRANSLATORS: D43l: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 h6 6. Bh4 dxc4 7. e4
			variation => N__('Semi-Slav: Moscow, 6. Bh4 Gambit, 7. e4'),
			moves => {
				'g7g5' => 1,
			},
		},
		'rnbqkb1r/pp3p2/2p1pn1p/6p1/2pPP2B/2N2N2/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'D43l',
			# TRANSLATORS: D43l: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 h6 6. Bh4 dxc4 7. e4 g5
			variation => N__('Semi-Slav: Moscow, 6. Bh4 Gambit, 7. e4'),
			moves => {
				'h4g3' => 1,
			},
		},
		'rnbqkb1r/pp3p2/2p1pn1p/6p1/2pPP3/2N2NB1/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'D43l',
			# TRANSLATORS: D43l: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 h6 6. Bh4 dxc4 7. e4 g5 8. Bg3
			variation => N__('Semi-Slav: Moscow, 6. Bh4 Gambit, 7. e4'),
			moves => {
				'b7b5' => 1,
			},
		},
		'rnbqkb1r/p4p2/2p1pn1p/1p4p1/2pPP3/2N2NB1/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'D43l',
			# TRANSLATORS: D43l: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 h6 6. Bh4 dxc4 7. e4 g5 8. Bg3 b5
			variation => N__('Semi-Slav: Moscow, 6. Bh4 Gambit, 7. e4'),
			moves => {
				'f1e2' => 1,
			},
		},
		'rnbqkb1r/p4p2/2p1pn1p/1p4p1/2pPP3/2N2NB1/PP2BPPP/R2QK2R b KQkq' => {
			eco => 'D43m',
			# TRANSLATORS: D43m: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 h6 6. Bh4 dxc4 7. e4 g5 8. Bg3 b5 9. Be2
			variation => N__('Semi-Slav: Moscow, 6. Bh4 Gambit, Main Line'),
			moves => {
				'c8b7' => 1,
			},
		},
		'rn1qkb1r/pb3p2/2p1pn1p/1p4p1/2pPP3/2N2NB1/PP2BPPP/R2QK2R w KQkq' => {
			eco => 'D43n',
			# TRANSLATORS: D43n: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 h6 6. Bh4 dxc4 7. e4 g5 8. Bg3 b5 9. Be2 Bb7
			variation => N__('Semi-Slav: Moscow, 6. Bh4 Gambit, Main Line, 9... Bb7'),
			moves => {
			},
		},
		'rnbqkb1r/pp3pp1/2p1pB1p/3p4/2PP4/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D43o',
			# TRANSLATORS: D43o: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 h6 6. Bxf6
			variation => N__('Semi-Slav: Moscow, 6.Bxf6'),
			moves => {
				'd8f6' => 1,
			},
		},
		'rnb1kb1r/pp3pp1/2p1pq1p/3p4/2PP4/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'D43o',
			# TRANSLATORS: D43o: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 h6 6. Bxf6 Qxf6
			variation => N__('Semi-Slav: Moscow, 6.Bxf6'),
			moves => {
				'd1b3' => 1,
				'd1c2' => 1,
				'e2e3' => 1,
				'g2g3' => 1,
			},
		},
		'rnb1kb1r/pp3pp1/2p1pq1p/3p4/2PP4/2N2NP1/PP2PP1P/R2QKB1R b KQkq' => {
			eco => 'D43p',
			# TRANSLATORS: D43p: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 h6 6. Bxf6 Qxf6 7. g3
			variation => N__('Semi-Slav: Moscow, 7. g3'),
			moves => {
			},
		},
		'rnb1kb1r/pp3pp1/2p1pq1p/3p4/2PP4/1QN2N2/PP2PPPP/R3KB1R b KQkq' => {
			eco => 'D43q',
			# TRANSLATORS: D43q: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 h6 6. Bxf6 Qxf6 7. Qb3
			variation => N__('Semi-Slav: Moscow, Hastings Variation'),
			moves => {
			},
		},
		'rnb1kb1r/pp3pp1/2p1pq1p/3p4/2PP4/2N2N2/PPQ1PPPP/R3KB1R b KQkq' => {
			eco => 'D43r',
			# TRANSLATORS: D43r: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 h6 6. Bxf6 Qxf6 7. Qc2
			variation => N__('Semi-Slav: Moscow, 7. Qc2'),
			moves => {
			},
		},
		'rnb1kb1r/pp3pp1/2p1pq1p/3p4/2PP4/2N1PN2/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'D43s',
			# TRANSLATORS: D43s: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 h6 6. Bxf6 Qxf6 7. e3
			variation => N__('Semi-Slav: Moscow, 7. e3'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r1b1kb1r/pp1n1pp1/2p1pq1p/3p4/2PP4/2N1PN2/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'D43t',
			# TRANSLATORS: D43t: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 h6 6. Bxf6 Qxf6 7. e3 Nd7
			variation => N__('Semi-Slav: Moscow, 7. e3 Nd7'),
			moves => {
				'f1d3' => 1,
			},
		},
		'r1b1kb1r/pp1n1pp1/2p1pq1p/3p4/2PP4/2NBPN2/PP3PPP/R2QK2R b KQkq' => {
			eco => 'D43u',
			# TRANSLATORS: D43u: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 h6 6. Bxf6 Qxf6 7. e3 Nd7 8. Bd3
			variation => N__('Semi-Slav: Moscow, 7. e3 Nd7 8. Bd3'),
			moves => {
				'd5c4' => 1,
			},
		},
		'r1b1kb1r/pp1n1pp1/2p1pq1p/8/2pP4/2NBPN2/PP3PPP/R2QK2R w KQkq' => {
			eco => 'D43v',
			# TRANSLATORS: D43v: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 h6 6. Bxf6 Qxf6 7. e3 Nd7 8. Bd3 dxc4
			variation => N__('Semi-Slav: Moscow, 7. e3 Nd7 8. Bd3 dxc4'),
			moves => {
				'd3c4' => 1,
			},
		},
		'r1b1kb1r/pp1n1pp1/2p1pq1p/8/2BP4/2N1PN2/PP3PPP/R2QK2R b KQkq' => {
			eco => 'D43v',
			# TRANSLATORS: D43v: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 h6 6. Bxf6 Qxf6 7. e3 Nd7 8. Bd3 dxc4 9. Bxc4
			variation => N__('Semi-Slav: Moscow, 7. e3 Nd7 8. Bd3 dxc4'),
			moves => {
				'g7g6' => 1,
			},
		},
		'r1b1kb1r/pp1n1p2/2p1pqpp/8/2BP4/2N1PN2/PP3PPP/R2QK2R w KQkq' => {
			eco => 'D43v',
			# TRANSLATORS: D43v: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 h6 6. Bxf6 Qxf6 7. e3 Nd7 8. Bd3 dxc4 9. Bxc4 g6
			variation => N__('Semi-Slav: Moscow, Main Line'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1b1kb1r/pp1n1p2/2p1pqpp/8/2BP4/2N1PN2/PP3PPP/R2Q1RK1 b kq' => {
			eco => 'D43v',
			# TRANSLATORS: D43v: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 h6 6. Bxf6 Qxf6 7. e3 Nd7 8. Bd3 dxc4 9. Bxc4 g6 10. O-O
			variation => N__('Semi-Slav: Moscow, Main Line'),
			moves => {
				'f8g7' => 1,
			},
		},
		'r1b1k2r/pp1n1pb1/2p1pqpp/8/2BP4/2N1PN2/PP3PPP/R2Q1RK1 w kq' => {
			eco => 'D43v',
			# TRANSLATORS: D43v: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 h6 6. Bxf6 Qxf6 7. e3 Nd7 8. Bd3 dxc4 9. Bxc4 g6 10. O-O Bg7
			variation => N__('Semi-Slav: Moscow, Main Line'),
			moves => {
				'a1c1' => 1,
				'b2b4' => 1,
			},
		},
		'r1b1k2r/pp1n1pb1/2p1pqpp/8/1PBP4/2N1PN2/P4PPP/R2Q1RK1 b kq' => {
			eco => 'D43w',
			# TRANSLATORS: D43w: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 h6 6. Bxf6 Qxf6 7. e3 Nd7 8. Bd3 dxc4 9. Bxc4 g6 10. O-O Bg7 11. b4
			variation => N__('Semi-Slav: Moscow, Main Line, 11. b4'),
			moves => {
			},
		},
		'r1b1k2r/pp1n1pb1/2p1pqpp/8/2BP4/2N1PN2/PP3PPP/2RQ1RK1 b kq' => {
			eco => 'D43x',
			# TRANSLATORS: D43x: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 h6 6. Bxf6 Qxf6 7. e3 Nd7 8. Bd3 dxc4 9. Bxc4 g6 10. O-O Bg7 11. Rc1
			variation => N__('Semi-Slav: Moscow, Main Line, 11. Rc1'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/2p1pn2/6B1/2pP4/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'D44a',
			# TRANSLATORS: D44a: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 dxc4
			variation => N__('Semi-Slav: Botvinnik Accepted'),
			moves => {
				'a2a4' => 1,
				'e2e4' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/2p1pn2/6B1/P1pP4/2N2N2/1P2PPPP/R2QKB1R b KQkq' => {
			eco => 'D44b',
			# TRANSLATORS: D44b: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 dxc4 6. a4
			variation => N__('Semi-Slav: Botvinnik, 6. a4'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/2p1pn2/6B1/2pPP3/2N2N2/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'D44c',
			# TRANSLATORS: D44c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 dxc4 6. e4
			variation => N__('Semi-Slav: Botvinnik, 6. e4'),
			moves => {
				'b7b5' => 1,
			},
		},
		'rnbqkb1r/p4ppp/2p1pn2/1p4B1/2pPP3/2N2N2/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'D44c',
			# TRANSLATORS: D44c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 dxc4 6. e4 b5
			variation => N__('Semi-Slav: Botvinnik, 6. e4'),
			moves => {
				'a2a4' => 1,
				'e4e5' => 1,
			},
		},
		'rnbqkb1r/p4ppp/2p1pn2/1p4B1/P1pPP3/2N2N2/1P3PPP/R2QKB1R b KQkq' => {
			eco => 'D44d',
			# TRANSLATORS: D44d: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 dxc4 6. e4 b5 7. a4
			variation => N__('Semi-Slav: Botvinnik, 7. a4'),
			moves => {
			},
		},
		'rnbqkb1r/p4ppp/2p1pn2/1p2P1B1/2pP4/2N2N2/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'D44e',
			# TRANSLATORS: D44e: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 dxc4 6. e4 b5 7. e5
			variation => N__('Semi-Slav: Botvinnik, 7. e5'),
			moves => {
				'h7h6' => 1,
			},
		},
		'rnbqkb1r/p4pp1/2p1pn1p/1p2P1B1/2pP4/2N2N2/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'D44e',
			# TRANSLATORS: D44e: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 dxc4 6. e4 b5 7. e5 h6
			variation => N__('Semi-Slav: Botvinnik, 7. e5'),
			moves => {
				'g5h4' => 1,
			},
		},
		'rnbqkb1r/p4pp1/2p1pn1p/1p2P3/2pP3B/2N2N2/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'D44e',
			# TRANSLATORS: D44e: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 dxc4 6. e4 b5 7. e5 h6 8. Bh4
			variation => N__('Semi-Slav: Botvinnik, 7. e5'),
			moves => {
				'g7g5' => 1,
			},
		},
		'rnbqkb1r/p4p2/2p1pn1p/1p2P1p1/2pP3B/2N2N2/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'D44e',
			# TRANSLATORS: D44e: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 dxc4 6. e4 b5 7. e5 h6 8. Bh4 g5
			variation => N__('Semi-Slav: Botvinnik, 7. e5'),
			moves => {
				'e5f6' => 1,
				'f3g5' => 1,
			},
		},
		'rnbqkb1r/p4p2/2p1pP1p/1p4p1/2pP3B/2N2N2/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'D44f',
			# TRANSLATORS: D44f: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 dxc4 6. e4 b5 7. e5 h6 8. Bh4 g5 9. exf6
			variation => N__('Semi-Slav: Botvinnik, 9.exf6'),
			moves => {
				'g5h4' => 1,
			},
		},
		'rnbqkb1r/p4p2/2p1pP1p/1p6/2pP3p/2N2N2/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'D44f',
			# TRANSLATORS: D44f: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 dxc4 6. e4 b5 7. e5 h6 8. Bh4 g5 9. exf6 gxh4
			variation => N__('Semi-Slav: Botvinnik, 9.exf6'),
			moves => {
				'f3e5' => 1,
			},
		},
		'rnbqkb1r/p4p2/2p1pP1p/1p2N3/2pP3p/2N5/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'D44g',
			# TRANSLATORS: D44g: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 dxc4 6. e4 b5 7. e5 h6 8. Bh4 g5 9. exf6 gxh4 10. Ne5
			variation => N__('Semi-Slav: Botvinnik, Ekstrom Variation'),
			moves => {
			},
		},
		'rnbqkb1r/p4p2/2p1pn1p/1p2P1N1/2pP3B/2N5/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'D44h',
			# TRANSLATORS: D44h: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 dxc4 6. e4 b5 7. e5 h6 8. Bh4 g5 9. Nxg5
			variation => N__('Semi-Slav: Botvinnik, 9.Nxg5'),
			moves => {
				'f6d5' => 1,
				'h6g5' => 1,
			},
		},
		'rnbqkb1r/p4p2/2p1p2p/1p1nP1N1/2pP3B/2N5/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'D44i',
			# TRANSLATORS: D44i: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 dxc4 6. e4 b5 7. e5 h6 8. Bh4 g5 9. Nxg5 Nd5
			variation => N__('Semi-Slav: Botvinnik, Alatortsev Variation'),
			moves => {
			},
		},
		'rnbqkb1r/p4p2/2p1pn2/1p2P1p1/2pP3B/2N5/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'D44j',
			# TRANSLATORS: D44j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 dxc4 6. e4 b5 7. e5 h6 8. Bh4 g5 9. Nxg5 hxg5
			variation => N__('Semi-Slav: Botvinnik, 9.Nxg5'),
			moves => {
				'h4g5' => 1,
			},
		},
		'rnbqkb1r/p4p2/2p1pn2/1p2P1B1/2pP4/2N5/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'D44j',
			# TRANSLATORS: D44j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 dxc4 6. e4 b5 7. e5 h6 8. Bh4 g5 9. Nxg5 hxg5 10. Bxg5
			variation => N__('Semi-Slav: Botvinnik, 9.Nxg5'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r1bqkb1r/p2n1p2/2p1pn2/1p2P1B1/2pP4/2N5/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'D44j',
			# TRANSLATORS: D44j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 dxc4 6. e4 b5 7. e5 h6 8. Bh4 g5 9. Nxg5 hxg5 10. Bxg5 Nbd7
			variation => N__('Semi-Slav: Botvinnik, 9.Nxg5'),
			moves => {
				'd1f3' => 1,
				'e5f6' => 1,
				'g2g3' => 1,
			},
		},
		'r1bqkb1r/p2n1p2/2p1pn2/1p2P1B1/2pP4/2N3P1/PP3P1P/R2QKB1R b KQkq' => {
			eco => 'D44k',
			# TRANSLATORS: D44k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 dxc4 6. e4 b5 7. e5 h6 8. Bh4 g5 9. Nxg5 hxg5 10. Bxg5 Nbd7 11. g3
			variation => N__('Semi-Slav: Botvinnik, Lilienthal Variation'),
			moves => {
				'c8b7' => 1,
				'd8a5' => 1,
			},
		},
		'r1b1kb1r/p2n1p2/2p1pn2/qp2P1B1/2pP4/2N3P1/PP3P1P/R2QKB1R w KQkq' => {
			eco => 'D44l',
			# TRANSLATORS: D44l: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 dxc4 6. e4 b5 7. e5 h6 8. Bh4 g5 9. Nxg5 hxg5 10. Bxg5 Nbd7 11. g3 Qa5
			variation => N__('Semi-Slav: Botvinnik, Lilienthal, 11... Qa5'),
			moves => {
			},
		},
		'r2qkb1r/pb1n1p2/2p1pn2/1p2P1B1/2pP4/2N3P1/PP3P1P/R2QKB1R w KQkq' => {
			eco => 'D44m',
			# TRANSLATORS: D44m: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 dxc4 6. e4 b5 7. e5 h6 8. Bh4 g5 9. Nxg5 hxg5 10. Bxg5 Nbd7 11. g3 Bb7
			variation => N__('Semi-Slav: Botvinnik, Lilienthal, 11... Bb7'),
			moves => {
			},
		},
		'r1bqkb1r/p2n1p2/2p1pn2/1p2P1B1/2pP4/2N2Q2/PP3PPP/R3KB1R b KQkq' => {
			eco => 'D44n',
			# TRANSLATORS: D44n: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 dxc4 6. e4 b5 7. e5 h6 8. Bh4 g5 9. Nxg5 hxg5 10. Bxg5 Nbd7 11. Qf3
			variation => N__('Semi-Slav: Botvinnik, Szabo Variation'),
			moves => {
			},
		},
		'r1bqkb1r/p2n1p2/2p1pP2/1p4B1/2pP4/2N5/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'D44o',
			# TRANSLATORS: D44o: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 dxc4 6. e4 b5 7. e5 h6 8. Bh4 g5 9. Nxg5 hxg5 10. Bxg5 Nbd7 11. exf6
			variation => N__('Semi-Slav: Botvinnik, Main Line'),
			moves => {
				'c8b7' => 1,
			},
		},
		'r2qkb1r/pb1n1p2/2p1pP2/1p4B1/2pP4/2N5/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'D44o',
			# TRANSLATORS: D44o: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 dxc4 6. e4 b5 7. e5 h6 8. Bh4 g5 9. Nxg5 hxg5 10. Bxg5 Nbd7 11. exf6 Bb7
			variation => N__('Semi-Slav: Botvinnik, Main Line'),
			moves => {
				'g2g3' => 1,
			},
		},
		'r2qkb1r/pb1n1p2/2p1pP2/1p4B1/2pP4/2N3P1/PP3P1P/R2QKB1R b KQkq' => {
			eco => 'D44p',
			# TRANSLATORS: D44p: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 dxc4 6. e4 b5 7. e5 h6 8. Bh4 g5 9. Nxg5 hxg5 10. Bxg5 Nbd7 11. exf6 Bb7 12. g3
			variation => N__('Semi-Slav: Botvinnik, Main Line, 12. g3'),
			moves => {
				'c6c5' => 1,
			},
		},
		'r2qkb1r/pb1n1p2/4pP2/1pp3B1/2pP4/2N3P1/PP3P1P/R2QKB1R w KQkq' => {
			eco => 'D44q',
			# TRANSLATORS: D44q: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 dxc4 6. e4 b5 7. e5 h6 8. Bh4 g5 9. Nxg5 hxg5 10. Bxg5 Nbd7 11. exf6 Bb7 12. g3 c5
			variation => N__('Semi-Slav: Botvinnik, Main Line, 12. g3 c5'),
			moves => {
				'd4d5' => 1,
			},
		},
		'r2qkb1r/pb1n1p2/4pP2/1ppP2B1/2p5/2N3P1/PP3P1P/R2QKB1R b KQkq' => {
			eco => 'D44q',
			# TRANSLATORS: D44q: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 dxc4 6. e4 b5 7. e5 h6 8. Bh4 g5 9. Nxg5 hxg5 10. Bxg5 Nbd7 11. exf6 Bb7 12. g3 c5 13. d5
			variation => N__('Semi-Slav: Botvinnik, Main Line, 12. g3 c5'),
			moves => {
				'd8b6' => 1,
			},
		},
		'r3kb1r/pb1n1p2/1q2pP2/1ppP2B1/2p5/2N3P1/PP3P1P/R2QKB1R w KQkq' => {
			eco => 'D44r',
			# TRANSLATORS: D44r: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. Bg5 dxc4 6. e4 b5 7. e5 h6 8. Bh4 g5 9. Nxg5 hxg5 10. Bxg5 Nbd7 11. exf6 Bb7 12. g3 c5 13. d5 Qb6
			variation => N__('Semi-Slav: Botvinnik, Main Line, 12. g3 c5 13. d5 Qb6'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/2p1pn2/3p4/2PP4/2N1PN2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'D45a',
			# TRANSLATORS: D45a: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3
			variation => N__('Semi-Slav: 5. e3'),
			moves => {
				'a7a6' => 1,
				'b8d7' => 1,
				'f6e4' => 1,
				'f8d6' => 1,
				'f8e7' => 1,
			},
		},
		'rnbqk2r/pp3ppp/2pbpn2/3p4/2PP4/2N1PN2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'D45b',
			# TRANSLATORS: D45b: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Bd6
			variation => N__('Semi-Slav: 5. e3 Bd6'),
			moves => {
			},
		},
		'rnbqk2r/pp2bppp/2p1pn2/3p4/2PP4/2N1PN2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'D45c',
			# TRANSLATORS: D45c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Be7
			variation => N__('Semi-Slav: 5. e3 Be7'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/2p1p3/3p4/2PPn3/2N1PN2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'D45d',
			# TRANSLATORS: D45d: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Ne4
			variation => N__('Semi-Slav: 5. e3 Ne4'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/2p1p3/3p4/2PPn3/2NBPN2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'D45d',
			# TRANSLATORS: D45d: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Ne4 6. Bd3
			variation => N__('Semi-Slav: 5. e3 Ne4'),
			moves => {
				'f7f5' => 1,
			},
		},
		'rnbqkb1r/pp4pp/2p1p3/3p1p2/2PPn3/2NBPN2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D45d',
			# TRANSLATORS: D45d: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Ne4 6. Bd3 f5
			variation => N__('Semi-Slav: Stonewall Defence'),
			moves => {
			},
		},
		'rnbqkb1r/1p3ppp/p1p1pn2/3p4/2PP4/2N1PN2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'D45e',
			# TRANSLATORS: D45e: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 a6
			variation => N__('Semi-Slav: Accelerated Meran (Alekhine Variation)'),
			moves => {
			},
		},
		'r1bqkb1r/pp1n1ppp/2p1pn2/3p4/2PP4/2N1PN2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'D45f',
			# TRANSLATORS: D45f: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7
			variation => N__('Semi-Slav: 5. e3 Nbd7'),
			moves => {
				'a2a3' => 1,
				'd1c2' => 1,
				'f1d3' => 1,
				'f3e5' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/2p1pn2/3pN3/2PP4/2N1P3/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'D45f',
			# TRANSLATORS: D45f: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Ne5
			variation => N__('Semi-Slav: Rubinstein System'),
			moves => {
			},
		},
		'r1bqkb1r/pp1n1ppp/2p1pn2/3p4/2PP4/P1N1PN2/1P3PPP/R1BQKB1R b KQkq' => {
			eco => 'D45g',
			# TRANSLATORS: D45g: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. a3
			variation => N__('Semi-Slav: 6. a3'),
			moves => {
			},
		},
		'r1bqkb1r/pp1n1ppp/2p1pn2/3p4/2PP4/2N1PN2/PPQ2PPP/R1B1KB1R b KQkq' => {
			eco => 'D45h',
			# TRANSLATORS: D45h: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Qc2
			variation => N__('Semi-Slav: 6. Qc2'),
			moves => {
				'b7b6' => 1,
				'f8d6' => 1,
				'f8e7' => 1,
			},
		},
		'r1bqkb1r/p2n1ppp/1pp1pn2/3p4/2PP4/2N1PN2/PPQ2PPP/R1B1KB1R w KQkq' => {
			eco => 'D45i',
			# TRANSLATORS: D45i: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Qc2 b6
			variation => N__('Semi-Slav: 6. Qc2 b6'),
			moves => {
			},
		},
		'r1bqk2r/pp1nbppp/2p1pn2/3p4/2PP4/2N1PN2/PPQ2PPP/R1B1KB1R w KQkq' => {
			eco => 'D45j',
			# TRANSLATORS: D45j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Qc2 Be7
			variation => N__('Semi-Slav: 6. Qc2 Be7'),
			moves => {
			},
		},
		'r1bqk2r/pp1n1ppp/2pbpn2/3p4/2PP4/2N1PN2/PPQ2PPP/R1B1KB1R w KQkq' => {
			eco => 'D45k',
			# TRANSLATORS: D45k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Qc2 Bd6
			variation => N__('Semi-Slav: 6. Qc2 Bd6'),
			moves => {
				'b2b3' => 1,
				'c1d2' => 1,
				'e3e4' => 1,
				'f1e2' => 1,
				'g2g4' => 1,
			},
		},
		'r1bqk2r/pp1n1ppp/2pbpn2/3p4/2PPP3/2N2N2/PPQ2PPP/R1B1KB1R b KQkq' => {
			eco => 'D45k',
			# TRANSLATORS: D45k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Qc2 Bd6 7. e4
			variation => N__('Semi-Slav: 6. Qc2 Bd6 7. e4'),
			moves => {
			},
		},
		'r1bqk2r/pp1n1ppp/2pbpn2/3p4/2PP2P1/2N1PN2/PPQ2P1P/R1B1KB1R b KQkq' => {
			eco => 'D45l',
			# TRANSLATORS: D45l: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Qc2 Bd6 7. g4
			variation => N__('Semi-Slav: 6. Qc2 Bd6 7. g4'),
			moves => {
				'd5c4' => 1,
				'd6b4' => 1,
				'f6g4' => 1,
				'h7h6' => 1,
			},
		},
		'r1bqk2r/pp1n1pp1/2pbpn1p/3p4/2PP2P1/2N1PN2/PPQ2P1P/R1B1KB1R w KQkq' => {
			eco => 'D45l',
			# TRANSLATORS: D45l: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Qc2 Bd6 7. g4 h6
			variation => N__('Semi-Slav: 6. Qc2 Bd6 7. g4 h6'),
			moves => {
			},
		},
		'r1bqk2r/pp1n1ppp/2pbpn2/8/2pP2P1/2N1PN2/PPQ2P1P/R1B1KB1R w KQkq' => {
			eco => 'D45m',
			# TRANSLATORS: D45m: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Qc2 Bd6 7. g4 dxc4
			variation => N__('Semi-Slav: 6. Qc2 Bd6 7. g4 dxc4'),
			moves => {
			},
		},
		'r1bqk2r/pp1n1ppp/2p1pn2/3p4/1bPP2P1/2N1PN2/PPQ2P1P/R1B1KB1R w KQkq' => {
			eco => 'D45n',
			# TRANSLATORS: D45n: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Qc2 Bd6 7. g4 Bb4
			variation => N__('Semi-Slav: 6. Qc2 Bd6 7. g4 Bb4'),
			moves => {
			},
		},
		'r1bqk2r/pp1n1ppp/2pbp3/3p4/2PP2n1/2N1PN2/PPQ2P1P/R1B1KB1R w KQkq' => {
			eco => 'D45o',
			# TRANSLATORS: D45o: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Qc2 Bd6 7. g4 Nxg4
			variation => N__('Semi-Slav: 6. Qc2 Bd6 7. g4 Nxg4'),
			moves => {
			},
		},
		'r1bqk2r/pp1n1ppp/2pbpn2/3p4/2PP4/1PN1PN2/P1Q2PPP/R1B1KB1R b KQkq' => {
			eco => 'D45p',
			# TRANSLATORS: D45p: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Qc2 Bd6 7. b3
			variation => N__('Semi-Slav: 6. Qc2 Bd6 7. b3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp1n1ppp/2pbpn2/3p4/2PP4/1PN1PN2/P1Q2PPP/R1B1KB1R w KQ' => {
			eco => 'D45p',
			# TRANSLATORS: D45p: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Qc2 Bd6 7. b3 O-O
			variation => N__('Semi-Slav: 6. Qc2 Bd6 7. b3 O-O'),
			moves => {
				'c1b2' => 1,
				'f1e2' => 1,
			},
		},
		'r1bq1rk1/pp1n1ppp/2pbpn2/3p4/2PP4/1PN1PN2/PBQ2PPP/R3KB1R b KQ' => {
			eco => 'D45q',
			# TRANSLATORS: D45q: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Qc2 Bd6 7. b3 O-O 8. Bb2
			variation => N__('Semi-Slav: 6. Qc2 Bd6 7. b3 O-O 8. Bb2'),
			moves => {
			},
		},
		'r1bq1rk1/pp1n1ppp/2pbpn2/3p4/2PP4/1PN1PN2/P1Q1BPPP/R1B1K2R b KQ' => {
			eco => 'D45r',
			# TRANSLATORS: D45r: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Qc2 Bd6 7. b3 O-O 8. Be2
			variation => N__('Semi-Slav: 6. Qc2 Bd6 7. b3 O-O 8. Be2'),
			moves => {
				'b7b6' => 1,
				'f8e8' => 1,
			},
		},
		'r1bq1rk1/p2n1ppp/1ppbpn2/3p4/2PP4/1PN1PN2/P1Q1BPPP/R1B1K2R w KQ' => {
			eco => 'D45s',
			# TRANSLATORS: D45s: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Qc2 Bd6 7. b3 O-O 8. Be2 b6
			variation => N__('Semi-Slav: 6. Qc2 Bd6 7. b3 O-O 8. Be2 b6'),
			moves => {
			},
		},
		'r1bqr1k1/pp1n1ppp/2pbpn2/3p4/2PP4/1PN1PN2/P1Q1BPPP/R1B1K2R w KQ' => {
			eco => 'D45t',
			# TRANSLATORS: D45t: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Qc2 Bd6 7. b3 O-O 8. Be2 Re8
			variation => N__('Semi-Slav: 6. Qc2 Bd6 7. b3 O-O 8. Be2 Re8'),
			moves => {
			},
		},
		'r1bqk2r/pp1n1ppp/2pbpn2/3p4/2PP4/2N1PN2/PPQB1PPP/R3KB1R b KQkq' => {
			eco => 'D45u',
			# TRANSLATORS: D45u: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Qc2 Bd6 7. Bd2
			variation => N__('Semi-Slav: 6. Qc2 Bd6 7. Bd2'),
			moves => {
			},
		},
		'r1bqk2r/pp1n1ppp/2pbpn2/3p4/2PP4/2N1PN2/PPQ1BPPP/R1B1K2R b KQkq' => {
			eco => 'D45v',
			# TRANSLATORS: D45v: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Qc2 Bd6 7. Be2
			variation => N__('Semi-Slav: 6. Qc2 Bd6 7. Be2'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp1n1ppp/2pbpn2/3p4/2PP4/2N1PN2/PPQ1BPPP/R1B1K2R w KQ' => {
			eco => 'D45v',
			# TRANSLATORS: D45v: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Qc2 Bd6 7. Be2 O-O
			variation => N__('Semi-Slav: 6. Qc2 Bd6 7. Be2'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bq1rk1/pp1n1ppp/2pbpn2/3p4/2PP4/2N1PN2/PPQ1BPPP/R1B2RK1 b -' => {
			eco => 'D45v',
			# TRANSLATORS: D45v: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Qc2 Bd6 7. Be2 O-O 8. O-O
			variation => N__('Semi-Slav: 6. Qc2 Bd6 7. Be2 O-O 8.O-O'),
			moves => {
				'd8e7' => 1,
				'e6e5' => 1,
				'f8e8' => 1,
			},
		},
		'r1bq1rk1/pp1n1ppp/2pb1n2/3pp3/2PP4/2N1PN2/PPQ1BPPP/R1B2RK1 w -' => {
			eco => 'D45w',
			# TRANSLATORS: D45w: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Qc2 Bd6 7. Be2 O-O 8. O-O e5
			variation => N__('Semi-Slav: 6. Qc2 Bd6 7. Be2 O-O 8.O-O e5'),
			moves => {
			},
		},
		'r1b2rk1/pp1nqppp/2pbpn2/3p4/2PP4/2N1PN2/PPQ1BPPP/R1B2RK1 w -' => {
			eco => 'D45x',
			# TRANSLATORS: D45x: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Qc2 Bd6 7. Be2 O-O 8. O-O Qe7
			variation => N__('Semi-Slav: 6. Qc2 Bd6 7. Be2 O-O 8.O-O Qe7'),
			moves => {
			},
		},
		'r1bqr1k1/pp1n1ppp/2pbpn2/3p4/2PP4/2N1PN2/PPQ1BPPP/R1B2RK1 w -' => {
			eco => 'D45y',
			# TRANSLATORS: D45y: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Qc2 Bd6 7. Be2 O-O 8. O-O Re8
			variation => N__('Semi-Slav: 6. Qc2 Bd6 7. Be2 O-O 8.O-O Re8'),
			moves => {
			},
		},
		'r1bqkb1r/pp1n1ppp/2p1pn2/3p4/2PP4/2NBPN2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'D46a',
			# TRANSLATORS: D46a: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3
			variation => N__('Semi-Slav: 6. Bd3'),
			moves => {
				'a7a6' => 1,
				'd5c4' => 1,
				'f8b4' => 1,
				'f8d6' => 1,
				'f8e7' => 1,
			},
		},
		'r1bqkb1r/1p1n1ppp/p1p1pn2/3p4/2PP4/2NBPN2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D46a',
			# TRANSLATORS: D46a: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 a6
			variation => N__('Semi-Slav: 6. Bd3 a6'),
			moves => {
			},
		},
		'r1bqk2r/pp1n1ppp/2p1pn2/3p4/1bPP4/2NBPN2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D46b',
			# TRANSLATORS: D46b: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bb4
			variation => N__('Semi-Slav: Romih Variation'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqk2r/pp1n1ppp/2p1pn2/3p4/1bPP4/2NBPN2/PP3PPP/R1BQ1RK1 b kq' => {
			eco => 'D46b',
			# TRANSLATORS: D46b: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bb4 7. O-O
			variation => N__('Semi-Slav: Romih, 7.O-O'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp1n1ppp/2p1pn2/3p4/1bPP4/2NBPN2/PP3PPP/R1BQ1RK1 w -' => {
			eco => 'D46b',
			# TRANSLATORS: D46b: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bb4 7. O-O O-O
			variation => N__('Semi-Slav: Romih, 7.O-O O-O'),
			moves => {
			},
		},
		'r1bqk2r/pp1nbppp/2p1pn2/3p4/2PP4/2NBPN2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D46c',
			# TRANSLATORS: D46c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Be7
			variation => N__('Semi-Slav: Bogoljubow Variation'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqk2r/pp1nbppp/2p1pn2/3p4/2PP4/2NBPN2/PP3PPP/R1BQ1RK1 b kq' => {
			eco => 'D46c',
			# TRANSLATORS: D46c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Be7 7. O-O
			variation => N__('Semi-Slav: Bogoljubow, 7.O-O'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/2p1pn2/3p4/2PP4/2NBPN2/PP3PPP/R1BQ1RK1 w -' => {
			eco => 'D46c',
			# TRANSLATORS: D46c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Be7 7. O-O O-O
			variation => N__('Semi-Slav: Bogoljubow, 7.O-O O-O'),
			moves => {
				'b2b3' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/2p1pn2/3p4/2PP4/1PNBPN2/P4PPP/R1BQ1RK1 b -' => {
			eco => 'D46d',
			# TRANSLATORS: D46d: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Be7 7. O-O O-O 8. b3
			variation => N__('Semi-Slav: Bogoljubow, 7.O-O O-O 8. b3'),
			moves => {
			},
		},
		'r1bqk2r/pp1n1ppp/2pbpn2/3p4/2PP4/2NBPN2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D46e',
			# TRANSLATORS: D46e: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6
			variation => N__('Semi-Slav: Chigorin Defence'),
			moves => {
				'd1c2' => 1,
				'e1g1' => 1,
				'e3e4' => 1,
			},
		},
		'r1bqk2r/pp1n1ppp/2pbpn2/3p4/2PPP3/2NB1N2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'D46e',
			# TRANSLATORS: D46e: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6 7. e4
			variation => N__('Semi-Slav: Chigorin, 7. e4'),
			moves => {
				'd5e4' => 1,
			},
		},
		'r1bqk2r/pp1n1ppp/2pbpn2/8/2PPp3/2NB1N2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D46e',
			# TRANSLATORS: D46e: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6 7. e4 dxe4
			variation => N__('Semi-Slav: Chigorin, 7. e4'),
			moves => {
				'c3e4' => 1,
			},
		},
		'r1bqk2r/pp1n1ppp/2pbpn2/8/2PPN3/3B1N2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'D46e',
			# TRANSLATORS: D46e: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6 7. e4 dxe4 8. Nxe4
			variation => N__('Semi-Slav: Chigorin, 7. e4 dxe4 8.Nxe4'),
			moves => {
			},
		},
		'r1bqk2r/pp1n1ppp/2pbpn2/3p4/2PP4/2NBPN2/PPQ2PPP/R1B1K2R b KQkq' => {
			eco => 'D46f',
			# TRANSLATORS: D46f: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6 7. Qc2
			variation => N__('Semi-Slav: Chigorin, 7. Qc2'),
			moves => {
				'd5c4' => 1,
				'e8g8' => 1,
			},
		},
		'r1bqk2r/pp1n1ppp/2pbpn2/8/2pP4/2NBPN2/PPQ2PPP/R1B1K2R w KQkq' => {
			eco => 'D46g',
			# TRANSLATORS: D46g: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6 7. Qc2 dxc4
			variation => N__('Semi-Slav: Chigorin, 7. Qc2 dxc4'),
			moves => {
				'd3c4' => 1,
			},
		},
		'r1bqk2r/pp1n1ppp/2pbpn2/8/2BP4/2N1PN2/PPQ2PPP/R1B1K2R b KQkq' => {
			eco => 'D46g',
			# TRANSLATORS: D46g: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6 7. Qc2 dxc4 8. Bxc4
			variation => N__('Semi-Slav: Chigorin, 7. Qc2 dxc4'),
			moves => {
			},
		},
		'r1bq1rk1/pp1n1ppp/2pbpn2/3p4/2PP4/2NBPN2/PPQ2PPP/R1B1K2R w KQ' => {
			eco => 'D46h',
			# TRANSLATORS: D46h: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6 7. Qc2 O-O
			variation => N__('Semi-Slav: Chigorin, 7. Qc2 O-O'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bq1rk1/pp1n1ppp/2pbpn2/3p4/2PP4/2NBPN2/PPQ2PPP/R1B2RK1 b -' => {
			eco => 'D46h',
			# TRANSLATORS: D46h: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6 7. Qc2 O-O 8. O-O
			variation => N__('Semi-Slav: Chigorin, 7. Qc2 O-O'),
			moves => {
				'd5c4' => 1,
			},
		},
		'r1bq1rk1/pp1n1ppp/2pbpn2/8/2pP4/2NBPN2/PPQ2PPP/R1B2RK1 w -' => {
			eco => 'D46h',
			# TRANSLATORS: D46h: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6 7. Qc2 O-O 8. O-O dxc4
			variation => N__('Semi-Slav: Chigorin, 7. Qc2 O-O'),
			moves => {
				'd3c4' => 1,
			},
		},
		'r1bq1rk1/pp1n1ppp/2pbpn2/8/2BP4/2N1PN2/PPQ2PPP/R1B2RK1 b -' => {
			eco => 'D46i',
			# TRANSLATORS: D46i: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6 7. Qc2 O-O 8. O-O dxc4 9. Bxc4
			variation => N__('Semi-Slav: Chigorin, 7. Qc2 Main Line'),
			moves => {
				'a7a6' => 1,
				'b7b5' => 1,
				'd8e7' => 1,
				'e6e5' => 1,
			},
		},
		'r1bq1rk1/pp1n1ppp/2pb1n2/4p3/2BP4/2N1PN2/PPQ2PPP/R1B2RK1 w -' => {
			eco => 'D46i',
			# TRANSLATORS: D46i: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6 7. Qc2 O-O 8. O-O dxc4 9. Bxc4 e5
			variation => N__('Semi-Slav: Chigorin, 7. Qc2 Main Line, 9... e5'),
			moves => {
			},
		},
		'r1b2rk1/pp1nqppp/2pbpn2/8/2BP4/2N1PN2/PPQ2PPP/R1B2RK1 w -' => {
			eco => 'D46j',
			# TRANSLATORS: D46j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6 7. Qc2 O-O 8. O-O dxc4 9. Bxc4 Qe7
			variation => N__('Semi-Slav: Chigorin, 7. Qc2 Main Line, 9... Qe7'),
			moves => {
				'a2a3' => 1,
				'c1d2' => 1,
				'h2h3' => 1,
			},
		},
		'r1b2rk1/pp1nqppp/2pbpn2/8/2BP4/P1N1PN2/1PQ2PPP/R1B2RK1 b -' => {
			eco => 'D46j',
			# TRANSLATORS: D46j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6 7. Qc2 O-O 8. O-O dxc4 9. Bxc4 Qe7 10. a3
			variation => N__('Semi-Slav: Chigorin, 7. Qc2 Main Line, 9... Qe7 10. a3'),
			moves => {
			},
		},
		'r1b2rk1/pp1nqppp/2pbpn2/8/2BP4/2N1PN2/PPQB1PPP/R4RK1 b -' => {
			eco => 'D46j',
			# TRANSLATORS: D46j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6 7. Qc2 O-O 8. O-O dxc4 9. Bxc4 Qe7 10. Bd2
			variation => N__('Semi-Slav: Chigorin, 7. Qc2 Main Line, 9... Qe7 10. Bd2'),
			moves => {
			},
		},
		'r1b2rk1/pp1nqppp/2pbpn2/8/2BP4/2N1PN1P/PPQ2PP1/R1B2RK1 b -' => {
			eco => 'D46j',
			# TRANSLATORS: D46j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6 7. Qc2 O-O 8. O-O dxc4 9. Bxc4 Qe7 10. h3
			variation => N__('Semi-Slav: Chigorin, 7. Qc2 Main Line, 9... Qe7 10. h3'),
			moves => {
			},
		},
		'r1bq1rk1/1p1n1ppp/p1pbpn2/8/2BP4/2N1PN2/PPQ2PPP/R1B2RK1 w -' => {
			eco => 'D46k',
			# TRANSLATORS: D46k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6 7. Qc2 O-O 8. O-O dxc4 9. Bxc4 a6
			variation => N__('Semi-Slav: Chigorin, 7. Qc2 Main Line, 9... a6'),
			moves => {
				'f1d1' => 1,
			},
		},
		'r1bq1rk1/1p1n1ppp/p1pbpn2/8/2BP4/2N1PN2/PPQ2PPP/R1BR2K1 b -' => {
			eco => 'D46k',
			# TRANSLATORS: D46k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6 7. Qc2 O-O 8. O-O dxc4 9. Bxc4 a6 10. Rd1
			variation => N__('Semi-Slav: Chigorin, 7. Qc2 Main Line, 9... a6 10. Rd1'),
			moves => {
				'b7b5' => 1,
			},
		},
		'r1bq1rk1/3n1ppp/p1pbpn2/1p6/2BP4/2N1PN2/PPQ2PPP/R1BR2K1 w -' => {
			eco => 'D46k',
			# TRANSLATORS: D46k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6 7. Qc2 O-O 8. O-O dxc4 9. Bxc4 a6 10. Rd1 b5
			variation => N__('Semi-Slav: Chigorin, 7. Qc2 Main Line, 9... a6 10. Rd1 b5'),
			moves => {
			},
		},
		'r1bq1rk1/p2n1ppp/2pbpn2/1p6/2BP4/2N1PN2/PPQ2PPP/R1B2RK1 w -' => {
			eco => 'D46l',
			# TRANSLATORS: D46l: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6 7. Qc2 O-O 8. O-O dxc4 9. Bxc4 b5
			variation => N__('Semi-Slav: Chigorin, 7. Qc2 Main Line, 9... b5'),
			moves => {
				'c4e2' => 1,
			},
		},
		'r1bq1rk1/p2n1ppp/2pbpn2/1p6/3P4/2N1PN2/PPQ1BPPP/R1B2RK1 b -' => {
			eco => 'D46m',
			# TRANSLATORS: D46m: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6 7. Qc2 O-O 8. O-O dxc4 9. Bxc4 b5 10. Be2
			variation => N__('Semi-Slav: Chigorin, 7. Qc2 Main Line, 9... b5 10. Be2'),
			moves => {
				'c8b7' => 1,
			},
		},
		'r2q1rk1/pb1n1ppp/2pbpn2/1p6/3P4/2N1PN2/PPQ1BPPP/R1B2RK1 w -' => {
			eco => 'D46m',
			# TRANSLATORS: D46m: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6 7. Qc2 O-O 8. O-O dxc4 9. Bxc4 b5 10. Be2 Bb7
			variation => N__('Semi-Slav: Chigorin, 7. Qc2 Main Line, 9... b5 10. Be2 Bb7'),
			moves => {
				'f1d1' => 1,
			},
		},
		'r2q1rk1/pb1n1ppp/2pbpn2/1p6/3P4/2N1PN2/PPQ1BPPP/R1BR2K1 b -' => {
			eco => 'D46m',
			# TRANSLATORS: D46m: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6 7. Qc2 O-O 8. O-O dxc4 9. Bxc4 b5 10. Be2 Bb7 11. Rd1
			variation => N__('Semi-Slav: Chigorin, 7. Qc2 Main Line, 9... b5 10. Be2 Bb7 11. Rd1'),
			moves => {
			},
		},
		'r1bqk2r/pp1n1ppp/2pbpn2/3p4/2PP4/2NBPN2/PP3PPP/R1BQ1RK1 b kq' => {
			eco => 'D46n',
			# TRANSLATORS: D46n: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6 7. O-O
			variation => N__('Semi-Slav: Chigorin, 7.O-O'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/pp1n1ppp/2pbpn2/3p4/2PP4/2NBPN2/PP3PPP/R1BQ1RK1 w -' => {
			eco => 'D46o',
			# TRANSLATORS: D46o: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6 7. O-O O-O
			variation => N__('Semi-Slav: Chigorin, 7.O-O O-O'),
			moves => {
				'e3e4' => 1,
			},
		},
		'r1bq1rk1/pp1n1ppp/2pbpn2/3p4/2PPP3/2NB1N2/PP3PPP/R1BQ1RK1 b -' => {
			eco => 'D46p',
			# TRANSLATORS: D46p: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6 7. O-O O-O 8. e4
			variation => N__('Semi-Slav: Chigorin, 7.O-O O-O 8. e4'),
			moves => {
				'd5c4' => 1,
				'd5e4' => 1,
			},
		},
		'r1bq1rk1/pp1n1ppp/2pbpn2/8/2pPP3/2NB1N2/PP3PPP/R1BQ1RK1 w -' => {
			eco => 'D46p',
			# TRANSLATORS: D46p: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6 7. O-O O-O 8. e4 dxc4
			variation => N__('Semi-Slav: Chigorin, 7.O-O O-O 8. e4 dxc4'),
			moves => {
				'd3c4' => 1,
			},
		},
		'r1bq1rk1/pp1n1ppp/2pbpn2/8/2BPP3/2N2N2/PP3PPP/R1BQ1RK1 b -' => {
			eco => 'D46p',
			# TRANSLATORS: D46p: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6 7. O-O O-O 8. e4 dxc4 9. Bxc4
			variation => N__('Semi-Slav: Chigorin, 7.O-O O-O 8. e4 dxc4 9.Bxc4'),
			moves => {
				'e6e5' => 1,
			},
		},
		'r1bq1rk1/pp1n1ppp/2pb1n2/4p3/2BPP3/2N2N2/PP3PPP/R1BQ1RK1 w -' => {
			eco => 'D46p',
			# TRANSLATORS: D46p: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6 7. O-O O-O 8. e4 dxc4 9. Bxc4 e5
			variation => N__('Semi-Slav: Chigorin, 7.O-O O-O 8. e4 dxc4 9.Bxc4 e5'),
			moves => {
			},
		},
		'r1bq1rk1/pp1n1ppp/2pbpn2/8/2PPp3/2NB1N2/PP3PPP/R1BQ1RK1 w -' => {
			eco => 'D46q',
			# TRANSLATORS: D46q: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6 7. O-O O-O 8. e4 dxe4
			variation => N__('Semi-Slav: Chigorin, Main Line'),
			moves => {
				'c3e4' => 1,
			},
		},
		'r1bq1rk1/pp1n1ppp/2pbpn2/8/2PPN3/3B1N2/PP3PPP/R1BQ1RK1 b -' => {
			eco => 'D46q',
			# TRANSLATORS: D46q: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6 7. O-O O-O 8. e4 dxe4 9. Nxe4
			variation => N__('Semi-Slav: Chigorin, Main Line'),
			moves => {
				'f6e4' => 1,
			},
		},
		'r1bq1rk1/pp1n1ppp/2pbp3/8/2PPn3/3B1N2/PP3PPP/R1BQ1RK1 w -' => {
			eco => 'D46q',
			# TRANSLATORS: D46q: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6 7. O-O O-O 8. e4 dxe4 9. Nxe4 Nxe4
			variation => N__('Semi-Slav: Chigorin, Main Line'),
			moves => {
				'd3e4' => 1,
			},
		},
		'r1bq1rk1/pp1n1ppp/2pbp3/8/2PPB3/5N2/PP3PPP/R1BQ1RK1 b -' => {
			eco => 'D46q',
			# TRANSLATORS: D46q: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6 7. O-O O-O 8. e4 dxe4 9. Nxe4 Nxe4 10. Bxe4
			variation => N__('Semi-Slav: Chigorin, Main Line'),
			moves => {
				'h7h6' => 1,
			},
		},
		'r1bq1rk1/pp1n1pp1/2pbp2p/8/2PPB3/5N2/PP3PPP/R1BQ1RK1 w -' => {
			eco => 'D46r',
			# TRANSLATORS: D46r: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6 7. O-O O-O 8. e4 dxe4 9. Nxe4 Nxe4 10. Bxe4 h6
			variation => N__('Semi-Slav: Chigorin, Main Line, 10... h6'),
			moves => {
				'e4c2' => 1,
			},
		},
		'r1bq1rk1/pp1n1pp1/2pbp2p/8/2PP4/5N2/PPB2PPP/R1BQ1RK1 b -' => {
			eco => 'D46r',
			# TRANSLATORS: D46r: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6 7. O-O O-O 8. e4 dxe4 9. Nxe4 Nxe4 10. Bxe4 h6 11. Bc2
			variation => N__('Semi-Slav: Chigorin, Main Line, 10... h6 11. Bc2'),
			moves => {
				'e6e5' => 1,
			},
		},
		'r1bq1rk1/pp1n1pp1/2pb3p/4p3/2PP4/5N2/PPB2PPP/R1BQ1RK1 w -' => {
			eco => 'D46r',
			# TRANSLATORS: D46r: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 Bd6 7. O-O O-O 8. e4 dxe4 9. Nxe4 Nxe4 10. Bxe4 h6 11. Bc2 e5
			variation => N__('Semi-Slav: Chigorin, Main Line, 10... h6 11. Bc2 e5'),
			moves => {
			},
		},
		'r1bqkb1r/pp1n1ppp/2p1pn2/8/2pP4/2NBPN2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D47a',
			# TRANSLATORS: D47a: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4
			variation => N__('Semi-Slav: Meran Variation'),
			moves => {
				'd3c4' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/2p1pn2/8/2BP4/2N1PN2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'D47a',
			# TRANSLATORS: D47a: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4
			variation => N__('Semi-Slav: Meran Variation'),
			moves => {
				'b7b5' => 1,
			},
		},
		'r1bqkb1r/p2n1ppp/2p1pn2/1p6/2BP4/2N1PN2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D47a',
			# TRANSLATORS: D47a: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5
			variation => N__('Semi-Slav: Meran, 7... b5'),
			moves => {
				'c4b3' => 1,
				'c4d3' => 1,
				'c4e2' => 1,
			},
		},
		'r1bqkb1r/p2n1ppp/2p1pn2/1p6/3P4/1BN1PN2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'D47b',
			# TRANSLATORS: D47b: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bb3
			variation => N__('Semi-Slav: Meran, Freymann Variation'),
			moves => {
				'b5b4' => 1,
			},
		},
		'r1bqkb1r/p2n1ppp/2p1pn2/8/1p1P4/1BN1PN2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D47c',
			# TRANSLATORS: D47c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bb3 b4
			variation => N__('Semi-Slav: Meran, Freymann, 8... b4'),
			moves => {
			},
		},
		'r1bqkb1r/p2n1ppp/2p1pn2/1p6/3P4/2N1PN2/PP2BPPP/R1BQK2R b KQkq' => {
			eco => 'D47d',
			# TRANSLATORS: D47d: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Be2
			variation => N__('Semi-Slav: Meran, Capablanca Variation'),
			moves => {
				'a7a6' => 1,
				'b5b4' => 1,
				'c8b7' => 1,
			},
		},
		'r1bqkb1r/p2n1ppp/2p1pn2/8/1p1P4/2N1PN2/PP2BPPP/R1BQK2R w KQkq' => {
			eco => 'D47d',
			# TRANSLATORS: D47d: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Be2 b4
			variation => N__('Semi-Slav: Meran, Capablanca, 8... b4'),
			moves => {
			},
		},
		'r1bqkb1r/3n1ppp/p1p1pn2/1p6/3P4/2N1PN2/PP2BPPP/R1BQK2R w KQkq' => {
			eco => 'D47e',
			# TRANSLATORS: D47e: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Be2 a6
			variation => N__('Semi-Slav: Meran, Capablanca, 8... a6'),
			moves => {
			},
		},
		'r2qkb1r/pb1n1ppp/2p1pn2/1p6/3P4/2N1PN2/PP2BPPP/R1BQK2R w KQkq' => {
			eco => 'D47f',
			# TRANSLATORS: D47f: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Be2 Bb7
			variation => N__('Semi-Slav: Meran, Capablanca, 8... Bb7'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r2qkb1r/pb1n1ppp/2p1pn2/1p6/3P4/2N1PN2/PP2BPPP/R1BQ1RK1 b kq' => {
			eco => 'D47f',
			# TRANSLATORS: D47f: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Be2 Bb7 9. O-O
			variation => N__('Semi-Slav: Meran, Capablanca, 8... Bb7 9.O-O'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r2qkb1r/1b1n1ppp/p1p1pn2/1p6/3P4/2N1PN2/PP2BPPP/R1BQ1RK1 w kq' => {
			eco => 'D47g',
			# TRANSLATORS: D47g: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Be2 Bb7 9. O-O a6
			variation => N__('Semi-Slav: Meran, Capablanca, 8... Bb7 9.O-O a6'),
			moves => {
			},
		},
		'r1bqkb1r/p2n1ppp/2p1pn2/1p6/3P4/2NBPN2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'D47h',
			# TRANSLATORS: D47h: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3
			variation => N__('Semi-Slav: Meran, 8. Bd3'),
			moves => {
				'a7a6' => 1,
				'b5b4' => 1,
				'c8b7' => 1,
				'f8d6' => 1,
			},
		},
		'r1bqk2r/p2n1ppp/2pbpn2/1p6/3P4/2NBPN2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D47h',
			# TRANSLATORS: D47h: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 Bd6
			variation => N__('Semi-Slav: Meran, 8. Bd3 Bd6'),
			moves => {
			},
		},
		'r1bqkb1r/p2n1ppp/2p1pn2/8/1p1P4/2NBPN2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D47i',
			# TRANSLATORS: D47i: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 b4
			variation => N__('Semi-Slav: Meran, Lundin Variation'),
			moves => {
				'c3a4' => 1,
				'c3e4' => 1,
			},
		},
		'r1bqkb1r/p2n1ppp/2p1pn2/8/Np1P4/3BPN2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'D47i',
			# TRANSLATORS: D47i: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 b4 9. Na4
			variation => N__('Semi-Slav: Meran, Lundin, 9. Na4'),
			moves => {
			},
		},
		'r1bqkb1r/p2n1ppp/2p1pn2/8/1p1PN3/3BPN2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'D47j',
			# TRANSLATORS: D47j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 b4 9. Ne4
			variation => N__('Semi-Slav: Meran, Lundin, 9. Ne4'),
			moves => {
				'f6e4' => 1,
				'f8e7' => 1,
			},
		},
		'r1bqkb1r/p2n1ppp/2p1p3/8/1p1Pn3/3BPN2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D47k',
			# TRANSLATORS: D47k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 b4 9. Ne4 Nxe4
			variation => N__('Semi-Slav: Meran, Lundin, 9. Ne4 Nxe4'),
			moves => {
			},
		},
		'r1bqk2r/p2nbppp/2p1pn2/8/1p1PN3/3BPN2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D47l',
			# TRANSLATORS: D47l: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 b4 9. Ne4 Be7
			variation => N__('Semi-Slav: Meran, Lundin, 9. Ne4 Be7'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqk2r/p2nbppp/2p1pn2/8/1p1PN3/3BPN2/PP3PPP/R1BQ1RK1 b kq' => {
			eco => 'D47l',
			# TRANSLATORS: D47l: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 b4 9. Ne4 Be7 10. O-O
			variation => N__('Semi-Slav: Meran, Lundin, 9. Ne4 Be7 10.O-O'),
			moves => {
			},
		},
		'r2qkb1r/pb1n1ppp/2p1pn2/1p6/3P4/2NBPN2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D47m',
			# TRANSLATORS: D47m: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 Bb7
			variation => N__('Semi-Slav: Meran, Wade Variation'),
			moves => {
				'a2a3' => 1,
				'e1g1' => 1,
				'e3e4' => 1,
			},
		},
		'r2qkb1r/pb1n1ppp/2p1pn2/1p6/3P4/P1NBPN2/1P3PPP/R1BQK2R b KQkq' => {
			eco => 'D47m',
			# TRANSLATORS: D47m: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 Bb7 9. a3
			variation => N__('Semi-Slav: Meran, Wade, 9. a3'),
			moves => {
			},
		},
		'r2qkb1r/pb1n1ppp/2p1pn2/1p6/3P4/2NBPN2/PP3PPP/R1BQ1RK1 b kq' => {
			eco => 'D47n',
			# TRANSLATORS: D47n: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 Bb7 9. O-O
			variation => N__('Semi-Slav: Meran, Wade, 9.O-O'),
			moves => {
				'b5b4' => 1,
			},
		},
		'r2qkb1r/pb1n1ppp/2p1pn2/8/1p1P4/2NBPN2/PP3PPP/R1BQ1RK1 w kq' => {
			eco => 'D47n',
			# TRANSLATORS: D47n: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 Bb7 9. O-O b4
			variation => N__('Semi-Slav: Meran, Wade, 9.O-O b4'),
			moves => {
				'c3e4' => 1,
			},
		},
		'r2qkb1r/pb1n1ppp/2p1pn2/8/1p1PN3/3BPN2/PP3PPP/R1BQ1RK1 b kq' => {
			eco => 'D47o',
			# TRANSLATORS: D47o: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 Bb7 9. O-O b4 10. Ne4
			variation => N__('Semi-Slav: Meran, Wade, 9.O-O b4 10. Ne4'),
			moves => {
				'f8e7' => 1,
			},
		},
		'r2qk2r/pb1nbppp/2p1pn2/8/1p1PN3/3BPN2/PP3PPP/R1BQ1RK1 w kq' => {
			eco => 'D47o',
			# TRANSLATORS: D47o: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 Bb7 9. O-O b4 10. Ne4 Be7
			variation => N__('Semi-Slav: Meran, Wade, 9.O-O b4 10. Ne4 Be7'),
			moves => {
				'e4f6' => 1,
			},
		},
		'r2qk2r/pb1nbppp/2p1pN2/8/1p1P4/3BPN2/PP3PPP/R1BQ1RK1 b kq' => {
			eco => 'D47p',
			# TRANSLATORS: D47p: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 Bb7 9. O-O b4 10. Ne4 Be7 11. Nxf6+
			variation => N__('Semi-Slav: Meran, Wade, 9.O-O b4 10. Ne4 Be7 11.Nxf6+'),
			moves => {
				'd7f6' => 1,
			},
		},
		'r2qk2r/pb2bppp/2p1pn2/8/1p1P4/3BPN2/PP3PPP/R1BQ1RK1 w kq' => {
			eco => 'D47p',
			# TRANSLATORS: D47p: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 Bb7 9. O-O b4 10. Ne4 Be7 11. Nxf6+ Nxf6
			variation => N__('Semi-Slav: Meran, Wade, 9.O-O b4 10. Ne4 Be7 11.Nxf6+ Nxf6'),
			moves => {
				'e3e4' => 1,
			},
		},
		'r2qk2r/pb2bppp/2p1pn2/8/1p1PP3/3B1N2/PP3PPP/R1BQ1RK1 b kq' => {
			eco => 'D47p',
			# TRANSLATORS: D47p: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 Bb7 9. O-O b4 10. Ne4 Be7 11. Nxf6+ Nxf6 12. e4
			variation => N__('Semi-Slav: Meran, Wade, 9.O-O b4 10. Ne4 Be7 11.Nxf6+ Nxf6 12. e4'),
			moves => {
			},
		},
		'r2qkb1r/pb1n1ppp/2p1pn2/1p6/3PP3/2NB1N2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'D47q',
			# TRANSLATORS: D47q: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 Bb7 9. e4
			variation => N__('Semi-Slav: Meran, Wade, 9. e4'),
			moves => {
				'b5b4' => 1,
			},
		},
		'r2qkb1r/pb1n1ppp/2p1pn2/8/1p1PP3/2NB1N2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D47q',
			# TRANSLATORS: D47q: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 Bb7 9. e4 b4
			variation => N__('Semi-Slav: Meran, Wade, 9. e4'),
			moves => {
				'c3a4' => 1,
			},
		},
		'r2qkb1r/pb1n1ppp/2p1pn2/8/Np1PP3/3B1N2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'D47q',
			# TRANSLATORS: D47q: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 Bb7 9. e4 b4 10. Na4
			variation => N__('Semi-Slav: Meran, Wade, 9. e4'),
			moves => {
				'c6c5' => 1,
			},
		},
		'r2qkb1r/pb1n1ppp/4pn2/2p5/Np1PP3/3B1N2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D47q',
			# TRANSLATORS: D47q: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 Bb7 9. e4 b4 10. Na4 c5
			variation => N__('Semi-Slav: Meran, Wade, 9. e4'),
			moves => {
				'e4e5' => 1,
			},
		},
		'r2qkb1r/pb1n1ppp/4pn2/2p1P3/Np1P4/3B1N2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'D47q',
			# TRANSLATORS: D47q: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 Bb7 9. e4 b4 10. Na4 c5 11. e5
			variation => N__('Semi-Slav: Meran, Wade, 9. e4'),
			moves => {
				'f6d5' => 1,
			},
		},
		'r2qkb1r/pb1n1ppp/4p3/2pnP3/Np1P4/3B1N2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D47r',
			# TRANSLATORS: D47r: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 Bb7 9. e4 b4 10. Na4 c5 11. e5 Nd5
			variation => N__('Semi-Slav: Meran, Wade, Main Line'),
			moves => {
				'a4c5' => 1,
				'e1g1' => 1,
			},
		},
		'r2qkb1r/pb1n1ppp/4p3/2NnP3/1p1P4/3B1N2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'D47s',
			# TRANSLATORS: D47s: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 Bb7 9. e4 b4 10. Na4 c5 11. e5 Nd5 12. Nxc5
			variation => N__('Semi-Slav: Meran, Wade, Main Line, 12.Nxc5'),
			moves => {
			},
		},
		'r2qkb1r/pb1n1ppp/4p3/2pnP3/Np1P4/3B1N2/PP3PPP/R1BQ1RK1 b kq' => {
			eco => 'D47t',
			# TRANSLATORS: D47t: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 Bb7 9. e4 b4 10. Na4 c5 11. e5 Nd5 12. O-O
			variation => N__('Semi-Slav: Meran, Wade, Main Line, 12.O-O'),
			moves => {
			},
		},
		'r1bqkb1r/3n1ppp/p1p1pn2/1p6/3P4/2NBPN2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D48a',
			# TRANSLATORS: D48a: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6
			variation => N__('Semi-Slav: Meran, 8... a6'),
			moves => {
				'a2a4' => 1,
				'e1g1' => 1,
				'e3e4' => 1,
			},
		},
		'r1bqkb1r/3n1ppp/p1p1pn2/1p6/P2P4/2NBPN2/1P3PPP/R1BQK2R b KQkq' => {
			eco => 'D48b',
			# TRANSLATORS: D48b: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. a4
			variation => N__('Semi-Slav: Meran, 8... a6 9. a4'),
			moves => {
			},
		},
		'r1bqkb1r/3n1ppp/p1p1pn2/1p6/3P4/2NBPN2/PP3PPP/R1BQ1RK1 b kq' => {
			eco => 'D48c',
			# TRANSLATORS: D48c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. O-O
			variation => N__('Semi-Slav: Meran, 8... a6 9.O-O'),
			moves => {
				'c6c5' => 1,
				'c8b7' => 1,
			},
		},
		'r1bqkb1r/3n1ppp/p3pn2/1pp5/3P4/2NBPN2/PP3PPP/R1BQ1RK1 w kq' => {
			eco => 'D48c',
			# TRANSLATORS: D48c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. O-O c5
			variation => N__('Semi-Slav: Meran, 8... a6 9.O-O c5'),
			moves => {
				'd1e2' => 1,
			},
		},
		'r1bqkb1r/3n1ppp/p3pn2/1pp5/3P4/2NBPN2/PP2QPPP/R1B2RK1 b kq' => {
			eco => 'D48d',
			# TRANSLATORS: D48d: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. O-O c5 10. Qe2
			variation => N__('Semi-Slav: Meran, 8... a6 9.O-O c5 10. Qe2'),
			moves => {
			},
		},
		'r2qkb1r/1b1n1ppp/p1p1pn2/1p6/3P4/2NBPN2/PP3PPP/R1BQ1RK1 w kq' => {
			eco => 'D48e',
			# TRANSLATORS: D48e: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. O-O Bb7
			variation => N__('Semi-Slav: Meran, 8... a6 9.O-O Bb7'),
			moves => {
				'e3e4' => 1,
			},
		},
		'r2qkb1r/1b1n1ppp/p1p1pn2/1p6/3PP3/2NB1N2/PP3PPP/R1BQ1RK1 b kq' => {
			eco => 'D48f',
			# TRANSLATORS: D48f: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. O-O Bb7 10. e4
			variation => N__('Semi-Slav: Meran, 8... a6 9.O-O Bb7 10. e4'),
			moves => {
				'c6c5' => 1,
			},
		},
		'r2qkb1r/1b1n1ppp/p3pn2/1pp5/3PP3/2NB1N2/PP3PPP/R1BQ1RK1 w kq' => {
			eco => 'D48f',
			# TRANSLATORS: D48f: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. O-O Bb7 10. e4 c5
			variation => N__('Semi-Slav: Meran, 8... a6 9.O-O Bb7 10. e4'),
			moves => {
				'd4d5' => 1,
			},
		},
		'r2qkb1r/1b1n1ppp/p3pn2/1ppP4/4P3/2NB1N2/PP3PPP/R1BQ1RK1 b kq' => {
			eco => 'D48f',
			# TRANSLATORS: D48f: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. O-O Bb7 10. e4 c5 11. d5
			variation => N__('Semi-Slav: Meran, 8... a6 9.O-O Bb7 10. e4 c5 11. d5'),
			moves => {
				'd8c7' => 1,
			},
		},
		'r3kb1r/1bqn1ppp/p3pn2/1ppP4/4P3/2NB1N2/PP3PPP/R1BQ1RK1 w kq' => {
			eco => 'D48g',
			# TRANSLATORS: D48g: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. O-O Bb7 10. e4 c5 11. d5 Qc7
			variation => N__('Semi-Slav: Meran, 8... a6 9.O-O Bb7 10. e4 c5 11. d5 Qc7'),
			moves => {
				'd5e6' => 1,
			},
		},
		'r3kb1r/1bqn1ppp/p3Pn2/1pp5/4P3/2NB1N2/PP3PPP/R1BQ1RK1 b kq' => {
			eco => 'D48g',
			# TRANSLATORS: D48g: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. O-O Bb7 10. e4 c5 11. d5 Qc7 12. dxe6
			variation => N__('Semi-Slav: Meran, 8... a6 9.O-O Bb7 10. e4 c5 11. d5 Qc7 12.dxe6'),
			moves => {
				'f7e6' => 1,
			},
		},
		'r3kb1r/1bqn2pp/p3pn2/1pp5/4P3/2NB1N2/PP3PPP/R1BQ1RK1 w kq' => {
			eco => 'D48g',
			# TRANSLATORS: D48g: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. O-O Bb7 10. e4 c5 11. d5 Qc7 12. dxe6 fxe6
			variation => N__('Semi-Slav: Meran, 8... a6 9.O-O Bb7 10. e4 c5 11. d5 Qc7 12.dxe6 fxe6'),
			moves => {
			},
		},
		'r1bqkb1r/3n1ppp/p1p1pn2/1p6/3PP3/2NB1N2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'D48h',
			# TRANSLATORS: D48h: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. e4
			variation => N__('Semi-Slav: Meran, 8... a6 9. e4'),
			moves => {
				'b5b4' => 1,
				'c6c5' => 1,
				'c8b7' => 1,
			},
		},
		'r2qkb1r/1b1n1ppp/p1p1pn2/1p6/3PP3/2NB1N2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D48i',
			# TRANSLATORS: D48i: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. e4 Bb7
			variation => N__('Semi-Slav: Meran, 8... a6 9. e4 Bb7'),
			moves => {
			},
		},
		'r1bqkb1r/3n1ppp/p1p1pn2/8/1p1PP3/2NB1N2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D48j',
			# TRANSLATORS: D48j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. e4 b4
			variation => N__('Semi-Slav: Meran, Pirc Variation'),
			moves => {
			},
		},
		'r1bqkb1r/3n1ppp/p3pn2/1pp5/3PP3/2NB1N2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D48k',
			# TRANSLATORS: D48k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. e4 c5
			variation => N__('Semi-Slav: Meran, 8... a6 9. e4 c5'),
			moves => {
				'd4d5' => 1,
				'e4e5' => 1,
			},
		},
		'r1bqkb1r/3n1ppp/p3pn2/1ppP4/4P3/2NB1N2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'D48l',
			# TRANSLATORS: D48l: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. e4 c5 10. d5
			variation => N__('Semi-Slav: Meran, Reynolds Variation'),
			moves => {
				'c5c4' => 1,
				'd8c7' => 1,
				'e6e5' => 1,
			},
		},
		'r1bqkb1r/3n1ppp/p4n2/1ppPp3/4P3/2NB1N2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D48m',
			# TRANSLATORS: D48m: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. e4 c5 10. d5 e5
			variation => N__('Semi-Slav: Meran, Reynolds, 10... e5'),
			moves => {
			},
		},
		'r1b1kb1r/2qn1ppp/p3pn2/1ppP4/4P3/2NB1N2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D48n',
			# TRANSLATORS: D48n: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. e4 c5 10. d5 Qc7
			variation => N__('Semi-Slav: Meran, Reynolds, 10... Qc7'),
			moves => {
			},
		},
		'r1bqkb1r/3n1ppp/p3pn2/1p1P4/2p1P3/2NB1N2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D48o',
			# TRANSLATORS: D48o: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. e4 c5 10. d5 c4
			variation => N__('Semi-Slav: Meran, Reynolds, 10... c4'),
			moves => {
				'd5e6' => 1,
			},
		},
		'r1bqkb1r/3n1ppp/p3Pn2/1p6/2p1P3/2NB1N2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'D48o',
			# TRANSLATORS: D48o: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. e4 c5 10. d5 c4 11. dxe6
			variation => N__('Semi-Slav: Meran, Reynolds, 10... c4'),
			moves => {
				'f7e6' => 1,
			},
		},
		'r1bqkb1r/3n2pp/p3pn2/1p6/2p1P3/2NB1N2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D48p',
			# TRANSLATORS: D48p: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. e4 c5 10. d5 c4 11. dxe6 fxe6
			variation => N__('Semi-Slav: Meran, Reynolds, 10... c4 11.dxe6 fxe6'),
			moves => {
				'd3c2' => 1,
			},
		},
		'r1bqkb1r/3n2pp/p3pn2/1p6/2p1P3/2N2N2/PPB2PPP/R1BQK2R b KQkq' => {
			eco => 'D48p',
			# TRANSLATORS: D48p: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. e4 c5 10. d5 c4 11. dxe6 fxe6 12. Bc2
			variation => N__('Semi-Slav: Meran, Reynolds, 10... c4 11.dxe6 fxe6 12. Bc2'),
			moves => {
				'd8c7' => 1,
			},
		},
		'r1b1kb1r/2qn2pp/p3pn2/1p6/2p1P3/2N2N2/PPB2PPP/R1BQK2R w KQkq' => {
			eco => 'D48p',
			# TRANSLATORS: D48p: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. e4 c5 10. d5 c4 11. dxe6 fxe6 12. Bc2 Qc7
			variation => N__('Semi-Slav: Meran, Reynolds, 10... c4 11.dxe6 fxe6 12. Bc2 Qc7'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1b1kb1r/2qn2pp/p3pn2/1p6/2p1P3/2N2N2/PPB2PPP/R1BQ1RK1 b kq' => {
			eco => 'D48p',
			# TRANSLATORS: D48p: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. e4 c5 10. d5 c4 11. dxe6 fxe6 12. Bc2 Qc7 13. O-O
			variation => N__('Semi-Slav: Meran, Reynolds, 10... c4 11.dxe6 fxe6 12. Bc2 Qc7 13.O-O'),
			moves => {
			},
		},
		'r1bqkb1r/3n1ppp/p3pn2/1pp1P3/3P4/2NB1N2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'D48q',
			# TRANSLATORS: D48q: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. e4 c5 10. e5
			variation => N__('Semi-Slav: Meran, Old Main Line'),
			moves => {
				'c5d4' => 1,
				'f6g4' => 1,
			},
		},
		'r1bqkb1r/3n1ppp/p3p3/1pp1P3/3P2n1/2NB1N2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D48r',
			# TRANSLATORS: D48r: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. e4 c5 10. e5 Ng4
			variation => N__('Semi-Slav: Meran, Rabinovich Variation'),
			moves => {
			},
		},
		'r1bqkb1r/3n1ppp/p3pn2/1p2P3/3p4/2NB1N2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D48s',
			# TRANSLATORS: D48s: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. e4 c5 10. e5 cxd4
			variation => N__('Semi-Slav: Meran, Old Main Line, 10...cxd4'),
			moves => {
				'c3b5' => 1,
			},
		},
		'r1bqkb1r/3n1ppp/p3pn2/1N2P3/3p4/3B1N2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'D49a',
			# TRANSLATORS: D49a: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. e4 c5 10. e5 cxd4 11. Nxb5
			variation => N__('Semi-Slav: Meran, Blumenfeld Variation'),
			moves => {
				'a6b5' => 1,
				'd7e5' => 1,
				'f6g4' => 1,
			},
		},
		'r1bqkb1r/3n1ppp/p3p3/1N2P3/3p2n1/3B1N2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D49b',
			# TRANSLATORS: D49b: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. e4 c5 10. e5 cxd4 11. Nxb5 Ng4
			variation => N__('Semi-Slav: Meran, Old Main Line, Gligoric Variation'),
			moves => {
				'd1a4' => 1,
			},
		},
		'r1bqkb1r/3n1ppp/p3p3/1N2P3/Q2p2n1/3B1N2/PP3PPP/R1B1K2R b KQkq' => {
			eco => 'D49c',
			# TRANSLATORS: D49c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. e4 c5 10. e5 cxd4 11. Nxb5 Ng4 12. Qa4
			variation => N__('Semi-Slav: Meran, Old Main Line, Gligoric, 12. Qa4'),
			moves => {
				'g4e5' => 1,
			},
		},
		'r1bqkb1r/3n1ppp/p3p3/1N2n3/Q2p4/3B1N2/PP3PPP/R1B1K2R w KQkq' => {
			eco => 'D49d',
			# TRANSLATORS: D49d: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. e4 c5 10. e5 cxd4 11. Nxb5 Ng4 12. Qa4 Ngxe5
			variation => N__('Semi-Slav: Meran, Trifunovic Variation'),
			moves => {
			},
		},
		'r1bqkb1r/5ppp/p3pn2/1N2n3/3p4/3B1N2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D49e',
			# TRANSLATORS: D49e: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. e4 c5 10. e5 cxd4 11. Nxb5 Nxe5
			variation => N__('Semi-Slav: Meran, Sozin Variation'),
			moves => {
				'f3e5' => 1,
			},
		},
		'r1bqkb1r/5ppp/p3pn2/1N2N3/3p4/3B4/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'D49e',
			# TRANSLATORS: D49e: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. e4 c5 10. e5 cxd4 11. Nxb5 Nxe5 12. Nxe5
			variation => N__('Semi-Slav: Meran, Sozin Variation'),
			moves => {
				'a6b5' => 1,
			},
		},
		'r1bqkb1r/5ppp/4pn2/1p2N3/3p4/3B4/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D49e',
			# TRANSLATORS: D49e: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. e4 c5 10. e5 cxd4 11. Nxb5 Nxe5 12. Nxe5 axb5
			variation => N__('Semi-Slav: Meran, Sozin Variation'),
			moves => {
				'd1f3' => 1,
				'd3b5' => 1,
				'e1g1' => 1,
			},
		},
		'r1bqkb1r/5ppp/4pn2/1p2N3/3p4/3B4/PP3PPP/R1BQ1RK1 b kq' => {
			eco => 'D49f',
			# TRANSLATORS: D49f: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. e4 c5 10. e5 cxd4 11. Nxb5 Nxe5 12. Nxe5 axb5 13. O-O
			variation => N__('Semi-Slav: Meran, Sozin, Rellstab Attack'),
			moves => {
			},
		},
		'r1bqkb1r/5ppp/4pn2/1p2N3/3p4/3B1Q2/PP3PPP/R1B1K2R b KQkq' => {
			eco => 'D49g',
			# TRANSLATORS: D49g: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. e4 c5 10. e5 cxd4 11. Nxb5 Nxe5 12. Nxe5 axb5 13. Qf3
			variation => N__('Semi-Slav: Meran, Sozin, Stahlberg Attack'),
			moves => {
				'f8b4' => 1,
			},
		},
		'r1bqk2r/5ppp/4pn2/1p2N3/1b1p4/3B1Q2/PP3PPP/R1B1K2R w KQkq' => {
			eco => 'D49g',
			# TRANSLATORS: D49g: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. e4 c5 10. e5 cxd4 11. Nxb5 Nxe5 12. Nxe5 axb5 13. Qf3 Bb4+
			variation => N__('Semi-Slav: Meran, Sozin, Stahlberg Attack, 13... Bb4'),
			moves => {
			},
		},
		'r1bqkb1r/5ppp/4pn2/1B2N3/3p4/8/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'D49h',
			# TRANSLATORS: D49h: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. e4 c5 10. e5 cxd4 11. Nxb5 Nxe5 12. Nxe5 axb5 13. Bxb5+
			variation => N__('Semi-Slav: Meran, Sozin, 13.Bxb5+'),
			moves => {
			},
		},
		'r1bqkb1r/3n1ppp/4pn2/1p2P3/3p4/3B1N2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D49i',
			# TRANSLATORS: D49i: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. e4 c5 10. e5 cxd4 11. Nxb5 axb5
			variation => N__('Semi-Slav: Meran, Old Main Line, 11.Nxb5 axb5'),
			moves => {
				'e5f6' => 1,
			},
		},
		'r1bqkb1r/3n1ppp/4pP2/1p6/3p4/3B1N2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'D49i',
			# TRANSLATORS: D49i: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. e4 c5 10. e5 cxd4 11. Nxb5 axb5 12. exf6
			variation => N__('Semi-Slav: Meran, Old Main Line, 11.Nxb5 axb5'),
			moves => {
				'd8b6' => 1,
				'g7f6' => 1,
			},
		},
		'r1b1kb1r/3n1ppp/1q2pP2/1p6/3p4/3B1N2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D49j',
			# TRANSLATORS: D49j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. e4 c5 10. e5 cxd4 11. Nxb5 axb5 12. exf6 Qb6
			variation => N__('Semi-Slav: Meran, Old Main Line, Botvinnik Variation'),
			moves => {
			},
		},
		'r1bqkb1r/3n1p1p/4pp2/1p6/3p4/3B1N2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'D49k',
			# TRANSLATORS: D49k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Nf3 c6 5. e3 Nbd7 6. Bd3 dxc4 7. Bxc4 b5 8. Bd3 a6 9. e4 c5 10. e5 cxd4 11. Nxb5 axb5 12. exf6 gxf6
			variation => N__('Semi-Slav: Meran, Old Main Line, 11.Nxb5 axb5 12.exf6 gxf6'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p2B1/2PP4/2N5/PP2PPPP/R2QKBNR b KQkq' => {
			eco => 'D50',
			# TRANSLATORS: D50: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5
			variation => N__('QGD: 4. Bg5'),
			moves => {
				'b8d7' => 1,
				'c7c5' => 1,
				'c7c6' => 1,
				'd5c4' => 1,
				'f8b4' => 1,
				'f8e7' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2pp2B1/2PP4/2N5/PP2PPPP/R2QKBNR w KQkq' => {
			eco => 'D50',
			# TRANSLATORS: D50: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 c5
			variation => N__('QGD: Dutch-Peruvian Gambit'),
			moves => {
				'c4d5' => 1,
				'e2e3' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2pP2B1/3P4/2N5/PP2PPPP/R2QKBNR b KQkq' => {
			eco => 'D50',
			# TRANSLATORS: D50: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 c5 5. cxd5
			variation => N__('QGD: Dutch-Peruvian, 5.cxd5'),
			moves => {
				'c5d4' => 1,
				'd8b6' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/3P2B1/3p4/2N5/PP2PPPP/R2QKBNR w KQkq' => {
			eco => 'D50',
			# TRANSLATORS: D50: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 c5 5. cxd5 cxd4
			variation => N__('QGD: Dutch-Peruvian, Prins Variation'),
			moves => {
				'd1d4' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/3P2B1/3Q4/2N5/PP2PPPP/R3KBNR b KQkq' => {
			eco => 'D50',
			# TRANSLATORS: D50: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 c5 5. cxd5 cxd4 6. Qxd4
			variation => N__('QGD: Dutch-Peruvian, Prins Variation'),
			moves => {
				'f8e7' => 1,
			},
		},
		'rnbqk2r/pp2bppp/4pn2/3P2B1/3Q4/2N5/PP2PPPP/R3KBNR w KQkq' => {
			eco => 'D50',
			# TRANSLATORS: D50: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 c5 5. cxd5 cxd4 6. Qxd4 Be7
			variation => N__('QGD: Dutch-Peruvian, Prins Variation'),
			moves => {
				'e2e4' => 1,
			},
		},
		'rnbqk2r/pp2bppp/4pn2/3P2B1/3QP3/2N5/PP3PPP/R3KBNR b KQkq' => {
			eco => 'D50',
			# TRANSLATORS: D50: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 c5 5. cxd5 cxd4 6. Qxd4 Be7 7. e4
			variation => N__('QGD: Dutch-Peruvian, Prins Variation'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2n1pn2/3P2B1/3QP3/2N5/PP3PPP/R3KBNR w KQkq' => {
			eco => 'D50',
			# TRANSLATORS: D50: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 c5 5. cxd5 cxd4 6. Qxd4 Be7 7. e4 Nc6
			variation => N__('QGD: Dutch-Peruvian, Prins, 6.Qxd4 Be7 7. e4 Nc6'),
			moves => {
				'd4d2' => 1,
			},
		},
		'r1bqk2r/pp2bppp/2n1pn2/3P2B1/4P3/2N5/PP1Q1PPP/R3KBNR b KQkq' => {
			eco => 'D50',
			# TRANSLATORS: D50: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 c5 5. cxd5 cxd4 6. Qxd4 Be7 7. e4 Nc6 8. Qd2
			variation => N__('QGD: Dutch-Peruvian, Prins, 6.Qxd4 Be7 7. e4 Nc6 8. Qd2'),
			moves => {
			},
		},
		'rnb1kb1r/pp3ppp/1q2pn2/2pP2B1/3P4/2N5/PP2PPPP/R2QKBNR w KQkq' => {
			eco => 'D50',
			# TRANSLATORS: D50: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 c5 5. cxd5 Qb6
			variation => N__('QGD: Dutch-Peruvian, Canal (Venice) Variation'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2pp2B1/2PP4/2N1P3/PP3PPP/R2QKBNR b KQkq' => {
			eco => 'D50',
			# TRANSLATORS: D50: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 c5 5. e3
			variation => N__('QGD: Dutch-Peruvian, 5. e3'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2pp2B1/2PP4/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D50',
			# TRANSLATORS: D50: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 c5 5. Nf3
			variation => N__('QGD: Semi-Tarrasch, Pillsbury Variation'),
			moves => {
				'c5d4' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/3p2B1/2Pp4/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'D50',
			# TRANSLATORS: D50: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 c5 5. Nf3 cxd4
			variation => N__('QGD: Semi-Tarrasch, Pillsbury Variation'),
			moves => {
				'd1d4' => 1,
				'f3d4' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/3p2B1/2PQ4/2N2N2/PP2PPPP/R3KB1R b KQkq' => {
			eco => 'D50',
			# TRANSLATORS: D50: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 c5 5. Nf3 cxd4 6. Qxd4
			variation => N__('QGD: Semi-Tarrasch, Old Pillsbury Variation'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/3p2B1/2PN4/2N5/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D50',
			# TRANSLATORS: D50: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 c5 5. Nf3 cxd4 6. Nxd4
			variation => N__('QGD: Semi-Tarrasch, Pillsbury, 6.Nxd4'),
			moves => {
				'e6e5' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/5n2/3pp1B1/2PN4/2N5/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'D50',
			# TRANSLATORS: D50: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 c5 5. Nf3 cxd4 6. Nxd4 e5
			variation => N__('QGD: Semi-Tarrasch, Pillsbury, 6.Nxd4 e5'),
			moves => {
				'd4b5' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/5n2/1N1pp1B1/2P5/2N5/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D50',
			# TRANSLATORS: D50: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 c5 5. Nf3 cxd4 6. Nxd4 e5 7. Ndb5
			variation => N__('QGD: Semi-Tarrasch, Pillsbury, 6.Nxd4 e5'),
			moves => {
				'a7a6' => 1,
			},
		},
		'rnbqkb1r/1p3ppp/p4n2/1N1pp1B1/2P5/2N5/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'D50',
			# TRANSLATORS: D50: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 c5 5. Nf3 cxd4 6. Nxd4 e5 7. Ndb5 a6
			variation => N__('QGD: Semi-Tarrasch, Pillsbury, 6.Nxd4 e5'),
			moves => {
				'd1a4' => 1,
			},
		},
		'rnbqkb1r/1p3ppp/p4n2/1N1pp1B1/Q1P5/2N5/PP2PPPP/R3KB1R b KQkq' => {
			eco => 'D50',
			# TRANSLATORS: D50: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 c5 5. Nf3 cxd4 6. Nxd4 e5 7. Ndb5 a6 8. Qa4
			variation => N__('QGD: Semi-Tarrasch, Pillsbury, Krause Variation'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/2p1pn2/3p2B1/2PP4/2N5/PP2PPPP/R2QKBNR w KQkq' => {
			eco => 'D50',
			# TRANSLATORS: D50: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 c6
			variation => N__('QGD: 4. Bg5 c6'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/6B1/2pP4/2N5/PP2PPPP/R2QKBNR w KQkq' => {
			eco => 'D50',
			# TRANSLATORS: D50: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 dxc4
			variation => N__('QGD: 4. Bg5 dxc4'),
			moves => {
			},
		},
		'rnbqk2r/ppp2ppp/4pn2/3p2B1/1bPP4/2N5/PP2PPPP/R2QKBNR w KQkq' => {
			eco => 'D50',
			# TRANSLATORS: D50: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Bb4
			variation => N__('QGD: 4. Bg5 Bb4'),
			moves => {
			},
		},
		'r1bqkb1r/pppn1ppp/4pn2/3p2B1/2PP4/2N5/PP2PPPP/R2QKBNR w KQkq' => {
			eco => 'D51',
			# TRANSLATORS: D51: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Nbd7
			variation => N__('QGD: 4. Bg5 Nbd7'),
			moves => {
				'e2e3' => 1,
				'g1f3' => 1,
			},
		},
		'r1bqkb1r/pppn1ppp/4pn2/3p2B1/2PP4/2N1P3/PP3PPP/R2QKBNR b KQkq' => {
			eco => 'D51',
			# TRANSLATORS: D51: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Nbd7 5. e3
			variation => N__('QGD: 4. Bg5 Nbd7 5. e3'),
			moves => {
				'c7c6' => 1,
				'f8b4' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/2p1pn2/3p2B1/2PP4/2N1P3/PP3PPP/R2QKBNR w KQkq' => {
			eco => 'D51',
			# TRANSLATORS: D51: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Nbd7 5. e3 c6
			variation => N__('QGD: 4. Bg5 Nbd7 5. e3 c6'),
			moves => {
				'a2a3' => 1,
				'c4d5' => 1,
				'd1c2' => 1,
				'g1f3' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/2p1pn2/3p2B1/2PP4/P1N1P3/1P3PPP/R2QKBNR b KQkq' => {
			eco => 'D51',
			# TRANSLATORS: D51: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Nbd7 5. e3 c6 6. a3
			variation => N__('QGD: Capablanca\'s Anti-Cambridge Springs'),
			moves => {
			},
		},
		'r1bqkb1r/pp1n1ppp/2p1pn2/3P2B1/3P4/2N1P3/PP3PPP/R2QKBNR b KQkq' => {
			eco => 'D51',
			# TRANSLATORS: D51: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Nbd7 5. e3 c6 6. cxd5
			variation => N__('QGD: 4. Bg5 Nbd7 5. e3 c6'),
			moves => {
				'c6d5' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/4pn2/3p2B1/3P4/2N1P3/PP3PPP/R2QKBNR w KQkq' => {
			eco => 'D51',
			# TRANSLATORS: D51: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Nbd7 5. e3 c6 6. cxd5 cxd5
			variation => N__('QGD: 4. Bg5 Nbd7 5. e3 c6 6.cxd5 cxd5'),
			moves => {
			},
		},
		'r1bqkb1r/pp1n1ppp/2p1pn2/3p2B1/2PP4/2N1P3/PPQ2PPP/R3KBNR b KQkq' => {
			eco => 'D51',
			# TRANSLATORS: D51: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Nbd7 5. e3 c6 6. Qc2
			variation => N__('QGD: 4. Bg5 Nbd7 5. e3 c6 6. Qc2'),
			moves => {
			},
		},
		'r1bqk2r/pppn1ppp/4pn2/3p2B1/1bPP4/2N1P3/PP3PPP/R2QKBNR w KQkq' => {
			eco => 'D51',
			# TRANSLATORS: D51: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Nbd7 5. e3 Bb4
			variation => N__('QGD: Manhattan Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pppn1ppp/4pn2/3p2B1/2PP4/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D51',
			# TRANSLATORS: D51: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Nbd7 5. Nf3
			variation => N__('QGD: 4. Bg5 Nbd7 5. Nf3'),
			moves => {
				'c7c6' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/2p1pn2/3p2B1/2PP4/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'D51',
			# TRANSLATORS: D51: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Nbd7 5. Nf3 c6
			variation => N__('QGD: 4. Bg5 Nbd7 5. Nf3 c6'),
			moves => {
				'a1c1' => 1,
				'e2e4' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/2p1pn2/3p2B1/2PP4/2N2N2/PP2PPPP/2RQKB1R b Kkq' => {
			eco => 'D51',
			# TRANSLATORS: D51: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Nbd7 5. Nf3 c6 6. Rc1
			variation => N__('QGD: 4. Bg5 Nbd7 5. Nf3 c6'),
			moves => {
				'd8a5' => 1,
			},
		},
		'r1b1kb1r/pp1n1ppp/2p1pn2/q2p2B1/2PP4/2N2N2/PP2PPPP/2RQKB1R w Kkq' => {
			eco => 'D51',
			# TRANSLATORS: D51: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Nbd7 5. Nf3 c6 6. Rc1 Qa5
			variation => N__('QGD: 4. Bg5 Nbd7 5. Nf3 c6'),
			moves => {
				'g5d2' => 1,
			},
		},
		'r1b1kb1r/pp1n1ppp/2p1pn2/q2p4/2PP4/2N2N2/PP1BPPPP/2RQKB1R b Kkq' => {
			eco => 'D51',
			# TRANSLATORS: D51: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Nbd7 5. Nf3 c6 6. Rc1 Qa5 7. Bd2
			variation => N__('QGD: Rochlin Variation'),
			moves => {
			},
		},
		'r1bqkb1r/pp1n1ppp/2p1pn2/3p2B1/2PPP3/2N2N2/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'D51',
			# TRANSLATORS: D51: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Nbd7 5. Nf3 c6 6. e4
			variation => N__('QGD: Alekhine 4. Bg5 Nbd7 5. Nf3 c6 6. e4'),
			moves => {
			},
		},
		'r1bqkb1r/pp1n1ppp/2p1pn2/3p2B1/2PP4/2N1PN2/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'D52a',
			# TRANSLATORS: D52a: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Nbd7 5. e3 c6 6. Nf3
			variation => N__('QGD: 4. Bg5 Nbd7 5. e3 c6 6. Nf3'),
			moves => {
				'd8a5' => 1,
			},
		},
		'r1b1kb1r/pp1n1ppp/2p1pn2/q2p2B1/2PP4/2N1PN2/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'D52b',
			# TRANSLATORS: D52b: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Nbd7 5. e3 c6 6. Nf3 Qa5
			variation => N__('QGD: Cambridge Springs Defence'),
			moves => {
				'c4d5' => 1,
				'f3d2' => 1,
				'g5f6' => 1,
			},
		},
		'r1b1kb1r/pp1n1ppp/2p1pB2/q2p4/2PP4/2N1PN2/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'D52c',
			# TRANSLATORS: D52c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Nbd7 5. e3 c6 6. Nf3 Qa5 7. Bxf6
			variation => N__('QGD: Cambridge Springs, Capablanca Variation'),
			moves => {
			},
		},
		'r1b1kb1r/pp1n1ppp/2p1pn2/q2P2B1/3P4/2N1PN2/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'D52d',
			# TRANSLATORS: D52d: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Nbd7 5. e3 c6 6. Nf3 Qa5 7. cxd5
			variation => N__('QGD: Cambridge Springs, 7.cxd5'),
			moves => {
				'f6d5' => 1,
			},
		},
		'r1b1kb1r/pp1n1ppp/2p1p3/q2n2B1/3P4/2N1PN2/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'D52e',
			# TRANSLATORS: D52e: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Nbd7 5. e3 c6 6. Nf3 Qa5 7. cxd5 Nxd5
			variation => N__('QGD: Cambridge Springs, Yugoslav Variation'),
			moves => {
				'd1d2' => 1,
			},
		},
		'r1b1kb1r/pp1n1ppp/2p1p3/q2n2B1/3P4/2N1PN2/PP1Q1PPP/R3KB1R b KQkq' => {
			eco => 'D52f',
			# TRANSLATORS: D52f: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Nbd7 5. e3 c6 6. Nf3 Qa5 7. cxd5 Nxd5 8. Qd2
			variation => N__('QGD: Cambridge Springs, Yugoslav, 8. Qd2'),
			moves => {
			},
		},
		'r1b1kb1r/pp1n1ppp/2p1pn2/q2p2B1/2PP4/2N1P3/PP1N1PPP/R2QKB1R b KQkq' => {
			eco => 'D52g',
			# TRANSLATORS: D52g: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Nbd7 5. e3 c6 6. Nf3 Qa5 7. Nd2
			variation => N__('QGD: Cambridge Springs, 7. Nd2'),
			moves => {
				'd5c4' => 1,
				'f8b4' => 1,
			},
		},
		'r1b1kb1r/pp1n1ppp/2p1pn2/q5B1/2pP4/2N1P3/PP1N1PPP/R2QKB1R w KQkq' => {
			eco => 'D52h',
			# TRANSLATORS: D52h: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Nbd7 5. e3 c6 6. Nf3 Qa5 7. Nd2 dxc4
			variation => N__('QGD: Cambridge Springs, Rubinstein Variation'),
			moves => {
			},
		},
		'r1b1k2r/pp1n1ppp/2p1pn2/q2p2B1/1bPP4/2N1P3/PP1N1PPP/R2QKB1R w KQkq' => {
			eco => 'D52i',
			# TRANSLATORS: D52i: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Nbd7 5. e3 c6 6. Nf3 Qa5 7. Nd2 Bb4
			variation => N__('QGD: Cambridge Springs, Bogoljubow Variation'),
			moves => {
				'd1c2' => 1,
			},
		},
		'r1b1k2r/pp1n1ppp/2p1pn2/q2p2B1/1bPP4/2N1P3/PPQN1PPP/R3KB1R b KQkq' => {
			eco => 'D52j',
			# TRANSLATORS: D52j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Nbd7 5. e3 c6 6. Nf3 Qa5 7. Nd2 Bb4 8. Qc2
			variation => N__('QGD: Cambridge Springs, Bogoljubow, 8. Qc2'),
			moves => {
				'd5c4' => 1,
				'e8g8' => 1,
			},
		},
		'r1b1k2r/pp1n1ppp/2p1pn2/q5B1/1bpP4/2N1P3/PPQN1PPP/R3KB1R w KQkq' => {
			eco => 'D52k',
			# TRANSLATORS: D52k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Nbd7 5. e3 c6 6. Nf3 Qa5 7. Nd2 Bb4 8. Qc2 dxc4
			variation => N__('QGD: Cambridge Springs, 8. Qc2 dxc4'),
			moves => {
			},
		},
		'r1b2rk1/pp1n1ppp/2p1pn2/q2p2B1/1bPP4/2N1P3/PPQN1PPP/R3KB1R w KQ' => {
			eco => 'D52l',
			# TRANSLATORS: D52l: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Nbd7 5. e3 c6 6. Nf3 Qa5 7. Nd2 Bb4 8. Qc2 O-O
			variation => N__('QGD: Cambridge Springs, 8. Qc2 O-O'),
			moves => {
				'f1e2' => 1,
				'g5h4' => 1,
			},
		},
		'r1b2rk1/pp1n1ppp/2p1pn2/q2p4/1bPP3B/2N1P3/PPQN1PPP/R3KB1R b KQ' => {
			eco => 'D52m',
			# TRANSLATORS: D52m: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Nbd7 5. e3 c6 6. Nf3 Qa5 7. Nd2 Bb4 8. Qc2 O-O 9. Bh4
			variation => N__('QGD: Cambridge Springs, Argentine Variation'),
			moves => {
			},
		},
		'r1b2rk1/pp1n1ppp/2p1pn2/q2p2B1/1bPP4/2N1P3/PPQNBPPP/R3K2R b KQ' => {
			eco => 'D52n',
			# TRANSLATORS: D52n: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Nbd7 5. e3 c6 6. Nf3 Qa5 7. Nd2 Bb4 8. Qc2 O-O 9. Be2
			variation => N__('QGD: Cambridge Springs, 8. Qc2 O-O 9. Be2'),
			moves => {
				'e6e5' => 1,
			},
		},
		'r1b2rk1/pp1n1ppp/2p2n2/q2pp1B1/1bPP4/2N1P3/PPQNBPPP/R3K2R w KQ' => {
			eco => 'D52o',
			# TRANSLATORS: D52o: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Nbd7 5. e3 c6 6. Nf3 Qa5 7. Nd2 Bb4 8. Qc2 O-O 9. Be2 e5
			variation => N__('QGD: Cambridge Springs, 8. Qc2 O-O 9. Be2 e5'),
			moves => {
			},
		},
		'rnbqk2r/ppp1bppp/4pn2/3p2B1/2PP4/2N5/PP2PPPP/R2QKBNR w KQkq' => {
			eco => 'D53a',
			# TRANSLATORS: D53a: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7
			variation => N__('QGD: 4. Bg5 Be7'),
			moves => {
				'c4d5' => 1,
				'e2e3' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqk2r/ppp1bppp/4pn2/3P2B1/3P4/2N5/PP2PPPP/R2QKBNR b KQkq' => {
			eco => 'D53a',
			# TRANSLATORS: D53a: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. cxd5
			variation => N__('QGD: 4. Bg5 Be7'),
			moves => {
				'f6d5' => 1,
			},
		},
		'rnbqk2r/ppp1bppp/4p3/3n2B1/3P4/2N5/PP2PPPP/R2QKBNR w KQkq' => {
			eco => 'D53b',
			# TRANSLATORS: D53b: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. cxd5 Nxd5
			variation => N__('QGD: 4. Bg5 Be7 5.cxd5 Nxd5'),
			moves => {
			},
		},
		'rnbqk2r/ppp1bppp/4pn2/3p2B1/2PP4/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D53c',
			# TRANSLATORS: D53c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. Nf3
			variation => N__('QGD: 4. Bg5 Be7 5. Nf3'),
			moves => {
				'e8g8' => 1,
				'h7h6' => 1,
			},
		},
		'rnbqk2r/ppp1bpp1/4pn1p/3p2B1/2PP4/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'D53d',
			# TRANSLATORS: D53d: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. Nf3 h6
			variation => N__('QGD: 4. Bg5 Be7 5. Nf3 h6'),
			moves => {
				'g5f6' => 1,
				'g5h4' => 1,
			},
		},
		'rnbqk2r/ppp1bpp1/4pB1p/3p4/2PP4/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D53e',
			# TRANSLATORS: D53e: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. Nf3 h6 6. Bxf6
			variation => N__('QGD: 4. Bg5 Be7 5. Nf3 h6 6.Bxf6'),
			moves => {
				'e7f6' => 1,
			},
		},
		'rnbqk2r/ppp2pp1/4pb1p/3p4/2PP4/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'D53f',
			# TRANSLATORS: D53f: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. Nf3 h6 6. Bxf6 Bxf6
			variation => N__('QGD: 4. Bg5 Be7 5. Nf3 h6 6.Bxf6 Bxf6'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbqk2r/ppp2pp1/4pb1p/3p4/2PP4/2N1PN2/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'D53g',
			# TRANSLATORS: D53g: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. Nf3 h6 6. Bxf6 Bxf6 7. e3
			variation => N__('QGD: 4. Bg5 Be7 5. Nf3 h6 6.Bxf6 Bxf6 7. e3'),
			moves => {
			},
		},
		'rnbqk2r/ppp1bpp1/4pn1p/3p4/2PP3B/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D53h',
			# TRANSLATORS: D53h: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. Nf3 h6 6. Bh4
			variation => N__('QGD: 4. Bg5 Be7 5. Nf3 h6 6. Bh4'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppp1bpp1/4pn1p/3p4/2PP3B/2N2N2/PP2PPPP/R2QKB1R w KQ' => {
			eco => 'D53i',
			# TRANSLATORS: D53i: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. Nf3 h6 6. Bh4 O-O
			variation => N__('QGD: 4. Bg5 Be7 5. Nf3 h6 6. Bh4 O-O'),
			moves => {
				'a1c1' => 1,
				'd1c2' => 1,
			},
		},
		'rnbq1rk1/ppp1bpp1/4pn1p/3p4/2PP3B/2N2N2/PPQ1PPPP/R3KB1R b KQ' => {
			eco => 'D53j',
			# TRANSLATORS: D53j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. Nf3 h6 6. Bh4 O-O 7. Qc2
			variation => N__('QGD: 4. Bg5 Be7 5. Nf3 h6 6. Bh4 O-O 7. Qc2'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1bpp1/4pn1p/3p4/2PP3B/2N2N2/PP2PPPP/2RQKB1R b K' => {
			eco => 'D53k',
			# TRANSLATORS: D53k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. Nf3 h6 6. Bh4 O-O 7. Rc1
			variation => N__('QGD: 4. Bg5 Be7 5. Nf3 h6 6. Bh4 O-O 7. Rc1'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1bppp/4pn2/3p2B1/2PP4/2N2N2/PP2PPPP/R2QKB1R w KQ' => {
			eco => 'D53l',
			# TRANSLATORS: D53l: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. Nf3 O-O
			variation => N__('QGD: 4. Bg5 Be7 5. Nf3 O-O'),
			moves => {
				'd1c2' => 1,
			},
		},
		'rnbq1rk1/ppp1bppp/4pn2/3p2B1/2PP4/2N2N2/PPQ1PPPP/R3KB1R b KQ' => {
			eco => 'D53m',
			# TRANSLATORS: D53m: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. Nf3 O-O 6. Qc2
			variation => N__('QGD: 4. Bg5 Be7 5. Nf3 O-O 6. Qc2'),
			moves => {
				'b8d7' => 1,
				'c7c5' => 1,
			},
		},
		'r1bq1rk1/pppnbppp/4pn2/3p2B1/2PP4/2N2N2/PPQ1PPPP/R3KB1R w KQ' => {
			eco => 'D53n',
			# TRANSLATORS: D53n: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. Nf3 O-O 6. Qc2 Nbd7
			variation => N__('QGD: 4. Bg5 Be7 5. Nf3 O-O 6. Qc2 Nbd7'),
			moves => {
			},
		},
		'rnbq1rk1/pp2bppp/4pn2/2pp2B1/2PP4/2N2N2/PPQ1PPPP/R3KB1R w KQ' => {
			eco => 'D53o',
			# TRANSLATORS: D53o: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. Nf3 O-O 6. Qc2 c5
			variation => N__('QGD: 4. Bg5 Be7 5. Nf3 O-O 6. Qc2 c5'),
			moves => {
			},
		},
		'rnbqk2r/ppp1bppp/4pn2/3p2B1/2PP4/2N1P3/PP3PPP/R2QKBNR b KQkq' => {
			eco => 'D53p',
			# TRANSLATORS: D53p: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3
			variation => N__('QGD: 4. Bg5 Be7 5. e3'),
			moves => {
				'b8d7' => 1,
				'e8g8' => 1,
				'f6e4' => 1,
				'h7h6' => 1,
			},
		},
		'rnbqk2r/ppp1bppp/4p3/3p2B1/2PPn3/2N1P3/PP3PPP/R2QKBNR w KQkq' => {
			eco => 'D53q',
			# TRANSLATORS: D53q: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 Ne4
			variation => N__('QGD: Early Lasker Variation'),
			moves => {
			},
		},
		'r1bqk2r/pppnbppp/4pn2/3p2B1/2PP4/2N1P3/PP3PPP/R2QKBNR w KQkq' => {
			eco => 'D53r',
			# TRANSLATORS: D53r: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 Nbd7
			variation => N__('QGD: 4. Bg5 Be7 5. e3 Nbd7'),
			moves => {
				'g1f3' => 1,
			},
		},
		'r1bqk2r/pppnbppp/4pn2/3p2B1/2PP4/2N1PN2/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'D53s',
			# TRANSLATORS: D53s: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 Nbd7 6. Nf3
			variation => N__('QGD: 4. Bg5 Be7 5. e3 Nbd7 6. Nf3'),
			moves => {
			},
		},
		'rnbqk2r/ppp1bpp1/4pn1p/3p2B1/2PP4/2N1P3/PP3PPP/R2QKBNR w KQkq' => {
			eco => 'D53t',
			# TRANSLATORS: D53t: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 h6
			variation => N__('QGD: 4. Bg5 Be7 5. e3 h6'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1bppp/4pn2/3p2B1/2PP4/2N1P3/PP3PPP/R2QKBNR w KQ' => {
			eco => 'D53u',
			# TRANSLATORS: D53u: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O
			variation => N__('QGD: 4. Bg5 Be7 5. e3 O-O'),
			moves => {
				'a1c1' => 1,
				'd1c2' => 1,
				'g1f3' => 1,
			},
		},
		'rnbq1rk1/ppp1bppp/4pn2/3p2B1/2PP4/2N1P3/PPQ2PPP/R3KBNR b KQ' => {
			eco => 'D53v',
			# TRANSLATORS: D53v: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Qc2
			variation => N__('QGD: 4. Bg5 Be7 5. e3 O-O 6. Qc2'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbq1rk1/pp2bppp/4pn2/2pp2B1/2PP4/2N1P3/PPQ2PPP/R3KBNR w KQ' => {
			eco => 'D53v',
			# TRANSLATORS: D53v: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Qc2 c5
			variation => N__('QGD: 4. Bg5 Be7 5. e3 O-O 6. Qc2 c5'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1bppp/4pn2/3p2B1/2PP4/2N1P3/PP3PPP/2RQKBNR b K' => {
			eco => 'D54a',
			# TRANSLATORS: D54a: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Rc1
			variation => N__('QGD: Anti-Neo-Orthodox Variation'),
			moves => {
				'h7h6' => 1,
			},
		},
		'rnbq1rk1/ppp1bpp1/4pn1p/3p2B1/2PP4/2N1P3/PP3PPP/2RQKBNR w K' => {
			eco => 'D54a',
			# TRANSLATORS: D54a: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Rc1 h6
			variation => N__('QGD: Anti-Neo-Orthodox Variation'),
			moves => {
				'g5h4' => 1,
			},
		},
		'rnbq1rk1/ppp1bpp1/4pn1p/3p4/2PP3B/2N1P3/PP3PPP/2RQKBNR b K' => {
			eco => 'D54b',
			# TRANSLATORS: D54b: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Rc1 h6 7. Bh4
			variation => N__('QGD: Anti-Neo-Orthodox Variation'),
			moves => {
				'b7b6' => 1,
			},
		},
		'rnbq1rk1/p1p1bpp1/1p2pn1p/3p4/2PP3B/2N1P3/PP3PPP/2RQKBNR w K' => {
			eco => 'D54c',
			# TRANSLATORS: D54c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Rc1 h6 7. Bh4 b6
			variation => N__('QGD: Anti-Neo-Orthodox, 7. Bh4 b6'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rnbq1rk1/p1p1bpp1/1p2pn1p/3P4/3P3B/2N1P3/PP3PPP/2RQKBNR b K' => {
			eco => 'D54c',
			# TRANSLATORS: D54c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Rc1 h6 7. Bh4 b6 8. cxd5
			variation => N__('QGD: Anti-Neo-Orthodox, 7. Bh4 b6'),
			moves => {
				'f6d5' => 1,
			},
		},
		'rnbq1rk1/p1p1bpp1/1p2p2p/3n4/3P3B/2N1P3/PP3PPP/2RQKBNR w K' => {
			eco => 'D54c',
			# TRANSLATORS: D54c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Rc1 h6 7. Bh4 b6 8. cxd5 Nxd5
			variation => N__('QGD: Anti-Neo-Orthodox, 7. Bh4 b6'),
			moves => {
				'c3d5' => 1,
			},
		},
		'rnbq1rk1/p1p1bpp1/1p2p2p/3N4/3P3B/4P3/PP3PPP/2RQKBNR b K' => {
			eco => 'D54c',
			# TRANSLATORS: D54c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Rc1 h6 7. Bh4 b6 8. cxd5 Nxd5 9. Nxd5
			variation => N__('QGD: Anti-Neo-Orthodox, 8.cxd5 Nxd5 9.Nxd5'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rnbq1rk1/p1p1bpp1/1p5p/3p4/3P3B/4P3/PP3PPP/2RQKBNR w K' => {
			eco => 'D54c',
			# TRANSLATORS: D54c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Rc1 h6 7. Bh4 b6 8. cxd5 Nxd5 9. Nxd5 exd5
			variation => N__('QGD: Anti-Neo-Orthodox, 8.cxd5 Nxd5 9.Nxd5'),
			moves => {
				'h4e7' => 1,
			},
		},
		'rnbq1rk1/p1p1Bpp1/1p5p/3p4/3P4/4P3/PP3PPP/2RQKBNR b K' => {
			eco => 'D54c',
			# TRANSLATORS: D54c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Rc1 h6 7. Bh4 b6 8. cxd5 Nxd5 9. Nxd5 exd5 10. Bxe7
			variation => N__('QGD: Anti-Neo-Orthodox, 8.cxd5 Nxd5 9.Nxd5'),
			moves => {
				'd8e7' => 1,
			},
		},
		'rnb2rk1/p1p1qpp1/1p5p/3p4/3P4/4P3/PP3PPP/2RQKBNR w K' => {
			eco => 'D54d',
			# TRANSLATORS: D54d: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Rc1 h6 7. Bh4 b6 8. cxd5 Nxd5 9. Nxd5 exd5 10. Bxe7 Qxe7
			variation => N__('QGD: Anti-Neo-Orthodox, Main Line'),
			moves => {
				'f1e2' => 1,
			},
		},
		'rnb2rk1/p1p1qpp1/1p5p/3p4/3P4/4P3/PP2BPPP/2RQK1NR b K' => {
			eco => 'D54e',
			# TRANSLATORS: D54e: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Rc1 h6 7. Bh4 b6 8. cxd5 Nxd5 9. Nxd5 exd5 10. Bxe7 Qxe7 11. Be2
			variation => N__('QGD: Anti-Neo-Orthodox, Main Line, 11. Be2'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1bppp/4pn2/3p2B1/2PP4/2N1PN2/PP3PPP/R2QKB1R b KQ' => {
			eco => 'D55a',
			# TRANSLATORS: D55a: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3
			variation => N__('QGD: 6. Nf3'),
			moves => {
				'b7b6' => 1,
				'b8d7' => 1,
				'f6e4' => 1,
				'h7h6' => 1,
			},
		},
		'rnbq1rk1/ppp1bppp/4p3/3p2B1/2PPn3/2N1PN2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'D55b',
			# TRANSLATORS: D55b: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Ne4
			variation => N__('QGD: Lasker without ...h6'),
			moves => {
			},
		},
		'rnbq1rk1/p1p1bppp/1p2pn2/3p2B1/2PP4/2N1PN2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'D55c',
			# TRANSLATORS: D55c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 b6
			variation => N__('QGD: 6. Nf3 b6'),
			moves => {
				'c4d5' => 1,
				'f1e2' => 1,
			},
		},
		'rnbq1rk1/p1p1bppp/1p2pn2/3P2B1/3P4/2N1PN2/PP3PPP/R2QKB1R b KQ' => {
			eco => 'D55c',
			# TRANSLATORS: D55c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 b6 7. cxd5
			variation => N__('QGD: 6. Nf3 b6'),
			moves => {
				'e6d5' => 1,
				'f6d5' => 1,
			},
		},
		'rnbq1rk1/p1p1bppp/1p2pn2/3p2B1/2PP4/2N1PN2/PP2BPPP/R2QK2R b KQ' => {
			eco => 'D55d',
			# TRANSLATORS: D55d: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 b6 7. Be2
			variation => N__('QGD: 6. Nf3 b6 7. Be2'),
			moves => {
			},
		},
		'rnbq1rk1/p1p1bppp/1p3n2/3p2B1/3P4/2N1PN2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'D55e',
			# TRANSLATORS: D55e: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 b6 7. cxd5 exd5
			variation => N__('QGD: 6. Nf3 b6 7.cxd5 exd5'),
			moves => {
			},
		},
		'rnbq1rk1/p1p1bppp/1p2p3/3n2B1/3P4/2N1PN2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'D55f',
			# TRANSLATORS: D55f: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 b6 7. cxd5 Nxd5
			variation => N__('QGD: 6. Nf3 b6 7.cxd5 Nxd5'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1bpp1/4pn1p/3p2B1/2PP4/2N1PN2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'D55g',
			# TRANSLATORS: D55g: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6
			variation => N__('QGD: Neo-Orthodox Variation'),
			moves => {
				'g5f6' => 1,
				'g5h4' => 1,
			},
		},
		'rnbq1rk1/ppp1bpp1/4pB1p/3p4/2PP4/2N1PN2/PP3PPP/R2QKB1R b KQ' => {
			eco => 'D55h',
			# TRANSLATORS: D55h: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bxf6
			variation => N__('QGD: Neo-Orthodox, 7.Bxf6'),
			moves => {
				'e7f6' => 1,
			},
		},
		'rnbq1rk1/ppp2pp1/4pb1p/3p4/2PP4/2N1PN2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'D55h',
			# TRANSLATORS: D55h: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bxf6 Bxf6
			variation => N__('QGD: Neo-Orthodox, 7.Bxf6'),
			moves => {
				'a1c1' => 1,
				'd1b3' => 1,
			},
		},
		'rnbq1rk1/ppp2pp1/4pb1p/3p4/2PP4/1QN1PN2/PP3PPP/R3KB1R b KQ' => {
			eco => 'D55i',
			# TRANSLATORS: D55i: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bxf6 Bxf6 8. Qb3
			variation => N__('QGD: Neo-Orthodox, 7.Bxf6 Bxf6 8. Qb3'),
			moves => {
			},
		},
		'rnbq1rk1/ppp2pp1/4pb1p/3p4/2PP4/2N1PN2/PP3PPP/2RQKB1R b K' => {
			eco => 'D55j',
			# TRANSLATORS: D55j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bxf6 Bxf6 8. Rc1
			variation => N__('QGD: Neo-Orthodox, Gligoric Variation'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rnbq1rk1/pp3pp1/2p1pb1p/3p4/2PP4/2N1PN2/PP3PPP/2RQKB1R w K' => {
			eco => 'D55j',
			# TRANSLATORS: D55j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bxf6 Bxf6 8. Rc1 c6
			variation => N__('QGD: Neo-Orthodox, Gligoric Variation'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rnbq1rk1/pp3pp1/2p1pb1p/3p4/2PP4/2NBPN2/PP3PPP/2RQK2R b K' => {
			eco => 'D55j',
			# TRANSLATORS: D55j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bxf6 Bxf6 8. Rc1 c6 9. Bd3
			variation => N__('QGD: Neo-Orthodox, Gligoric Variation'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r1bq1rk1/pp1n1pp1/2p1pb1p/3p4/2PP4/2NBPN2/PP3PPP/2RQK2R w K' => {
			eco => 'D55j',
			# TRANSLATORS: D55j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bxf6 Bxf6 8. Rc1 c6 9. Bd3 Nd7
			variation => N__('QGD: Neo-Orthodox, Gligoric Variation'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bq1rk1/pp1n1pp1/2p1pb1p/3p4/2PP4/2NBPN2/PP3PPP/2RQ1RK1 b -' => {
			eco => 'D55j',
			# TRANSLATORS: D55j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bxf6 Bxf6 8. Rc1 c6 9. Bd3 Nd7 10. O-O
			variation => N__('QGD: Neo-Orthodox, Gligoric Variation'),
			moves => {
				'd5c4' => 1,
			},
		},
		'r1bq1rk1/pp1n1pp1/2p1pb1p/8/2pP4/2NBPN2/PP3PPP/2RQ1RK1 w -' => {
			eco => 'D55j',
			# TRANSLATORS: D55j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bxf6 Bxf6 8. Rc1 c6 9. Bd3 Nd7 10. O-O dxc4
			variation => N__('QGD: Neo-Orthodox, Gligoric Variation'),
			moves => {
				'd3c4' => 1,
			},
		},
		'r1bq1rk1/pp1n1pp1/2p1pb1p/8/2BP4/2N1PN2/PP3PPP/2RQ1RK1 b -' => {
			eco => 'D55k',
			# TRANSLATORS: D55k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bxf6 Bxf6 8. Rc1 c6 9. Bd3 Nd7 10. O-O dxc4 11. Bxc4
			variation => N__('QGD: Neo-Orthodox, Petrosian Variation'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1bpp1/4pn1p/3p4/2PP3B/2N1PN2/PP3PPP/R2QKB1R b KQ' => {
			eco => 'D56',
			# TRANSLATORS: D56: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4
			variation => N__('QGD: Neo-Orthodox, 7. Bh4'),
			moves => {
				'b7b6' => 1,
				'f6e4' => 1,
			},
		},
		'rnbq1rk1/ppp1bpp1/4p2p/3p4/2PPn2B/2N1PN2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'D56',
			# TRANSLATORS: D56: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 Ne4
			variation => N__('QGD: Lasker Defence'),
			moves => {
				'h4e7' => 1,
			},
		},
		'rnbq1rk1/ppp1Bpp1/4p2p/3p4/2PPn3/2N1PN2/PP3PPP/R2QKB1R b KQ' => {
			eco => 'D56',
			# TRANSLATORS: D56: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 Ne4 8. Bxe7
			variation => N__('QGD: Lasker Defence'),
			moves => {
				'd8e7' => 1,
			},
		},
		'rnb2rk1/ppp1qpp1/4p2p/3p4/2PPn3/2N1PN2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'D56',
			# TRANSLATORS: D56: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 Ne4 8. Bxe7 Qxe7
			variation => N__('QGD: Lasker Defence'),
			moves => {
				'a1c1' => 1,
				'c3e4' => 1,
				'c4d5' => 1,
				'd1c2' => 1,
			},
		},
		'rnb2rk1/ppp1qpp1/4p2p/3p4/2PPn3/2N1PN2/PP3PPP/2RQKB1R b K' => {
			eco => 'D56',
			# TRANSLATORS: D56: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 Ne4 8. Bxe7 Qxe7 9. Rc1
			variation => N__('QGD: Lasker Defence, 9. Rc1'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rnb2rk1/pp2qpp1/2p1p2p/3p4/2PPn3/2N1PN2/PP3PPP/2RQKB1R w K' => {
			eco => 'D56',
			# TRANSLATORS: D56: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 Ne4 8. Bxe7 Qxe7 9. Rc1 c6
			variation => N__('QGD: Lasker Defence, 9. Rc1 c6'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rnb2rk1/pp2qpp1/2p1p2p/3p4/2PPn3/2NBPN2/PP3PPP/2RQK2R b K' => {
			eco => 'D56',
			# TRANSLATORS: D56: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 Ne4 8. Bxe7 Qxe7 9. Rc1 c6 10. Bd3
			variation => N__('QGD: Lasker Defence, 9. Rc1 c6 10. Bd3'),
			moves => {
			},
		},
		'rnb2rk1/ppp1qpp1/4p2p/3p4/2PPN3/4PN2/PP3PPP/R2QKB1R b KQ' => {
			eco => 'D56',
			# TRANSLATORS: D56: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 Ne4 8. Bxe7 Qxe7 9. Nxe4
			variation => N__('QGD: Lasker Defence, 9.Nxe4'),
			moves => {
			},
		},
		'rnb2rk1/ppp1qpp1/4p2p/3p4/2PPn3/2N1PN2/PPQ2PPP/R3KB1R b KQ' => {
			eco => 'D56',
			# TRANSLATORS: D56: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 Ne4 8. Bxe7 Qxe7 9. Qc2
			variation => N__('QGD: Lasker Defence, Teichmann Variation'),
			moves => {
				'c7c6' => 1,
				'e4c3' => 1,
			},
		},
		'rnb2rk1/pp2qpp1/2p1p2p/3p4/2PPn3/2N1PN2/PPQ2PPP/R3KB1R w KQ' => {
			eco => 'D56',
			# TRANSLATORS: D56: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 Ne4 8. Bxe7 Qxe7 9. Qc2 c6
			variation => N__('QGD: Lasker Defence, Teichmann, 9... c6'),
			moves => {
			},
		},
		'rnb2rk1/ppp1qpp1/4p2p/3p4/2PP4/2n1PN2/PPQ2PPP/R3KB1R w KQ' => {
			eco => 'D56',
			# TRANSLATORS: D56: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 Ne4 8. Bxe7 Qxe7 9. Qc2 Nxc3
			variation => N__('QGD: Lasker Defence, Teichmann, 9...Nxc3'),
			moves => {
			},
		},
		'rnb2rk1/ppp1qpp1/4p2p/3P4/3Pn3/2N1PN2/PP3PPP/R2QKB1R b KQ' => {
			eco => 'D57',
			# TRANSLATORS: D57: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 Ne4 8. Bxe7 Qxe7 9. cxd5
			variation => N__('QGD: Lasker Defence, Main Line'),
			moves => {
				'e4c3' => 1,
			},
		},
		'rnb2rk1/ppp1qpp1/4p2p/3P4/3P4/2n1PN2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'D57',
			# TRANSLATORS: D57: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 Ne4 8. Bxe7 Qxe7 9. cxd5 Nxc3
			variation => N__('QGD: Lasker Defence, Main Line'),
			moves => {
				'b2c3' => 1,
			},
		},
		'rnb2rk1/ppp1qpp1/4p2p/3P4/3P4/2P1PN2/P4PPP/R2QKB1R b KQ' => {
			eco => 'D57',
			# TRANSLATORS: D57: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 Ne4 8. Bxe7 Qxe7 9. cxd5 Nxc3 10. bxc3
			variation => N__('QGD: Lasker Defence, Main Line'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rnb2rk1/ppp1qpp1/7p/3p4/3P4/2P1PN2/P4PPP/R2QKB1R w KQ' => {
			eco => 'D57',
			# TRANSLATORS: D57: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 Ne4 8. Bxe7 Qxe7 9. cxd5 Nxc3 10. bxc3 exd5
			variation => N__('QGD: Lasker Defence, Main Line'),
			moves => {
				'd1b3' => 1,
			},
		},
		'rnb2rk1/ppp1qpp1/7p/3p4/3P4/1QP1PN2/P4PPP/R3KB1R b KQ' => {
			eco => 'D57',
			# TRANSLATORS: D57: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 Ne4 8. Bxe7 Qxe7 9. cxd5 Nxc3 10. bxc3 exd5 11. Qb3
			variation => N__('QGD: Lasker Defence, Main Line, 11. Qb3'),
			moves => {
				'e7d6' => 1,
				'f8d8' => 1,
			},
		},
		'rnb2rk1/ppp2pp1/3q3p/3p4/3P4/1QP1PN2/P4PPP/R3KB1R w KQ' => {
			eco => 'D57',
			# TRANSLATORS: D57: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 Ne4 8. Bxe7 Qxe7 9. cxd5 Nxc3 10. bxc3 exd5 11. Qb3 Qd6
			variation => N__('QGD: Lasker Defence, Main Line, Bernstein Variation'),
			moves => {
				'c3c4' => 1,
			},
		},
		'rnb2rk1/ppp2pp1/3q3p/3p4/2PP4/1Q2PN2/P4PPP/R3KB1R b KQ' => {
			eco => 'D57',
			# TRANSLATORS: D57: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 Ne4 8. Bxe7 Qxe7 9. cxd5 Nxc3 10. bxc3 exd5 11. Qb3 Qd6 12. c4
			variation => N__('QGD: Lasker Defence, Main Line, Bernstein Variation'),
			moves => {
				'd5c4' => 1,
			},
		},
		'rnb2rk1/ppp2pp1/3q3p/8/2pP4/1Q2PN2/P4PPP/R3KB1R w KQ' => {
			eco => 'D57',
			# TRANSLATORS: D57: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 Ne4 8. Bxe7 Qxe7 9. cxd5 Nxc3 10. bxc3 exd5 11. Qb3 Qd6 12. c4 dxc4
			variation => N__('QGD: Lasker Defence, Main Line, Bernstein Variation'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnb2rk1/ppp2pp1/3q3p/8/2BP4/1Q2PN2/P4PPP/R3K2R b KQ' => {
			eco => 'D57',
			# TRANSLATORS: D57: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 Ne4 8. Bxe7 Qxe7 9. cxd5 Nxc3 10. bxc3 exd5 11. Qb3 Qd6 12. c4 dxc4 13. Bxc4
			variation => N__('QGD: Lasker Defence, Main Line, Bernstein, 12. c4 dxc4 13.Bxc4'),
			moves => {
			},
		},
		'rnbr2k1/ppp1qpp1/7p/3p4/3P4/1QP1PN2/P4PPP/R3KB1R w KQ' => {
			eco => 'D57',
			# TRANSLATORS: D57: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 Ne4 8. Bxe7 Qxe7 9. cxd5 Nxc3 10. bxc3 exd5 11. Qb3 Rd8
			variation => N__('QGD: Lasker Defence, Main Line, 11. Qb3 Rd8'),
			moves => {
			},
		},
		'rnbq1rk1/p1p1bpp1/1p2pn1p/3p4/2PP3B/2N1PN2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'D58a',
			# TRANSLATORS: D58a: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6
			variation => N__('QGD: Tartakower System'),
			moves => {
				'a1c1' => 1,
				'c4d5' => 1,
				'd1b3' => 1,
				'd1c2' => 1,
				'f1d3' => 1,
				'f1e2' => 1,
				'h4f6' => 1,
			},
		},
		'rnbq1rk1/p1p1bpp1/1p2pn1p/3p4/2PP3B/1QN1PN2/PP3PPP/R3KB1R b KQ' => {
			eco => 'D58b',
			# TRANSLATORS: D58b: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. Qb3
			variation => N__('QGD: Tartakower, 8. Qb3'),
			moves => {
			},
		},
		'rnbq1rk1/p1p1bpp1/1p2pn1p/3p4/2PP3B/2N1PN2/PPQ2PPP/R3KB1R b KQ' => {
			eco => 'D58c',
			# TRANSLATORS: D58c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. Qc2
			variation => N__('QGD: Tartakower, 8. Qc2'),
			moves => {
			},
		},
		'rnbq1rk1/p1p1bpp1/1p2pB1p/3p4/2PP4/2N1PN2/PP3PPP/R2QKB1R b KQ' => {
			eco => 'D58d',
			# TRANSLATORS: D58d: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. Bxf6
			variation => N__('QGD: Tartakower, 8.Bxf6'),
			moves => {
			},
		},
		'rnbq1rk1/p1p1bpp1/1p2pn1p/3p4/2PP3B/2NBPN2/PP3PPP/R2QK2R b KQ' => {
			eco => 'D58e',
			# TRANSLATORS: D58e: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. Bd3
			variation => N__('QGD: Tartakower, 8. Bd3'),
			moves => {
				'c8b7' => 1,
			},
		},
		'rn1q1rk1/pbp1bpp1/1p2pn1p/3p4/2PP3B/2NBPN2/PP3PPP/R2QK2R w KQ' => {
			eco => 'D58f',
			# TRANSLATORS: D58f: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. Bd3 Bb7
			variation => N__('QGD: Tartakower, 8. Bd3 Bb7'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rn1q1rk1/pbp1bpp1/1p2pn1p/3p4/2PP3B/2NBPN2/PP3PPP/R2Q1RK1 b -' => {
			eco => 'D58g',
			# TRANSLATORS: D58g: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. Bd3 Bb7 9. O-O
			variation => N__('QGD: Tartakower, 8. Bd3 Bb7 9.O-O'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r2q1rk1/pbpnbpp1/1p2pn1p/3p4/2PP3B/2NBPN2/PP3PPP/R2Q1RK1 w -' => {
			eco => 'D58h',
			# TRANSLATORS: D58h: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. Bd3 Bb7 9. O-O Nbd7
			variation => N__('QGD: Tartakower, 8. Bd3 Bb7 9.O-O Nbd7'),
			moves => {
				'a1c1' => 1,
				'd1e2' => 1,
				'h4g3' => 1,
			},
		},
		'r2q1rk1/pbpnbpp1/1p2pn1p/3p4/2PP3B/2NBPN2/PP3PPP/2RQ1RK1 b -' => {
			eco => 'D58h',
			# TRANSLATORS: D58h: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. Bd3 Bb7 9. O-O Nbd7 10. Rc1
			variation => N__('QGD: Tartakower, 8. Bd3 Bb7 9.O-O Nbd7 10. Rc1'),
			moves => {
				'c7c5' => 1,
			},
		},
		'r2q1rk1/pb1nbpp1/1p2pn1p/2pp4/2PP3B/2NBPN2/PP3PPP/2RQ1RK1 w -' => {
			eco => 'D58h',
			# TRANSLATORS: D58h: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. Bd3 Bb7 9. O-O Nbd7 10. Rc1 c5
			variation => N__('QGD: Tartakower, 8. Bd3 Bb7 9.O-O Nbd7 10. Rc1 c5'),
			moves => {
			},
		},
		'r2q1rk1/pbpnbpp1/1p2pn1p/3p4/2PP4/2NBPNB1/PP3PPP/R2Q1RK1 b -' => {
			eco => 'D58h',
			# TRANSLATORS: D58h: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. Bd3 Bb7 9. O-O Nbd7 10. Bg3
			variation => N__('QGD: Tartakower, 8. Bd3 Bb7 9.O-O Nbd7 10. Bg3'),
			moves => {
			},
		},
		'r2q1rk1/pbpnbpp1/1p2pn1p/3p4/2PP3B/2NBPN2/PP2QPPP/R4RK1 b -' => {
			eco => 'D58i',
			# TRANSLATORS: D58i: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. Bd3 Bb7 9. O-O Nbd7 10. Qe2
			variation => N__('QGD: Tartakower, 8. Bd3 Bb7 9.O-O Nbd7 10. Qe2'),
			moves => {
				'c7c5' => 1,
			},
		},
		'r2q1rk1/pb1nbpp1/1p2pn1p/2pp4/2PP3B/2NBPN2/PP2QPPP/R4RK1 w -' => {
			eco => 'D58j',
			# TRANSLATORS: D58j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. Bd3 Bb7 9. O-O Nbd7 10. Qe2 c5
			variation => N__('QGD: Tartakower, 8. Bd3 Bb7 9.O-O Nbd7 10. Qe2 c5'),
			moves => {
				'f1d1' => 1,
				'h4g3' => 1,
			},
		},
		'r2q1rk1/pb1nbpp1/1p2pn1p/2pp4/2PP3B/2NBPN2/PP2QPPP/R2R2K1 b -' => {
			eco => 'D58j',
			# TRANSLATORS: D58j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. Bd3 Bb7 9. O-O Nbd7 10. Qe2 c5 11. Rfd1
			variation => N__('QGD: Tartakower, 8. Bd3 Bb7 9.O-O Nbd7 10. Qe2 c5 11.Rfd1'),
			moves => {
			},
		},
		'r2q1rk1/pb1nbpp1/1p2pn1p/2pp4/2PP4/2NBPNB1/PP2QPPP/R4RK1 b -' => {
			eco => 'D58j',
			# TRANSLATORS: D58j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. Bd3 Bb7 9. O-O Nbd7 10. Qe2 c5 11. Bg3
			variation => N__('QGD: Tartakower, 8. Bd3 Bb7 9.O-O Nbd7 10. Qe2 c5 11. Bg3'),
			moves => {
			},
		},
		'rnbq1rk1/p1p1bpp1/1p2pn1p/3p4/2PP3B/2N1PN2/PP2BPPP/R2QK2R b KQ' => {
			eco => 'D58k',
			# TRANSLATORS: D58k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. Be2
			variation => N__('QGD: Tartakower, 8. Be2'),
			moves => {
				'c8b7' => 1,
			},
		},
		'rn1q1rk1/pbp1bpp1/1p2pn1p/3p4/2PP3B/2N1PN2/PP2BPPP/R2QK2R w KQ' => {
			eco => 'D58k',
			# TRANSLATORS: D58k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. Be2 Bb7
			variation => N__('QGD: Tartakower, 8. Be2 Bb7'),
			moves => {
				'h4f6' => 1,
			},
		},
		'rn1q1rk1/pbp1bpp1/1p2pB1p/3p4/2PP4/2N1PN2/PP2BPPP/R2QK2R b KQ' => {
			eco => 'D58k',
			# TRANSLATORS: D58k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. Be2 Bb7 9. Bxf6
			variation => N__('QGD: Tartakower, 8. Be2 Bb7'),
			moves => {
				'e7f6' => 1,
			},
		},
		'rn1q1rk1/pbp2pp1/1p2pb1p/3p4/2PP4/2N1PN2/PP2BPPP/R2QK2R w KQ' => {
			eco => 'D58k',
			# TRANSLATORS: D58k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. Be2 Bb7 9. Bxf6 Bxf6
			variation => N__('QGD: Tartakower, 8. Be2 Bb7'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rn1q1rk1/pbp2pp1/1p2pb1p/3P4/3P4/2N1PN2/PP2BPPP/R2QK2R b KQ' => {
			eco => 'D58l',
			# TRANSLATORS: D58l: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. Be2 Bb7 9. Bxf6 Bxf6 10. cxd5
			variation => N__('QGD: Tartakower, 8. Be2 Bb7 9.Bxf6 Bxf6 10.cxd5'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rn1q1rk1/pbp2pp1/1p3b1p/3p4/3P4/2N1PN2/PP2BPPP/R2QK2R w KQ' => {
			eco => 'D58l',
			# TRANSLATORS: D58l: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. Be2 Bb7 9. Bxf6 Bxf6 10. cxd5 exd5
			variation => N__('QGD: Tartakower, 8. Be2 Bb7 9.Bxf6 Bxf6 10.cxd5 exd5'),
			moves => {
				'b2b4' => 1,
				'e1g1' => 1,
			},
		},
		'rn1q1rk1/pbp2pp1/1p3b1p/3p4/3P4/2N1PN2/PP2BPPP/R2Q1RK1 b -' => {
			eco => 'D58m',
			# TRANSLATORS: D58m: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. Be2 Bb7 9. Bxf6 Bxf6 10. cxd5 exd5 11. O-O
			variation => N__('QGD: Tartakower, 8. Be2 Bb7 9.Bxf6 Bxf6 10.cxd5 exd5 11.O-O'),
			moves => {
			},
		},
		'rn1q1rk1/pbp2pp1/1p3b1p/3p4/1P1P4/2N1PN2/P3BPPP/R2QK2R b KQ' => {
			eco => 'D58n',
			# TRANSLATORS: D58n: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. Be2 Bb7 9. Bxf6 Bxf6 10. cxd5 exd5 11. b4
			variation => N__('QGD: Tartakower, 8. Be2 Bb7 9.Bxf6 Bxf6 10.cxd5 exd5 11. b4'),
			moves => {
				'c7c5' => 1,
				'c7c6' => 1,
			},
		},
		'rn1q1rk1/pb3pp1/1p3b1p/2pp4/1P1P4/2N1PN2/P3BPPP/R2QK2R w KQ' => {
			eco => 'D58n',
			# TRANSLATORS: D58n: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. Be2 Bb7 9. Bxf6 Bxf6 10. cxd5 exd5 11. b4 c5
			variation => N__('QGD: Tartakower, 8. Be2 Bb7 9.Bxf6 Bxf6 10.cxd5 exd5 11. b4 c5'),
			moves => {
			},
		},
		'rn1q1rk1/pb3pp1/1pp2b1p/3p4/1P1P4/2N1PN2/P3BPPP/R2QK2R w KQ' => {
			eco => 'D58o',
			# TRANSLATORS: D58o: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. Be2 Bb7 9. Bxf6 Bxf6 10. cxd5 exd5 11. b4 c6
			variation => N__('QGD: Tartakower, 8. Be2 Bb7 9.Bxf6 Bxf6 10.cxd5 exd5 11. b4 c6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rn1q1rk1/pb3pp1/1pp2b1p/3p4/1P1P4/2N1PN2/P3BPPP/R2Q1RK1 b -' => {
			eco => 'D58o',
			# TRANSLATORS: D58o: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. Be2 Bb7 9. Bxf6 Bxf6 10. cxd5 exd5 11. b4 c6 12. O-O
			variation => N__('QGD: Tartakower, 8. Be2 Bb7 9.Bxf6 Bxf6 10.cxd5 exd5 11. b4 c6 12.O-O'),
			moves => {
			},
		},
		'rnbq1rk1/p1p1bpp1/1p2pn1p/3p4/2PP3B/2N1PN2/PP3PPP/2RQKB1R b K' => {
			eco => 'D58p',
			# TRANSLATORS: D58p: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. Rc1
			variation => N__('QGD: Tartakower, 8. Rc1'),
			moves => {
				'c8b7' => 1,
			},
		},
		'rn1q1rk1/pbp1bpp1/1p2pn1p/3p4/2PP3B/2N1PN2/PP3PPP/2RQKB1R w K' => {
			eco => 'D58p',
			# TRANSLATORS: D58p: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. Rc1 Bb7
			variation => N__('QGD: Tartakower, 8. Rc1 Bb7'),
			moves => {
				'c4d5' => 1,
				'h4f6' => 1,
			},
		},
		'rn1q1rk1/pbp1bpp1/1p2pn1p/3P4/3P3B/2N1PN2/PP3PPP/2RQKB1R b K' => {
			eco => 'D58q',
			# TRANSLATORS: D58q: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. Rc1 Bb7 9. cxd5
			variation => N__('QGD: Tartakower, 8. Rc1 Bb7 9.cxd5'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rn1q1rk1/pbp1bpp1/1p3n1p/3p4/3P3B/2N1PN2/PP3PPP/2RQKB1R w K' => {
			eco => 'D58q',
			# TRANSLATORS: D58q: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. Rc1 Bb7 9. cxd5 exd5
			variation => N__('QGD: Tartakower, 8. Rc1 Bb7 9.cxd5 exd5'),
			moves => {
			},
		},
		'rn1q1rk1/pbp1bpp1/1p2pB1p/3p4/2PP4/2N1PN2/PP3PPP/2RQKB1R b K' => {
			eco => 'D58r',
			# TRANSLATORS: D58r: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. Rc1 Bb7 9. Bxf6
			variation => N__('QGD: Tartakower, 8. Rc1 Bb7 9.Bxf6'),
			moves => {
				'e7f6' => 1,
			},
		},
		'rn1q1rk1/pbp2pp1/1p2pb1p/3p4/2PP4/2N1PN2/PP3PPP/2RQKB1R w K' => {
			eco => 'D58r',
			# TRANSLATORS: D58r: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. Rc1 Bb7 9. Bxf6 Bxf6
			variation => N__('QGD: Tartakower, 8. Rc1 Bb7 9.Bxf6'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rn1q1rk1/pbp2pp1/1p2pb1p/3P4/3P4/2N1PN2/PP3PPP/2RQKB1R b K' => {
			eco => 'D58r',
			# TRANSLATORS: D58r: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. Rc1 Bb7 9. Bxf6 Bxf6 10. cxd5
			variation => N__('QGD: Tartakower, 8. Rc1 Bb7 9.Bxf6'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rn1q1rk1/pbp2pp1/1p3b1p/3p4/3P4/2N1PN2/PP3PPP/2RQKB1R w K' => {
			eco => 'D58r',
			# TRANSLATORS: D58r: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. Rc1 Bb7 9. Bxf6 Bxf6 10. cxd5 exd5
			variation => N__('QGD: Tartakower, 8. Rc1 Bb7 9.Bxf6 Bxf6 10.cxd5 exd5'),
			moves => {
			},
		},
		'rnbq1rk1/p1p1bpp1/1p2pn1p/3P4/3P3B/2N1PN2/PP3PPP/R2QKB1R b KQ' => {
			eco => 'D58s',
			# TRANSLATORS: D58s: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. cxd5
			variation => N__('QGD: Tartakower, 8.cxd5'),
			moves => {
				'e6d5' => 1,
				'f6d5' => 1,
			},
		},
		'rnbq1rk1/p1p1bpp1/1p3n1p/3p4/3P3B/2N1PN2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'D58s',
			# TRANSLATORS: D58s: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. cxd5 exd5
			variation => N__('QGD: Tartakower, 8.cxd5 exd5'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rnbq1rk1/p1p1bpp1/1p3n1p/3p4/3P3B/2NBPN2/PP3PPP/R2QK2R b KQ' => {
			eco => 'D58t',
			# TRANSLATORS: D58t: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. cxd5 exd5 9. Bd3
			variation => N__('QGD: Tartakower, 8.cxd5 exd5 9. Bd3'),
			moves => {
			},
		},
		'rnbq1rk1/p1p1bpp1/1p2p2p/3n4/3P3B/2N1PN2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'D59a',
			# TRANSLATORS: D59a: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. cxd5 Nxd5
			variation => N__('QGD: Tartakower, 8.cxd5 Nxd5'),
			moves => {
				'c3d5' => 1,
				'h4e7' => 1,
			},
		},
		'rnbq1rk1/p1p1bpp1/1p2p2p/3N4/3P3B/4PN2/PP3PPP/R2QKB1R b KQ' => {
			eco => 'D59b',
			# TRANSLATORS: D59b: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. cxd5 Nxd5 9. Nxd5
			variation => N__('QGD: Tartakower, 8.cxd5 Nxd5 9.Nxd5'),
			moves => {
			},
		},
		'rnbq1rk1/p1p1Bpp1/1p2p2p/3n4/3P4/2N1PN2/PP3PPP/R2QKB1R b KQ' => {
			eco => 'D59c',
			# TRANSLATORS: D59c: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. cxd5 Nxd5 9. Bxe7
			variation => N__('QGD: Tartakower, 8.cxd5 Nxd5 9.Bxe7'),
			moves => {
				'd8e7' => 1,
			},
		},
		'rnb2rk1/p1p1qpp1/1p2p2p/3n4/3P4/2N1PN2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'D59d',
			# TRANSLATORS: D59d: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. cxd5 Nxd5 9. Bxe7 Qxe7
			variation => N__('QGD: Tartakower, 8.cxd5 Nxd5 9.Bxe7 Qxe7'),
			moves => {
				'a1c1' => 1,
				'c3d5' => 1,
			},
		},
		'rnb2rk1/p1p1qpp1/1p2p2p/3n4/3P4/2N1PN2/PP3PPP/2RQKB1R b K' => {
			eco => 'D59e',
			# TRANSLATORS: D59e: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. cxd5 Nxd5 9. Bxe7 Qxe7 10. Rc1
			variation => N__('QGD: Tartakower, 8.cxd5 Nxd5 9.Bxe7 Qxe7 10. Rc1'),
			moves => {
				'c8b7' => 1,
			},
		},
		'rn3rk1/pbp1qpp1/1p2p2p/3n4/3P4/2N1PN2/PP3PPP/2RQKB1R w K' => {
			eco => 'D59e',
			# TRANSLATORS: D59e: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. cxd5 Nxd5 9. Bxe7 Qxe7 10. Rc1 Bb7
			variation => N__('QGD: Tartakower, 8.cxd5 Nxd5 9.Bxe7 Qxe7 10. Rc1 Bb7'),
			moves => {
				'c3d5' => 1,
				'f1d3' => 1,
				'f1e2' => 1,
			},
		},
		'rn3rk1/pbp1qpp1/1p2p2p/3N4/3P4/4PN2/PP3PPP/2RQKB1R b K' => {
			eco => 'D59f',
			# TRANSLATORS: D59f: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. cxd5 Nxd5 9. Bxe7 Qxe7 10. Rc1 Bb7 11. Nxd5
			variation => N__('QGD: Tartakower, 8.cxd5 Nxd5 9.Bxe7 Qxe7 10. Rc1 Bb7 11.Nxd5'),
			moves => {
				'b7d5' => 1,
			},
		},
		'rn3rk1/p1p1qpp1/1p2p2p/3b4/3P4/4PN2/PP3PPP/2RQKB1R w K' => {
			eco => 'D59f',
			# TRANSLATORS: D59f: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. cxd5 Nxd5 9. Bxe7 Qxe7 10. Rc1 Bb7 11. Nxd5 Bxd5
			variation => N__('QGD: Tartakower, 8.cxd5 Nxd5 9.Bxe7 Qxe7 10. Rc1 Bb7 11.Nxd5 Bxd5'),
			moves => {
			},
		},
		'rn3rk1/pbp1qpp1/1p2p2p/3n4/3P4/2NBPN2/PP3PPP/2RQK2R b K' => {
			eco => 'D59g',
			# TRANSLATORS: D59g: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. cxd5 Nxd5 9. Bxe7 Qxe7 10. Rc1 Bb7 11. Bd3
			variation => N__('QGD: Tartakower, 8.cxd5 Nxd5 9.Bxe7 Qxe7 10. Rc1 Bb7 11. Bd3'),
			moves => {
			},
		},
		'rn3rk1/pbp1qpp1/1p2p2p/3n4/3P4/2N1PN2/PP2BPPP/2RQK2R b K' => {
			eco => 'D59h',
			# TRANSLATORS: D59h: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. cxd5 Nxd5 9. Bxe7 Qxe7 10. Rc1 Bb7 11. Be2
			variation => N__('QGD: Tartakower, 8.cxd5 Nxd5 9.Bxe7 Qxe7 10. Rc1 Bb7 11. Be2'),
			moves => {
			},
		},
		'rnb2rk1/p1p1qpp1/1p2p2p/3N4/3P4/4PN2/PP3PPP/R2QKB1R b KQ' => {
			eco => 'D59i',
			# TRANSLATORS: D59i: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. cxd5 Nxd5 9. Bxe7 Qxe7 10. Nxd5
			variation => N__('QGD: Tartakower, 8.cxd5 Nxd5 9.Bxe7 Qxe7 10.Nxd5'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rnb2rk1/p1p1qpp1/1p5p/3p4/3P4/4PN2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'D59i',
			# TRANSLATORS: D59i: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. cxd5 Nxd5 9. Bxe7 Qxe7 10. Nxd5 exd5
			variation => N__('QGD: Tartakower, 8.cxd5 Nxd5 9.Bxe7 Qxe7 10.Nxd5'),
			moves => {
				'a1c1' => 1,
				'f1e2' => 1,
			},
		},
		'rnb2rk1/p1p1qpp1/1p5p/3p4/3P4/4PN2/PP2BPPP/R2QK2R b KQ' => {
			eco => 'D59j',
			# TRANSLATORS: D59j: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. cxd5 Nxd5 9. Bxe7 Qxe7 10. Nxd5 exd5 11. Be2
			variation => N__('QGD: Tartakower, Main Line, 11. Rc1'),
			moves => {
			},
		},
		'rnb2rk1/p1p1qpp1/1p5p/3p4/3P4/4PN2/PP3PPP/2RQKB1R b K' => {
			eco => 'D59k',
			# TRANSLATORS: D59k: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. cxd5 Nxd5 9. Bxe7 Qxe7 10. Nxd5 exd5 11. Rc1
			variation => N__('QGD: Tartakower, Main Line, 11. Rc1'),
			moves => {
				'c8e6' => 1,
			},
		},
		'rn3rk1/p1p1qpp1/1p2b2p/3p4/3P4/4PN2/PP3PPP/2RQKB1R w K' => {
			eco => 'D59l',
			# TRANSLATORS: D59l: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. cxd5 Nxd5 9. Bxe7 Qxe7 10. Nxd5 exd5 11. Rc1 Be6
			variation => N__('QGD: Tartakower, Main Line, 11. Rc1 Be6'),
			moves => {
				'd1a4' => 1,
				'f1d3' => 1,
			},
		},
		'rn3rk1/p1p1qpp1/1p2b2p/3p4/3P4/3BPN2/PP3PPP/2RQK2R b K' => {
			eco => 'D59m',
			# TRANSLATORS: D59m: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. cxd5 Nxd5 9. Bxe7 Qxe7 10. Nxd5 exd5 11. Rc1 Be6 12. Bd3
			variation => N__('QGD: Tartakower, Main Line, 12. Bd3'),
			moves => {
			},
		},
		'rn3rk1/p1p1qpp1/1p2b2p/3p4/Q2P4/4PN2/PP3PPP/2R1KB1R b K' => {
			eco => 'D59n',
			# TRANSLATORS: D59n: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. cxd5 Nxd5 9. Bxe7 Qxe7 10. Nxd5 exd5 11. Rc1 Be6 12. Qa4
			variation => N__('QGD: Tartakower, Main Line, 12. Qa4'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rn3rk1/p3qpp1/1p2b2p/2pp4/Q2P4/4PN2/PP3PPP/2R1KB1R w K' => {
			eco => 'D59n',
			# TRANSLATORS: D59n: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 h6 7. Bh4 b6 8. cxd5 Nxd5 9. Bxe7 Qxe7 10. Nxd5 exd5 11. Rc1 Be6 12. Qa4 c5
			variation => N__('QGD: Tartakower, Main Line, 12. Qa4 c5'),
			moves => {
			},
		},
		'r1bq1rk1/pppnbppp/4pn2/3p2B1/2PP4/2N1PN2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'D60',
			# TRANSLATORS: D60: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7
			variation => N__('QGD: Orthodox Defence'),
			moves => {
				'a1c1' => 1,
				'c4d5' => 1,
				'd1b3' => 1,
				'd1c2' => 1,
				'f1d3' => 1,
			},
		},
		'r1bq1rk1/pppnbppp/4pn2/3P2B1/3P4/2N1PN2/PP3PPP/R2QKB1R b KQ' => {
			eco => 'D60',
			# TRANSLATORS: D60: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. cxd5
			variation => N__('QGD: Orthodox Defence'),
			moves => {
				'f6d5' => 1,
			},
		},
		'r1bq1rk1/pppnbppp/4p3/3n2B1/3P4/2N1PN2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'D60',
			# TRANSLATORS: D60: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. cxd5 Nxd5
			variation => N__('QGD: Orthodox, 7.cxd5 Nxd5'),
			moves => {
			},
		},
		'r1bq1rk1/pppnbppp/4pn2/3p2B1/2PP4/1QN1PN2/PP3PPP/R3KB1R b KQ' => {
			eco => 'D60',
			# TRANSLATORS: D60: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Qb3
			variation => N__('QGD: Orthodox, Rauzer Variation'),
			moves => {
				'c7c6' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/2p1pn2/3p2B1/2PP4/1QN1PN2/PP3PPP/R3KB1R w KQ' => {
			eco => 'D60',
			# TRANSLATORS: D60: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Qb3 c6
			variation => N__('QGD: Orthodox, Rauzer Variation'),
			moves => {
			},
		},
		'r1bq1rk1/pppnbppp/4pn2/3p2B1/2PP4/2NBPN2/PP3PPP/R2QK2R b KQ' => {
			eco => 'D60',
			# TRANSLATORS: D60: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Bd3
			variation => N__('QGD: Orthodox, Botvinnik Variation'),
			moves => {
				'b7b6' => 1,
				'c7c6' => 1,
				'd5c4' => 1,
			},
		},
		'r1bq1rk1/p1pnbppp/1p2pn2/3p2B1/2PP4/2NBPN2/PP3PPP/R2QK2R w KQ' => {
			eco => 'D60',
			# TRANSLATORS: D60: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Bd3 b6
			variation => N__('QGD: Orthodox, Botvinnik, 7... b6'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nbppp/2p1pn2/3p2B1/2PP4/2NBPN2/PP3PPP/R2QK2R w KQ' => {
			eco => 'D60',
			# TRANSLATORS: D60: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Bd3 c6
			variation => N__('QGD: Orthodox, Botvinnik, 7... c6'),
			moves => {
			},
		},
		'r1bq1rk1/pppnbppp/4pn2/6B1/2pP4/2NBPN2/PP3PPP/R2QK2R w KQ' => {
			eco => 'D60',
			# TRANSLATORS: D60: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Bd3 dxc4
			variation => N__('QGD: Orthodox, Botvinnik, 7...dxc4'),
			moves => {
				'd3c4' => 1,
			},
		},
		'r1bq1rk1/pppnbppp/4pn2/6B1/2BP4/2N1PN2/PP3PPP/R2QK2R b KQ' => {
			eco => 'D60',
			# TRANSLATORS: D60: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Bd3 dxc4 8. Bxc4
			variation => N__('QGD: Orthodox, Botvinnik, 7...dxc4 8.Bxc4'),
			moves => {
				'a7a6' => 1,
				'c7c5' => 1,
			},
		},
		'r1bq1rk1/1ppnbppp/p3pn2/6B1/2BP4/2N1PN2/PP3PPP/R2QK2R w KQ' => {
			eco => 'D60',
			# TRANSLATORS: D60: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Bd3 dxc4 8. Bxc4 a6
			variation => N__('QGD: Orthodox, Botvinnik, 8... a6'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nbppp/4pn2/2p3B1/2BP4/2N1PN2/PP3PPP/R2QK2R w KQ' => {
			eco => 'D60',
			# TRANSLATORS: D60: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Bd3 dxc4 8. Bxc4 c5
			variation => N__('QGD: Orthodox, Botvinnik, 8... c5'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/4pn2/2p3B1/2BP4/2N1PN2/PP3PPP/R2Q1RK1 b -' => {
			eco => 'D60',
			# TRANSLATORS: D60: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Bd3 dxc4 8. Bxc4 c5 9. O-O
			variation => N__('QGD: Orthodox, Botvinnik, 8... c5'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r1bq1rk1/1p1nbppp/p3pn2/2p3B1/2BP4/2N1PN2/PP3PPP/R2Q1RK1 w -' => {
			eco => 'D60',
			# TRANSLATORS: D60: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Bd3 dxc4 8. Bxc4 c5 9. O-O a6
			variation => N__('QGD: Orthodox, Botvinnik, 8... c5 9.O-O a6'),
			moves => {
			},
		},
		'r1bq1rk1/pppnbppp/4pn2/3p2B1/2PP4/2N1PN2/PPQ2PPP/R3KB1R b KQ' => {
			eco => 'D61',
			# TRANSLATORS: D61: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Qc2
			variation => N__('QGD: Orthodox, Rubinstein Variation'),
			moves => {
				'a7a6' => 1,
				'c7c5' => 1,
				'c7c6' => 1,
				'h7h6' => 1,
			},
		},
		'r1bq1rk1/1ppnbppp/p3pn2/3p2B1/2PP4/2N1PN2/PPQ2PPP/R3KB1R w KQ' => {
			eco => 'D61',
			# TRANSLATORS: D61: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Qc2 a6
			variation => N__('QGD: Orthodox, Rubinstein, 7. Qc2 a6'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nbppp/4pn2/2pp2B1/2PP4/2N1PN2/PPQ2PPP/R3KB1R w KQ' => {
			eco => 'D61',
			# TRANSLATORS: D61: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Qc2 c5
			variation => N__('QGD: Orthodox, Rubinstein, 7. Qc2 c5'),
			moves => {
				'a1d1' => 1,
				'c4d5' => 1,
				'e1c1' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/4pn2/2pp2B1/2PP4/2N1PN2/PPQ2PPP/3RKB1R b K' => {
			eco => 'D61',
			# TRANSLATORS: D61: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Qc2 c5 8. Rd1
			variation => N__('QGD: Orthodox, Rubinstein, 7. Qc2 c5 8. Rd1'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nbppp/4pn2/2pp2B1/2PP4/2N1PN2/PPQ2PPP/2KR1B1R b -' => {
			eco => 'D61',
			# TRANSLATORS: D61: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Qc2 c5 8. O-O-O
			variation => N__('QGD: Orthodox, Rubinstein, 7. Qc2 c5 8.O-O-O'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nbppp/2p1pn2/3p2B1/2PP4/2N1PN2/PPQ2PPP/R3KB1R w KQ' => {
			eco => 'D61',
			# TRANSLATORS: D61: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Qc2 c6
			variation => N__('QGD: Orthodox, Rubinstein, 7. Qc2 c6'),
			moves => {
				'a1d1' => 1,
				'a2a3' => 1,
				'f1d3' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/2p1pn2/3p2B1/2PP4/2N1PN2/PPQ2PPP/3RKB1R b K' => {
			eco => 'D61',
			# TRANSLATORS: D61: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Qc2 c6 8. Rd1
			variation => N__('QGD: Orthodox, Rubinstein, 7. Qc2 c6 8. Rd1'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nbppp/2p1pn2/3p2B1/2PP4/P1N1PN2/1PQ2PPP/R3KB1R b KQ' => {
			eco => 'D61',
			# TRANSLATORS: D61: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Qc2 c6 8. a3
			variation => N__('QGD: Orthodox, Rubinstein, 7. Qc2 c6 8. a3'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nbppp/2p1pn2/3p2B1/2PP4/2NBPN2/PPQ2PPP/R3K2R b KQ' => {
			eco => 'D61',
			# TRANSLATORS: D61: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Qc2 c6 8. Bd3
			variation => N__('QGD: Orthodox, Rubinstein, 7. Qc2 c6 8. Bd3'),
			moves => {
				'd5c4' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/2p1pn2/6B1/2pP4/2NBPN2/PPQ2PPP/R3K2R w KQ' => {
			eco => 'D61',
			# TRANSLATORS: D61: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Qc2 c6 8. Bd3 dxc4
			variation => N__('QGD: Orthodox, Rubinstein, 7. Qc2 c6 8. Bd3'),
			moves => {
				'd3c4' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/2p1pn2/6B1/2BP4/2N1PN2/PPQ2PPP/R3K2R b KQ' => {
			eco => 'D61',
			# TRANSLATORS: D61: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Qc2 c6 8. Bd3 dxc4 9. Bxc4
			variation => N__('QGD: Orthodox, Rubinstein, 7. Qc2 c6 8. Bd3 dxc4 9.Bxc4'),
			moves => {
			},
		},
		'r1bq1rk1/pppnbpp1/4pn1p/3p2B1/2PP4/2N1PN2/PPQ2PPP/R3KB1R w KQ' => {
			eco => 'D61',
			# TRANSLATORS: D61: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Qc2 h6
			variation => N__('QGD: Orthodox, Rubinstein, 7. Qc2 h6'),
			moves => {
				'g5h4' => 1,
			},
		},
		'r1bq1rk1/pppnbpp1/4pn1p/3p4/2PP3B/2N1PN2/PPQ2PPP/R3KB1R b KQ' => {
			eco => 'D61',
			# TRANSLATORS: D61: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Qc2 h6 8. Bh4
			variation => N__('QGD: Orthodox, Rubinstein, 7. Qc2 h6 8. Bh4'),
			moves => {
				'c7c5' => 1,
			},
		},
		'r1bq1rk1/pp1nbpp1/4pn1p/2pp4/2PP3B/2N1PN2/PPQ2PPP/R3KB1R w KQ' => {
			eco => 'D61',
			# TRANSLATORS: D61: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Qc2 h6 8. Bh4 c5
			variation => N__('QGD: Orthodox, Rubinstein, 7. Qc2 h6 8. Bh4 c5'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nbppp/4pn2/2pP2B1/3P4/2N1PN2/PPQ2PPP/R3KB1R b KQ' => {
			eco => 'D62',
			# TRANSLATORS: D62: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Qc2 c5 8. cxd5
			variation => N__('QGD: Orthodox, Rubinstein, 7. Qc2 c5 8.cxd5'),
			moves => {
				'c5d4' => 1,
				'e6d5' => 1,
				'f6d5' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/4pn2/3P2B1/3p4/2N1PN2/PPQ2PPP/R3KB1R w KQ' => {
			eco => 'D62',
			# TRANSLATORS: D62: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Qc2 c5 8. cxd5 cxd4
			variation => N__('QGD: Orthodox, Rubinstein, 7. Qc2 c5 8.cxd5 cxd4'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nbppp/5n2/2pp2B1/3P4/2N1PN2/PPQ2PPP/R3KB1R w KQ' => {
			eco => 'D62',
			# TRANSLATORS: D62: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Qc2 c5 8. cxd5 exd5
			variation => N__('QGD: Orthodox, Rubinstein, 7. Qc2 c5 8.cxd5 exd5'),
			moves => {
				'f1d3' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/5n2/2pp2B1/3P4/2NBPN2/PPQ2PPP/R3K2R b KQ' => {
			eco => 'D62',
			# TRANSLATORS: D62: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Qc2 c5 8. cxd5 exd5 9. Bd3
			variation => N__('QGD: Orthodox, Rubinstein, 7. Qc2 c5 8.cxd5 exd5 9. Bd3'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nbppp/4p3/2pn2B1/3P4/2N1PN2/PPQ2PPP/R3KB1R w KQ' => {
			eco => 'D62',
			# TRANSLATORS: D62: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Qc2 c5 8. cxd5 Nxd5
			variation => N__('QGD: Orthodox, Rubinstein, 7. Qc2 c5 8.cxd5 Nxd5'),
			moves => {
				'g5e7' => 1,
			},
		},
		'r1bq1rk1/pp1nBppp/4p3/2pn4/3P4/2N1PN2/PPQ2PPP/R3KB1R b KQ' => {
			eco => 'D62',
			# TRANSLATORS: D62: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Qc2 c5 8. cxd5 Nxd5 9. Bxe7
			variation => N__('QGD: Orthodox, Rubinstein, 7. Qc2 c5 8.cxd5 Nxd5'),
			moves => {
				'd8e7' => 1,
			},
		},
		'r1b2rk1/pp1nqppp/4p3/2pn4/3P4/2N1PN2/PPQ2PPP/R3KB1R w KQ' => {
			eco => 'D62',
			# TRANSLATORS: D62: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Qc2 c5 8. cxd5 Nxd5 9. Bxe7 Qxe7
			variation => N__('QGD: Orthodox, Rubinstein, 7. Qc2 c5 8.cxd5 Nxd5 9.Bxe7 Qxe7'),
			moves => {
				'c3d5' => 1,
			},
		},
		'r1b2rk1/pp1nqppp/4p3/2pN4/3P4/4PN2/PPQ2PPP/R3KB1R b KQ' => {
			eco => 'D62',
			# TRANSLATORS: D62: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Qc2 c5 8. cxd5 Nxd5 9. Bxe7 Qxe7 10. Nxd5
			variation => N__('QGD: Orthodox, Rubinstein, 7. Qc2 c5 8.cxd5 Nxd5 9.Bxe7 Qxe7'),
			moves => {
				'e6d5' => 1,
			},
		},
		'r1b2rk1/pp1nqppp/8/2pp4/3P4/4PN2/PPQ2PPP/R3KB1R w KQ' => {
			eco => 'D62',
			# TRANSLATORS: D62: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Qc2 c5 8. cxd5 Nxd5 9. Bxe7 Qxe7 10. Nxd5 exd5
			variation => N__('QGD: Orthodox, Rubinstein, 7. Qc2 c5 8.cxd5, Main Line'),
			moves => {
				'f1d3' => 1,
			},
		},
		'r1b2rk1/pp1nqppp/8/2pp4/3P4/3BPN2/PPQ2PPP/R3K2R b KQ' => {
			eco => 'D62',
			# TRANSLATORS: D62: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Qc2 c5 8. cxd5 Nxd5 9. Bxe7 Qxe7 10. Nxd5 exd5 11. Bd3
			variation => N__('QGD: Orthodox, Rubinstein, 7. Qc2 c5 8.cxd5, Main Line, 11. Bd3'),
			moves => {
				'g7g6' => 1,
			},
		},
		'r1b2rk1/pp1nqp1p/6p1/2pp4/3P4/3BPN2/PPQ2PPP/R3K2R w KQ' => {
			eco => 'D62',
			# TRANSLATORS: D62: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Qc2 c5 8. cxd5 Nxd5 9. Bxe7 Qxe7 10. Nxd5 exd5 11. Bd3 g6
			variation => N__('QGD: Orthodox, Rubinstein, 7. Qc2 c5 8.cxd5, Main Line, 11. Bd3 g6'),
			moves => {
			},
		},
		'r1bq1rk1/pppnbppp/4pn2/3p2B1/2PP4/2N1PN2/PP3PPP/2RQKB1R b K' => {
			eco => 'D63',
			# TRANSLATORS: D63: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1
			variation => N__('QGD: Orthodox, 7. Rc1'),
			moves => {
				'a7a6' => 1,
				'b7b6' => 1,
				'c7c6' => 1,
				'd5c4' => 1,
				'f8e8' => 1,
				'h7h6' => 1,
			},
		},
		'r1bq1rk1/1ppnbppp/p3pn2/3p2B1/2PP4/2N1PN2/PP3PPP/2RQKB1R w K' => {
			eco => 'D63',
			# TRANSLATORS: D63: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 a6
			variation => N__('QGD: Orthodox, Swiss Variation'),
			moves => {
				'a2a3' => 1,
				'c4c5' => 1,
				'c4d5' => 1,
			},
		},
		'r1bq1rk1/1ppnbppp/p3pn2/3p2B1/2PP4/P1N1PN2/1P3PPP/2RQKB1R b K' => {
			eco => 'D63',
			# TRANSLATORS: D63: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 a6 8. a3
			variation => N__('QGD: Orthodox, Swiss, 8. a3'),
			moves => {
			},
		},
		'r1bq1rk1/1ppnbppp/p3pn2/2Pp2B1/3P4/2N1PN2/PP3PPP/2RQKB1R b K' => {
			eco => 'D63',
			# TRANSLATORS: D63: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 a6 8. c5
			variation => N__('QGD: Orthodox, Swiss, 8. c5'),
			moves => {
				'c7c6' => 1,
			},
		},
		'r1bq1rk1/1p1nbppp/p1p1pn2/2Pp2B1/3P4/2N1PN2/PP3PPP/2RQKB1R w K' => {
			eco => 'D63',
			# TRANSLATORS: D63: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 a6 8. c5 c6
			variation => N__('QGD: Orthodox, Swiss, 8. c5 c6'),
			moves => {
			},
		},
		'r1bq1rk1/1ppnbppp/p3pn2/3P2B1/3P4/2N1PN2/PP3PPP/2RQKB1R b K' => {
			eco => 'D63',
			# TRANSLATORS: D63: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 a6 8. cxd5
			variation => N__('QGD: Orthodox, Swiss, Karlsbad Variation'),
			moves => {
				'e6d5' => 1,
			},
		},
		'r1bq1rk1/1ppnbppp/p4n2/3p2B1/3P4/2N1PN2/PP3PPP/2RQKB1R w K' => {
			eco => 'D63',
			# TRANSLATORS: D63: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 a6 8. cxd5 exd5
			variation => N__('QGD: Orthodox, Swiss, Karlsbad Variation'),
			moves => {
				'f1d3' => 1,
			},
		},
		'r1bq1rk1/1ppnbppp/p4n2/3p2B1/3P4/2NBPN2/PP3PPP/2RQK2R b K' => {
			eco => 'D63',
			# TRANSLATORS: D63: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 a6 8. cxd5 exd5 9. Bd3
			variation => N__('QGD: Orthodox, Swiss, Karlsbad, 9. Bd3'),
			moves => {
				'c7c6' => 1,
				'f8e8' => 1,
			},
		},
		'r1bq1rk1/1p1nbppp/p1p2n2/3p2B1/3P4/2NBPN2/PP3PPP/2RQK2R w K' => {
			eco => 'D63',
			# TRANSLATORS: D63: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 a6 8. cxd5 exd5 9. Bd3 c6
			variation => N__('QGD: Orthodox, Swiss, Karlsbad, 9. Bd3 c6'),
			moves => {
			},
		},
		'r1bqr1k1/1ppnbppp/p4n2/3p2B1/3P4/2NBPN2/PP3PPP/2RQK2R w K' => {
			eco => 'D63',
			# TRANSLATORS: D63: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 a6 8. cxd5 exd5 9. Bd3 Re8
			variation => N__('QGD: Orthodox, Swiss, Karlsbad, 9. Bd3 Re8'),
			moves => {
			},
		},
		'r1bq1rk1/p1pnbppp/1p2pn2/3p2B1/2PP4/2N1PN2/PP3PPP/2RQKB1R w K' => {
			eco => 'D63',
			# TRANSLATORS: D63: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 b6
			variation => N__('QGD: Orthodox, 7. Rc1 b6'),
			moves => {
				'c4d5' => 1,
			},
		},
		'r1bq1rk1/p1pnbppp/1p2pn2/3P2B1/3P4/2N1PN2/PP3PPP/2RQKB1R b K' => {
			eco => 'D63',
			# TRANSLATORS: D63: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 b6 8. cxd5
			variation => N__('QGD: Orthodox, 7. Rc1 b6'),
			moves => {
				'e6d5' => 1,
			},
		},
		'r1bq1rk1/p1pnbppp/1p3n2/3p2B1/3P4/2N1PN2/PP3PPP/2RQKB1R w K' => {
			eco => 'D63',
			# TRANSLATORS: D63: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 b6 8. cxd5 exd5
			variation => N__('QGD: Orthodox, 7. Rc1 b6'),
			moves => {
				'd1a4' => 1,
				'f1b5' => 1,
				'f1d3' => 1,
			},
		},
		'r1bq1rk1/p1pnbppp/1p3n2/3p2B1/Q2P4/2N1PN2/PP3PPP/2R1KB1R b K' => {
			eco => 'D63',
			# TRANSLATORS: D63: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 b6 8. cxd5 exd5 9. Qa4
			variation => N__('QGD: Orthodox, 7. Rc1 b6, Duras Variation'),
			moves => {
			},
		},
		'r1bq1rk1/p1pnbppp/1p3n2/1B1p2B1/3P4/2N1PN2/PP3PPP/2RQK2R b K' => {
			eco => 'D63',
			# TRANSLATORS: D63: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 b6 8. cxd5 exd5 9. Bb5
			variation => N__('QGD: Orthodox, 7. Rc1 b6, Capablanca Variation'),
			moves => {
			},
		},
		'r1bq1rk1/p1pnbppp/1p3n2/3p2B1/3P4/2NBPN2/PP3PPP/2RQK2R b K' => {
			eco => 'D63',
			# TRANSLATORS: D63: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 b6 8. cxd5 exd5 9. Bd3
			variation => N__('QGD: Orthodox, 7. Rc1 b6, Pillsbury Attack'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nbppp/2p1pn2/3p2B1/2PP4/2N1PN2/PP3PPP/2RQKB1R w K' => {
			eco => 'D63',
			# TRANSLATORS: D63: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6
			variation => N__('QGD: Orthodox, 7. Rc1 c6'),
			moves => {
				'a2a3' => 1,
				'd1c2' => 1,
				'f1d3' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/2p1pn2/3p2B1/2PP4/P1N1PN2/1P3PPP/2RQKB1R b K' => {
			eco => 'D63',
			# TRANSLATORS: D63: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. a3
			variation => N__('QGD: Orthodox, 7. Rc1 c6 8. a3'),
			moves => {
			},
		},
		'r1bq1rk1/pppnbppp/4pn2/6B1/2pP4/2N1PN2/PP3PPP/2RQKB1R w K' => {
			eco => 'D63',
			# TRANSLATORS: D63: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 dxc4
			variation => N__('QGD: Orthodox, 7. Rc1 dxc4'),
			moves => {
				'f1c4' => 1,
			},
		},
		'r1bq1rk1/pppnbppp/4pn2/6B1/2BP4/2N1PN2/PP3PPP/2RQK2R b K' => {
			eco => 'D63',
			# TRANSLATORS: D63: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 dxc4 8. Bxc4
			variation => N__('QGD: Orthodox, 7. Rc1 dxc4'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r1bq1rk1/1ppnbppp/p3pn2/6B1/2BP4/2N1PN2/PP3PPP/2RQK2R w K' => {
			eco => 'D63',
			# TRANSLATORS: D63: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 dxc4 8. Bxc4 a6
			variation => N__('QGD: Orthodox, 7. Rc1 dxc4 8.Bxc4 a6'),
			moves => {
			},
		},
		'r1bqr1k1/pppnbppp/4pn2/3p2B1/2PP4/2N1PN2/PP3PPP/2RQKB1R w K' => {
			eco => 'D63',
			# TRANSLATORS: D63: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 Re8
			variation => N__('QGD: Orthodox, 7. Rc1 Re8'),
			moves => {
			},
		},
		'r1bq1rk1/pppnbpp1/4pn1p/3p2B1/2PP4/2N1PN2/PP3PPP/2RQKB1R w K' => {
			eco => 'D63',
			# TRANSLATORS: D63: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 h6
			variation => N__('QGD: Orthodox, 7. Rc1 h6'),
			moves => {
				'g5h4' => 1,
			},
		},
		'r1bq1rk1/pppnbpp1/4pn1p/3p4/2PP3B/2N1PN2/PP3PPP/2RQKB1R b K' => {
			eco => 'D63',
			# TRANSLATORS: D63: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 h6 8. Bh4
			variation => N__('QGD: Orthodox, 7. Rc1 h6 8. Bh4'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nbppp/2p1pn2/3p2B1/2PP4/2N1PN2/PPQ2PPP/2R1KB1R b K' => {
			eco => 'D64',
			# TRANSLATORS: D64: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Qc2
			variation => N__('QGD: Orthodox, Rubinstein Attack'),
			moves => {
				'a7a6' => 1,
				'd5c4' => 1,
				'f6e4' => 1,
				'f8e8' => 1,
				'h7h6' => 1,
			},
		},
		'r1bq1rk1/1p1nbppp/p1p1pn2/3p2B1/2PP4/2N1PN2/PPQ2PPP/2R1KB1R w K' => {
			eco => 'D64',
			# TRANSLATORS: D64: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Qc2 a6
			variation => N__('QGD: Orthodox, Rubinstein Attack, Carlsbad Variation'),
			moves => {
				'a2a3' => 1,
				'c4d5' => 1,
			},
		},
		'r1bq1rk1/1p1nbppp/p1p1pn2/3p2B1/2PP4/P1N1PN2/1PQ2PPP/2R1KB1R b K' => {
			eco => 'D64',
			# TRANSLATORS: D64: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Qc2 a6 9. a3
			variation => N__('QGD: Orthodox, Rubinstein Attack, Grünfeld Variation'),
			moves => {
				'h7h6' => 1,
			},
		},
		'r1bq1rk1/1p1nbpp1/p1p1pn1p/3p2B1/2PP4/P1N1PN2/1PQ2PPP/2R1KB1R w K' => {
			eco => 'D64',
			# TRANSLATORS: D64: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Qc2 a6 9. a3 h6
			variation => N__('QGD: Orthodox, Rubinstein Attack, Grünfeld Variation, 9... h6'),
			moves => {
				'g5h4' => 1,
			},
		},
		'r1bq1rk1/1p1nbpp1/p1p1pn1p/3p4/2PP3B/P1N1PN2/1PQ2PPP/2R1KB1R b K' => {
			eco => 'D64',
			# TRANSLATORS: D64: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Qc2 a6 9. a3 h6 10. Bh4
			variation => N__('QGD: Orthodox, Rubinstein Attack, Grünfeld Variation, 9... h6 10. Bh4'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nbppp/2p1pn2/6B1/2pP4/2N1PN2/PPQ2PPP/2R1KB1R w K' => {
			eco => 'D64',
			# TRANSLATORS: D64: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Qc2 dxc4
			variation => N__('QGD: Orthodox, Rubinstein Attack, 8...dxc4'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nbppp/2p1p3/3p2B1/2PPn3/2N1PN2/PPQ2PPP/2R1KB1R w K' => {
			eco => 'D64',
			# TRANSLATORS: D64: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Qc2 Ne4
			variation => N__('QGD: Orthodox, Rubinstein Attack, Wolf Variation'),
			moves => {
			},
		},
		'r1bqr1k1/pp1nbppp/2p1pn2/3p2B1/2PP4/2N1PN2/PPQ2PPP/2R1KB1R w K' => {
			eco => 'D64',
			# TRANSLATORS: D64: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Qc2 Re8
			variation => N__('QGD: Orthodox, Rubinstein Attack, 8... Re8'),
			moves => {
				'a2a3' => 1,
			},
		},
		'r1bqr1k1/pp1nbppp/2p1pn2/3p2B1/2PP4/P1N1PN2/1PQ2PPP/2R1KB1R b K' => {
			eco => 'D64',
			# TRANSLATORS: D64: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Qc2 Re8 9. a3
			variation => N__('QGD: Orthodox, Rubinstein Attack, 8... Re8 9. a3'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r1bqr1k1/1p1nbppp/p1p1pn2/3p2B1/2PP4/P1N1PN2/1PQ2PPP/2R1KB1R w K' => {
			eco => 'D64',
			# TRANSLATORS: D64: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Qc2 Re8 9. a3 a6
			variation => N__('QGD: Orthodox, Rubinstein Attack, 8... Re8 9. a3 a6'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nbpp1/2p1pn1p/3p2B1/2PP4/2N1PN2/PPQ2PPP/2R1KB1R w K' => {
			eco => 'D64',
			# TRANSLATORS: D64: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Qc2 h6
			variation => N__('QGD: Orthodox, Rubinstein Attack, 8... h6'),
			moves => {
			},
		},
		'r1bq1rk1/1p1nbppp/p1p1pn2/3P2B1/3P4/2N1PN2/PPQ2PPP/2R1KB1R b K' => {
			eco => 'D65',
			# TRANSLATORS: D65: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Qc2 a6 9. cxd5
			variation => N__('QGD: Orthodox, Rubinstein Attack, 9.cxd5'),
			moves => {
				'e6d5' => 1,
				'f6d5' => 1,
			},
		},
		'r1bq1rk1/1p1nbppp/p1p2n2/3p2B1/3P4/2N1PN2/PPQ2PPP/2R1KB1R w K' => {
			eco => 'D65',
			# TRANSLATORS: D65: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Qc2 a6 9. cxd5 exd5
			variation => N__('QGD: Orthodox, Rubinstein Attack, 9.cxd5 exd5'),
			moves => {
				'f1d3' => 1,
			},
		},
		'r1bq1rk1/1p1nbppp/p1p2n2/3p2B1/3P4/2NBPN2/PPQ2PPP/2R1K2R b K' => {
			eco => 'D65',
			# TRANSLATORS: D65: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Qc2 a6 9. cxd5 exd5 10. Bd3
			variation => N__('QGD: Orthodox, Rubinstein Attack, 9.cxd5 exd5'),
			moves => {
				'f8e8' => 1,
				'h7h6' => 1,
			},
		},
		'r1bqr1k1/1p1nbppp/p1p2n2/3p2B1/3P4/2NBPN2/PPQ2PPP/2R1K2R w K' => {
			eco => 'D65',
			# TRANSLATORS: D65: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Qc2 a6 9. cxd5 exd5 10. Bd3 Re8
			variation => N__('QGD: Orthodox, Rubinstein, 9.cxd5 exd5 10. Bd3 Re8'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqr1k1/1p1nbppp/p1p2n2/3p2B1/3P4/2NBPN2/PPQ2PPP/2R2RK1 b -' => {
			eco => 'D65',
			# TRANSLATORS: D65: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Qc2 a6 9. cxd5 exd5 10. Bd3 Re8 11. O-O
			variation => N__('QGD: Orthodox, Rubinstein, 9.cxd5 exd5 10. Bd3 Re8'),
			moves => {
				'd7f8' => 1,
			},
		},
		'r1bqrnk1/1p2bppp/p1p2n2/3p2B1/3P4/2NBPN2/PPQ2PPP/2R2RK1 w -' => {
			eco => 'D65',
			# TRANSLATORS: D65: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Qc2 a6 9. cxd5 exd5 10. Bd3 Re8 11. O-O Nf8
			variation => N__('QGD: Orthodox, Rubinstein, 9.cxd5 exd5 10. Bd3 Re8 11.O-O Nf8'),
			moves => {
				'f3e5' => 1,
				'h2h3' => 1,
			},
		},
		'r1bqrnk1/1p2bppp/p1p2n2/3pN1B1/3P4/2NBP3/PPQ2PPP/2R2RK1 b -' => {
			eco => 'D65',
			# TRANSLATORS: D65: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Qc2 a6 9. cxd5 exd5 10. Bd3 Re8 11. O-O Nf8 12. Ne5
			variation => N__('QGD: Orthodox, Rubinstein, 9.cxd5 exd5 10. Bd3 Re8 11.O-O Nf8 12. Ne5'),
			moves => {
			},
		},
		'r1bqrnk1/1p2bppp/p1p2n2/3p2B1/3P4/2NBPN1P/PPQ2PP1/2R2RK1 b -' => {
			eco => 'D65',
			# TRANSLATORS: D65: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Qc2 a6 9. cxd5 exd5 10. Bd3 Re8 11. O-O Nf8 12. h3
			variation => N__('QGD: Orthodox, Rubinstein, 9.cxd5 exd5 10. Bd3 Re8 11.O-O Nf8 12. h3'),
			moves => {
			},
		},
		'r1bq1rk1/1p1nbpp1/p1p2n1p/3p2B1/3P4/2NBPN2/PPQ2PPP/2R1K2R w K' => {
			eco => 'D65',
			# TRANSLATORS: D65: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Qc2 a6 9. cxd5 exd5 10. Bd3 h6
			variation => N__('QGD: Orthodox, Rubinstein, 9.cxd5 exd5 10. Bd3 h6'),
			moves => {
				'g5h4' => 1,
			},
		},
		'r1bq1rk1/1p1nbpp1/p1p2n1p/3p4/3P3B/2NBPN2/PPQ2PPP/2R1K2R b K' => {
			eco => 'D65',
			# TRANSLATORS: D65: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Qc2 a6 9. cxd5 exd5 10. Bd3 h6 11. Bh4
			variation => N__('QGD: Orthodox, Rubinstein, 9.cxd5 exd5 10. Bd3 h6 11. Bh4'),
			moves => {
			},
		},
		'r1bq1rk1/1p1nbppp/p1p1p3/3n2B1/3P4/2N1PN2/PPQ2PPP/2R1KB1R w K' => {
			eco => 'D65',
			# TRANSLATORS: D65: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Qc2 a6 9. cxd5 Nxd5
			variation => N__('QGD: Orthodox, Rubinstein Attack, 9.cxd5 Nxd5'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nbppp/2p1pn2/3p2B1/2PP4/2NBPN2/PP3PPP/2RQK2R b K' => {
			eco => 'D66',
			# TRANSLATORS: D66: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3
			variation => N__('QGD: Orthodox, Main Line'),
			moves => {
				'a7a6' => 1,
				'd5c4' => 1,
				'f8e8' => 1,
				'h7h6' => 1,
			},
		},
		'r1bq1rk1/1p1nbppp/p1p1pn2/3p2B1/2PP4/2NBPN2/PP3PPP/2RQK2R w K' => {
			eco => 'D66',
			# TRANSLATORS: D66: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 a6
			variation => N__('QGD: Orthodox, Main Line, 8... a6'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nbppp/2p1pn2/6B1/2pP4/2NBPN2/PP3PPP/2RQK2R w K' => {
			eco => 'D66',
			# TRANSLATORS: D66: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 dxc4
			variation => N__('QGD: Orthodox, Main Line, 8...dxc4'),
			moves => {
				'd3c4' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/2p1pn2/6B1/2BP4/2N1PN2/PP3PPP/2RQK2R b K' => {
			eco => 'D66',
			# TRANSLATORS: D66: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 dxc4 9. Bxc4
			variation => N__('QGD: Orthodox, Main Line, 8...dxc4'),
			moves => {
				'b7b5' => 1,
				'f6d5' => 1,
			},
		},
		'r1bq1rk1/p2nbppp/2p1pn2/1p4B1/2BP4/2N1PN2/PP3PPP/2RQK2R w K' => {
			eco => 'D66',
			# TRANSLATORS: D66: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 dxc4 9. Bxc4 b5
			variation => N__('QGD: Orthodox, Main Line, Fianchetto Variation'),
			moves => {
				'c4d3' => 1,
			},
		},
		'r1bq1rk1/p2nbppp/2p1pn2/1p4B1/3P4/2NBPN2/PP3PPP/2RQK2R b K' => {
			eco => 'D66',
			# TRANSLATORS: D66: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 dxc4 9. Bxc4 b5 10. Bd3
			variation => N__('QGD: Orthodox, Main Line, Fianchetto Variation'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r1bq1rk1/3nbppp/p1p1pn2/1p4B1/3P4/2NBPN2/PP3PPP/2RQK2R w K' => {
			eco => 'D66',
			# TRANSLATORS: D66: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 dxc4 9. Bxc4 b5 10. Bd3 a6
			variation => N__('QGD: Orthodox, Main Line, Fianchetto Variation'),
			moves => {
				'e1g1' => 1,
				'e3e4' => 1,
			},
		},
		'r1bq1rk1/3nbppp/p1p1pn2/1p4B1/3P4/2NBPN2/PP3PPP/2RQ1RK1 b -' => {
			eco => 'D66',
			# TRANSLATORS: D66: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 dxc4 9. Bxc4 b5 10. Bd3 a6 11. O-O
			variation => N__('QGD: Orthodox, Main Line, Fianchetto, 11.O-O'),
			moves => {
			},
		},
		'r1bq1rk1/3nbppp/p1p1pn2/1p4B1/3PP3/2NB1N2/PP3PPP/2RQK2R b K' => {
			eco => 'D66',
			# TRANSLATORS: D66: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 dxc4 9. Bxc4 b5 10. Bd3 a6 11. e4
			variation => N__('QGD: Orthodox, Main Line, Fianchetto, 11. e4'),
			moves => {
			},
		},
		'r1bqr1k1/pp1nbppp/2p1pn2/3p2B1/2PP4/2NBPN2/PP3PPP/2RQK2R w K' => {
			eco => 'D66',
			# TRANSLATORS: D66: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 Re8
			variation => N__('QGD: Orthodox, Main Line, 8... Re8'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nbpp1/2p1pn1p/3p2B1/2PP4/2NBPN2/PP3PPP/2RQK2R w K' => {
			eco => 'D66',
			# TRANSLATORS: D66: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 h6
			variation => N__('QGD: Orthodox, Main Line, 8... h6'),
			moves => {
				'g5h4' => 1,
			},
		},
		'r1bq1rk1/pp1nbpp1/2p1pn1p/3p4/2PP3B/2NBPN2/PP3PPP/2RQK2R b K' => {
			eco => 'D66',
			# TRANSLATORS: D66: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 h6 9. Bh4
			variation => N__('QGD: Orthodox, Main Line, 8... h6 9. Bh4'),
			moves => {
				'd5c4' => 1,
			},
		},
		'r1bq1rk1/pp1nbpp1/2p1pn1p/8/2pP3B/2NBPN2/PP3PPP/2RQK2R w K' => {
			eco => 'D66',
			# TRANSLATORS: D66: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 h6 9. Bh4 dxc4
			variation => N__('QGD: Orthodox, Main Line, 8... h6 9. Bh4 dxc4'),
			moves => {
				'd3c4' => 1,
			},
		},
		'r1bq1rk1/pp1nbpp1/2p1pn1p/8/2BP3B/2N1PN2/PP3PPP/2RQK2R b K' => {
			eco => 'D66',
			# TRANSLATORS: D66: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 h6 9. Bh4 dxc4 10. Bxc4
			variation => N__('QGD: Orthodox, Main Line, 8... h6 9. Bh4 dxc4 10.Bxc4'),
			moves => {
				'b7b5' => 1,
			},
		},
		'r1bq1rk1/p2nbpp1/2p1pn1p/1p6/2BP3B/2N1PN2/PP3PPP/2RQK2R w K' => {
			eco => 'D66',
			# TRANSLATORS: D66: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 h6 9. Bh4 dxc4 10. Bxc4 b5
			variation => N__('QGD: Orthodox, Main Line, 8... h6 9. Bh4 dxc4 10.Bxc4 b5'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nbppp/2p1p3/3n2B1/2BP4/2N1PN2/PP3PPP/2RQK2R w K' => {
			eco => 'D67',
			# TRANSLATORS: D67: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 dxc4 9. Bxc4 Nd5
			variation => N__('QGD: Orthodox, Main Line, Capablanca Freeing Manoevure'),
			moves => {
				'g5e7' => 1,
				'h2h4' => 1,
			},
		},
		'r1bq1rk1/pp1nBppp/2p1p3/3n4/2BP4/2N1PN2/PP3PPP/2RQK2R b K' => {
			eco => 'D67',
			# TRANSLATORS: D67: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 dxc4 9. Bxc4 Nd5 10. Bxe7
			variation => N__('QGD: Orthodox, Main Line, Capablanca Freeing Manoevure'),
			moves => {
				'd8e7' => 1,
			},
		},
		'r1b2rk1/pp1nqppp/2p1p3/3n4/2BP4/2N1PN2/PP3PPP/2RQK2R w K' => {
			eco => 'D67',
			# TRANSLATORS: D67: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 dxc4 9. Bxc4 Nd5 10. Bxe7 Qxe7
			variation => N__('QGD: Orthodox, Main Line, Capablanca Variation'),
			moves => {
				'c3e4' => 1,
				'e1g1' => 1,
			},
		},
		'r1b2rk1/pp1nqppp/2p1p3/3n4/2BPN3/4PN2/PP3PPP/2RQK2R b K' => {
			eco => 'D67',
			# TRANSLATORS: D67: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 dxc4 9. Bxc4 Nd5 10. Bxe7 Qxe7 11. Ne4
			variation => N__('QGD: Orthodox, Main Line, Alekhine Variation'),
			moves => {
				'd5f6' => 1,
				'e6e5' => 1,
			},
		},
		'r1b2rk1/pp1nqppp/2p1pn2/8/2BPN3/4PN2/PP3PPP/2RQK2R w K' => {
			eco => 'D67',
			# TRANSLATORS: D67: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 dxc4 9. Bxc4 Nd5 10. Bxe7 Qxe7 11. Ne4 N5f6
			variation => N__('QGD: Orthodox, Main Line, Alekhine, 11...N5f6'),
			moves => {
			},
		},
		'r1b2rk1/pp1nqppp/2p5/3np3/2BPN3/4PN2/PP3PPP/2RQK2R w K' => {
			eco => 'D67',
			# TRANSLATORS: D67: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 dxc4 9. Bxc4 Nd5 10. Bxe7 Qxe7 11. Ne4 e5
			variation => N__('QGD: Orthodox, Main Line, Alekhine, 11... e5 (Lasker)'),
			moves => {
			},
		},
		'r1b2rk1/pp1nqppp/2p1p3/3n4/2BP4/2N1PN2/PP3PPP/2RQ1RK1 b -' => {
			eco => 'D67',
			# TRANSLATORS: D67: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 dxc4 9. Bxc4 Nd5 10. Bxe7 Qxe7 11. O-O
			variation => N__('QGD: Orthodox, Main Line, Capablanca, 11.O-O'),
			moves => {
				'd5c3' => 1,
			},
		},
		'r1b2rk1/pp1nqppp/2p1p3/8/2BP4/2n1PN2/PP3PPP/2RQ1RK1 w -' => {
			eco => 'D67',
			# TRANSLATORS: D67: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 dxc4 9. Bxc4 Nd5 10. Bxe7 Qxe7 11. O-O Nxc3
			variation => N__('QGD: Orthodox, Main Line, Capablanca, 11.O-O Nxc3'),
			moves => {
				'c1c3' => 1,
			},
		},
		'r1b2rk1/pp1nqppp/2p1p3/8/2BP4/2R1PN2/PP3PPP/3Q1RK1 b -' => {
			eco => 'D67',
			# TRANSLATORS: D67: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 dxc4 9. Bxc4 Nd5 10. Bxe7 Qxe7 11. O-O Nxc3 12. Rxc3
			variation => N__('QGD: Orthodox, Main Line, Capablanca, 11.O-O Nxc3'),
			moves => {
				'e6e5' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/2p1p3/3n2B1/2BP3P/2N1PN2/PP3PP1/2RQK2R b K' => {
			eco => 'D67',
			# TRANSLATORS: D67: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 dxc4 9. Bxc4 Nd5 10. h4
			variation => N__('QGD: Orthodox, Main Line, Janowski Variation'),
			moves => {
			},
		},
		'r1b2rk1/pp1nqppp/2p5/4p3/2BP4/2R1PN2/PP3PPP/3Q1RK1 w -' => {
			eco => 'D68',
			# TRANSLATORS: D68: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 dxc4 9. Bxc4 Nd5 10. Bxe7 Qxe7 11. O-O Nxc3 12. Rxc3 e5
			variation => N__('QGD: Orthodox, Classical Variation'),
			moves => {
				'c4b3' => 1,
				'd1b1' => 1,
				'd1c2' => 1,
				'd4e5' => 1,
			},
		},
		'r1b2rk1/pp1nqppp/2p5/4p3/3P4/1BR1PN2/PP3PPP/3Q1RK1 b -' => {
			eco => 'D68',
			# TRANSLATORS: D68: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 dxc4 9. Bxc4 Nd5 10. Bxe7 Qxe7 11. O-O Nxc3 12. Rxc3 e5 13. Bb3
			variation => N__('QGD: Orthodox, Classical, 13. Bb3'),
			moves => {
			},
		},
		'r1b2rk1/pp1nqppp/2p5/4p3/2BP4/2R1PN2/PP3PPP/1Q3RK1 b -' => {
			eco => 'D68',
			# TRANSLATORS: D68: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 dxc4 9. Bxc4 Nd5 10. Bxe7 Qxe7 11. O-O Nxc3 12. Rxc3 e5 13. Qb1
			variation => N__('QGD: Orthodox, Classical, Maroczy Variation'),
			moves => {
				'e5d4' => 1,
			},
		},
		'r1b2rk1/pp1nqppp/2p5/8/2Bp4/2R1PN2/PP3PPP/1Q3RK1 w -' => {
			eco => 'D68',
			# TRANSLATORS: D68: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 dxc4 9. Bxc4 Nd5 10. Bxe7 Qxe7 11. O-O Nxc3 12. Rxc3 e5 13. Qb1 exd4
			variation => N__('QGD: Orthodox, Classical, Maroczy, 13...exd4'),
			moves => {
			},
		},
		'r1b2rk1/pp1nqppp/2p5/4p3/2BP4/2R1PN2/PPQ2PPP/5RK1 b -' => {
			eco => 'D68',
			# TRANSLATORS: D68: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 dxc4 9. Bxc4 Nd5 10. Bxe7 Qxe7 11. O-O Nxc3 12. Rxc3 e5 13. Qc2
			variation => N__('QGD: Orthodox, Classical, Vidmar Variation'),
			moves => {
				'e5d4' => 1,
				'e5e4' => 1,
			},
		},
		'r1b2rk1/pp1nqppp/2p5/8/2Bp4/2R1PN2/PPQ2PPP/5RK1 w -' => {
			eco => 'D68',
			# TRANSLATORS: D68: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 dxc4 9. Bxc4 Nd5 10. Bxe7 Qxe7 11. O-O Nxc3 12. Rxc3 e5 13. Qc2 exd4
			variation => N__('QGD: Orthodox, Classical, Vidmar, 13...exd4'),
			moves => {
				'e3d4' => 1,
			},
		},
		'r1b2rk1/pp1nqppp/2p5/8/2BP4/2R2N2/PPQ2PPP/5RK1 b -' => {
			eco => 'D68',
			# TRANSLATORS: D68: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 dxc4 9. Bxc4 Nd5 10. Bxe7 Qxe7 11. O-O Nxc3 12. Rxc3 e5 13. Qc2 exd4 14. exd4
			variation => N__('QGD: Orthodox, Classical, Vidmar, 13...exd4'),
			moves => {
				'd7b6' => 1,
			},
		},
		'r1b2rk1/pp2qppp/1np5/8/2BP4/2R2N2/PPQ2PPP/5RK1 w -' => {
			eco => 'D68',
			# TRANSLATORS: D68: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 dxc4 9. Bxc4 Nd5 10. Bxe7 Qxe7 11. O-O Nxc3 12. Rxc3 e5 13. Qc2 exd4 14. exd4 Nb6
			variation => N__('QGD: Orthodox, Classical, Vidmar, 13...exd4 14.exd4 Nb6'),
			moves => {
			},
		},
		'r1b2rk1/pp1nqppp/2p5/8/2BPp3/2R1PN2/PPQ2PPP/5RK1 w -' => {
			eco => 'D68',
			# TRANSLATORS: D68: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 dxc4 9. Bxc4 Nd5 10. Bxe7 Qxe7 11. O-O Nxc3 12. Rxc3 e5 13. Qc2 e4
			variation => N__('QGD: Orthodox, Classical, Vidmar, 13... e4'),
			moves => {
			},
		},
		'r1b2rk1/pp1nqppp/2p5/4P3/2B5/2R1PN2/PP3PPP/3Q1RK1 b -' => {
			eco => 'D69',
			# TRANSLATORS: D69: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 dxc4 9. Bxc4 Nd5 10. Bxe7 Qxe7 11. O-O Nxc3 12. Rxc3 e5 13. dxe5
			variation => N__('QGD: Orthodox, Classical, 13.dxe5'),
			moves => {
				'd7e5' => 1,
			},
		},
		'r1b2rk1/pp2qppp/2p5/4n3/2B5/2R1PN2/PP3PPP/3Q1RK1 w -' => {
			eco => 'D69',
			# TRANSLATORS: D69: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 dxc4 9. Bxc4 Nd5 10. Bxe7 Qxe7 11. O-O Nxc3 12. Rxc3 e5 13. dxe5 Nxe5
			variation => N__('QGD: Orthodox, Classical, 13.dxe5'),
			moves => {
				'f3e5' => 1,
			},
		},
		'r1b2rk1/pp2qppp/2p5/4N3/2B5/2R1P3/PP3PPP/3Q1RK1 b -' => {
			eco => 'D69',
			# TRANSLATORS: D69: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 dxc4 9. Bxc4 Nd5 10. Bxe7 Qxe7 11. O-O Nxc3 12. Rxc3 e5 13. dxe5 Nxe5 14. Nxe5
			variation => N__('QGD: Orthodox, Classical, 13.dxe5'),
			moves => {
				'e7e5' => 1,
			},
		},
		'r1b2rk1/pp3ppp/2p5/4q3/2B5/2R1P3/PP3PPP/3Q1RK1 w -' => {
			eco => 'D69',
			# TRANSLATORS: D69: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 dxc4 9. Bxc4 Nd5 10. Bxe7 Qxe7 11. O-O Nxc3 12. Rxc3 e5 13. dxe5 Nxe5 14. Nxe5 Qxe5
			variation => N__('QGD: Orthodox, Classical, 13.dxe5'),
			moves => {
				'f2f4' => 1,
			},
		},
		'r1b2rk1/pp3ppp/2p5/4q3/2B2P2/2R1P3/PP4PP/3Q1RK1 b -' => {
			eco => 'D69',
			# TRANSLATORS: D69: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 dxc4 9. Bxc4 Nd5 10. Bxe7 Qxe7 11. O-O Nxc3 12. Rxc3 e5 13. dxe5 Nxe5 14. Nxe5 Qxe5 15. f4
			variation => N__('QGD: Orthodox, Classical, 13.dxe5: 15. f4'),
			moves => {
				'e5e4' => 1,
				'e5f6' => 1,
			},
		},
		'r1b2rk1/pp3ppp/2p5/8/2B1qP2/2R1P3/PP4PP/3Q1RK1 w -' => {
			eco => 'D69',
			# TRANSLATORS: D69: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 dxc4 9. Bxc4 Nd5 10. Bxe7 Qxe7 11. O-O Nxc3 12. Rxc3 e5 13. dxe5 Nxe5 14. Nxe5 Qxe5 15. f4 Qe4
			variation => N__('QGD: Orthodox, Classical, 13.dxe5: 15. f4 Qe4'),
			moves => {
			},
		},
		'r1b2rk1/pp3ppp/2p2q2/8/2B2P2/2R1P3/PP4PP/3Q1RK1 w -' => {
			eco => 'D69',
			# TRANSLATORS: D69: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 dxc4 9. Bxc4 Nd5 10. Bxe7 Qxe7 11. O-O Nxc3 12. Rxc3 e5 13. dxe5 Nxe5 14. Nxe5 Qxe5 15. f4 Qf6
			variation => N__('QGD: Orthodox, Classical, 13.dxe5: 15. f4 Qf6'),
			moves => {
				'e3e4' => 1,
				'f4f5' => 1,
			},
		},
		'r1b2rk1/pp3ppp/2p2q2/8/2B1PP2/2R5/PP4PP/3Q1RK1 b -' => {
			eco => 'D69',
			# TRANSLATORS: D69: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 dxc4 9. Bxc4 Nd5 10. Bxe7 Qxe7 11. O-O Nxc3 12. Rxc3 e5 13. dxe5 Nxe5 14. Nxe5 Qxe5 15. f4 Qf6 16. e4
			variation => N__('QGD: Orthodox, Classical, 13.dxe5: 15. f4 Qf6 16. e4'),
			moves => {
			},
		},
		'r1b2rk1/pp3ppp/2p2q2/5P2/2B5/2R1P3/PP4PP/3Q1RK1 b -' => {
			eco => 'D69',
			# TRANSLATORS: D69: 1. d4 d5 2. c4 e6 3. Nc3 Nf6 4. Bg5 Be7 5. e3 O-O 6. Nf3 Nbd7 7. Rc1 c6 8. Bd3 dxc4 9. Bxc4 Nd5 10. Bxe7 Qxe7 11. O-O Nxc3 12. Rxc3 e5 13. dxe5 Nxe5 14. Nxe5 Qxe5 15. f4 Qf6 16. f5
			variation => N__('QGD: Orthodox, Classical, 13.dxe5: 15. f4 Qf6 16. f5'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/3p4/2PP4/5P2/PP2P1PP/RNBQKBNR w KQkq' => {
			eco => 'D70',
			# TRANSLATORS: D70: 1. d4 Nf6 2. c4 g6 3. f3 d5
			variation => N__('Neo-Grünfeld: Alekhine\'s Anti-Grünfeld'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/3P4/3P4/5P2/PP2P1PP/RNBQKBNR b KQkq' => {
			eco => 'D70',
			# TRANSLATORS: D70: 1. d4 Nf6 2. c4 g6 3. f3 d5 4. cxd5
			variation => N__('Neo-Grünfeld: Alekhine\'s Anti-Grünfeld'),
			moves => {
				'f6d5' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/6p1/3n4/3P4/5P2/PP2P1PP/RNBQKBNR w KQkq' => {
			eco => 'D70',
			# TRANSLATORS: D70: 1. d4 Nf6 2. c4 g6 3. f3 d5 4. cxd5 Nxd5
			variation => N__('Neo-Grünfeld: Alekhine\'s Anti-Grünfeld'),
			moves => {
				'e2e4' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/6p1/3n4/3PP3/5P2/PP4PP/RNBQKBNR b KQkq' => {
			eco => 'D70',
			# TRANSLATORS: D70: 1. d4 Nf6 2. c4 g6 3. f3 d5 4. cxd5 Nxd5 5. e4
			variation => N__('Neo-Grünfeld: Alekhine\'s Anti-Grünfeld'),
			moves => {
				'd5b6' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/1n4p1/8/3PP3/5P2/PP4PP/RNBQKBNR w KQkq' => {
			eco => 'D70',
			# TRANSLATORS: D70: 1. d4 Nf6 2. c4 g6 3. f3 d5 4. cxd5 Nxd5 5. e4 Nb6
			variation => N__('Neo-Grünfeld: Alekhine\'s, 5. e4 Nb6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/1n4p1/8/3PP3/2N2P2/PP4PP/R1BQKBNR b KQkq' => {
			eco => 'D70',
			# TRANSLATORS: D70: 1. d4 Nf6 2. c4 g6 3. f3 d5 4. cxd5 Nxd5 5. e4 Nb6 6. Nc3
			variation => N__('Neo-Grünfeld: Alekhine\'s, 5. e4 Nb6'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/1n4p1/8/3PP3/2N2P2/PP4PP/R1BQKBNR w KQkq' => {
			eco => 'D70',
			# TRANSLATORS: D70: 1. d4 Nf6 2. c4 g6 3. f3 d5 4. cxd5 Nxd5 5. e4 Nb6 6. Nc3 Bg7
			variation => N__('Neo-Grünfeld: Alekhine\'s, 5. e4 Nb6'),
			moves => {
				'c1e3' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/1n4p1/8/3PP3/2N1BP2/PP4PP/R2QKBNR b KQkq' => {
			eco => 'D70',
			# TRANSLATORS: D70: 1. d4 Nf6 2. c4 g6 3. f3 d5 4. cxd5 Nxd5 5. e4 Nb6 6. Nc3 Bg7 7. Be3
			variation => N__('Neo-Grünfeld: Alekhine\'s, 5. e4 Nb6'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/1n4p1/8/3PP3/2N1BP2/PP4PP/R2QKBNR w KQ' => {
			eco => 'D70',
			# TRANSLATORS: D70: 1. d4 Nf6 2. c4 g6 3. f3 d5 4. cxd5 Nxd5 5. e4 Nb6 6. Nc3 Bg7 7. Be3 O-O
			variation => N__('Neo-Grünfeld: Alekhine\'s, 7. Be3 O-O'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/3p4/2PP4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'D70',
			# TRANSLATORS: D70: 1. d4 Nf6 2. c4 g6 3. Nf3 d5
			variation => N__('Neo-Grünfeld: 3. Nf3 d5'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/3p4/2PP4/6P1/PP2PP1P/RNBQKBNR w KQkq' => {
			eco => 'D70',
			# TRANSLATORS: D70: 1. d4 Nf6 2. c4 g6 3. g3 d5
			variation => N__('Neo-Grünfeld: 3. g3 d5'),
			moves => {
				'c4d5' => 1,
				'f1g2' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/3P4/3P4/6P1/PP2PP1P/RNBQKBNR b KQkq' => {
			eco => 'D70',
			# TRANSLATORS: D70: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. cxd5
			variation => N__('Neo-Grünfeld: 4.cxd5'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/3p4/2PP4/6P1/PP2PPBP/RNBQK1NR b KQkq' => {
			eco => 'D70',
			# TRANSLATORS: D70: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2
			variation => N__('Neo-Grünfeld: 4. Bg2'),
			moves => {
				'c7c6' => 1,
				'f8g7' => 1,
			},
		},
		'rnbqkb1r/pp2pp1p/2p2np1/3p4/2PP4/6P1/PP2PPBP/RNBQK1NR w KQkq' => {
			eco => 'D70',
			# TRANSLATORS: D70: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 c6
			variation => N__('Neo-Grünfeld: 4. Bg2 c6'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/3p4/2PP4/6P1/PP2PPBP/RNBQK1NR w KQkq' => {
			eco => 'D70',
			# TRANSLATORS: D70: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7
			variation => N__('Neo-Grünfeld: 4. Bg2 Bg7'),
			moves => {
				'c4d5' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/3P4/3P4/6P1/PP2PPBP/RNBQK1NR b KQkq' => {
			eco => 'D70',
			# TRANSLATORS: D70: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. cxd5
			variation => N__('Neo-Grünfeld: 4. Bg2 Bg7'),
			moves => {
				'f6d5' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/6p1/3n4/3P4/6P1/PP2PPBP/RNBQK1NR w KQkq' => {
			eco => 'D71',
			# TRANSLATORS: D71: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. cxd5 Nxd5
			variation => N__('Neo-Grünfeld, 5.cxd5 Nxd5'),
			moves => {
				'b1c3' => 1,
				'e2e4' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/6p1/3n4/3P4/2N3P1/PP2PPBP/R1BQK1NR b KQkq' => {
			eco => 'D71',
			# TRANSLATORS: D71: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. cxd5 Nxd5 6. Nc3
			variation => N__('Neo-Grünfeld, 5.cxd5 Nxd5 6. Nc3'),
			moves => {
				'd5b6' => 1,
				'd5c3' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/1n4p1/8/3P4/2N3P1/PP2PPBP/R1BQK1NR w KQkq' => {
			eco => 'D71',
			# TRANSLATORS: D71: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. cxd5 Nxd5 6. Nc3 Nb6
			variation => N__('Neo-Grünfeld, 5.cxd5 Nxd5 6. Nc3 Nb6'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/6p1/8/3P4/2n3P1/PP2PPBP/R1BQK1NR w KQkq' => {
			eco => 'D71',
			# TRANSLATORS: D71: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. cxd5 Nxd5 6. Nc3 Nxc3
			variation => N__('Neo-Grünfeld, 5.cxd5 Nxd5 6. Nc3 Nxc3'),
			moves => {
				'b2c3' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/6p1/8/3P4/2P3P1/P3PPBP/R1BQK1NR b KQkq' => {
			eco => 'D71',
			# TRANSLATORS: D71: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. cxd5 Nxd5 6. Nc3 Nxc3 7. bxc3
			variation => N__('Neo-Grünfeld, 5.cxd5 Nxd5 6. Nc3 Nxc3'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/6p1/2p5/3P4/2P3P1/P3PPBP/R1BQK1NR w KQkq' => {
			eco => 'D71',
			# TRANSLATORS: D71: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. cxd5 Nxd5 6. Nc3 Nxc3 7. bxc3 c5
			variation => N__('Neo-Grünfeld, 5.cxd5 Nxd5 6. Nc3 Nxc3 7.bxc3 c5'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/6p1/3n4/3PP3/6P1/PP3PBP/RNBQK1NR b KQkq' => {
			eco => 'D71',
			# TRANSLATORS: D71: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. cxd5 Nxd5 6. e4
			variation => N__('Neo-Grünfeld, 5.cxd5 Nxd5 6. e4'),
			moves => {
				'd5b4' => 1,
				'd5b6' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/6p1/8/1n1PP3/6P1/PP3PBP/RNBQK1NR w KQkq' => {
			eco => 'D71',
			# TRANSLATORS: D71: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. cxd5 Nxd5 6. e4 Nb4
			variation => N__('Neo-Grünfeld, 5.cxd5 Nxd5 6. e4 Nb4'),
			moves => {
				'd4d5' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/6p1/3P4/1n2P3/6P1/PP3PBP/RNBQK1NR b KQkq' => {
			eco => 'D71',
			# TRANSLATORS: D71: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. cxd5 Nxd5 6. e4 Nb4 7. d5
			variation => N__('Neo-Grünfeld, 5.cxd5 Nxd5 6. e4 Nb4 7. d5'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/1n4p1/8/3PP3/6P1/PP3PBP/RNBQK1NR w KQkq' => {
			eco => 'D71',
			# TRANSLATORS: D71: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. cxd5 Nxd5 6. e4 Nb6
			variation => N__('Neo-Grünfeld, 5.cxd5 Nxd5 6. e4 Nb6'),
			moves => {
				'g1e2' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/1n4p1/8/3PP3/6P1/PP2NPBP/RNBQK2R b KQkq' => {
			eco => 'D72',
			# TRANSLATORS: D72: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. cxd5 Nxd5 6. e4 Nb6 7. Ne2
			variation => N__('Neo-Grünfeld, 5.cxd5 Nxd5 6. e4 Nb6 7. Ne2'),
			moves => {
				'b8c6' => 1,
				'c7c5' => 1,
				'e7e5' => 1,
				'e8g8' => 1,
			},
		},
		'r1bqk2r/ppp1ppbp/1nn3p1/8/3PP3/6P1/PP2NPBP/RNBQK2R w KQkq' => {
			eco => 'D72',
			# TRANSLATORS: D72: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. cxd5 Nxd5 6. e4 Nb6 7. Ne2 Nc6
			variation => N__('Neo-Grünfeld, 5.cxd5 Nxd5 6. e4 Nb6 7. Ne2 Nc6'),
			moves => {
			},
		},
		'rnbqk2r/pp2ppbp/1n4p1/2p5/3PP3/6P1/PP2NPBP/RNBQK2R w KQkq' => {
			eco => 'D72',
			# TRANSLATORS: D72: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. cxd5 Nxd5 6. e4 Nb6 7. Ne2 c5
			variation => N__('Neo-Grünfeld, 5.cxd5 Nxd5 6. e4 Nb6 7. Ne2 c5'),
			moves => {
			},
		},
		'rnbqk2r/ppp2pbp/1n4p1/4p3/3PP3/6P1/PP2NPBP/RNBQK2R w KQkq' => {
			eco => 'D72',
			# TRANSLATORS: D72: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. cxd5 Nxd5 6. e4 Nb6 7. Ne2 e5
			variation => N__('Neo-Grünfeld, 5.cxd5 Nxd5 6. e4 Nb6 7. Ne2 e5'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/1n4p1/8/3PP3/6P1/PP2NPBP/RNBQK2R w KQ' => {
			eco => 'D72',
			# TRANSLATORS: D72: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. cxd5 Nxd5 6. e4 Nb6 7. Ne2 O-O
			variation => N__('Neo-Grünfeld, 5.cxd5 Nxd5 6. e4 Nb6 7. Ne2 O-O'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/1n4p1/8/3PP3/6P1/PP2NPBP/RNBQ1RK1 b -' => {
			eco => 'D72',
			# TRANSLATORS: D72: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. cxd5 Nxd5 6. e4 Nb6 7. Ne2 O-O 8. O-O
			variation => N__('Neo-Grünfeld, 5.cxd5 Nxd5 6. e4 Nb6 7. Ne2 O-O 8.O-O'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/3p4/2PP4/5NP1/PP2PPBP/RNBQK2R b KQkq' => {
			eco => 'D73',
			# TRANSLATORS: D73: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3
			variation => N__('Neo-Grünfeld, 5. Nf3'),
			moves => {
				'c7c5' => 1,
				'c7c6' => 1,
				'd5c4' => 1,
				'e8g8' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/5np1/2pp4/2PP4/5NP1/PP2PPBP/RNBQK2R w KQkq' => {
			eco => 'D73',
			# TRANSLATORS: D73: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 c5
			variation => N__('Neo-Grünfeld, 5. Nf3 c5'),
			moves => {
			},
		},
		'rnbqk2r/pp2ppbp/2p2np1/3p4/2PP4/5NP1/PP2PPBP/RNBQK2R w KQkq' => {
			eco => 'D73',
			# TRANSLATORS: D73: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 c6
			variation => N__('Neo-Grünfeld, 5. Nf3 c6'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/2p2np1/3P4/3P4/5NP1/PP2PPBP/RNBQK2R b KQkq' => {
			eco => 'D73',
			# TRANSLATORS: D73: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 c6 6. cxd5
			variation => N__('Neo-Grünfeld, 5. Nf3 c6 6.cxd5'),
			moves => {
				'c6d5' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/5np1/3p4/3P4/5NP1/PP2PPBP/RNBQK2R w KQkq' => {
			eco => 'D73',
			# TRANSLATORS: D73: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 c6 6. cxd5 cxd5
			variation => N__('Neo-Grünfeld, 5. Nf3 c6 6.cxd5 cxd5'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/5np1/3p4/3P4/2N2NP1/PP2PPBP/R1BQK2R b KQkq' => {
			eco => 'D73',
			# TRANSLATORS: D73: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 c6 6. cxd5 cxd5 7. Nc3
			variation => N__('Neo-Grünfeld, 5. Nf3 c6 6.cxd5 cxd5 7. Nc3'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/8/2pP4/5NP1/PP2PPBP/RNBQK2R w KQkq' => {
			eco => 'D73',
			# TRANSLATORS: D73: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 dxc4
			variation => N__('Neo-Grünfeld, 5. Nf3 dxc4'),
			moves => {
				'b1a3' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/8/2pP4/N4NP1/PP2PPBP/R1BQK2R b KQkq' => {
			eco => 'D73',
			# TRANSLATORS: D73: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 dxc4 6. Na3
			variation => N__('Neo-Grünfeld, 5. Nf3 dxc4 6. Na3'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/3p4/2PP4/5NP1/PP2PPBP/RNBQK2R w KQ' => {
			eco => 'D73',
			# TRANSLATORS: D73: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O
			variation => N__('Neo-Grünfeld, 5. Nf3 O-O'),
			moves => {
				'b1c3' => 1,
				'c4d5' => 1,
				'd1b3' => 1,
				'e1g1' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/3p4/2PP4/2N2NP1/PP2PPBP/R1BQK2R b KQ' => {
			eco => 'D73',
			# TRANSLATORS: D73: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. Nc3
			variation => N__('Neo-Grünfeld, 6. Nc3'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/3P4/3P4/5NP1/PP2PPBP/RNBQK2R b KQ' => {
			eco => 'D73',
			# TRANSLATORS: D73: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. cxd5
			variation => N__('Neo-Grünfeld, 6.cxd5'),
			moves => {
				'f6d5' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/6p1/3n4/3P4/5NP1/PP2PPBP/RNBQK2R w KQ' => {
			eco => 'D73',
			# TRANSLATORS: D73: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. cxd5 Nxd5
			variation => N__('Neo-Grünfeld, 6.cxd5'),
			moves => {
				'e1g1' => 1,
				'e2e4' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/6p1/3n4/3PP3/5NP1/PP3PBP/RNBQK2R b KQ' => {
			eco => 'D73',
			# TRANSLATORS: D73: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. cxd5 Nxd5 7. e4
			variation => N__('Neo-Grünfeld, 6.cxd5 Nxd5 7. e4'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/3p4/2PP4/1Q3NP1/PP2PPBP/RNB1K2R b KQ' => {
			eco => 'D73',
			# TRANSLATORS: D73: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. Qb3
			variation => N__('Neo-Grünfeld, 6. Qb3'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/6p1/3n4/3P4/5NP1/PP2PPBP/RNBQ1RK1 b -' => {
			eco => 'D74',
			# TRANSLATORS: D74: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. cxd5 Nxd5 7. O-O
			variation => N__('Neo-Grünfeld, 6.cxd5 Nxd5 7.O-O'),
			moves => {
				'b8a6' => 1,
				'b8c6' => 1,
				'c7c5' => 1,
				'c7c6' => 1,
				'd5b6' => 1,
			},
		},
		'r1bq1rk1/ppp1ppbp/n5p1/3n4/3P4/5NP1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'D74',
			# TRANSLATORS: D74: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. cxd5 Nxd5 7. O-O Na6
			variation => N__('Neo-Grünfeld, 6.cxd5 Nxd5 7.O-O Na6'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1ppbp/2n3p1/3n4/3P4/5NP1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'D74',
			# TRANSLATORS: D74: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. cxd5 Nxd5 7. O-O Nc6
			variation => N__('Neo-Grünfeld, 6.cxd5 Nxd5 7.O-O Nc6'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/6p1/2pn4/3P4/5NP1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'D74',
			# TRANSLATORS: D74: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. cxd5 Nxd5 7. O-O c5
			variation => N__('Neo-Grünfeld, 6.cxd5 Nxd5 7.O-O c5'),
			moves => {
				'b1c3' => 1,
				'd4c5' => 1,
				'e2e4' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/6p1/2pn4/3PP3/5NP1/PP3PBP/RNBQ1RK1 b -' => {
			eco => 'D74',
			# TRANSLATORS: D74: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. cxd5 Nxd5 7. O-O c5 8. e4
			variation => N__('Neo-Grünfeld, 6.cxd5 Nxd5 7.O-O c5 8. e4'),
			moves => {
				'd5f6' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/5np1/2p5/3PP3/5NP1/PP3PBP/RNBQ1RK1 w -' => {
			eco => 'D74',
			# TRANSLATORS: D74: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. cxd5 Nxd5 7. O-O c5 8. e4 Nf6
			variation => N__('Neo-Grünfeld, 6.cxd5 Nxd5 7.O-O c5 8. e4 Nf6'),
			moves => {
				'e4e5' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/5np1/2p1P3/3P4/5NP1/PP3PBP/RNBQ1RK1 b -' => {
			eco => 'D74',
			# TRANSLATORS: D74: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. cxd5 Nxd5 7. O-O c5 8. e4 Nf6 9. e5
			variation => N__('Neo-Grünfeld, 6.cxd5 Nxd5 7.O-O c5 8. e4 Nf6'),
			moves => {
				'f6d5' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/6p1/2pnP3/3P4/5NP1/PP3PBP/RNBQ1RK1 w -' => {
			eco => 'D74',
			# TRANSLATORS: D74: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. cxd5 Nxd5 7. O-O c5 8. e4 Nf6 9. e5 Nd5
			variation => N__('Neo-Grünfeld, 6.cxd5 Nxd5 7.O-O c5 8. e4 Nf6 9. e5 Nd5'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/2p3p1/3n4/3P4/5NP1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'D74',
			# TRANSLATORS: D74: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. cxd5 Nxd5 7. O-O c6
			variation => N__('Neo-Grünfeld, 6.cxd5 Nxd5 7.O-O c6'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/6p1/2pn4/3P4/2N2NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'D75',
			# TRANSLATORS: D75: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. cxd5 Nxd5 7. O-O c5 8. Nc3
			variation => N__('Neo-Grünfeld, 6.cxd5 Nxd5 7.O-O c5 8. Nc3'),
			moves => {
				'd5c3' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/6p1/2p5/3P4/2n2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'D75',
			# TRANSLATORS: D75: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. cxd5 Nxd5 7. O-O c5 8. Nc3 Nxc3
			variation => N__('Neo-Grünfeld, 6.cxd5 Nxd5 7.O-O c5 8. Nc3 Nxc3'),
			moves => {
				'b2c3' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/6p1/2p5/3P4/2P2NP1/P3PPBP/R1BQ1RK1 b -' => {
			eco => 'D75',
			# TRANSLATORS: D75: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. cxd5 Nxd5 7. O-O c5 8. Nc3 Nxc3 9. bxc3
			variation => N__('Neo-Grünfeld, 6.cxd5 Nxd5 7.O-O c5 8. Nc3 Nxc3'),
			moves => {
				'c5d4' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/6p1/8/3p4/2P2NP1/P3PPBP/R1BQ1RK1 w -' => {
			eco => 'D75',
			# TRANSLATORS: D75: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. cxd5 Nxd5 7. O-O c5 8. Nc3 Nxc3 9. bxc3 cxd4
			variation => N__('Neo-Grünfeld, 6.cxd5 Nxd5 7.O-O c5 8. Nc3 Nxc3 9.bxc3 cxd4'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/6p1/2Pn4/8/5NP1/PP2PPBP/RNBQ1RK1 b -' => {
			eco => 'D75',
			# TRANSLATORS: D75: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. cxd5 Nxd5 7. O-O c5 8. dxc5
			variation => N__('Neo-Grünfeld, 6.cxd5 Nxd5 7.O-O c5 8.dxc5'),
			moves => {
				'b8a6' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/n5p1/2Pn4/8/5NP1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'D75',
			# TRANSLATORS: D75: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. cxd5 Nxd5 7. O-O c5 8. dxc5 Na6
			variation => N__('Neo-Grünfeld, 6.cxd5 Nxd5 7.O-O c5 8.dxc5 Na6'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/1n4p1/8/3P4/5NP1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'D76a',
			# TRANSLATORS: D76a: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. cxd5 Nxd5 7. O-O Nb6
			variation => N__('Neo-Grünfeld, 6.cxd5 Nxd5 7.O-O Nb6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/1n4p1/8/3P4/2N2NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'D76b',
			# TRANSLATORS: D76b: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. cxd5 Nxd5 7. O-O Nb6 8. Nc3
			variation => N__('Neo-Grünfeld, 6.cxd5 Nxd5 7.O-O Nb6 8. Nc3'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bq1rk1/ppp1ppbp/1nn3p1/8/3P4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'D76c',
			# TRANSLATORS: D76c: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. cxd5 Nxd5 7. O-O Nb6 8. Nc3 Nc6
			variation => N__('Neo-Grünfeld, 6.cxd5 Nxd5 7.O-O Nb6 8. Nc3 Nc6'),
			moves => {
				'd4d5' => 1,
				'e2e3' => 1,
			},
		},
		'r1bq1rk1/ppp1ppbp/1nn3p1/8/3P4/2N1PNP1/PP3PBP/R1BQ1RK1 b -' => {
			eco => 'D76d',
			# TRANSLATORS: D76d: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. cxd5 Nxd5 7. O-O Nb6 8. Nc3 Nc6 9. e3
			variation => N__('Neo-Grünfeld, 6.cxd5 Nxd5 7.O-O Nb6 8. Nc3 Nc6 9. e3'),
			moves => {
				'e7e5' => 1,
				'f8e8' => 1,
			},
		},
		'r1bq1rk1/ppp2pbp/1nn3p1/4p3/3P4/2N1PNP1/PP3PBP/R1BQ1RK1 w -' => {
			eco => 'D76e',
			# TRANSLATORS: D76e: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. cxd5 Nxd5 7. O-O Nb6 8. Nc3 Nc6 9. e3 e5
			variation => N__('Neo-Grünfeld, 6.cxd5 Nxd5 7.O-O Nb6 8. Nc3 Nc6 9. e3 e5'),
			moves => {
				'd4d5' => 1,
			},
		},
		'r1bq1rk1/ppp2pbp/1nn3p1/3Pp3/8/2N1PNP1/PP3PBP/R1BQ1RK1 b -' => {
			eco => 'D76e',
			# TRANSLATORS: D76e: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. cxd5 Nxd5 7. O-O Nb6 8. Nc3 Nc6 9. e3 e5 10. d5
			variation => N__('Neo-Grünfeld, 6.cxd5 Nxd5 7.O-O Nb6 8. Nc3 Nc6 9. e3 e5 10. d5'),
			moves => {
				'c6a5' => 1,
			},
		},
		'r1bq1rk1/ppp2pbp/1n4p1/n2Pp3/8/2N1PNP1/PP3PBP/R1BQ1RK1 w -' => {
			eco => 'D76f',
			# TRANSLATORS: D76f: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. cxd5 Nxd5 7. O-O Nb6 8. Nc3 Nc6 9. e3 e5 10. d5 Na5
			variation => N__('Neo-Grünfeld, 6.cxd5 Nxd5 7.O-O Nb6 8. Nc3 Nc6 9. e3 e5 10. d5 Na5'),
			moves => {
			},
		},
		'r1bqr1k1/ppp1ppbp/1nn3p1/8/3P4/2N1PNP1/PP3PBP/R1BQ1RK1 w -' => {
			eco => 'D76g',
			# TRANSLATORS: D76g: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. cxd5 Nxd5 7. O-O Nb6 8. Nc3 Nc6 9. e3 Re8
			variation => N__('Neo-Grünfeld, 6.cxd5 Nxd5 7.O-O Nb6 8. Nc3 Nc6 9. e3 Re8'),
			moves => {
				'd4d5' => 1,
			},
		},
		'r1bqr1k1/ppp1ppbp/1nn3p1/3P4/8/2N1PNP1/PP3PBP/R1BQ1RK1 b -' => {
			eco => 'D76h',
			# TRANSLATORS: D76h: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. cxd5 Nxd5 7. O-O Nb6 8. Nc3 Nc6 9. e3 Re8 10. d5
			variation => N__('Neo-Grünfeld, 6.cxd5 Nxd5 7.O-O Nb6 8. Nc3 Nc6 9. e3 Re8 10. d5'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1ppbp/1nn3p1/3P4/8/2N2NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'D76i',
			# TRANSLATORS: D76i: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. cxd5 Nxd5 7. O-O Nb6 8. Nc3 Nc6 9. d5
			variation => N__('Neo-Grünfeld, 6.cxd5 Nxd5 7.O-O Nb6 8. Nc3 Nc6 9. d5'),
			moves => {
				'c6a5' => 1,
			},
		},
		'r1bq1rk1/ppp1ppbp/1n4p1/n2P4/8/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'D76j',
			# TRANSLATORS: D76j: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. cxd5 Nxd5 7. O-O Nb6 8. Nc3 Nc6 9. d5 Na5
			variation => N__('Neo-Grünfeld, 6.cxd5 Nxd5 7.O-O Nb6 8. Nc3 Nc6 9. d5 Na5'),
			moves => {
				'e2e4' => 1,
			},
		},
		'r1bq1rk1/ppp1ppbp/1n4p1/n2P4/4P3/2N2NP1/PP3PBP/R1BQ1RK1 b -' => {
			eco => 'D76k',
			# TRANSLATORS: D76k: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. cxd5 Nxd5 7. O-O Nb6 8. Nc3 Nc6 9. d5 Na5 10. e4
			variation => N__('Neo-Grünfeld, 6.cxd5 Nxd5 7.O-O Nb6 8. Nc3 Nc6 9. d5 Na5 10. e4'),
			moves => {
				'c7c6' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/1np3p1/n2P4/4P3/2N2NP1/PP3PBP/R1BQ1RK1 w -' => {
			eco => 'D76k',
			# TRANSLATORS: D76k: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. cxd5 Nxd5 7. O-O Nb6 8. Nc3 Nc6 9. d5 Na5 10. e4 c6
			variation => N__('Neo-Grünfeld, 6.cxd5 Nxd5 7.O-O Nb6 8. Nc3 Nc6 9. d5 Na5 10. e4 c6'),
			moves => {
				'c1g5' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/1np3p1/n2P2B1/4P3/2N2NP1/PP3PBP/R2Q1RK1 b -' => {
			eco => 'D76l',
			# TRANSLATORS: D76l: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. cxd5 Nxd5 7. O-O Nb6 8. Nc3 Nc6 9. d5 Na5 10. e4 c6 11. Bg5
			variation => N__('Neo-Grünfeld, 6.cxd5 Nxd5 7.O-O Nb6 8. Nc3 Nc6 9. d5 Na5 10. e4 c6 11. Bg5'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/3p4/2PP4/5NP1/PP2PPBP/RNBQ1RK1 b -' => {
			eco => 'D77a',
			# TRANSLATORS: D77a: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O
			variation => N__('Neo-Grünfeld, 6.O-O'),
			moves => {
				'b8c6' => 1,
				'c7c5' => 1,
				'c7c6' => 1,
				'd5c4' => 1,
				'e7e6' => 1,
			},
		},
		'rnbq1rk1/ppp2pbp/4pnp1/3p4/2PP4/5NP1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'D77b',
			# TRANSLATORS: D77b: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O e6
			variation => N__('Neo-Grünfeld, 6.O-O e6'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/5np1/2pp4/2PP4/5NP1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'D77c',
			# TRANSLATORS: D77c: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c5
			variation => N__('Neo-Grünfeld, 6.O-O c5'),
			moves => {
				'd4c5' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/5np1/2Pp4/2P5/5NP1/PP2PPBP/RNBQ1RK1 b -' => {
			eco => 'D77c',
			# TRANSLATORS: D77c: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c5 7. dxc5
			variation => N__('Neo-Grünfeld, 6.O-O c5'),
			moves => {
				'd5c4' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/5np1/2P5/2p5/5NP1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'D77c',
			# TRANSLATORS: D77c: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c5 7. dxc5 dxc4
			variation => N__('Neo-Grünfeld, 6.O-O c5 7.dxc5 dxc4'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1ppbp/2n2np1/3p4/2PP4/5NP1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'D77d',
			# TRANSLATORS: D77d: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O Nc6
			variation => N__('Neo-Grünfeld, 6.O-O Nc6'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/8/2pP4/5NP1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'D77e',
			# TRANSLATORS: D77e: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O dxc4
			variation => N__('Neo-Grünfeld, 6.O-O dxc4'),
			moves => {
				'b1a3' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/8/2pP4/N4NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'D77f',
			# TRANSLATORS: D77f: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O dxc4 7. Na3
			variation => N__('Neo-Grünfeld, 6.O-O dxc4 7. Na3'),
			moves => {
				'b8a6' => 1,
				'b8c6' => 1,
				'c4c3' => 1,
			},
		},
		'r1bq1rk1/ppp1ppbp/n4np1/8/2pP4/N4NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'D77g',
			# TRANSLATORS: D77g: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O dxc4 7. Na3 Na6
			variation => N__('Neo-Grünfeld, 6.O-O dxc4 7. Na3 Na6'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/8/3P4/N1p2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'D77h',
			# TRANSLATORS: D77h: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O dxc4 7. Na3 c3
			variation => N__('Neo-Grünfeld, 6.O-O dxc4 7. Na3 c3'),
			moves => {
				'b2c3' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/8/3P4/N1P2NP1/P3PPBP/R1BQ1RK1 b -' => {
			eco => 'D77h',
			# TRANSLATORS: D77h: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O dxc4 7. Na3 c3 8. bxc3
			variation => N__('Neo-Grünfeld, 6.O-O dxc4 7. Na3 c3'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/5np1/2p5/3P4/N1P2NP1/P3PPBP/R1BQ1RK1 w -' => {
			eco => 'D77h',
			# TRANSLATORS: D77h: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O dxc4 7. Na3 c3 8. bxc3 c5
			variation => N__('Neo-Grünfeld, 6.O-O dxc4 7. Na3 c3 8.bxc3 c5'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/5np1/2p5/3P4/N1P1PNP1/P4PBP/R1BQ1RK1 b -' => {
			eco => 'D77i',
			# TRANSLATORS: D77i: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O dxc4 7. Na3 c3 8. bxc3 c5 9. e3
			variation => N__('Neo-Grünfeld, 6.O-O dxc4 7. Na3 c3 8.bxc3 c5 9. e3'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1ppbp/2n2np1/8/2pP4/N4NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'D77j',
			# TRANSLATORS: D77j: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O dxc4 7. Na3 Nc6
			variation => N__('Neo-Grünfeld, 6.O-O dxc4 7. Na3 Nc6'),
			moves => {
				'a3c4' => 1,
			},
		},
		'r1bq1rk1/ppp1ppbp/2n2np1/8/2NP4/5NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'D77j',
			# TRANSLATORS: D77j: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O dxc4 7. Na3 Nc6 8. Nxc4
			variation => N__('Neo-Grünfeld, 6.O-O dxc4 7. Na3 Nc6 8.Nxc4'),
			moves => {
				'c8e6' => 1,
			},
		},
		'r2q1rk1/ppp1ppbp/2n1bnp1/8/2NP4/5NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'D77j',
			# TRANSLATORS: D77j: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O dxc4 7. Na3 Nc6 8. Nxc4 Be6
			variation => N__('Neo-Grünfeld, 6.O-O dxc4 7. Na3 Nc6 8.Nxc4 Be6'),
			moves => {
				'b2b3' => 1,
			},
		},
		'r2q1rk1/ppp1ppbp/2n1bnp1/8/2NP4/1P3NP1/P3PPBP/R1BQ1RK1 b -' => {
			eco => 'D77k',
			# TRANSLATORS: D77k: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O dxc4 7. Na3 Nc6 8. Nxc4 Be6 9. b3
			variation => N__('Neo-Grünfeld, 6.O-O dxc4 7. Na3 Nc6 8.Nxc4 Be6 9. b3'),
			moves => {
				'e6d5' => 1,
			},
		},
		'r2q1rk1/ppp1ppbp/2n2np1/3b4/2NP4/1P3NP1/P3PPBP/R1BQ1RK1 w -' => {
			eco => 'D77l',
			# TRANSLATORS: D77l: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O dxc4 7. Na3 Nc6 8. Nxc4 Be6 9. b3 Bd5
			variation => N__('Neo-Grünfeld, 6.O-O dxc4 7. Na3 Nc6 8.Nxc4 Be6 9. b3 Bd5'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/2p2np1/3p4/2PP4/5NP1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'D78a',
			# TRANSLATORS: D78a: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6
			variation => N__('Neo-Grünfeld, 6.O-O c6'),
			moves => {
				'b1a3' => 1,
				'b1c3' => 1,
				'b1d2' => 1,
				'b2b3' => 1,
				'c4d5' => 1,
				'd1a4' => 1,
				'd1b3' => 1,
				'f3e5' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/2p2np1/3p4/2PP4/N4NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'D78b',
			# TRANSLATORS: D78b: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. Na3
			variation => N__('Neo-Grünfeld, 6.O-O c6 7. Na3'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/2p2np1/3pN3/2PP4/6P1/PP2PPBP/RNBQ1RK1 b -' => {
			eco => 'D78c',
			# TRANSLATORS: D78c: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. Ne5
			variation => N__('Neo-Grünfeld, 6.O-O c6 7. Ne5'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/2p2np1/3p4/Q1PP4/5NP1/PP2PPBP/RNB2RK1 b -' => {
			eco => 'D78d',
			# TRANSLATORS: D78d: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. Qa4
			variation => N__('Neo-Grünfeld, 6.O-O c6 7. Qa4'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/2p2np1/3p4/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'D78e',
			# TRANSLATORS: D78e: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. Nc3
			variation => N__('Neo-Grünfeld, 6.O-O c6 7. Nc3'),
			moves => {
				'd5c4' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/2p2np1/8/2pP4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'D78f',
			# TRANSLATORS: D78f: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. Nc3 dxc4
			variation => N__('Neo-Grünfeld, 6.O-O c6 7. Nc3 dxc4'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/2p2np1/3p4/2PP4/1Q3NP1/PP2PPBP/RNB2RK1 b -' => {
			eco => 'D78g',
			# TRANSLATORS: D78g: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. Qb3
			variation => N__('Neo-Grünfeld, 6.O-O c6 7. Qb3'),
			moves => {
				'd5c4' => 1,
				'd8b6' => 1,
			},
		},
		'rnb2rk1/pp2ppbp/1qp2np1/3p4/2PP4/1Q3NP1/PP2PPBP/RNB2RK1 w -' => {
			eco => 'D78h',
			# TRANSLATORS: D78h: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. Qb3 Qb6
			variation => N__('Neo-Grünfeld, 6.O-O c6 7. Qb3 Qb6'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/2p2np1/8/2pP4/1Q3NP1/PP2PPBP/RNB2RK1 w -' => {
			eco => 'D78i',
			# TRANSLATORS: D78i: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. Qb3 dxc4
			variation => N__('Neo-Grünfeld, 6.O-O c6 7. Qb3 dxc4'),
			moves => {
				'b3c4' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/2p2np1/8/2QP4/5NP1/PP2PPBP/RNB2RK1 b -' => {
			eco => 'D78j',
			# TRANSLATORS: D78j: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. Qb3 dxc4 8. Qxc4
			variation => N__('Neo-Grünfeld, 6.O-O c6 7. Qb3 dxc4'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/2p2np1/3p4/2PP4/5NP1/PP1NPPBP/R1BQ1RK1 b -' => {
			eco => 'D78k',
			# TRANSLATORS: D78k: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. Nbd2
			variation => N__('Neo-Grünfeld, 6.O-O c6 7.Nbd2'),
			moves => {
				'b8d7' => 1,
				'c8f5' => 1,
				'f6e4' => 1,
			},
		},
		'r1bq1rk1/pp1nppbp/2p2np1/3p4/2PP4/5NP1/PP1NPPBP/R1BQ1RK1 w -' => {
			eco => 'D78l',
			# TRANSLATORS: D78l: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. Nbd2 Nbd7
			variation => N__('Neo-Grünfeld, 6.O-O c6 7.Nbd2 Nbd7'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/2p3p1/3p4/2PPn3/5NP1/PP1NPPBP/R1BQ1RK1 w -' => {
			eco => 'D78m',
			# TRANSLATORS: D78m: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. Nbd2 Ne4
			variation => N__('Neo-Grünfeld, 6.O-O c6 7.Nbd2 Ne4'),
			moves => {
			},
		},
		'rn1q1rk1/pp2ppbp/2p2np1/3p1b2/2PP4/5NP1/PP1NPPBP/R1BQ1RK1 w -' => {
			eco => 'D78n',
			# TRANSLATORS: D78n: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. Nbd2 Bf5
			variation => N__('Neo-Grünfeld, 6.O-O c6 7.Nbd2 Bf5'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/2p2np1/3p4/2PP4/1P3NP1/P3PPBP/RNBQ1RK1 b -' => {
			eco => 'D78o',
			# TRANSLATORS: D78o: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. b3
			variation => N__('Neo-Grünfeld, 6.O-O c6 7. b3'),
			moves => {
				'c8f5' => 1,
				'f6e4' => 1,
			},
		},
		'rn1q1rk1/pp2ppbp/2p2np1/3p1b2/2PP4/1P3NP1/P3PPBP/RNBQ1RK1 w -' => {
			eco => 'D78p',
			# TRANSLATORS: D78p: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. b3 Bf5
			variation => N__('Neo-Grünfeld, 6.O-O c6 7. b3 Bf5'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/2p3p1/3p4/2PPn3/1P3NP1/P3PPBP/RNBQ1RK1 w -' => {
			eco => 'D78q',
			# TRANSLATORS: D78q: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. b3 Ne4
			variation => N__('Neo-Grünfeld, 6.O-O c6 7. b3 Ne4'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/2p2np1/3P4/3P4/5NP1/PP2PPBP/RNBQ1RK1 b -' => {
			eco => 'D79a',
			# TRANSLATORS: D79a: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. cxd5
			variation => N__('Neo-Grünfeld, 6.O-O c6 7.cxd5'),
			moves => {
				'c6d5' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/5np1/3p4/3P4/5NP1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'D79a',
			# TRANSLATORS: D79a: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. cxd5 cxd5
			variation => N__('Neo-Grünfeld, 6.O-O c6 7.cxd5 cxd5'),
			moves => {
				'b1c3' => 1,
				'f3e5' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/5np1/3p4/3P4/2N2NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'D79b',
			# TRANSLATORS: D79b: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. cxd5 cxd5 8. Nc3
			variation => N__('Neo-Grünfeld, 6.O-O c6 7.cxd5 cxd5 8. Nc3'),
			moves => {
				'b8c6' => 1,
				'e7e6' => 1,
				'f6e4' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/4pnp1/3p4/3P4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'D79c',
			# TRANSLATORS: D79c: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. cxd5 cxd5 8. Nc3 e6
			variation => N__('Neo-Grünfeld, 6.O-O c6 7.cxd5 cxd5 8. Nc3 e6'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/6p1/3p4/3Pn3/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'D79d',
			# TRANSLATORS: D79d: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. cxd5 cxd5 8. Nc3 Ne4
			variation => N__('Neo-Grünfeld, 6.O-O c6 7.cxd5 cxd5 8. Nc3 Ne4'),
			moves => {
				'c3e4' => 1,
				'f3e5' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/6p1/3pN3/3Pn3/2N3P1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'D79d',
			# TRANSLATORS: D79d: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. cxd5 cxd5 8. Nc3 Ne4 9. Ne5
			variation => N__('Neo-Grünfeld, 6.O-O c6 7.cxd5 cxd5 8. Nc3 Ne4 9. Ne5'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/6p1/3p4/3PN3/5NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'D79e',
			# TRANSLATORS: D79e: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. cxd5 cxd5 8. Nc3 Ne4 9. Nxe4
			variation => N__('Neo-Grünfeld, 6.O-O c6 7.cxd5 cxd5 8. Nc3 Ne4 9.Nxe4'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/2n2np1/3p4/3P4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'D79f',
			# TRANSLATORS: D79f: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. cxd5 cxd5 8. Nc3 Nc6
			variation => N__('Neo-Grünfeld, 6.O-O c6 7.cxd5 cxd5 8. Nc3 Nc6'),
			moves => {
				'f3e5' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2n2np1/3pN3/3P4/2N3P1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'D79g',
			# TRANSLATORS: D79g: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. cxd5 cxd5 8. Nc3 Nc6 9. Ne5
			variation => N__('Neo-Grünfeld, 6.O-O c6 7.cxd5 cxd5 8. Nc3 Nc6 9. Ne5'),
			moves => {
				'e7e6' => 1,
			},
		},
		'r1bq1rk1/pp3pbp/2n1pnp1/3pN3/3P4/2N3P1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'D79h',
			# TRANSLATORS: D79h: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. cxd5 cxd5 8. Nc3 Nc6 9. Ne5 e6
			variation => N__('Neo-Grünfeld, 6.O-O c6 7.cxd5 cxd5 8. Nc3 Nc6 9. Ne5 e6'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/5np1/3pN3/3P4/6P1/PP2PPBP/RNBQ1RK1 b -' => {
			eco => 'D79i',
			# TRANSLATORS: D79i: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. cxd5 cxd5 8. Ne5
			variation => N__('Neo-Grünfeld, 6.O-O c6 7.cxd5 cxd5 8. Ne5'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/4pnp1/3pN3/3P4/6P1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'D79i',
			# TRANSLATORS: D79i: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. cxd5 cxd5 8. Ne5 e6
			variation => N__('Neo-Grünfeld, 6.O-O c6 7.cxd5 cxd5 8. Ne5 e6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/4pnp1/3pN3/3P4/2N3P1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'D79j',
			# TRANSLATORS: D79j: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. cxd5 cxd5 8. Ne5 e6 9. Nc3
			variation => N__('Neo-Grünfeld, Main Line'),
			moves => {
				'f6d7' => 1,
			},
		},
		'rnbq1rk1/pp1n1pbp/4p1p1/3pN3/3P4/2N3P1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'D79j',
			# TRANSLATORS: D79j: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. cxd5 cxd5 8. Ne5 e6 9. Nc3 Nfd7
			variation => N__('Neo-Grünfeld, Main Line'),
			moves => {
				'f2f4' => 1,
			},
		},
		'rnbq1rk1/pp1n1pbp/4p1p1/3pN3/3P1P2/2N3P1/PP2P1BP/R1BQ1RK1 b -' => {
			eco => 'D79k',
			# TRANSLATORS: D79k: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. cxd5 cxd5 8. Ne5 e6 9. Nc3 Nfd7 10. f4
			variation => N__('Neo-Grünfeld, Main Line, 10. f4'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bq1rk1/pp1n1pbp/2n1p1p1/3pN3/3P1P2/2N3P1/PP2P1BP/R1BQ1RK1 w -' => {
			eco => 'D79l',
			# TRANSLATORS: D79l: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. cxd5 cxd5 8. Ne5 e6 9. Nc3 Nfd7 10. f4 Nc6
			variation => N__('Neo-Grünfeld, Main Line, 10. f4 Nc6'),
			moves => {
				'c1e3' => 1,
			},
		},
		'r1bq1rk1/pp1n1pbp/2n1p1p1/3pN3/3P1P2/2N1B1P1/PP2P1BP/R2Q1RK1 b -' => {
			eco => 'D79m',
			# TRANSLATORS: D79m: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. cxd5 cxd5 8. Ne5 e6 9. Nc3 Nfd7 10. f4 Nc6 11. Be3
			variation => N__('Neo-Grünfeld, Main Line, 10. f4 Nc6 11. Be3'),
			moves => {
				'd7b6' => 1,
				'f7f6' => 1,
			},
		},
		'r1bq1rk1/pp1n2bp/2n1ppp1/3pN3/3P1P2/2N1B1P1/PP2P1BP/R2Q1RK1 w -' => {
			eco => 'D79m',
			# TRANSLATORS: D79m: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. cxd5 cxd5 8. Ne5 e6 9. Nc3 Nfd7 10. f4 Nc6 11. Be3 f6
			variation => N__('Neo-Grünfeld, Main Line, 10. f4 Nc6 11. Be3 f6'),
			moves => {
			},
		},
		'r1bq1rk1/pp3pbp/1nn1p1p1/3pN3/3P1P2/2N1B1P1/PP2P1BP/R2Q1RK1 w -' => {
			eco => 'D79n',
			# TRANSLATORS: D79n: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. cxd5 cxd5 8. Ne5 e6 9. Nc3 Nfd7 10. f4 Nc6 11. Be3 Nb6
			variation => N__('Neo-Grünfeld, Main Line, 10. f4 Nc6 11. Be3 Nb6'),
			moves => {
				'e3f2' => 1,
			},
		},
		'r1bq1rk1/pp3pbp/1nn1p1p1/3pN3/3P1P2/2N3P1/PP2PBBP/R2Q1RK1 b -' => {
			eco => 'D79n',
			# TRANSLATORS: D79n: 1. d4 Nf6 2. c4 g6 3. g3 d5 4. Bg2 Bg7 5. Nf3 O-O 6. O-O c6 7. cxd5 cxd5 8. Ne5 e6 9. Nc3 Nfd7 10. f4 Nc6 11. Be3 Nb6 12. Bf2
			variation => N__('Neo-Grünfeld, Main Line, 10. f4 Nc6 11. Be3 Nb6 12. Bf2'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/3p4/2PP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'D80',
			# TRANSLATORS: D80: 1. d4 Nf6 2. c4 g6 3. Nc3 d5
			variation => N__('Grünfeld Defence'),
			moves => {
				'c1f4' => 1,
				'c1g5' => 1,
				'c4d5' => 1,
				'd1b3' => 1,
				'e2e3' => 1,
				'f2f3' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
				'g2g4' => 1,
				'h2h4' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/3p2B1/2PP4/2N5/PP2PPPP/R2QKBNR b KQkq' => {
			eco => 'D80',
			# TRANSLATORS: D80: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bg5
			variation => N__('Grünfeld: Stockholm Variation'),
			moves => {
				'f6e4' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/6p1/3p2B1/2PPn3/2N5/PP2PPPP/R2QKBNR w KQkq' => {
			eco => 'D80',
			# TRANSLATORS: D80: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bg5 Ne4
			variation => N__('Grünfeld: Stockholm, 4... Ne4'),
			moves => {
				'c3e4' => 1,
				'g5f4' => 1,
				'g5h4' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/6p1/3p2B1/2PPN3/8/PP2PPPP/R2QKBNR b KQkq' => {
			eco => 'D80',
			# TRANSLATORS: D80: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bg5 Ne4 5. Nxe4
			variation => N__('Grünfeld: Stockholm, 4... Ne4 5.Nxe4'),
			moves => {
				'd5e4' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/6p1/6B1/2PPp3/8/PP2PPPP/R2QKBNR w KQkq' => {
			eco => 'D80',
			# TRANSLATORS: D80: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bg5 Ne4 5. Nxe4 dxe4
			variation => N__('Grünfeld: Stockholm, 4... Ne4 5.Nxe4'),
			moves => {
				'd1d2' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/6p1/6B1/2PPp3/8/PP1QPPPP/R3KBNR b KQkq' => {
			eco => 'D80',
			# TRANSLATORS: D80: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bg5 Ne4 5. Nxe4 dxe4 6. Qd2
			variation => N__('Grünfeld: Stockholm, 4... Ne4 5.Nxe4'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqkb1r/pp2pp1p/6p1/2p3B1/2PPp3/8/PP1QPPPP/R3KBNR w KQkq' => {
			eco => 'D80',
			# TRANSLATORS: D80: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bg5 Ne4 5. Nxe4 dxe4 6. Qd2 c5
			variation => N__('Grünfeld: Stockholm, Lundin Variation'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/6p1/3p4/2PPnB2/2N5/PP2PPPP/R2QKBNR b KQkq' => {
			eco => 'D80',
			# TRANSLATORS: D80: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bg5 Ne4 5. Bf4
			variation => N__('Grünfeld: Stockholm, 4... Ne4 5. Bf4'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/6p1/3p4/2PPn2B/2N5/PP2PPPP/R2QKBNR b KQkq' => {
			eco => 'D80',
			# TRANSLATORS: D80: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bg5 Ne4 5. Bh4
			variation => N__('Grünfeld: Stockholm, Taimanov Variation'),
			moves => {
				'e4c3' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/6p1/3p4/2PP3B/2n5/PP2PPPP/R2QKBNR w KQkq' => {
			eco => 'D80',
			# TRANSLATORS: D80: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bg5 Ne4 5. Bh4 Nxc3
			variation => N__('Grünfeld: Stockholm, Taimanov, 5...Nxc3'),
			moves => {
				'b2c3' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/6p1/3p4/2PP3B/2P5/P3PPPP/R2QKBNR b KQkq' => {
			eco => 'D80',
			# TRANSLATORS: D80: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bg5 Ne4 5. Bh4 Nxc3 6. bxc3
			variation => N__('Grünfeld: Stockholm, Taimanov, 5...Nxc3'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/6p1/3p4/2PP3B/2P5/P3PPPP/R2QKBNR w KQkq' => {
			eco => 'D80',
			# TRANSLATORS: D80: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bg5 Ne4 5. Bh4 Nxc3 6. bxc3 Bg7
			variation => N__('Grünfeld: Stockholm, Taimanov, 5...Nxc3 6.bxc3 Bg7'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/3p4/2PP4/2N1P3/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'D80',
			# TRANSLATORS: D80: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. e3
			variation => N__('Grünfeld: 4. e3'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/3p4/2PP4/2N1P3/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'D80',
			# TRANSLATORS: D80: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. e3 Bg7
			variation => N__('Grünfeld: 4. e3 Bg7'),
			moves => {
				'd1b3' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/3p4/2PP4/1QN1P3/PP3PPP/R1B1KBNR b KQkq' => {
			eco => 'D80',
			# TRANSLATORS: D80: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. e3 Bg7 5. Qb3
			variation => N__('Grünfeld: 4. e3 Bg7 5. Qb3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/3p4/2PP4/2N2P2/PP2P1PP/R1BQKBNR b KQkq' => {
			eco => 'D80',
			# TRANSLATORS: D80: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. f3
			variation => N__('Grünfeld: 4. f3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/3p4/2PP4/2N3P1/PP2PP1P/R1BQKBNR b KQkq' => {
			eco => 'D80',
			# TRANSLATORS: D80: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. g3
			variation => N__('Grünfeld: 4. g3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/3p4/2PP2P1/2N5/PP2PP1P/R1BQKBNR b KQkq' => {
			eco => 'D80',
			# TRANSLATORS: D80: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. g4
			variation => N__('Grünfeld: Spike/Gibbon Gambit'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/3p4/2PP3P/2N5/PP2PPP1/R1BQKBNR b KQkq' => {
			eco => 'D80',
			# TRANSLATORS: D80: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. h4
			variation => N__('Grünfeld: 4. h4'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/3p4/2PP4/1QN5/PP2PPPP/R1B1KBNR b KQkq' => {
			eco => 'D81',
			# TRANSLATORS: D81: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Qb3
			variation => N__('Grünfeld: Early Russian Variation'),
			moves => {
				'd5c4' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/8/2pP4/1QN5/PP2PPPP/R1B1KBNR w KQkq' => {
			eco => 'D81',
			# TRANSLATORS: D81: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Qb3 dxc4
			variation => N__('Grünfeld: Early Russian Variation'),
			moves => {
				'b3c4' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/8/2QP4/2N5/PP2PPPP/R1B1KBNR b KQkq' => {
			eco => 'D81',
			# TRANSLATORS: D81: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Qb3 dxc4 5. Qxc4
			variation => N__('Grünfeld: Early Russian Variation'),
			moves => {
				'c8e6' => 1,
				'f8g7' => 1,
			},
		},
		'rn1qkb1r/ppp1pp1p/4bnp1/8/2QP4/2N5/PP2PPPP/R1B1KBNR w KQkq' => {
			eco => 'D81',
			# TRANSLATORS: D81: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Qb3 dxc4 5. Qxc4 Be6
			variation => N__('Grünfeld: Early Russian, 5... Be6'),
			moves => {
				'c4b5' => 1,
			},
		},
		'rn1qkb1r/ppp1pp1p/4bnp1/1Q6/3P4/2N5/PP2PPPP/R1B1KBNR b KQkq' => {
			eco => 'D81',
			# TRANSLATORS: D81: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Qb3 dxc4 5. Qxc4 Be6 6. Qb5+
			variation => N__('Grünfeld: Early Russian, 5... Be6 6. Qb5+'),
			moves => {
				'e6d7' => 1,
			},
		},
		'rn1qkb1r/pppbpp1p/5np1/1Q6/3P4/2N5/PP2PPPP/R1B1KBNR w KQkq' => {
			eco => 'D81',
			# TRANSLATORS: D81: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Qb3 dxc4 5. Qxc4 Be6 6. Qb5+ Bd7
			variation => N__('Grünfeld: Early Russian, Adorjan Gambit'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/8/2QP4/2N5/PP2PPPP/R1B1KBNR w KQkq' => {
			eco => 'D81',
			# TRANSLATORS: D81: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Qb3 dxc4 5. Qxc4 Bg7
			variation => N__('Grünfeld: Early Russian, 5... Bg7'),
			moves => {
				'e2e4' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/8/2QPP3/2N5/PP3PPP/R1B1KBNR b KQkq' => {
			eco => 'D81',
			# TRANSLATORS: D81: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Qb3 dxc4 5. Qxc4 Bg7 6. e4
			variation => N__('Grünfeld: Early Russian, 5... Bg7 6. e4'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/8/2QPP3/2N5/PP3PPP/R1B1KBNR w KQ' => {
			eco => 'D81',
			# TRANSLATORS: D81: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Qb3 dxc4 5. Qxc4 Bg7 6. e4 O-O
			variation => N__('Grünfeld: Early Russian, 5... Bg7 6. e4 O-O'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/3p4/2PP1B2/2N5/PP2PPPP/R2QKBNR b KQkq' => {
			eco => 'D82',
			# TRANSLATORS: D82: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bf4
			variation => N__('Grünfeld: 4. Bf4'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/3p4/2PP1B2/2N5/PP2PPPP/R2QKBNR w KQkq' => {
			eco => 'D82',
			# TRANSLATORS: D82: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bf4 Bg7
			variation => N__('Grünfeld: 4. Bf4 Bg7'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/3p4/2PP1B2/2N1P3/PP3PPP/R2QKBNR b KQkq' => {
			eco => 'D82',
			# TRANSLATORS: D82: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bf4 Bg7 5. e3
			variation => N__('Grünfeld: 4. Bf4 Bg7 5. e3'),
			moves => {
				'c7c5' => 1,
				'e8g8' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/5np1/2pp4/2PP1B2/2N1P3/PP3PPP/R2QKBNR w KQkq' => {
			eco => 'D82',
			# TRANSLATORS: D82: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bf4 Bg7 5. e3 c5
			variation => N__('Grünfeld: 4. Bf4 Bg7 5. e3 c5'),
			moves => {
				'd4c5' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/5np1/2Pp4/2P2B2/2N1P3/PP3PPP/R2QKBNR b KQkq' => {
			eco => 'D82',
			# TRANSLATORS: D82: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bf4 Bg7 5. e3 c5 6. dxc5
			variation => N__('Grünfeld: 4. Bf4 Bg7 5. e3 c5'),
			moves => {
				'd8a5' => 1,
			},
		},
		'rnb1k2r/pp2ppbp/5np1/q1Pp4/2P2B2/2N1P3/PP3PPP/R2QKBNR w KQkq' => {
			eco => 'D82',
			# TRANSLATORS: D82: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bf4 Bg7 5. e3 c5 6. dxc5 Qa5
			variation => N__('Grünfeld: 4. Bf4 Bg7 5. e3 c5 6.dxc5 Qa5'),
			moves => {
				'a1c1' => 1,
				'd1a4' => 1,
			},
		},
		'rnb1k2r/pp2ppbp/5np1/q1Pp4/2P2B2/2N1P3/PP3PPP/2RQKBNR b Kkq' => {
			eco => 'D82',
			# TRANSLATORS: D82: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bf4 Bg7 5. e3 c5 6. dxc5 Qa5 7. Rc1
			variation => N__('Grünfeld: 4. Bf4 Bg7 5. e3 c5 6.dxc5 Qa5 7. Rc1'),
			moves => {
			},
		},
		'rnb1k2r/pp2ppbp/5np1/q1Pp4/Q1P2B2/2N1P3/PP3PPP/R3KBNR b KQkq' => {
			eco => 'D82',
			# TRANSLATORS: D82: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bf4 Bg7 5. e3 c5 6. dxc5 Qa5 7. Qa4+
			variation => N__('Grünfeld: 4. Bf4 Bg7 5. e3 c5 6.dxc5 Qa5 7. Qa4+'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/3p4/2PP1B2/2N1P3/PP3PPP/R2QKBNR w KQ' => {
			eco => 'D83',
			# TRANSLATORS: D83: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bf4 Bg7 5. e3 O-O
			variation => N__('Grünfeld: Grünfeld Gambit'),
			moves => {
				'a1c1' => 1,
				'c4d5' => 1,
				'd1b3' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/3p4/2PP1B2/2N1P3/PP3PPP/2RQKBNR b K' => {
			eco => 'D83',
			# TRANSLATORS: D83: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bf4 Bg7 5. e3 O-O 6. Rc1
			variation => N__('Grünfeld: Grünfeld Gambit, Capablanca Variation'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/5np1/2pp4/2PP1B2/2N1P3/PP3PPP/2RQKBNR w K' => {
			eco => 'D83',
			# TRANSLATORS: D83: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bf4 Bg7 5. e3 O-O 6. Rc1 c5
			variation => N__('Grünfeld: Grünfeld Gambit, Capablanca Variation'),
			moves => {
				'd4c5' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/5np1/2Pp4/2P2B2/2N1P3/PP3PPP/2RQKBNR b K' => {
			eco => 'D83',
			# TRANSLATORS: D83: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bf4 Bg7 5. e3 O-O 6. Rc1 c5 7. dxc5
			variation => N__('Grünfeld: Grünfeld Gambit, Capablanca Variation'),
			moves => {
				'c8e6' => 1,
			},
		},
		'rn1q1rk1/pp2ppbp/4bnp1/2Pp4/2P2B2/2N1P3/PP3PPP/2RQKBNR w K' => {
			eco => 'D83',
			# TRANSLATORS: D83: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bf4 Bg7 5. e3 O-O 6. Rc1 c5 7. dxc5 Be6
			variation => N__('Grünfeld: Grünfeld Gambit, Botvinnik Variation'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/3p4/2PP1B2/1QN1P3/PP3PPP/R3KBNR b KQ' => {
			eco => 'D83',
			# TRANSLATORS: D83: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bf4 Bg7 5. e3 O-O 6. Qb3
			variation => N__('Grünfeld: Grünfeld Gambit, 6. Qb3'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/3P4/3P1B2/2N1P3/PP3PPP/R2QKBNR b KQ' => {
			eco => 'D84',
			# TRANSLATORS: D84: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bf4 Bg7 5. e3 O-O 6. cxd5
			variation => N__('Grünfeld: Grünfeld Gambit Accepted'),
			moves => {
				'f6d5' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/6p1/3n4/3P1B2/2N1P3/PP3PPP/R2QKBNR w KQ' => {
			eco => 'D84',
			# TRANSLATORS: D84: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bf4 Bg7 5. e3 O-O 6. cxd5 Nxd5
			variation => N__('Grünfeld: Grünfeld Gambit Accepted'),
			moves => {
				'c3d5' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/6p1/3N4/3P1B2/4P3/PP3PPP/R2QKBNR b KQ' => {
			eco => 'D84',
			# TRANSLATORS: D84: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bf4 Bg7 5. e3 O-O 6. cxd5 Nxd5 7. Nxd5
			variation => N__('Grünfeld: Grünfeld Gambit Accepted'),
			moves => {
				'd8d5' => 1,
			},
		},
		'rnb2rk1/ppp1ppbp/6p1/3q4/3P1B2/4P3/PP3PPP/R2QKBNR w KQ' => {
			eco => 'D84',
			# TRANSLATORS: D84: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bf4 Bg7 5. e3 O-O 6. cxd5 Nxd5 7. Nxd5 Qxd5
			variation => N__('Grünfeld: Grünfeld Gambit Accepted'),
			moves => {
				'f4c7' => 1,
			},
		},
		'rnb2rk1/ppB1ppbp/6p1/3q4/3P4/4P3/PP3PPP/R2QKBNR b KQ' => {
			eco => 'D84',
			# TRANSLATORS: D84: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bf4 Bg7 5. e3 O-O 6. cxd5 Nxd5 7. Nxd5 Qxd5 8. Bxc7
			variation => N__('Grünfeld: Grünfeld Gambit Accepted'),
			moves => {
				'b7b6' => 1,
				'b8a6' => 1,
				'b8c6' => 1,
				'c8f5' => 1,
			},
		},
		'rnb2rk1/p1B1ppbp/1p4p1/3q4/3P4/4P3/PP3PPP/R2QKBNR w KQ' => {
			eco => 'D84',
			# TRANSLATORS: D84: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bf4 Bg7 5. e3 O-O 6. cxd5 Nxd5 7. Nxd5 Qxd5 8. Bxc7 b6
			variation => N__('Grünfeld: Grünfeld Gambit Accepted, 8... b6'),
			moves => {
			},
		},
		'r1b2rk1/ppB1ppbp/n5p1/3q4/3P4/4P3/PP3PPP/R2QKBNR w KQ' => {
			eco => 'D84',
			# TRANSLATORS: D84: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bf4 Bg7 5. e3 O-O 6. cxd5 Nxd5 7. Nxd5 Qxd5 8. Bxc7 Na6
			variation => N__('Grünfeld: Grünfeld Gambit Accepted, 8... Na6'),
			moves => {
				'f1a6' => 1,
			},
		},
		'r1b2rk1/ppB1ppbp/B5p1/3q4/3P4/4P3/PP3PPP/R2QK1NR b KQ' => {
			eco => 'D84',
			# TRANSLATORS: D84: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bf4 Bg7 5. e3 O-O 6. cxd5 Nxd5 7. Nxd5 Qxd5 8. Bxc7 Na6 9. Bxa6
			variation => N__('Grünfeld: Grünfeld Gambit Accepted, 8... Na6'),
			moves => {
				'd5g2' => 1,
			},
		},
		'r1b2rk1/ppB1ppbp/B5p1/8/3P4/4P3/PP3PqP/R2QK1NR w KQ' => {
			eco => 'D84',
			# TRANSLATORS: D84: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bf4 Bg7 5. e3 O-O 6. cxd5 Nxd5 7. Nxd5 Qxd5 8. Bxc7 Na6 9. Bxa6 Qxg2
			variation => N__('Grünfeld: Grünfeld Gambit Accepted, 8... Na6 9.Bxa6 Qxg2'),
			moves => {
			},
		},
		'r1b2rk1/ppB1ppbp/2n3p1/3q4/3P4/4P3/PP3PPP/R2QKBNR w KQ' => {
			eco => 'D84',
			# TRANSLATORS: D84: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bf4 Bg7 5. e3 O-O 6. cxd5 Nxd5 7. Nxd5 Qxd5 8. Bxc7 Nc6
			variation => N__('Grünfeld: Grünfeld Gambit Accepted, 8... Nc6'),
			moves => {
				'g1e2' => 1,
			},
		},
		'r1b2rk1/ppB1ppbp/2n3p1/3q4/3P4/4P3/PP2NPPP/R2QKB1R b KQ' => {
			eco => 'D84',
			# TRANSLATORS: D84: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bf4 Bg7 5. e3 O-O 6. cxd5 Nxd5 7. Nxd5 Qxd5 8. Bxc7 Nc6 9. Ne2
			variation => N__('Grünfeld: Grünfeld Gambit Accepted, 8... Nc6 9. Ne2'),
			moves => {
				'c8g4' => 1,
			},
		},
		'r4rk1/ppB1ppbp/2n3p1/3q4/3P2b1/4P3/PP2NPPP/R2QKB1R w KQ' => {
			eco => 'D84',
			# TRANSLATORS: D84: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bf4 Bg7 5. e3 O-O 6. cxd5 Nxd5 7. Nxd5 Qxd5 8. Bxc7 Nc6 9. Ne2 Bg4
			variation => N__('Grünfeld: Grünfeld Gambit Accepted, 8... Nc6 9. Ne2 Bg4'),
			moves => {
			},
		},
		'rn3rk1/ppB1ppbp/6p1/3q1b2/3P4/4P3/PP3PPP/R2QKBNR w KQ' => {
			eco => 'D84',
			# TRANSLATORS: D84: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Bf4 Bg7 5. e3 O-O 6. cxd5 Nxd5 7. Nxd5 Qxd5 8. Bxc7 Bf5
			variation => N__('Grünfeld: Grünfeld Gambit Accepted, 8... Bf5'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/3P4/3P4/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'D85a',
			# TRANSLATORS: D85a: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5
			variation => N__('Grünfeld: Exchange Variation'),
			moves => {
				'f6d5' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/6p1/3n4/3P4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'D85a',
			# TRANSLATORS: D85a: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5
			variation => N__('Grünfeld: Exchange Variation'),
			moves => {
				'c1d2' => 1,
				'c3a4' => 1,
				'e2e4' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/6p1/3n4/N2P4/8/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'D85a',
			# TRANSLATORS: D85a: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. Na4
			variation => N__('Grünfeld: Exchange, 5. Na4'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/6p1/3n4/3P4/2N3P1/PP2PP1P/R1BQKBNR b KQkq' => {
			eco => 'D85a',
			# TRANSLATORS: D85a: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. g3
			variation => N__('Grünfeld: Exchange, 5. g3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/6p1/3n4/3P4/2N5/PP1BPPPP/R2QKBNR b KQkq' => {
			eco => 'D85b',
			# TRANSLATORS: D85b: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. Bd2
			variation => N__('Grünfeld: Exchange, 5. Bd2'),
			moves => {
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/6p1/3n4/3P4/2N5/PP1BPPPP/R2QKBNR w KQkq' => {
			eco => 'D85b',
			# TRANSLATORS: D85b: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. Bd2 Bg7
			variation => N__('Grünfeld: Exchange, 5. Bd2'),
			moves => {
				'e2e4' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/6p1/3n4/3PP3/2N5/PP1B1PPP/R2QKBNR b KQkq' => {
			eco => 'D85b',
			# TRANSLATORS: D85b: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. Bd2 Bg7 6. e4
			variation => N__('Grünfeld: Exchange, 5. Bd2'),
			moves => {
				'd5b6' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/1n4p1/8/3PP3/2N5/PP1B1PPP/R2QKBNR w KQkq' => {
			eco => 'D85c',
			# TRANSLATORS: D85c: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. Bd2 Bg7 6. e4 Nb6
			variation => N__('Grünfeld: Exchange, 5. Bd2 Bg7 6. e4 Nb6'),
			moves => {
				'd2e3' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/1n4p1/8/3PP3/2N1B3/PP3PPP/R2QKBNR b KQkq' => {
			eco => 'D85c',
			# TRANSLATORS: D85c: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. Bd2 Bg7 6. e4 Nb6 7. Be3
			variation => N__('Grünfeld: Exchange, 5. Bd2 Bg7 6. e4 Nb6 7. Be3'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/6p1/3n4/3PP3/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'D85d',
			# TRANSLATORS: D85d: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4
			variation => N__('Grünfeld: Exchange, 5. e4'),
			moves => {
				'd5b6' => 1,
				'd5c3' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/1n4p1/8/3PP3/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'D85d',
			# TRANSLATORS: D85d: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nb6
			variation => N__('Grünfeld: Exchange, 5. e4 Nb6'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/6p1/8/3PP3/2n5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'D85d',
			# TRANSLATORS: D85d: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3
			variation => N__('Grünfeld: Exchange, 5. e4 Nxc3'),
			moves => {
				'b2c3' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/6p1/8/3PP3/2P5/P4PPP/R1BQKBNR b KQkq' => {
			eco => 'D85d',
			# TRANSLATORS: D85d: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3
			variation => N__('Grünfeld: Exchange, 5. e4 Nxc3'),
			moves => {
				'c7c5' => 1,
				'f8g7' => 1,
			},
		},
		'rnbqkb1r/pp2pp1p/6p1/2p5/3PP3/2P5/P4PPP/R1BQKBNR w KQkq' => {
			eco => 'D85d',
			# TRANSLATORS: D85d: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 c5
			variation => N__('Grünfeld: Exchange, 5. e4 Nxc3 6.bxc3 c5'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/6p1/8/3PP3/2P5/P4PPP/R1BQKBNR w KQkq' => {
			eco => 'D85d',
			# TRANSLATORS: D85d: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7
			variation => N__('Grünfeld: Exchange, 5. e4 Nxc3 6.bxc3 Bg7'),
			moves => {
				'c1a3' => 1,
				'c1e3' => 1,
				'f1b5' => 1,
				'f1c4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/6p1/8/3PP3/B1P5/P4PPP/R2QKBNR b KQkq' => {
			eco => 'D85d',
			# TRANSLATORS: D85d: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Ba3
			variation => N__('Grünfeld: Exchange, 7. Ba3'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/6p1/1B6/3PP3/2P5/P4PPP/R1BQK1NR b KQkq' => {
			eco => 'D85e',
			# TRANSLATORS: D85e: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bb5+
			variation => N__('Grünfeld: Exchange, 7. Bb5+'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/2p3p1/1B6/3PP3/2P5/P4PPP/R1BQK1NR w KQkq' => {
			eco => 'D85e',
			# TRANSLATORS: D85e: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bb5+ c6
			variation => N__('Grünfeld: Exchange, 7. Bb5+ c6'),
			moves => {
				'b5a4' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/2p3p1/8/B2PP3/2P5/P4PPP/R1BQK1NR b KQkq' => {
			eco => 'D85e',
			# TRANSLATORS: D85e: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bb5+ c6 8. Ba4
			variation => N__('Grünfeld: Exchange, 7. Bb5+ c6 8. Ba4'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/2p3p1/8/B2PP3/2P5/P4PPP/R1BQK1NR w KQ' => {
			eco => 'D85f',
			# TRANSLATORS: D85f: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bb5+ c6 8. Ba4 O-O
			variation => N__('Grünfeld: Exchange, 7. Bb5+ c6 8. Ba4 O-O'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/6p1/8/3PP3/2P1B3/P4PPP/R2QKBNR b KQkq' => {
			eco => 'D85g',
			# TRANSLATORS: D85g: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Be3
			variation => N__('Grünfeld: Exchange, 7. Be3'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/6p1/2p5/3PP3/2P1B3/P4PPP/R2QKBNR w KQkq' => {
			eco => 'D85g',
			# TRANSLATORS: D85g: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Be3 c5
			variation => N__('Grünfeld: Exchange, 7. Be3 c5'),
			moves => {
				'd1d2' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/6p1/2p5/3PP3/2P1B3/P2Q1PPP/R3KBNR b KQkq' => {
			eco => 'D85g',
			# TRANSLATORS: D85g: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Be3 c5 8. Qd2
			variation => N__('Grünfeld: Exchange, 7. Be3 c5 8. Qd2'),
			moves => {
				'd8a5' => 1,
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/6p1/2p5/3PP3/2P1B3/P2Q1PPP/R3KBNR w KQ' => {
			eco => 'D85g',
			# TRANSLATORS: D85g: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Be3 c5 8. Qd2 O-O
			variation => N__('Grünfeld: Exchange, 7. Be3 c5 8. Qd2 O-O'),
			moves => {
				'a1c1' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/6p1/2p5/3PP3/2P1B3/P2Q1PPP/2R1KBNR b K' => {
			eco => 'D85g',
			# TRANSLATORS: D85g: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Be3 c5 8. Qd2 O-O 9. Rc1
			variation => N__('Grünfeld: Exchange, 7. Be3 c5 8. Qd2 O-O 9. Rc1'),
			moves => {
			},
		},
		'rnb1k2r/pp2ppbp/6p1/q1p5/3PP3/2P1B3/P2Q1PPP/R3KBNR w KQkq' => {
			eco => 'D85h',
			# TRANSLATORS: D85h: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Be3 c5 8. Qd2 Qa5
			variation => N__('Grünfeld: Exchange, 7. Be3 c5 8. Qd2 Qa5'),
			moves => {
				'a1b1' => 1,
				'a1c1' => 1,
			},
		},
		'rnb1k2r/pp2ppbp/6p1/q1p5/3PP3/2P1B3/P2Q1PPP/1R2KBNR b Kkq' => {
			eco => 'D85h',
			# TRANSLATORS: D85h: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Be3 c5 8. Qd2 Qa5 9. Rb1
			variation => N__('Grünfeld: Exchange, 7. Be3 c5 8. Qd2 Qa5 9. Rb1'),
			moves => {
				'b7b6' => 1,
			},
		},
		'rnb1k2r/p3ppbp/1p4p1/q1p5/3PP3/2P1B3/P2Q1PPP/1R2KBNR w Kkq' => {
			eco => 'D85h',
			# TRANSLATORS: D85h: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Be3 c5 8. Qd2 Qa5 9. Rb1 b6
			variation => N__('Grünfeld: Exchange, 7. Be3 c5 8. Qd2 Qa5 9. Rb1 b6'),
			moves => {
			},
		},
		'rnb1k2r/pp2ppbp/6p1/q1p5/3PP3/2P1B3/P2Q1PPP/2R1KBNR b Kkq' => {
			eco => 'D85h',
			# TRANSLATORS: D85h: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Be3 c5 8. Qd2 Qa5 9. Rc1
			variation => N__('Grünfeld: Exchange, 7. Be3 c5 8. Qd2 Qa5 9. Rc1'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/6p1/8/3PP3/2P2N2/P4PPP/R1BQKB1R b KQkq' => {
			eco => 'D85i',
			# TRANSLATORS: D85i: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3
			variation => N__('Grünfeld: Modern Exchange'),
			moves => {
				'c7c5' => 1,
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/6p1/8/3PP3/2P2N2/P4PPP/R1BQKB1R w KQ' => {
			eco => 'D85i',
			# TRANSLATORS: D85i: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 O-O
			variation => N__('Grünfeld: Modern Exchange, 7...O-O'),
			moves => {
			},
		},
		'rnbqk2r/pp2ppbp/6p1/2p5/3PP3/2P2N2/P4PPP/R1BQKB1R w KQkq' => {
			eco => 'D85j',
			# TRANSLATORS: D85j: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5
			variation => N__('Grünfeld: Modern Exchange, 7... c5'),
			moves => {
				'a1b1' => 1,
				'c1e3' => 1,
				'f1b5' => 1,
				'f1e2' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/6p1/1Bp5/3PP3/2P2N2/P4PPP/R1BQK2R b KQkq' => {
			eco => 'D85k',
			# TRANSLATORS: D85k: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Bb5+
			variation => N__('Grünfeld: Modern Exchange, 8. Bb5+'),
			moves => {
			},
		},
		'rnbqk2r/pp2ppbp/6p1/2p5/3PP3/2P2N2/P3BPPP/R1BQK2R b KQkq' => {
			eco => 'D85l',
			# TRANSLATORS: D85l: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Be2
			variation => N__('Grünfeld: Modern Exchange, 8. Be2'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/6p1/2p5/3PP3/2P2N2/P3BPPP/R1BQK2R w KQ' => {
			eco => 'D85l',
			# TRANSLATORS: D85l: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Be2 O-O
			variation => N__('Grünfeld: Modern Exchange, 8. Be2 O-O'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/6p1/2p5/3PP3/2P2N2/P3BPPP/R1BQ1RK1 b -' => {
			eco => 'D85l',
			# TRANSLATORS: D85l: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Be2 O-O 9. O-O
			variation => N__('Grünfeld: Modern Exchange, 8. Be2 O-O 9.O-O'),
			moves => {
				'b7b6' => 1,
				'b8c6' => 1,
			},
		},
		'rnbq1rk1/p3ppbp/1p4p1/2p5/3PP3/2P2N2/P3BPPP/R1BQ1RK1 w -' => {
			eco => 'D85l',
			# TRANSLATORS: D85l: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Be2 O-O 9. O-O b6
			variation => N__('Grünfeld: Modern Exchange, 8. Be2 O-O 9.O-O b6'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/2n3p1/2p5/3PP3/2P2N2/P3BPPP/R1BQ1RK1 w -' => {
			eco => 'D85l',
			# TRANSLATORS: D85l: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Be2 O-O 9. O-O Nc6
			variation => N__('Grünfeld: Modern Exchange, 8. Be2 O-O 9.O-O Nc6'),
			moves => {
			},
		},
		'rnbqk2r/pp2ppbp/6p1/2p5/3PP3/2P2N2/P4PPP/1RBQKB1R b Kkq' => {
			eco => 'D85m',
			# TRANSLATORS: D85m: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Rb1
			variation => N__('Grünfeld: Modern Exchange, 8. Rb1'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/6p1/2p5/3PP3/2P2N2/P4PPP/1RBQKB1R w K' => {
			eco => 'D85m',
			# TRANSLATORS: D85m: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Rb1 O-O
			variation => N__('Grünfeld: Modern Exchange, 8. Rb1 O-O'),
			moves => {
				'f1e2' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/6p1/2p5/3PP3/2P2N2/P3BPPP/1RBQK2R b K' => {
			eco => 'D85m',
			# TRANSLATORS: D85m: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Rb1 O-O 9. Be2
			variation => N__('Grünfeld: Modern Exchange, 8. Rb1 O-O 9. Be2'),
			moves => {
				'b7b6' => 1,
				'b8c6' => 1,
				'c5d4' => 1,
				'd8a5' => 1,
			},
		},
		'rnb2rk1/pp2ppbp/6p1/q1p5/3PP3/2P2N2/P3BPPP/1RBQK2R w K' => {
			eco => 'D85m',
			# TRANSLATORS: D85m: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Rb1 O-O 9. Be2 Qa5
			variation => N__('Grünfeld: Modern Exchange, 8. Rb1 O-O 9. Be2 Qa5'),
			moves => {
			},
		},
		'rnbq1rk1/p3ppbp/1p4p1/2p5/3PP3/2P2N2/P3BPPP/1RBQK2R w K' => {
			eco => 'D85n',
			# TRANSLATORS: D85n: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Rb1 O-O 9. Be2 b6
			variation => N__('Grünfeld: Modern Exchange, 8. Rb1 O-O 9. Be2 b6'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/2n3p1/2p5/3PP3/2P2N2/P3BPPP/1RBQK2R w K' => {
			eco => 'D85o',
			# TRANSLATORS: D85o: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Rb1 O-O 9. Be2 Nc6
			variation => N__('Grünfeld: Modern Exchange, 8. Rb1 O-O 9. Be2 Nc6'),
			moves => {
				'd4d5' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2n3p1/2pP4/4P3/2P2N2/P3BPPP/1RBQK2R b K' => {
			eco => 'D85o',
			# TRANSLATORS: D85o: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Rb1 O-O 9. Be2 Nc6 10. d5
			variation => N__('Grünfeld: Modern Exchange, 8. Rb1 O-O 9. Be2 Nc6'),
			moves => {
				'c6e5' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/6p1/2pPn3/4P3/2P2N2/P3BPPP/1RBQK2R w K' => {
			eco => 'D85o',
			# TRANSLATORS: D85o: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Rb1 O-O 9. Be2 Nc6 10. d5 Ne5
			variation => N__('Grünfeld: Modern Exchange, 8. Rb1 O-O 9. Be2 Nc6'),
			moves => {
				'f3e5' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/6p1/2pPN3/4P3/2P5/P3BPPP/1RBQK2R b K' => {
			eco => 'D85o',
			# TRANSLATORS: D85o: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Rb1 O-O 9. Be2 Nc6 10. d5 Ne5 11. Nxe5
			variation => N__('Grünfeld: Modern Exchange, 8. Rb1 O-O 9. Be2 Nc6'),
			moves => {
				'g7e5' => 1,
			},
		},
		'r1bq1rk1/pp2pp1p/6p1/2pPb3/4P3/2P5/P3BPPP/1RBQK2R w K' => {
			eco => 'D85o',
			# TRANSLATORS: D85o: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Rb1 O-O 9. Be2 Nc6 10. d5 Ne5 11. Nxe5 Bxe5
			variation => N__('Grünfeld: Modern Exchange, 8. Rb1 O-O 9. Be2 Nc6'),
			moves => {
				'd1d2' => 1,
			},
		},
		'r1bq1rk1/pp2pp1p/6p1/2pPb3/4P3/2P5/P2QBPPP/1RB1K2R b K' => {
			eco => 'D85p',
			# TRANSLATORS: D85p: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Rb1 O-O 9. Be2 Nc6 10. d5 Ne5 11. Nxe5 Bxe5 12. Qd2
			variation => N__('Grünfeld: Modern Exchange, 8. Rb1 O-O 9. Be2 Nc6, Main Line'),
			moves => {
				'e7e6' => 1,
			},
		},
		'r1bq1rk1/pp3p1p/4p1p1/2pPb3/4P3/2P5/P2QBPPP/1RB1K2R w K' => {
			eco => 'D85p',
			# TRANSLATORS: D85p: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Rb1 O-O 9. Be2 Nc6 10. d5 Ne5 11. Nxe5 Bxe5 12. Qd2 e6
			variation => N__('Grünfeld: Modern Exchange, 8. Rb1 O-O 9. Be2 Nc6, Main Line, 12... e6'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/6p1/8/3pP3/2P2N2/P3BPPP/1RBQK2R w K' => {
			eco => 'D85q',
			# TRANSLATORS: D85q: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Rb1 O-O 9. Be2 cxd4
			variation => N__('Grünfeld: Modern Exchange, 8. Rb1 O-O 9. Be2 cd'),
			moves => {
				'c3d4' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/6p1/8/3PP3/5N2/P3BPPP/1RBQK2R b K' => {
			eco => 'D85q',
			# TRANSLATORS: D85q: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Rb1 O-O 9. Be2 cxd4 10. cxd4
			variation => N__('Grünfeld: Modern Exchange, 8. Rb1 O-O 9. Be2 cd 10.cd'),
			moves => {
				'd8a5' => 1,
			},
		},
		'rnb2rk1/pp2ppbp/6p1/q7/3PP3/5N2/P3BPPP/1RBQK2R w K' => {
			eco => 'D85q',
			# TRANSLATORS: D85q: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Rb1 O-O 9. Be2 cxd4 10. cxd4 Qa5+
			variation => N__('Grünfeld: Modern Exchange, 8. Rb1 O-O 9. Be2 cd 10.cd Qa5+'),
			moves => {
				'c1d2' => 1,
				'd1d2' => 1,
			},
		},
		'rnb2rk1/pp2ppbp/6p1/q7/3PP3/5N2/P2QBPPP/1RB1K2R b K' => {
			eco => 'D85q',
			# TRANSLATORS: D85q: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Rb1 O-O 9. Be2 cxd4 10. cxd4 Qa5+ 11. Qd2
			variation => N__('Grünfeld: Modern Exchange, 8. Rb1 O-O 9. Be2 cd 10.cd Qa5+ 11. Qd2'),
			moves => {
			},
		},
		'rnb2rk1/pp2ppbp/6p1/q7/3PP3/5N2/P2BBPPP/1R1QK2R b K' => {
			eco => 'D85r',
			# TRANSLATORS: D85r: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Rb1 O-O 9. Be2 cxd4 10. cxd4 Qa5+ 11. Bd2
			variation => N__('Grünfeld: Modern Exchange, 8. Rb1 O-O 9. Be2 cd 10.cd Qa5+ 11. Bd2'),
			moves => {
				'a5a2' => 1,
			},
		},
		'rnb2rk1/pp2ppbp/6p1/8/3PP3/5N2/q2BBPPP/1R1QK2R w K' => {
			eco => 'D85r',
			# TRANSLATORS: D85r: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Rb1 O-O 9. Be2 cxd4 10. cxd4 Qa5+ 11. Bd2 Qxa2
			variation => N__('Grünfeld: Modern Exchange, 8. Rb1 O-O 9. Be2 cd 10.cd Qa5+ 11. Bd2'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnb2rk1/pp2ppbp/6p1/8/3PP3/5N2/q2BBPPP/1R1Q1RK1 b -' => {
			eco => 'D85r',
			# TRANSLATORS: D85r: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Rb1 O-O 9. Be2 cxd4 10. cxd4 Qa5+ 11. Bd2 Qxa2 12. O-O
			variation => N__('Grünfeld: Modern Exchange, 8. Rb1 O-O 9. Be2 cd 10.cd Qa5+ 11. Bd2'),
			moves => {
				'c8g4' => 1,
			},
		},
		'rn3rk1/pp2ppbp/6p1/8/3PP1b1/5N2/q2BBPPP/1R1Q1RK1 w -' => {
			eco => 'D85s',
			# TRANSLATORS: D85s: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Rb1 O-O 9. Be2 cxd4 10. cxd4 Qa5+ 11. Bd2 Qxa2 12. O-O Bg4
			variation => N__('Grünfeld: Modern Exchange, 8. Rb1, 10... Qa5+ 11. Bd2 Qxa2 12.O-O Bg4'),
			moves => {
				'd2g5' => 1,
			},
		},
		'rn3rk1/pp2ppbp/6p1/6B1/3PP1b1/5N2/q3BPPP/1R1Q1RK1 b -' => {
			eco => 'D85s',
			# TRANSLATORS: D85s: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Rb1 O-O 9. Be2 cxd4 10. cxd4 Qa5+ 11. Bd2 Qxa2 12. O-O Bg4 13. Bg5
			variation => N__('Grünfeld: Modern Exchange, 8. Rb1, 10... Qa5+ 11. Bd2 Qxa2 12.O-O Bg4 13. Bg5'),
			moves => {
			},
		},
		'rnbqk2r/pp2ppbp/6p1/2p5/3PP3/2P1BN2/P4PPP/R2QKB1R b KQkq' => {
			eco => 'D85t',
			# TRANSLATORS: D85t: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Be3
			variation => N__('Grünfeld: Modern Exchange, 8. Be3'),
			moves => {
				'b8c6' => 1,
				'c8g4' => 1,
				'd8a5' => 1,
				'e8g8' => 1,
			},
		},
		'r1bqk2r/pp2ppbp/2n3p1/2p5/3PP3/2P1BN2/P4PPP/R2QKB1R w KQkq' => {
			eco => 'D85t',
			# TRANSLATORS: D85t: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Be3 Nc6
			variation => N__('Grünfeld: Modern Exchange, 8. Be3 Nc6'),
			moves => {
			},
		},
		'rn1qk2r/pp2ppbp/6p1/2p5/3PP1b1/2P1BN2/P4PPP/R2QKB1R w KQkq' => {
			eco => 'D85t',
			# TRANSLATORS: D85t: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Be3 Bg4
			variation => N__('Grünfeld: Modern Exchange, 8. Be3 Bg4'),
			moves => {
			},
		},
		'rnb1k2r/pp2ppbp/6p1/q1p5/3PP3/2P1BN2/P4PPP/R2QKB1R w KQkq' => {
			eco => 'D85u',
			# TRANSLATORS: D85u: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Be3 Qa5
			variation => N__('Grünfeld: Modern Exchange, 8. Be3 Qa5'),
			moves => {
				'd1d2' => 1,
			},
		},
		'rnb1k2r/pp2ppbp/6p1/q1p5/3PP3/2P1BN2/P2Q1PPP/R3KB1R b KQkq' => {
			eco => 'D85u',
			# TRANSLATORS: D85u: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Be3 Qa5 9. Qd2
			variation => N__('Grünfeld: Modern Exchange, 8. Be3 Qa5 9. Qd2'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1b1k2r/pp2ppbp/2n3p1/q1p5/3PP3/2P1BN2/P2Q1PPP/R3KB1R w KQkq' => {
			eco => 'D85u',
			# TRANSLATORS: D85u: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Be3 Qa5 9. Qd2 Nc6
			variation => N__('Grünfeld: Modern Exchange, 8. Be3 Qa5 9. Qd2'),
			moves => {
				'a1c1' => 1,
			},
		},
		'r1b1k2r/pp2ppbp/2n3p1/q1p5/3PP3/2P1BN2/P2Q1PPP/2R1KB1R b Kkq' => {
			eco => 'D85v',
			# TRANSLATORS: D85v: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Be3 Qa5 9. Qd2 Nc6 10. Rc1
			variation => N__('Grünfeld: Modern Exchange, 8. Be3 Qa5 9. Qd2 Nc6 10. Rc1'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/6p1/2p5/3PP3/2P1BN2/P4PPP/R2QKB1R w KQ' => {
			eco => 'D85w',
			# TRANSLATORS: D85w: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Be3 O-O
			variation => N__('Grünfeld: Modern Exchange, 8. Be3 O-O'),
			moves => {
				'a1c1' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/6p1/2p5/3PP3/2P1BN2/P4PPP/2RQKB1R b K' => {
			eco => 'D85w',
			# TRANSLATORS: D85w: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Be3 O-O 9. Rc1
			variation => N__('Grünfeld: Modern Exchange, 8. Be3 O-O'),
			moves => {
				'd8a5' => 1,
			},
		},
		'rnb2rk1/pp2ppbp/6p1/q1p5/3PP3/2P1BN2/P4PPP/2RQKB1R w K' => {
			eco => 'D85x',
			# TRANSLATORS: D85x: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Be3 O-O 9. Rc1 Qa5
			variation => N__('Grünfeld: Modern Exchange, 8. Be3 O-O 9. Rc1 Qa5'),
			moves => {
				'd1d2' => 1,
			},
		},
		'rnb2rk1/pp2ppbp/6p1/q1p5/3PP3/2P1BN2/P2Q1PPP/2R1KB1R b K' => {
			eco => 'D85x',
			# TRANSLATORS: D85x: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Be3 O-O 9. Rc1 Qa5 10. Qd2
			variation => N__('Grünfeld: Modern Exchange, 8. Be3 O-O 9. Rc1 Qa5 10. Qd2'),
			moves => {
				'c5d4' => 1,
			},
		},
		'rnb2rk1/pp2ppbp/6p1/q7/3pP3/2P1BN2/P2Q1PPP/2R1KB1R w K' => {
			eco => 'D85x',
			# TRANSLATORS: D85x: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Be3 O-O 9. Rc1 Qa5 10. Qd2 cxd4
			variation => N__('Grünfeld: Modern Exchange, 8. Be3 O-O 9. Rc1 Qa5 10. Qd2'),
			moves => {
				'c3d4' => 1,
			},
		},
		'rnb2rk1/pp2ppbp/6p1/q7/3PP3/4BN2/P2Q1PPP/2R1KB1R b K' => {
			eco => 'D85x',
			# TRANSLATORS: D85x: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Be3 O-O 9. Rc1 Qa5 10. Qd2 cxd4 11. cxd4
			variation => N__('Grünfeld: Modern Exchange, 8. Be3 O-O 9. Rc1 Qa5 10. Qd2'),
			moves => {
				'a5d2' => 1,
			},
		},
		'rnb2rk1/pp2ppbp/6p1/8/3PP3/4BN2/P2q1PPP/2R1KB1R w K' => {
			eco => 'D85x',
			# TRANSLATORS: D85x: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Be3 O-O 9. Rc1 Qa5 10. Qd2 cxd4 11. cxd4 Qxd2+
			variation => N__('Grünfeld: Modern Exchange, 8. Be3 O-O 9. Rc1 Qa5 10. Qd2'),
			moves => {
				'e1d2' => 1,
				'f3d2' => 1,
			},
		},
		'rnb2rk1/pp2ppbp/6p1/8/3PP3/4BN2/P2K1PPP/2R2B1R b -' => {
			eco => 'D85x',
			# TRANSLATORS: D85x: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Be3 O-O 9. Rc1 Qa5 10. Qd2 cxd4 11. cxd4 Qxd2+ 12. Kxd2
			variation => N__('Grünfeld: Modern Exchange, 8. Be3 O-O 9. Rc1 Qa5 Queenswap, 12.Kxd2'),
			moves => {
			},
		},
		'rnb2rk1/pp2ppbp/6p1/8/3PP3/4B3/P2N1PPP/2R1KB1R b K' => {
			eco => 'D85y',
			# TRANSLATORS: D85y: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Nf3 c5 8. Be3 O-O 9. Rc1 Qa5 10. Qd2 cxd4 11. cxd4 Qxd2+ 12. Nxd2
			variation => N__('Grünfeld: Modern Exchange, 8. Be3 O-O 9. Rc1 Qa5 Queenswap, 12.Nxd2'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/6p1/8/2BPP3/2P5/P4PPP/R1BQK1NR b KQkq' => {
			eco => 'D86',
			# TRANSLATORS: D86: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4
			variation => N__('Grünfeld: Classical Exchange'),
			moves => {
				'b7b6' => 1,
				'c7c5' => 1,
				'e8g8' => 1,
			},
		},
		'rnbqk2r/p1p1ppbp/1p4p1/8/2BPP3/2P5/P4PPP/R1BQK1NR w KQkq' => {
			eco => 'D86',
			# TRANSLATORS: D86: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 b6
			variation => N__('Grünfeld: Classical Exchange, 7... b6'),
			moves => {
			},
		},
		'rnbqk2r/pp2ppbp/6p1/2p5/2BPP3/2P5/P4PPP/R1BQK1NR w KQkq' => {
			eco => 'D86',
			# TRANSLATORS: D86: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 c5
			variation => N__('Grünfeld: Classical Exchange, 7... c5'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/6p1/8/2BPP3/2P5/P4PPP/R1BQK1NR w KQ' => {
			eco => 'D86',
			# TRANSLATORS: D86: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O
			variation => N__('Grünfeld: Classical Exchange, 7...O-O'),
			moves => {
				'g1e2' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/6p1/8/2BPP3/2P5/P3NPPP/R1BQK2R b KQ' => {
			eco => 'D86',
			# TRANSLATORS: D86: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2
			variation => N__('Grünfeld: Classical Exchange, 8. Ne2'),
			moves => {
				'b7b6' => 1,
				'b8c6' => 1,
				'c7c5' => 1,
				'd8d7' => 1,
			},
		},
		'rnbq1rk1/p1p1ppbp/1p4p1/8/2BPP3/2P5/P3NPPP/R1BQK2R w KQ' => {
			eco => 'D86',
			# TRANSLATORS: D86: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 b6
			variation => N__('Grünfeld: Classical Exchange, Simagin'),
			moves => {
				'e1g1' => 1,
				'h2h4' => 1,
			},
		},
		'rnbq1rk1/p1p1ppbp/1p4p1/8/2BPP3/2P5/P3NPPP/R1BQ1RK1 b -' => {
			eco => 'D86',
			# TRANSLATORS: D86: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 b6 9. O-O
			variation => N__('Grünfeld: Classical Exchange, Simagin, 9.O-O'),
			moves => {
			},
		},
		'rnbq1rk1/p1p1ppbp/1p4p1/8/2BPP2P/2P5/P3NPP1/R1BQK2R b KQ' => {
			eco => 'D86',
			# TRANSLATORS: D86: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 b6 9. h4
			variation => N__('Grünfeld: Classical Exchange, Simagin, 9. h4'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1ppbp/2n3p1/8/2BPP3/2P5/P3NPPP/R1BQK2R w KQ' => {
			eco => 'D86',
			# TRANSLATORS: D86: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 Nc6
			variation => N__('Grünfeld: Classical Exchange, Simagin Improved'),
			moves => {
				'c1e3' => 1,
				'e1g1' => 1,
			},
		},
		'r1bq1rk1/ppp1ppbp/2n3p1/8/2BPP3/2P1B3/P3NPPP/R2QK2R b KQ' => {
			eco => 'D86',
			# TRANSLATORS: D86: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 Nc6 9. Be3
			variation => N__('Grünfeld: Classical Exchange, Simagin Improved, 9. Be3'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1ppbp/2n3p1/8/2BPP3/2P5/P3NPPP/R1BQ1RK1 b -' => {
			eco => 'D86',
			# TRANSLATORS: D86: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 Nc6 9. O-O
			variation => N__('Grünfeld: Classical Exchange, Simagin Improved, 9.O-O'),
			moves => {
				'b7b6' => 1,
				'e7e5' => 1,
			},
		},
		'r1bq1rk1/p1p1ppbp/1pn3p1/8/2BPP3/2P5/P3NPPP/R1BQ1RK1 w -' => {
			eco => 'D86',
			# TRANSLATORS: D86: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 Nc6 9. O-O b6
			variation => N__('Grünfeld: Classical Exchange, Simagin Improved, 9.O-O b6'),
			moves => {
			},
		},
		'r1bq1rk1/ppp2pbp/2n3p1/4p3/2BPP3/2P5/P3NPPP/R1BQ1RK1 w -' => {
			eco => 'D86',
			# TRANSLATORS: D86: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 Nc6 9. O-O e5
			variation => N__('Grünfeld: Classical Exchange, Simagin Improved, 9.O-O e5'),
			moves => {
			},
		},
		'rnb2rk1/pppqppbp/6p1/8/2BPP3/2P5/P3NPPP/R1BQK2R w KQ' => {
			eco => 'D86',
			# TRANSLATORS: D86: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 Qd7
			variation => N__('Grünfeld: Classical Exchange, 8. Ne2'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnb2rk1/pppqppbp/6p1/8/2BPP3/2P5/P3NPPP/R1BQ1RK1 b -' => {
			eco => 'D86',
			# TRANSLATORS: D86: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 Qd7 9. O-O
			variation => N__('Grünfeld: Classical Exchange, 8. Ne2'),
			moves => {
				'b7b6' => 1,
			},
		},
		'rnb2rk1/p1pqppbp/1p4p1/8/2BPP3/2P5/P3NPPP/R1BQ1RK1 w -' => {
			eco => 'D86',
			# TRANSLATORS: D86: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 Qd7 9. O-O b6
			variation => N__('Grünfeld: Classical Exchange, Larsen Variation'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/6p1/2p5/2BPP3/2P5/P3NPPP/R1BQK2R w KQ' => {
			eco => 'D87a',
			# TRANSLATORS: D87a: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5
			variation => N__('Grünfeld: Classical Exchange, 8... c5'),
			moves => {
				'c1e3' => 1,
				'e1g1' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/6p1/2p5/2BPP3/2P1B3/P3NPPP/R2QK2R b KQ' => {
			eco => 'D87b',
			# TRANSLATORS: D87b: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. Be3
			variation => N__('Grünfeld: Classical Exchange, 8... c5 9. Be3'),
			moves => {
				'b8c6' => 1,
				'd8a5' => 1,
			},
		},
		'rnb2rk1/pp2ppbp/6p1/q1p5/2BPP3/2P1B3/P3NPPP/R2QK2R w KQ' => {
			eco => 'D87c',
			# TRANSLATORS: D87c: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. Be3 Qa5
			variation => N__('Grünfeld: Classical Exchange, 8... c5 9. Be3 Qa5'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnb2rk1/pp2ppbp/6p1/q1p5/2BPP3/2P1B3/P3NPPP/R2Q1RK1 b -' => {
			eco => 'D87c',
			# TRANSLATORS: D87c: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. Be3 Qa5 10. O-O
			variation => N__('Grünfeld: Classical Exchange, 8... c5 9. Be3 Qa5'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r1b2rk1/pp1nppbp/6p1/q1p5/2BPP3/2P1B3/P3NPPP/R2Q1RK1 w -' => {
			eco => 'D87c',
			# TRANSLATORS: D87c: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. Be3 Qa5 10. O-O Nd7
			variation => N__('Grünfeld: Classical Exchange, 8... c5 9. Be3 Qa5'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/2n3p1/2p5/2BPP3/2P1B3/P3NPPP/R2QK2R w KQ' => {
			eco => 'D87d',
			# TRANSLATORS: D87d: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. Be3 Nc6
			variation => N__('Grünfeld: Classical Exchange, 8... c5 9. Be3 Nc6'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/6p1/2p5/2BPP3/2P5/P3NPPP/R1BQ1RK1 b -' => {
			eco => 'D87e',
			# TRANSLATORS: D87e: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O
			variation => N__('Grünfeld: Classical Exchange, 9.O-O'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2n3p1/2p5/2BPP3/2P5/P3NPPP/R1BQ1RK1 w -' => {
			eco => 'D87f',
			# TRANSLATORS: D87f: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6
			variation => N__('Grünfeld: Classical Exchange, 9.O-O Nc6'),
			moves => {
				'c1e3' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2n3p1/2p5/2BPP3/2P1B3/P3NPPP/R2Q1RK1 b -' => {
			eco => 'D87g',
			# TRANSLATORS: D87g: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3
			variation => N__('Grünfeld: Classical Exchange, 9.O-O Nc6 10. Be3'),
			moves => {
				'c5d4' => 1,
				'c6a5' => 1,
				'c8g4' => 1,
				'd8a5' => 1,
				'd8c7' => 1,
			},
		},
		'r1b2rk1/pp2ppbp/2n3p1/q1p5/2BPP3/2P1B3/P3NPPP/R2Q1RK1 w -' => {
			eco => 'D87h',
			# TRANSLATORS: D87h: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 Qa5
			variation => N__('Grünfeld: Classical Exchange, 10. Be3 Qa5'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/6p1/n1p5/2BPP3/2P1B3/P3NPPP/R2Q1RK1 w -' => {
			eco => 'D87i',
			# TRANSLATORS: D87i: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 Na5
			variation => N__('Grünfeld: Classical Exchange, 10. Be3 Na5'),
			moves => {
			},
		},
		'r1b2rk1/ppq1ppbp/2n3p1/2p5/2BPP3/2P1B3/P3NPPP/R2Q1RK1 w -' => {
			eco => 'D87j',
			# TRANSLATORS: D87j: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 Qc7
			variation => N__('Grünfeld: Classical Exchange, 10. Be3 Qc7'),
			moves => {
				'a1c1' => 1,
			},
		},
		'r1b2rk1/ppq1ppbp/2n3p1/2p5/2BPP3/2P1B3/P3NPPP/2RQ1RK1 b -' => {
			eco => 'D87j',
			# TRANSLATORS: D87j: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 Qc7 11. Rc1
			variation => N__('Grünfeld: Classical Exchange, 10. Be3 Qc7'),
			moves => {
				'f8d8' => 1,
			},
		},
		'r1br2k1/ppq1ppbp/2n3p1/2p5/2BPP3/2P1B3/P3NPPP/2RQ1RK1 w -' => {
			eco => 'D87k',
			# TRANSLATORS: D87k: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 Qc7 11. Rc1 Rd8
			variation => N__('Grünfeld: Classical Exchange, 10. Be3 Qc7 11. Rc1 Rd8'),
			moves => {
				'd1d2' => 1,
				'e3f4' => 1,
			},
		},
		'r1br2k1/ppq1ppbp/2n3p1/2p5/2BPP3/2P1B3/P2QNPPP/2R2RK1 b -' => {
			eco => 'D87l',
			# TRANSLATORS: D87l: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 Qc7 11. Rc1 Rd8 12. Qd2
			variation => N__('Grünfeld: Classical Exchange, 10. Be3 Qc7 11. Rc1 Rd8 12. Qd2'),
			moves => {
			},
		},
		'r1br2k1/ppq1ppbp/2n3p1/2p5/2BPPB2/2P5/P3NPPP/2RQ1RK1 b -' => {
			eco => 'D87m',
			# TRANSLATORS: D87m: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 Qc7 11. Rc1 Rd8 12. Bf4
			variation => N__('Grünfeld: Classical Exchange, 10. Be3 Qc7 11. Rc1 Rd8 12. Bf4'),
			moves => {
			},
		},
		'r2q1rk1/pp2ppbp/2n3p1/2p5/2BPP1b1/2P1B3/P3NPPP/R2Q1RK1 w -' => {
			eco => 'D87n',
			# TRANSLATORS: D87n: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 Bg4
			variation => N__('Grünfeld: Classical Exchange, 10. Be3 Bg4'),
			moves => {
				'f2f3' => 1,
			},
		},
		'r2q1rk1/pp2ppbp/2n3p1/2p5/2BPP1b1/2P1BP2/P3N1PP/R2Q1RK1 b -' => {
			eco => 'D87n',
			# TRANSLATORS: D87n: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 Bg4 11. f3
			variation => N__('Grünfeld: Classical Exchange, 10. Be3 Bg4'),
			moves => {
				'c6a5' => 1,
			},
		},
		'r2q1rk1/pp2ppbp/6p1/n1p5/2BPP1b1/2P1BP2/P3N1PP/R2Q1RK1 w -' => {
			eco => 'D87n',
			# TRANSLATORS: D87n: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 Bg4 11. f3 Na5
			variation => N__('Grünfeld: Classical Exchange, 10. Be3 Bg4'),
			moves => {
				'c4d5' => 1,
				'c4f7' => 1,
			},
		},
		'r2q1rk1/pp2ppbp/6p1/n1pB4/3PP1b1/2P1BP2/P3N1PP/R2Q1RK1 b -' => {
			eco => 'D87o',
			# TRANSLATORS: D87o: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 Bg4 11. f3 Na5 12. Bd5
			variation => N__('Grünfeld: Classical Exchange, 10. Be3 Bg4 11. f3 Na5 12. Bd5'),
			moves => {
			},
		},
		'r2q1rk1/pp2pBbp/6p1/n1p5/3PP1b1/2P1BP2/P3N1PP/R2Q1RK1 b -' => {
			eco => 'D87p',
			# TRANSLATORS: D87p: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 Bg4 11. f3 Na5 12. Bxf7+
			variation => N__('Grünfeld: Classical Exchange, Seville Variation'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/2n3p1/8/2BpP3/2P1B3/P3NPPP/R2Q1RK1 w -' => {
			eco => 'D88',
			# TRANSLATORS: D88: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 cxd4
			variation => N__('Grünfeld: Classical Exchange, Main Line'),
			moves => {
				'c3d4' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2n3p1/8/2BPP3/4B3/P3NPPP/R2Q1RK1 b -' => {
			eco => 'D88',
			# TRANSLATORS: D88: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 cxd4 11. cxd4
			variation => N__('Grünfeld: Classical Exchange, Main Line, 11.cxd4'),
			moves => {
				'c6a5' => 1,
				'c8g4' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/6p1/n7/2BPP3/4B3/P3NPPP/R2Q1RK1 w -' => {
			eco => 'D88',
			# TRANSLATORS: D88: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 cxd4 11. cxd4 Na5
			variation => N__('Grünfeld: Classical Exchange, Main Line, 11.cxd4 Na5'),
			moves => {
				'c4d3' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/6p1/n7/3PP3/3BB3/P3NPPP/R2Q1RK1 b -' => {
			eco => 'D88',
			# TRANSLATORS: D88: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 cxd4 11. cxd4 Na5 12. Bd3
			variation => N__('Grünfeld: Classical Exchange, Main Line, 11.cxd4 Na5 12. Bd3'),
			moves => {
			},
		},
		'r2q1rk1/pp2ppbp/2n3p1/8/2BPP1b1/4B3/P3NPPP/R2Q1RK1 w -' => {
			eco => 'D88',
			# TRANSLATORS: D88: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 cxd4 11. cxd4 Bg4
			variation => N__('Grünfeld: Classical Exchange, Main Line, 11.cxd4 Bg4'),
			moves => {
				'f2f3' => 1,
			},
		},
		'r2q1rk1/pp2ppbp/2n3p1/8/2BPP1b1/4BP2/P3N1PP/R2Q1RK1 b -' => {
			eco => 'D88',
			# TRANSLATORS: D88: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 cxd4 11. cxd4 Bg4 12. f3
			variation => N__('Grünfeld: Classical Exchange, Main Line, 11.cxd4 Bg4 12. f3'),
			moves => {
				'c6a5' => 1,
			},
		},
		'r2q1rk1/pp2ppbp/6p1/n7/2BPP1b1/4BP2/P3N1PP/R2Q1RK1 w -' => {
			eco => 'D88',
			# TRANSLATORS: D88: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 cxd4 11. cxd4 Bg4 12. f3 Na5
			variation => N__('Grünfeld: Classical Exchange, Main Line, 11.cxd4 Bg4 12. f3 Na5'),
			moves => {
				'c4d3' => 1,
				'c4d5' => 1,
				'c4f7' => 1,
			},
		},
		'r2q1rk1/pp2ppbp/6p1/n2B4/3PP1b1/4BP2/P3N1PP/R2Q1RK1 b -' => {
			eco => 'D88',
			# TRANSLATORS: D88: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 cxd4 11. cxd4 Bg4 12. f3 Na5 13. Bd5
			variation => N__('Grünfeld: Classical Exchange, Main Line, 11.cxd4 Bg4 12. f3 Na5 13. Bd5'),
			moves => {
			},
		},
		'r2q1rk1/pp2pBbp/6p1/n7/3PP1b1/4BP2/P3N1PP/R2Q1RK1 b -' => {
			eco => 'D88',
			# TRANSLATORS: D88: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 cxd4 11. cxd4 Bg4 12. f3 Na5 13. Bxf7+
			variation => N__('Grünfeld: Classical Exchange, Main Line, Neo-Seville'),
			moves => {
			},
		},
		'r2q1rk1/pp2ppbp/6p1/n7/3PP1b1/3BBP2/P3N1PP/R2Q1RK1 b -' => {
			eco => 'D89a',
			# TRANSLATORS: D89a: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 cxd4 11. cxd4 Bg4 12. f3 Na5 13. Bd3
			variation => N__('Grünfeld: Classical Exchange, Main Line, 13. Bd3'),
			moves => {
				'g4e6' => 1,
			},
		},
		'r2q1rk1/pp2ppbp/4b1p1/n7/3PP3/3BBP2/P3N1PP/R2Q1RK1 w -' => {
			eco => 'D89b',
			# TRANSLATORS: D89b: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 cxd4 11. cxd4 Bg4 12. f3 Na5 13. Bd3 Be6
			variation => N__('Grünfeld: Classical Exchange, Main Line, 13. Bd3 Be6'),
			moves => {
				'a1c1' => 1,
				'd4d5' => 1,
			},
		},
		'r2q1rk1/pp2ppbp/4b1p1/n7/3PP3/3BBP2/P3N1PP/2RQ1RK1 b -' => {
			eco => 'D89c',
			# TRANSLATORS: D89c: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 cxd4 11. cxd4 Bg4 12. f3 Na5 13. Bd3 Be6 14. Rc1
			variation => N__('Grünfeld: Classical Exchange, Main Line, 13. Bd3 Be6 14. Rc1'),
			moves => {
				'e6a2' => 1,
			},
		},
		'r2q1rk1/pp2ppbp/6p1/n7/3PP3/3BBP2/b3N1PP/2RQ1RK1 w -' => {
			eco => 'D89c',
			# TRANSLATORS: D89c: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 cxd4 11. cxd4 Bg4 12. f3 Na5 13. Bd3 Be6 14. Rc1 Bxa2
			variation => N__('Grünfeld: Classical Exchange, Main Line, 13. Bd3 Be6 14. Rc1'),
			moves => {
				'd1a4' => 1,
			},
		},
		'r2q1rk1/pp2ppbp/6p1/n7/Q2PP3/3BBP2/b3N1PP/2R2RK1 b -' => {
			eco => 'D89c',
			# TRANSLATORS: D89c: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 cxd4 11. cxd4 Bg4 12. f3 Na5 13. Bd3 Be6 14. Rc1 Bxa2 15. Qa4
			variation => N__('Grünfeld: Classical Exchange, Main Line, 13. Bd3 Be6 14. Rc1'),
			moves => {
				'a2e6' => 1,
			},
		},
		'r2q1rk1/pp2ppbp/4b1p1/n7/Q2PP3/3BBP2/4N1PP/2R2RK1 w -' => {
			eco => 'D89c',
			# TRANSLATORS: D89c: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 cxd4 11. cxd4 Bg4 12. f3 Na5 13. Bd3 Be6 14. Rc1 Bxa2 15. Qa4 Be6
			variation => N__('Grünfeld: Classical Exchange, Main Line, 13. Bd3 Be6 14. Rc1'),
			moves => {
				'd4d5' => 1,
			},
		},
		'r2q1rk1/pp2ppbp/4b1p1/n2P4/Q3P3/3BBP2/4N1PP/2R2RK1 b -' => {
			eco => 'D89c',
			# TRANSLATORS: D89c: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 cxd4 11. cxd4 Bg4 12. f3 Na5 13. Bd3 Be6 14. Rc1 Bxa2 15. Qa4 Be6 16. d5
			variation => N__('Grünfeld: Classical Exchange, Main Line, 13. Bd3 Be6 14. Rc1'),
			moves => {
				'e6d7' => 1,
			},
		},
		'r2q1rk1/pp1bppbp/6p1/n2P4/Q3P3/3BBP2/4N1PP/2R2RK1 w -' => {
			eco => 'D89c',
			# TRANSLATORS: D89c: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 cxd4 11. cxd4 Bg4 12. f3 Na5 13. Bd3 Be6 14. Rc1 Bxa2 15. Qa4 Be6 16. d5 Bd7
			variation => N__('Grünfeld: Classical Exchange, Main Line, 13. Bd3 Be6 14. Rc1'),
			moves => {
				'a4b4' => 1,
			},
		},
		'r2q1rk1/pp1bppbp/6p1/n2P4/1Q2P3/3BBP2/4N1PP/2R2RK1 b -' => {
			eco => 'D89d',
			# TRANSLATORS: D89d: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 cxd4 11. cxd4 Bg4 12. f3 Na5 13. Bd3 Be6 14. Rc1 Bxa2 15. Qa4 Be6 16. d5 Bd7 17. Qb4
			variation => N__('Grünfeld: Classical Exchange, 14. Rc1 Bxa2 15. Qa4 Be6 16. d5 Be7 17. Qb4'),
			moves => {
				'b7b6' => 1,
				'e7e6' => 1,
			},
		},
		'r2q1rk1/p2bppbp/1p4p1/n2P4/1Q2P3/3BBP2/4N1PP/2R2RK1 w -' => {
			eco => 'D89e',
			# TRANSLATORS: D89e: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 cxd4 11. cxd4 Bg4 12. f3 Na5 13. Bd3 Be6 14. Rc1 Bxa2 15. Qa4 Be6 16. d5 Bd7 17. Qb4 b6
			variation => N__('Grünfeld: Classical Exchange, 14. Rc1 Bxa2 15. Qa4 with 17. Qb4 b6'),
			moves => {
			},
		},
		'r2q1rk1/pp1b1pbp/4p1p1/n2P4/1Q2P3/3BBP2/4N1PP/2R2RK1 w -' => {
			eco => 'D89f',
			# TRANSLATORS: D89f: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 cxd4 11. cxd4 Bg4 12. f3 Na5 13. Bd3 Be6 14. Rc1 Bxa2 15. Qa4 Be6 16. d5 Bd7 17. Qb4 e6
			variation => N__('Grünfeld: Classical Exchange, 14. Rc1 Bxa2 15. Qa4 with 17. Qb4 e6'),
			moves => {
			},
		},
		'r2q1rk1/pp2ppbp/4b1p1/n2P4/4P3/3BBP2/P3N1PP/R2Q1RK1 b -' => {
			eco => 'D89g',
			# TRANSLATORS: D89g: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 cxd4 11. cxd4 Bg4 12. f3 Na5 13. Bd3 Be6 14. d5
			variation => N__('Grünfeld: Classical Exchange, Main Line, Sokolsky Variation'),
			moves => {
				'g7a1' => 1,
			},
		},
		'r2q1rk1/pp2pp1p/4b1p1/n2P4/4P3/3BBP2/P3N1PP/b2Q1RK1 w -' => {
			eco => 'D89g',
			# TRANSLATORS: D89g: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 cxd4 11. cxd4 Bg4 12. f3 Na5 13. Bd3 Be6 14. d5 Bxa1
			variation => N__('Grünfeld: Classical Exchange, Main Line, Sokolsky Variation'),
			moves => {
				'd1a1' => 1,
			},
		},
		'r2q1rk1/pp2pp1p/4b1p1/n2P4/4P3/3BBP2/P3N1PP/Q4RK1 b -' => {
			eco => 'D89g',
			# TRANSLATORS: D89g: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 cxd4 11. cxd4 Bg4 12. f3 Na5 13. Bd3 Be6 14. d5 Bxa1 15. Qxa1
			variation => N__('Grünfeld: Classical Exchange, Main Line, Sokolsky Variation'),
			moves => {
				'f7f6' => 1,
			},
		},
		'r2q1rk1/pp2p2p/4bpp1/n2P4/4P3/3BBP2/P3N1PP/Q4RK1 w -' => {
			eco => 'D89g',
			# TRANSLATORS: D89g: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 cxd4 11. cxd4 Bg4 12. f3 Na5 13. Bd3 Be6 14. d5 Bxa1 15. Qxa1 f6
			variation => N__('Grünfeld: Classical Exchange, Main Line, Sokolsky Variation'),
			moves => {
				'e3h6' => 1,
				'f1b1' => 1,
			},
		},
		'r2q1rk1/pp2p2p/4bpp1/n2P4/4P3/3BBP2/P3N1PP/QR4K1 b -' => {
			eco => 'D89h',
			# TRANSLATORS: D89h: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 cxd4 11. cxd4 Bg4 12. f3 Na5 13. Bd3 Be6 14. d5 Bxa1 15. Qxa1 f6 16. Rb1
			variation => N__('Grünfeld: Classical Exchange, Main Line, Sokolsky, 16. Rb1'),
			moves => {
			},
		},
		'r2q1rk1/pp2p2p/4bppB/n2P4/4P3/3B1P2/P3N1PP/Q4RK1 b -' => {
			eco => 'D89i',
			# TRANSLATORS: D89i: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. cxd5 Nxd5 5. e4 Nxc3 6. bxc3 Bg7 7. Bc4 O-O 8. Ne2 c5 9. O-O Nc6 10. Be3 cxd4 11. cxd4 Bg4 12. f3 Na5 13. Bd3 Be6 14. d5 Bxa1 15. Qxa1 f6 16. Bh6
			variation => N__('Grünfeld: Classical Exchange, Main Line, Sokolsky, 16. Bh6'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/5np1/3p4/2PP4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D90',
			# TRANSLATORS: D90: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3
			variation => N__('Grünfeld: Three Knights Variation'),
			moves => {
				'c7c6' => 1,
				'f8g7' => 1,
			},
		},
		'rnbqkb1r/pp2pp1p/2p2np1/3p4/2PP4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D90',
			# TRANSLATORS: D90: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 c6
			variation => N__('Grünfeld: Schlechter Variation'),
			moves => {
				'c4d5' => 1,
				'd1b3' => 1,
			},
		},
		'rnbqkb1r/pp2pp1p/2p2np1/3P4/3P4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D90',
			# TRANSLATORS: D90: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 c6 5. cxd5
			variation => N__('Grünfeld: Schlechter, Exchange'),
			moves => {
				'c6d5' => 1,
			},
		},
		'rnbqkb1r/pp2pp1p/5np1/3p4/3P4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D90',
			# TRANSLATORS: D90: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 c6 5. cxd5 cxd5
			variation => N__('Grünfeld: Schlechter, Exchange'),
			moves => {
			},
		},
		'rnbqkb1r/pp2pp1p/2p2np1/3p4/2PP4/1QN2N2/PP2PPPP/R1B1KB1R b KQkq' => {
			eco => 'D90',
			# TRANSLATORS: D90: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 c6 5. Qb3
			variation => N__('Grünfeld: Schlechter, 5. Qb3'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/3p4/2PP4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D90',
			# TRANSLATORS: D90: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7
			variation => N__('Grünfeld: Three Knights Variation'),
			moves => {
				'c1f4' => 1,
				'c1g5' => 1,
				'c4d5' => 1,
				'd1a4' => 1,
				'd1b3' => 1,
				'e2e3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/3P4/3P4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'D90',
			# TRANSLATORS: D90: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. cxd5
			variation => N__('Grünfeld: Three Knights Exchange'),
			moves => {
				'f6d5' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/6p1/3n4/3P4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'D90',
			# TRANSLATORS: D90: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. cxd5 Nxd5
			variation => N__('Grünfeld: Three Knights Exchange'),
			moves => {
				'c1d2' => 1,
				'd1b3' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/6p1/3n4/3P4/2N2N2/PP1BPPPP/R2QKB1R b KQkq' => {
			eco => 'D90',
			# TRANSLATORS: D90: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. cxd5 Nxd5 6. Bd2
			variation => N__('Grünfeld: Three Knights Exchange, 6. Bd2'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/6p1/3n4/3P4/2N2N2/PP1BPPPP/R2QKB1R w KQ' => {
			eco => 'D90',
			# TRANSLATORS: D90: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. cxd5 Nxd5 6. Bd2 O-O
			variation => N__('Grünfeld: Three Knights Exchange, 6. Bd2 O-O'),
			moves => {
				'a1c1' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/6p1/3n4/3P4/2N2N2/PP1BPPPP/2RQKB1R b K' => {
			eco => 'D90',
			# TRANSLATORS: D90: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. cxd5 Nxd5 6. Bd2 O-O 7. Rc1
			variation => N__('Grünfeld: Three Knights Exchange, 6. Bd2 O-O 7. Rc1'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/6p1/3n4/3P4/1QN2N2/PP2PPPP/R1B1KB1R b KQkq' => {
			eco => 'D90',
			# TRANSLATORS: D90: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. cxd5 Nxd5 6. Qb3
			variation => N__('Grünfeld: Three Knights Exchange, Romanishin Variation'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/3p4/Q1PP4/2N2N2/PP2PPPP/R1B1KB1R b KQkq' => {
			eco => 'D90',
			# TRANSLATORS: D90: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qa4+
			variation => N__('Grünfeld: Flohr Variation'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/3p4/2PP4/2N2NP1/PP2PP1P/R1BQKB1R b KQkq' => {
			eco => 'D90',
			# TRANSLATORS: D90: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. g3
			variation => N__('Grünfeld: Three Knights, 5. g3'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/3p2B1/2PP4/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D91a',
			# TRANSLATORS: D91a: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bg5
			variation => N__('Grünfeld: 5. Bg5'),
			moves => {
				'c7c6' => 1,
				'd5c4' => 1,
				'f6e4' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/2p2np1/3p2B1/2PP4/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'D91a',
			# TRANSLATORS: D91a: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bg5 c6
			variation => N__('Grünfeld: 5. Bg5 c6'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/6B1/2pP4/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'D91b',
			# TRANSLATORS: D91b: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bg5 dxc4
			variation => N__('Grünfeld: 5. Bg5 dxc4'),
			moves => {
				'e2e4' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/6B1/2pPP3/2N2N2/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'D91c',
			# TRANSLATORS: D91c: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bg5 dxc4 6. e4
			variation => N__('Grünfeld: 5. Bg5 dxc4 6. e4'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/6p1/3p2B1/2PPn3/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'D91d',
			# TRANSLATORS: D91d: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bg5 Ne4
			variation => N__('Grünfeld: 5. Bg5 Ne4'),
			moves => {
				'c4d5' => 1,
				'g5f4' => 1,
				'g5h4' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/6p1/3p4/2PPnB2/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D91d',
			# TRANSLATORS: D91d: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bg5 Ne4 6. Bf4
			variation => N__('Grünfeld: 5. Bg5 Ne4 6. Bf4'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/6p1/3p4/2PPn2B/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D91e',
			# TRANSLATORS: D91e: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bg5 Ne4 6. Bh4
			variation => N__('Grünfeld: 5. Bg5 Ne4 6. Bh4'),
			moves => {
				'e4c3' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/6p1/3p4/2PP3B/2n2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'D91f',
			# TRANSLATORS: D91f: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bg5 Ne4 6. Bh4 Nxc3
			variation => N__('Grünfeld: 5. Bg5 Ne4 6. Bh4 Nxc3'),
			moves => {
				'b2c3' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/6p1/3p4/2PP3B/2P2N2/P3PPPP/R2QKB1R b KQkq' => {
			eco => 'D91f',
			# TRANSLATORS: D91f: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bg5 Ne4 6. Bh4 Nxc3 7. bxc3
			variation => N__('Grünfeld: 5. Bg5 Ne4 6. Bh4 Nxc3'),
			moves => {
				'd5c4' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/6p1/8/2pP3B/2P2N2/P3PPPP/R2QKB1R w KQkq' => {
			eco => 'D91g',
			# TRANSLATORS: D91g: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bg5 Ne4 6. Bh4 Nxc3 7. bxc3 dxc4
			variation => N__('Grünfeld: 5. Bg5 Ne4 6. Bh4 Nxc3 7.bxc3 dxc4'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/6p1/3P2B1/3Pn3/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D91h',
			# TRANSLATORS: D91h: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bg5 Ne4 6. cxd5
			variation => N__('Grünfeld: 5. Bg5 Ne4 6.cxd5'),
			moves => {
				'e4g5' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/6p1/3P2n1/3P4/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'D91i',
			# TRANSLATORS: D91i: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bg5 Ne4 6. cxd5 Nxg5
			variation => N__('Grünfeld: 5. Bg5 Ne4 6.cxd5 Nxg5'),
			moves => {
				'f3g5' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/6p1/3P2N1/3P4/2N5/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D91i',
			# TRANSLATORS: D91i: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bg5 Ne4 6. cxd5 Nxg5 7. Nxg5
			variation => N__('Grünfeld: 5. Bg5 Ne4 6.cxd5 Nxg5'),
			moves => {
				'c7c6' => 1,
				'e7e6' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/2p3p1/3P2N1/3P4/2N5/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'D91j',
			# TRANSLATORS: D91j: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bg5 Ne4 6. cxd5 Nxg5 7. Nxg5 c6
			variation => N__('Grünfeld: 5. Bg5 Ne4 6.cxd5 Nxg5 7.Nxg5 c6'),
			moves => {
			},
		},
		'rnbqk2r/ppp2pbp/4p1p1/3P2N1/3P4/2N5/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'D91k',
			# TRANSLATORS: D91k: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bg5 Ne4 6. cxd5 Nxg5 7. Nxg5 e6
			variation => N__('Grünfeld: 5. Bg5 Ne4 6.cxd5 Nxg5 7.Nxg5 e6'),
			moves => {
				'd1d2' => 1,
				'g5f3' => 1,
			},
		},
		'rnbqk2r/ppp2pbp/4p1p1/3P2N1/3P4/2N5/PP1QPPPP/R3KB1R b KQkq' => {
			eco => 'D91l',
			# TRANSLATORS: D91l: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bg5 Ne4 6. cxd5 Nxg5 7. Nxg5 e6 8. Qd2
			variation => N__('Grünfeld: 5. Bg5 Ne4 6.cxd5 Nxg5 7.Nxg5 e6 8. Qd2'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rnbqk2r/ppp2pbp/6p1/3p2N1/3P4/2N5/PP1QPPPP/R3KB1R w KQkq' => {
			eco => 'D91m',
			# TRANSLATORS: D91m: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bg5 Ne4 6. cxd5 Nxg5 7. Nxg5 e6 8. Qd2 exd5
			variation => N__('Grünfeld: 5. Bg5 Ne4 6.cxd5 Nxg5 7.Nxg5 e6 8. Qd2 exd5'),
			moves => {
				'd2e3' => 1,
			},
		},
		'rnbqk2r/ppp2pbp/6p1/3p2N1/3P4/2N1Q3/PP2PPPP/R3KB1R b KQkq' => {
			eco => 'D91m',
			# TRANSLATORS: D91m: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bg5 Ne4 6. cxd5 Nxg5 7. Nxg5 e6 8. Qd2 exd5 9. Qe3+
			variation => N__('Grünfeld: 5. Bg5 Ne4 6.cxd5 Nxg5 7.Nxg5 e6 8. Qd2 exd5'),
			moves => {
				'e8f8' => 1,
			},
		},
		'rnbq1k1r/ppp2pbp/6p1/3p2N1/3P4/2N1Q3/PP2PPPP/R3KB1R w KQ' => {
			eco => 'D91m',
			# TRANSLATORS: D91m: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bg5 Ne4 6. cxd5 Nxg5 7. Nxg5 e6 8. Qd2 exd5 9. Qe3+ Kf8
			variation => N__('Grünfeld: 5. Bg5 Ne4 6.cxd5 Nxg5 7.Nxg5 e6 8. Qd2 exd5'),
			moves => {
				'e3f4' => 1,
			},
		},
		'rnbq1k1r/ppp2pbp/6p1/3p2N1/3P1Q2/2N5/PP2PPPP/R3KB1R b KQ' => {
			eco => 'D91m',
			# TRANSLATORS: D91m: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bg5 Ne4 6. cxd5 Nxg5 7. Nxg5 e6 8. Qd2 exd5 9. Qe3+ Kf8 10. Qf4
			variation => N__('Grünfeld: 5. Bg5 Ne4 6.cxd5 Nxg5 7.Nxg5 e6 8. Qd2 exd5'),
			moves => {
				'g7f6' => 1,
			},
		},
		'rnbq1k1r/ppp2p1p/5bp1/3p2N1/3P1Q2/2N5/PP2PPPP/R3KB1R w KQ' => {
			eco => 'D91m',
			# TRANSLATORS: D91m: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bg5 Ne4 6. cxd5 Nxg5 7. Nxg5 e6 8. Qd2 exd5 9. Qe3+ Kf8 10. Qf4 Bf6
			variation => N__('Grünfeld: 5. Bg5 Ne4 6.cxd5 Nxg5 7.Nxg5 e6 8. Qd2 exd5'),
			moves => {
				'h2h4' => 1,
			},
		},
		'rnbq1k1r/ppp2p1p/5bp1/3p2N1/3P1Q1P/2N5/PP2PPP1/R3KB1R b KQ' => {
			eco => 'D91m',
			# TRANSLATORS: D91m: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bg5 Ne4 6. cxd5 Nxg5 7. Nxg5 e6 8. Qd2 exd5 9. Qe3+ Kf8 10. Qf4 Bf6 11. h4
			variation => N__('Grünfeld: 5. Bg5 Ne4 6.cxd5 Nxg5 7.Nxg5 e6 8. Qd2 exd5'),
			moves => {
				'h7h6' => 1,
			},
		},
		'rnbq1k1r/ppp2p2/5bpp/3p2N1/3P1Q1P/2N5/PP2PPP1/R3KB1R w KQ' => {
			eco => 'D91n',
			# TRANSLATORS: D91n: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bg5 Ne4 6. cxd5 Nxg5 7. Nxg5 e6 8. Qd2 exd5 9. Qe3+ Kf8 10. Qf4 Bf6 11. h4 h6
			variation => N__('Grünfeld: 5. Bg5 Ne4 6.cxd5 Nxg5 7.Nxg5 e6 8. Qd2 exd5: 11. h4 h6'),
			moves => {
			},
		},
		'rnbqk2r/ppp2pbp/4p1p1/3P4/3P4/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D91o',
			# TRANSLATORS: D91o: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bg5 Ne4 6. cxd5 Nxg5 7. Nxg5 e6 8. Nf3
			variation => N__('Grünfeld: 5. Bg5 Ne4 6.cxd5 Nxg5 7.Nxg5 e6 8. Nf3'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rnbqk2r/ppp2pbp/6p1/3p4/3P4/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'D91o',
			# TRANSLATORS: D91o: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bg5 Ne4 6. cxd5 Nxg5 7. Nxg5 e6 8. Nf3 exd5
			variation => N__('Grünfeld: 5. Bg5 Ne4 6.cxd5 Nxg5 7.Nxg5 e6 8. Nf3'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbqk2r/ppp2pbp/6p1/3p4/3P4/2N1PN2/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'D91p',
			# TRANSLATORS: D91p: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bg5 Ne4 6. cxd5 Nxg5 7. Nxg5 e6 8. Nf3 exd5 9. e3
			variation => N__('Grünfeld: 5. Bg5 Ne4 6.cxd5 Nxg5 7.Nxg5 e6 8. Nf3 exd5 9. e3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppp2pbp/6p1/3p4/3P4/2N1PN2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'D91q',
			# TRANSLATORS: D91q: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bg5 Ne4 6. cxd5 Nxg5 7. Nxg5 e6 8. Nf3 exd5 9. e3 O-O
			variation => N__('Grünfeld: 5. Bg5 Ne4 6.cxd5 Nxg5 7.Nxg5 e6 8. Nf3 exd5 9. e3 O-O'),
			moves => {
				'b2b4' => 1,
				'f1d3' => 1,
				'f1e2' => 1,
			},
		},
		'rnbq1rk1/ppp2pbp/6p1/3p4/3P4/2NBPN2/PP3PPP/R2QK2R b KQ' => {
			eco => 'D91r',
			# TRANSLATORS: D91r: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bg5 Ne4 6. cxd5 Nxg5 7. Nxg5 e6 8. Nf3 exd5 9. e3 O-O 10. Bd3
			variation => N__('Grünfeld: 5. Bg5 Ne4 6.cxd5 Nxg5 7.Nxg5 e6 8. Nf3 exd5 9. e3 O-O 10. Bd3'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/2p3p1/3p4/3P4/2NBPN2/PP3PPP/R2QK2R w KQ' => {
			eco => 'D91r',
			# TRANSLATORS: D91r: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bg5 Ne4 6. cxd5 Nxg5 7. Nxg5 e6 8. Nf3 exd5 9. e3 O-O 10. Bd3 c6
			variation => N__('Grünfeld: 5. Bg5 Ne4 6.cxd5 Nxg5 7.Nxg5 e6 8. Nf3 exd5 9. e3 O-O 10. Bd3'),
			moves => {
			},
		},
		'rnbq1rk1/ppp2pbp/6p1/3p4/3P4/2N1PN2/PP2BPPP/R2QK2R b KQ' => {
			eco => 'D91s',
			# TRANSLATORS: D91s: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bg5 Ne4 6. cxd5 Nxg5 7. Nxg5 e6 8. Nf3 exd5 9. e3 O-O 10. Be2
			variation => N__('Grünfeld: 5. Bg5 Ne4 6.cxd5 Nxg5 7.Nxg5 e6 8. Nf3 exd5 9. e3 O-O 10. Be2'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/2p3p1/3p4/3P4/2N1PN2/PP2BPPP/R2QK2R w KQ' => {
			eco => 'D91s',
			# TRANSLATORS: D91s: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bg5 Ne4 6. cxd5 Nxg5 7. Nxg5 e6 8. Nf3 exd5 9. e3 O-O 10. Be2 c6
			variation => N__('Grünfeld: 5. Bg5 Ne4 6.cxd5 Nxg5 7.Nxg5 e6 8. Nf3 exd5 9. e3 O-O 10. Be2'),
			moves => {
			},
		},
		'rnbq1rk1/ppp2pbp/6p1/3p4/1P1P4/2N1PN2/P4PPP/R2QKB1R b KQ' => {
			eco => 'D91t',
			# TRANSLATORS: D91t: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bg5 Ne4 6. cxd5 Nxg5 7. Nxg5 e6 8. Nf3 exd5 9. e3 O-O 10. b4
			variation => N__('Grünfeld: 5. Bg5 Ne4 6.cxd5 Nxg5 7.Nxg5 e6 8. Nf3 exd5 9. e3 O-O 10. b4'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/2p3p1/3p4/1P1P4/2N1PN2/P4PPP/R2QKB1R w KQ' => {
			eco => 'D91t',
			# TRANSLATORS: D91t: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bg5 Ne4 6. cxd5 Nxg5 7. Nxg5 e6 8. Nf3 exd5 9. e3 O-O 10. b4 c6
			variation => N__('Grünfeld: 5. Bg5 Ne4 6.cxd5 Nxg5 7.Nxg5 e6 8. Nf3 exd5 9. e3 O-O 10. b4 c6'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/3p4/2PP1B2/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'D92',
			# TRANSLATORS: D92: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bf4
			variation => N__('Grünfeld: 5. Bf4'),
			moves => {
				'c7c6' => 1,
				'e8g8' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/2p2np1/3p4/2PP1B2/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'D92',
			# TRANSLATORS: D92: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bf4 c6
			variation => N__('Grünfeld: 5. Bf4 c6'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/3p4/2PP1B2/2N2N2/PP2PPPP/R2QKB1R w KQ' => {
			eco => 'D92',
			# TRANSLATORS: D92: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bf4 O-O
			variation => N__('Grünfeld: 5. Bf4 O-O'),
			moves => {
				'a1c1' => 1,
				'e2e3' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/3p4/2PP1B2/2N2N2/PP2PPPP/2RQKB1R b K' => {
			eco => 'D92',
			# TRANSLATORS: D92: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bf4 O-O 6. Rc1
			variation => N__('Grünfeld: 5. Bf4 O-O 6. Rc1'),
			moves => {
				'c7c5' => 1,
				'd5c4' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/5np1/2pp4/2PP1B2/2N2N2/PP2PPPP/2RQKB1R w K' => {
			eco => 'D92',
			# TRANSLATORS: D92: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bf4 O-O 6. Rc1 c5
			variation => N__('Grünfeld: 5. Bf4 O-O 6. Rc1 c5'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/8/2pP1B2/2N2N2/PP2PPPP/2RQKB1R w K' => {
			eco => 'D92',
			# TRANSLATORS: D92: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bf4 O-O 6. Rc1 dxc4
			variation => N__('Grünfeld: 5. Bf4 O-O 6. Rc1 dxc4'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/3p4/2PP1B2/2N1PN2/PP3PPP/R2QKB1R b KQ' => {
			eco => 'D93',
			# TRANSLATORS: D93: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bf4 O-O 6. e3
			variation => N__('Grünfeld: 5. Bf4 O-O 6. e3'),
			moves => {
				'c7c5' => 1,
				'c7c6' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/5np1/2pp4/2PP1B2/2N1PN2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'D93',
			# TRANSLATORS: D93: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bf4 O-O 6. e3 c5
			variation => N__('Grünfeld: 5. Bf4 O-O 6. e3 c5'),
			moves => {
				'd4c5' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/5np1/2Pp4/2P2B2/2N1PN2/PP3PPP/R2QKB1R b KQ' => {
			eco => 'D93',
			# TRANSLATORS: D93: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bf4 O-O 6. e3 c5 7. dxc5
			variation => N__('Grünfeld: 5. Bf4 O-O 6. e3 c5 7.dxc5'),
			moves => {
				'd8a5' => 1,
			},
		},
		'rnb2rk1/pp2ppbp/5np1/q1Pp4/2P2B2/2N1PN2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'D93',
			# TRANSLATORS: D93: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bf4 O-O 6. e3 c5 7. dxc5 Qa5
			variation => N__('Grünfeld: 5. Bf4 O-O 6. e3 c5 7.dxc5 Qa5'),
			moves => {
				'a1c1' => 1,
			},
		},
		'rnb2rk1/pp2ppbp/5np1/q1Pp4/2P2B2/2N1PN2/PP3PPP/2RQKB1R b K' => {
			eco => 'D93',
			# TRANSLATORS: D93: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bf4 O-O 6. e3 c5 7. dxc5 Qa5 8. Rc1
			variation => N__('Grünfeld: 5. Bf4 O-O 6. e3 c5 7.dxc5 Qa5 8. Rc1'),
			moves => {
				'd5c4' => 1,
			},
		},
		'rnb2rk1/pp2ppbp/5np1/q1P5/2p2B2/2N1PN2/PP3PPP/2RQKB1R w K' => {
			eco => 'D93',
			# TRANSLATORS: D93: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bf4 O-O 6. e3 c5 7. dxc5 Qa5 8. Rc1 dxc4
			variation => N__('Grünfeld: 5. Bf4 O-O 6. e3 c5 7.dxc5 Qa5 8. Rc1'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnb2rk1/pp2ppbp/5np1/q1P5/2B2B2/2N1PN2/PP3PPP/2RQK2R b K' => {
			eco => 'D93',
			# TRANSLATORS: D93: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bf4 O-O 6. e3 c5 7. dxc5 Qa5 8. Rc1 dxc4 9. Bxc4
			variation => N__('Grünfeld: 5. Bf4 O-O 6. e3 c5 7.dxc5 Qa5 8. Rc1 dxc4 9.Bxc4'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/2p2np1/3p4/2PP1B2/2N1PN2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'D93',
			# TRANSLATORS: D93: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bf4 O-O 6. e3 c6
			variation => N__('Grünfeld: 5. Bf4 O-O 6. e3 c6'),
			moves => {
				'a1c1' => 1,
				'd1b3' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/2p2np1/3p4/2PP1B2/2N1PN2/PP3PPP/2RQKB1R b K' => {
			eco => 'D93',
			# TRANSLATORS: D93: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bf4 O-O 6. e3 c6 7. Rc1
			variation => N__('Grünfeld: 5. Bf4 O-O 6. e3 c6 7. Rc1'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/2p2np1/3p4/2PP1B2/1QN1PN2/PP3PPP/R3KB1R b KQ' => {
			eco => 'D93',
			# TRANSLATORS: D93: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Bf4 O-O 6. e3 c6 7. Qb3
			variation => N__('Grünfeld: 5. Bf4 O-O 6. e3 c6 7. Qb3'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/3p4/2PP4/2N1PN2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'D94',
			# TRANSLATORS: D94: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. e3
			variation => N__('Grünfeld: 5. e3'),
			moves => {
				'c7c6' => 1,
				'e8g8' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/2p2np1/3p4/2PP4/2N1PN2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'D94',
			# TRANSLATORS: D94: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. e3 c6
			variation => N__('Grünfeld: Slav/Schlecter'),
			moves => {
				'f1d3' => 1,
				'f1e2' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/2p2np1/3p4/2PP4/2NBPN2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'D94',
			# TRANSLATORS: D94: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. e3 c6 6. Bd3
			variation => N__('Grünfeld: Slav/Schlecter, 6. Bd3'),
			moves => {
			},
		},
		'rnbqk2r/pp2ppbp/2p2np1/3p4/2PP4/2N1PN2/PP2BPPP/R1BQK2R b KQkq' => {
			eco => 'D94',
			# TRANSLATORS: D94: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. e3 c6 6. Be2
			variation => N__('Grünfeld: Slav/Schlecter, 6. Be2'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/2p2np1/3p4/2PP4/2N1PN2/PP2BPPP/R1BQK2R w KQ' => {
			eco => 'D94',
			# TRANSLATORS: D94: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. e3 c6 6. Be2 O-O
			variation => N__('Grünfeld: Slav/Schlecter, 6. Be2 O-O'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/2p2np1/3p4/2PP4/2N1PN2/PP2BPPP/R1BQ1RK1 b -' => {
			eco => 'D94',
			# TRANSLATORS: D94: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. e3 c6 6. Be2 O-O 7. O-O
			variation => N__('Grünfeld: Slav/Schlecter, 6. Be2 O-O 7.O-O'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/3p4/2PP4/2N1PN2/PP3PPP/R1BQKB1R w KQ' => {
			eco => 'D94',
			# TRANSLATORS: D94: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. e3 O-O
			variation => N__('Grünfeld: 5. e3 O-O'),
			moves => {
				'b2b4' => 1,
				'c1d2' => 1,
				'c4d5' => 1,
				'd1b3' => 1,
				'f1d3' => 1,
				'f1e2' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/3p4/1PPP4/2N1PN2/P4PPP/R1BQKB1R b KQ' => {
			eco => 'D94',
			# TRANSLATORS: D94: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. e3 O-O 6. b4
			variation => N__('Grünfeld: Makogonov Variation'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/3p4/2PP4/2N1PN2/PP1B1PPP/R2QKB1R b KQ' => {
			eco => 'D94',
			# TRANSLATORS: D94: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. e3 O-O 6. Bd2
			variation => N__('Grünfeld: Opovcensky Variation'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/3P4/3P4/2N1PN2/PP3PPP/R1BQKB1R b KQ' => {
			eco => 'D94',
			# TRANSLATORS: D94: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. e3 O-O 6. cxd5
			variation => N__('Grünfeld: 5. e3 O-O 6.cxd5'),
			moves => {
				'f6d5' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/6p1/3n4/3P4/2N1PN2/PP3PPP/R1BQKB1R w KQ' => {
			eco => 'D94',
			# TRANSLATORS: D94: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. e3 O-O 6. cxd5 Nxd5
			variation => N__('Grünfeld: 5. e3 O-O 6.cxd5'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/6p1/3n4/2BP4/2N1PN2/PP3PPP/R1BQK2R b KQ' => {
			eco => 'D94',
			# TRANSLATORS: D94: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. e3 O-O 6. cxd5 Nxd5 7. Bc4
			variation => N__('Grünfeld: 5. e3 O-O 6.cxd5 Nxd5 7. Bc4'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/3p4/2PP4/2NBPN2/PP3PPP/R1BQK2R b KQ' => {
			eco => 'D94',
			# TRANSLATORS: D94: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. e3 O-O 6. Bd3
			variation => N__('Grünfeld: 5. e3 O-O 6. Bd3'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/2p2np1/3p4/2PP4/2NBPN2/PP3PPP/R1BQK2R w KQ' => {
			eco => 'D94',
			# TRANSLATORS: D94: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. e3 O-O 6. Bd3 c6
			variation => N__('Grünfeld: 5. e3 O-O 6. Bd3 c6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/2p2np1/3p4/2PP4/2NBPN2/PP3PPP/R1BQ1RK1 b -' => {
			eco => 'D94',
			# TRANSLATORS: D94: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. e3 O-O 6. Bd3 c6 7. O-O
			variation => N__('Grünfeld: 5. e3 O-O 6. Bd3 c6'),
			moves => {
				'c8f5' => 1,
				'c8g4' => 1,
			},
		},
		'rn1q1rk1/pp2ppbp/2p2np1/3p1b2/2PP4/2NBPN2/PP3PPP/R1BQ1RK1 w -' => {
			eco => 'D94',
			# TRANSLATORS: D94: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. e3 O-O 6. Bd3 c6 7. O-O Bf5
			variation => N__('Grünfeld: Flohr Defence'),
			moves => {
			},
		},
		'rn1q1rk1/pp2ppbp/2p2np1/3p4/2PP2b1/2NBPN2/PP3PPP/R1BQ1RK1 w -' => {
			eco => 'D94',
			# TRANSLATORS: D94: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. e3 O-O 6. Bd3 c6 7. O-O Bg4
			variation => N__('Grünfeld: Smyslov Defence'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/3p4/2PP4/2N1PN2/PP2BPPP/R1BQK2R b KQ' => {
			eco => 'D94',
			# TRANSLATORS: D94: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. e3 O-O 6. Be2
			variation => N__('Grünfeld: 5. e3 O-O 6. Be2'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/5np1/2pp4/2PP4/2N1PN2/PP2BPPP/R1BQK2R w KQ' => {
			eco => 'D94',
			# TRANSLATORS: D94: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. e3 O-O 6. Be2 c5
			variation => N__('Grünfeld: 5. e3 O-O 6. Be2 c5'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/3p4/2PP4/1QN1PN2/PP3PPP/R1B1KB1R b KQ' => {
			eco => 'D95a',
			# TRANSLATORS: D95a: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. e3 O-O 6. Qb3
			variation => N__('Grünfeld: 5. e3 O-O 6. Qb3'),
			moves => {
				'b7b6' => 1,
				'c7c6' => 1,
				'd5c4' => 1,
				'e7e6' => 1,
			},
		},
		'rnbq1rk1/p1p1ppbp/1p3np1/3p4/2PP4/1QN1PN2/PP3PPP/R1B1KB1R w KQ' => {
			eco => 'D95b',
			# TRANSLATORS: D95b: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. e3 O-O 6. Qb3 b6
			variation => N__('Grünfeld: 5. e3 O-O 6. Qb3 b6'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/2p2np1/3p4/2PP4/1QN1PN2/PP3PPP/R1B1KB1R w KQ' => {
			eco => 'D95c',
			# TRANSLATORS: D95c: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. e3 O-O 6. Qb3 c6
			variation => N__('Grünfeld: 5. e3 O-O 6. Qb3 c6'),
			moves => {
				'c1d2' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/2p2np1/3p4/2PP4/1QN1PN2/PP1B1PPP/R3KB1R b KQ' => {
			eco => 'D95d',
			# TRANSLATORS: D95d: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. e3 O-O 6. Qb3 c6 7. Bd2
			variation => N__('Grünfeld: 5. e3 O-O 6. Qb3 c6 7. Bd2'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/2p1pnp1/3p4/2PP4/1QN1PN2/PP1B1PPP/R3KB1R w KQ' => {
			eco => 'D95e',
			# TRANSLATORS: D95e: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. e3 O-O 6. Qb3 c6 7. Bd2 e6
			variation => N__('Grünfeld: 5. e3 O-O 6. Qb3 c6 7. Bd2 e6'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/2p1pnp1/3p4/2PP4/1QNBPN2/PP1B1PPP/R3K2R b KQ' => {
			eco => 'D95f',
			# TRANSLATORS: D95f: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. e3 O-O 6. Qb3 c6 7. Bd2 e6 8. Bd3
			variation => N__('Grünfeld: 5. e3 O-O 6. Qb3 c6 7. Bd2 e6 8. Bd3'),
			moves => {
			},
		},
		'rnbq1rk1/ppp2pbp/4pnp1/3p4/2PP4/1QN1PN2/PP3PPP/R1B1KB1R w KQ' => {
			eco => 'D95g',
			# TRANSLATORS: D95g: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. e3 O-O 6. Qb3 e6
			variation => N__('Grünfeld: Botvinnik Variation'),
			moves => {
				'c1d2' => 1,
			},
		},
		'rnbq1rk1/ppp2pbp/4pnp1/3p4/2PP4/1QN1PN2/PP1B1PPP/R3KB1R b KQ' => {
			eco => 'D95h',
			# TRANSLATORS: D95h: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. e3 O-O 6. Qb3 e6 7. Bd2
			variation => N__('Grünfeld: Botvinnik, 7. Bd2'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/8/2pP4/1QN1PN2/PP3PPP/R1B1KB1R w KQ' => {
			eco => 'D95i',
			# TRANSLATORS: D95i: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. e3 O-O 6. Qb3 dxc4
			variation => N__('Grünfeld: 5. e3 O-O 6. Qb3 dxc4'),
			moves => {
				'f1c4' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/8/2BP4/1QN1PN2/PP3PPP/R1B1K2R b KQ' => {
			eco => 'D95i',
			# TRANSLATORS: D95i: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. e3 O-O 6. Qb3 dxc4 7. Bxc4
			variation => N__('Grünfeld: 5. e3 O-O 6. Qb3 dxc4 7.Bxc4'),
			moves => {
				'b8c6' => 1,
				'b8d7' => 1,
			},
		},
		'r1bq1rk1/pppnppbp/5np1/8/2BP4/1QN1PN2/PP3PPP/R1B1K2R w KQ' => {
			eco => 'D95i',
			# TRANSLATORS: D95i: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. e3 O-O 6. Qb3 dxc4 7. Bxc4 Nbd7
			variation => N__('Grünfeld: 5. e3 O-O 6. Qb3 dxc4 7.Bxc4'),
			moves => {
				'f3g5' => 1,
			},
		},
		'r1bq1rk1/pppnppbp/5np1/6N1/2BP4/1QN1P3/PP3PPP/R1B1K2R b KQ' => {
			eco => 'D95i',
			# TRANSLATORS: D95i: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. e3 O-O 6. Qb3 dxc4 7. Bxc4 Nbd7 8. Ng5
			variation => N__('Grünfeld: Pachman Variation'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1ppbp/2n2np1/8/2BP4/1QN1PN2/PP3PPP/R1B1K2R w KQ' => {
			eco => 'D95j',
			# TRANSLATORS: D95j: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. e3 O-O 6. Qb3 dxc4 7. Bxc4 Nc6
			variation => N__('Grünfeld: 5. e3 O-O 6. Qb3 dxc4 7.Bxc4 Nc6'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/3p4/2PP4/1QN2N2/PP2PPPP/R1B1KB1R b KQkq' => {
			eco => 'D96',
			# TRANSLATORS: D96: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3
			variation => N__('Grünfeld: Russian Variation'),
			moves => {
				'c7c6' => 1,
				'd5c4' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/2p2np1/3p4/2PP4/1QN2N2/PP2PPPP/R1B1KB1R w KQkq' => {
			eco => 'D96',
			# TRANSLATORS: D96: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 c6
			variation => N__('Grünfeld: Russian, 5... c6'),
			moves => {
				'c1f4' => 1,
				'c4d5' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/2p2np1/3p4/2PP1B2/1QN2N2/PP2PPPP/R3KB1R b KQkq' => {
			eco => 'D96',
			# TRANSLATORS: D96: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 c6 6. Bf4
			variation => N__('Grünfeld: Russian, 5... c6 6. Bf4'),
			moves => {
			},
		},
		'rnbqk2r/pp2ppbp/2p2np1/3P4/3P4/1QN2N2/PP2PPPP/R1B1KB1R b KQkq' => {
			eco => 'D96',
			# TRANSLATORS: D96: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 c6 6. cxd5
			variation => N__('Grünfeld: Russian, 5... c6'),
			moves => {
				'c6d5' => 1,
				'f6d5' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/5np1/3p4/3P4/1QN2N2/PP2PPPP/R1B1KB1R w KQkq' => {
			eco => 'D96',
			# TRANSLATORS: D96: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 c6 6. cxd5 cxd5
			variation => N__('Grünfeld: Russian, 5... c6 6.cxd5 cxd5'),
			moves => {
			},
		},
		'rnbqk2r/pp2ppbp/2p3p1/3n4/3P4/1QN2N2/PP2PPPP/R1B1KB1R w KQkq' => {
			eco => 'D96',
			# TRANSLATORS: D96: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 c6 6. cxd5 Nxd5
			variation => N__('Grünfeld: Russian, 5... c6 6.cxd5 Nxd5'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/8/2pP4/1QN2N2/PP2PPPP/R1B1KB1R w KQkq' => {
			eco => 'D96',
			# TRANSLATORS: D96: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4
			variation => N__('Grünfeld: Russian, 5...dxc4'),
			moves => {
				'b3c4' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/5np1/8/2QP4/2N2N2/PP2PPPP/R1B1KB1R b KQkq' => {
			eco => 'D96',
			# TRANSLATORS: D96: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4
			variation => N__('Grünfeld: Russian, 5...dxc4'),
			moves => {
				'a7a6' => 1,
				'e8g8' => 1,
			},
		},
		'rnbqk2r/1pp1ppbp/p4np1/8/2QP4/2N2N2/PP2PPPP/R1B1KB1R w KQkq' => {
			eco => 'D96',
			# TRANSLATORS: D96: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 a6
			variation => N__('Grünfeld: Russian, 6... a6'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/8/2QP4/2N2N2/PP2PPPP/R1B1KB1R w KQ' => {
			eco => 'D96',
			# TRANSLATORS: D96: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O
			variation => N__('Grünfeld: Russian, 6...O-O'),
			moves => {
				'c1f4' => 1,
				'e2e4' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/8/2QP1B2/2N2N2/PP2PPPP/R3KB1R b KQ' => {
			eco => 'D96',
			# TRANSLATORS: D96: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. Bf4
			variation => N__('Grünfeld: Russian, 7. Bf4'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/2p2np1/8/2QP1B2/2N2N2/PP2PPPP/R3KB1R w KQ' => {
			eco => 'D96',
			# TRANSLATORS: D96: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. Bf4 c6
			variation => N__('Grünfeld: Russian, 7. Bf4 c6'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/5np1/8/2QPP3/2N2N2/PP3PPP/R1B1KB1R b KQ' => {
			eco => 'D97a',
			# TRANSLATORS: D97a: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4
			variation => N__('Grünfeld: Russian, 7. e4'),
			moves => {
				'a7a6' => 1,
				'b7b6' => 1,
				'b8a6' => 1,
				'b8c6' => 1,
				'c7c6' => 1,
				'c8g4' => 1,
				'f6d7' => 1,
			},
		},
		'rnbq1rk1/pppnppbp/6p1/8/2QPP3/2N2N2/PP3PPP/R1B1KB1R w KQ' => {
			eco => 'D97a',
			# TRANSLATORS: D97a: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 Nfd7
			variation => N__('Grünfeld: Russian, 7. e4 Nfd7'),
			moves => {
			},
		},
		'rnbq1rk1/p1p1ppbp/1p3np1/8/2QPP3/2N2N2/PP3PPP/R1B1KB1R w KQ' => {
			eco => 'D97b',
			# TRANSLATORS: D97b: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 b6
			variation => N__('Grünfeld: Russian, Levenfish Variation'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/2p2np1/8/2QPP3/2N2N2/PP3PPP/R1B1KB1R w KQ' => {
			eco => 'D97c',
			# TRANSLATORS: D97c: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 c6
			variation => N__('Grünfeld: Russian, Szabo Variation'),
			moves => {
				'f1e2' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/2p2np1/8/2QPP3/2N2N2/PP2BPPP/R1B1K2R b KQ' => {
			eco => 'D97c',
			# TRANSLATORS: D97c: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 c6 8. Be2
			variation => N__('Grünfeld: Russian, Szabo, 8. Be2'),
			moves => {
			},
		},
		'rnbq1rk1/1pp1ppbp/p4np1/8/2QPP3/2N2N2/PP3PPP/R1B1KB1R w KQ' => {
			eco => 'D97d',
			# TRANSLATORS: D97d: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 a6
			variation => N__('Grünfeld: Russian, Alekhine (Hungarian) Variation'),
			moves => {
				'c4b3' => 1,
				'e4e5' => 1,
				'f1e2' => 1,
			},
		},
		'rnbq1rk1/1pp1ppbp/p4np1/8/2QPP3/2N2N2/PP2BPPP/R1B1K2R b KQ' => {
			eco => 'D97e',
			# TRANSLATORS: D97e: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 a6 8. Be2
			variation => N__('Grünfeld: Russian, Alekhine, 8. Be2'),
			moves => {
				'b7b5' => 1,
			},
		},
		'rnbq1rk1/2p1ppbp/p4np1/1p6/2QPP3/2N2N2/PP2BPPP/R1B1K2R w KQ' => {
			eco => 'D97e',
			# TRANSLATORS: D97e: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 a6 8. Be2 b5
			variation => N__('Grünfeld: Russian, Alekhine, 8. Be2'),
			moves => {
				'c4b3' => 1,
			},
		},
		'rnbq1rk1/2p1ppbp/p4np1/1p6/3PP3/1QN2N2/PP2BPPP/R1B1K2R b KQ' => {
			eco => 'D97f',
			# TRANSLATORS: D97f: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 a6 8. Be2 b5 9. Qb3
			variation => N__('Grünfeld: Russian, Alekhine, 8. Be2 b5 9. Qb3'),
			moves => {
			},
		},
		'rnbq1rk1/1pp1ppbp/p4np1/8/3PP3/1QN2N2/PP3PPP/R1B1KB1R b KQ' => {
			eco => 'D97g',
			# TRANSLATORS: D97g: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 a6 8. Qb3
			variation => N__('Grünfeld: Russian, Alekhine, 8. Qb3'),
			moves => {
			},
		},
		'rnbq1rk1/1pp1ppbp/p4np1/4P3/2QP4/2N2N2/PP3PPP/R1B1KB1R b KQ' => {
			eco => 'D97h',
			# TRANSLATORS: D97h: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 a6 8. e5
			variation => N__('Grünfeld: Russian, Alekhine, 8. e5'),
			moves => {
				'b7b5' => 1,
			},
		},
		'rnbq1rk1/2p1ppbp/p4np1/1p2P3/2QP4/2N2N2/PP3PPP/R1B1KB1R w KQ' => {
			eco => 'D97h',
			# TRANSLATORS: D97h: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 a6 8. e5 b5
			variation => N__('Grünfeld: Russian, Alekhine, 8. e5'),
			moves => {
				'c4b3' => 1,
			},
		},
		'rnbq1rk1/2p1ppbp/p4np1/1p2P3/3P4/1QN2N2/PP3PPP/R1B1KB1R b KQ' => {
			eco => 'D97i',
			# TRANSLATORS: D97i: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 a6 8. e5 b5 9. Qb3
			variation => N__('Grünfeld: Russian, Alekhine, 8. e5 b5 9. Qb3'),
			moves => {
				'f6d7' => 1,
			},
		},
		'rnbq1rk1/2pnppbp/p5p1/1p2P3/3P4/1QN2N2/PP3PPP/R1B1KB1R w KQ' => {
			eco => 'D97j',
			# TRANSLATORS: D97j: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 a6 8. e5 b5 9. Qb3 Nfd7
			variation => N__('Grünfeld: Russian, Alekhine, 8. e5 b5 9. Qb3 Nfd7'),
			moves => {
				'c1e3' => 1,
			},
		},
		'rnbq1rk1/2pnppbp/p5p1/1p2P3/3P4/1QN1BN2/PP3PPP/R3KB1R b KQ' => {
			eco => 'D97k',
			# TRANSLATORS: D97k: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 a6 8. e5 b5 9. Qb3 Nfd7 10. Be3
			variation => N__('Grünfeld: Russian, Alekhine, 8. e5 b5 9. Qb3 Nfd7 10. Be3'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1ppbp/2n2np1/8/2QPP3/2N2N2/PP3PPP/R1B1KB1R w KQ' => {
			eco => 'D97l',
			# TRANSLATORS: D97l: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 Nc6
			variation => N__('Grünfeld: Russian, Simagin Variation'),
			moves => {
				'f1e2' => 1,
			},
		},
		'r1bq1rk1/ppp1ppbp/2n2np1/8/2QPP3/2N2N2/PP2BPPP/R1B1K2R b KQ' => {
			eco => 'D97l',
			# TRANSLATORS: D97l: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 Nc6 8. Be2
			variation => N__('Grünfeld: Russian, Simagin, 8. Be2'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1ppbp/n4np1/8/2QPP3/2N2N2/PP3PPP/R1B1KB1R w KQ' => {
			eco => 'D97m',
			# TRANSLATORS: D97m: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 Na6
			variation => N__('Grünfeld: Russian, Prins Variation'),
			moves => {
				'c1f4' => 1,
				'f1e2' => 1,
			},
		},
		'r1bq1rk1/ppp1ppbp/n4np1/8/2QPPB2/2N2N2/PP3PPP/R3KB1R b KQ' => {
			eco => 'D97n',
			# TRANSLATORS: D97n: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 Na6 8. Bf4
			variation => N__('Grünfeld: Russian, Prins, 8. Bf4'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1ppbp/n4np1/8/2QPP3/2N2N2/PP2BPPP/R1B1K2R b KQ' => {
			eco => 'D97o',
			# TRANSLATORS: D97o: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 Na6 8. Be2
			variation => N__('Grünfeld: Russian, Prins, 8. Be2'),
			moves => {
				'c7c5' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/n4np1/2p5/2QPP3/2N2N2/PP2BPPP/R1B1K2R w KQ' => {
			eco => 'D97o',
			# TRANSLATORS: D97o: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 Na6 8. Be2 c5
			variation => N__('Grünfeld: Russian, Prins, 8. Be2'),
			moves => {
				'd4d5' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/n4np1/2pP4/2Q1P3/2N2N2/PP2BPPP/R1B1K2R b KQ' => {
			eco => 'D97o',
			# TRANSLATORS: D97o: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 Na6 8. Be2 c5 9. d5
			variation => N__('Grünfeld: Russian, Prins, 8. Be2'),
			moves => {
				'e7e6' => 1,
			},
		},
		'r1bq1rk1/pp3pbp/n3pnp1/2pP4/2Q1P3/2N2N2/PP2BPPP/R1B1K2R w KQ' => {
			eco => 'D97o',
			# TRANSLATORS: D97o: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 Na6 8. Be2 c5 9. d5 e6
			variation => N__('Grünfeld: Russian, Prins, 8. Be2'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bq1rk1/pp3pbp/n3pnp1/2pP4/2Q1P3/2N2N2/PP2BPPP/R1B2RK1 b -' => {
			eco => 'D97o',
			# TRANSLATORS: D97o: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 Na6 8. Be2 c5 9. d5 e6 10. O-O
			variation => N__('Grünfeld: Russian, Prins, 8. Be2'),
			moves => {
				'e6d5' => 1,
			},
		},
		'r1bq1rk1/pp3pbp/n4np1/2pp4/2Q1P3/2N2N2/PP2BPPP/R1B2RK1 w -' => {
			eco => 'D97o',
			# TRANSLATORS: D97o: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 Na6 8. Be2 c5 9. d5 e6 10. O-O exd5
			variation => N__('Grünfeld: Russian, Prins, 8. Be2'),
			moves => {
				'e4d5' => 1,
			},
		},
		'r1bq1rk1/pp3pbp/n4np1/2pP4/2Q5/2N2N2/PP2BPPP/R1B2RK1 b -' => {
			eco => 'D97o',
			# TRANSLATORS: D97o: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 Na6 8. Be2 c5 9. d5 e6 10. O-O exd5 11. exd5
			variation => N__('Grünfeld: Russian, Prins, 8. Be2'),
			moves => {
				'c8f5' => 1,
			},
		},
		'r2q1rk1/pp3pbp/n4np1/2pP1b2/2Q5/2N2N2/PP2BPPP/R1B2RK1 w -' => {
			eco => 'D97p',
			# TRANSLATORS: D97p: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 Na6 8. Be2 c5 9. d5 e6 10. O-O exd5 11. exd5 Bf5
			variation => N__('Grünfeld: Russian, Prins, 8. Be2, Main Line'),
			moves => {
			},
		},
		'rn1q1rk1/ppp1ppbp/5np1/8/2QPP1b1/2N2N2/PP3PPP/R1B1KB1R w KQ' => {
			eco => 'D98a',
			# TRANSLATORS: D98a: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 Bg4
			variation => N__('Grünfeld: Russian, Smyslov Variation'),
			moves => {
				'c1e3' => 1,
				'f1e2' => 1,
			},
		},
		'rn1q1rk1/ppp1ppbp/5np1/8/2QPP1b1/2N2N2/PP2BPPP/R1B1K2R b KQ' => {
			eco => 'D98b',
			# TRANSLATORS: D98b: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 Bg4 8. Be2
			variation => N__('Grünfeld: Russian, Smyslov, 8. Be2'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r2q1rk1/ppp1ppbp/2n2np1/8/2QPP1b1/2N2N2/PP2BPPP/R1B1K2R w KQ' => {
			eco => 'D98c',
			# TRANSLATORS: D98c: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 Bg4 8. Be2 Nc6
			variation => N__('Grünfeld: Russian, Smyslov, 8. Be2 Nc6'),
			moves => {
				'd4d5' => 1,
			},
		},
		'r2q1rk1/ppp1ppbp/2n2np1/3P4/2Q1P1b1/2N2N2/PP2BPPP/R1B1K2R b KQ' => {
			eco => 'D98d',
			# TRANSLATORS: D98d: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 Bg4 8. Be2 Nc6 9. d5
			variation => N__('Grünfeld: Russian, Smyslov, 8. Be2 Nc6 9. d5'),
			moves => {
			},
		},
		'rn1q1rk1/ppp1ppbp/5np1/8/2QPP1b1/2N1BN2/PP3PPP/R3KB1R b KQ' => {
			eco => 'D98e',
			# TRANSLATORS: D98e: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 Bg4 8. Be3
			variation => N__('Grünfeld: Russian, Smyslov, 8. Be3'),
			moves => {
				'f6d7' => 1,
			},
		},
		'rn1q1rk1/pppnppbp/6p1/8/2QPP1b1/2N1BN2/PP3PPP/R3KB1R w KQ' => {
			eco => 'D98f',
			# TRANSLATORS: D98f: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 Bg4 8. Be3 Nfd7
			variation => N__('Grünfeld: Russian, Smyslov, 8. Be3 Nfd7'),
			moves => {
				'a1d1' => 1,
				'c4b3' => 1,
				'e1c1' => 1,
				'f1e2' => 1,
			},
		},
		'rn1q1rk1/pppnppbp/6p1/8/2QPP1b1/2N1BN2/PP2BPPP/R3K2R b KQ' => {
			eco => 'D98g',
			# TRANSLATORS: D98g: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 Bg4 8. Be3 Nfd7 9. Be2
			variation => N__('Grünfeld: Russian, Smyslov, 8. Be3 Nfd7 9. Be2'),
			moves => {
				'd7b6' => 1,
			},
		},
		'rn1q1rk1/ppp1ppbp/1n4p1/8/2QPP1b1/2N1BN2/PP2BPPP/R3K2R w KQ' => {
			eco => 'D98g',
			# TRANSLATORS: D98g: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 Bg4 8. Be3 Nfd7 9. Be2 Nb6
			variation => N__('Grünfeld: Russian, Smyslov, 8. Be3 Nfd7 9. Be2'),
			moves => {
				'c4d3' => 1,
			},
		},
		'rn1q1rk1/ppp1ppbp/1n4p1/8/3PP1b1/2NQBN2/PP2BPPP/R3K2R b KQ' => {
			eco => 'D98g',
			# TRANSLATORS: D98g: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 Bg4 8. Be3 Nfd7 9. Be2 Nb6 10. Qd3
			variation => N__('Grünfeld: Russian, Smyslov, 8. Be3 Nfd7 9. Be2'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r2q1rk1/ppp1ppbp/1nn3p1/8/3PP1b1/2NQBN2/PP2BPPP/R3K2R w KQ' => {
			eco => 'D98g',
			# TRANSLATORS: D98g: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 Bg4 8. Be3 Nfd7 9. Be2 Nb6 10. Qd3 Nc6
			variation => N__('Grünfeld: Russian, Smyslov, 8. Be3 Nfd7 9. Be2'),
			moves => {
				'e1c1' => 1,
			},
		},
		'r2q1rk1/ppp1ppbp/1nn3p1/8/3PP1b1/2NQBN2/PP2BPPP/2KR3R b -' => {
			eco => 'D98h',
			# TRANSLATORS: D98h: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 Bg4 8. Be3 Nfd7 9. Be2 Nb6 10. Qd3 Nc6 11. O-O-O
			variation => N__('Grünfeld: Russian, Smyslov, Keres Variation'),
			moves => {
			},
		},
		'rn1q1rk1/pppnppbp/6p1/8/2QPP1b1/2N1BN2/PP3PPP/2KR1B1R b -' => {
			eco => 'D98i',
			# TRANSLATORS: D98i: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 Bg4 8. Be3 Nfd7 9. O-O-O
			variation => N__('Grünfeld: Russian, Smyslov, 8. Be3 Nfd7 9.O-O-O'),
			moves => {
			},
		},
		'rn1q1rk1/pppnppbp/6p1/8/2QPP1b1/2N1BN2/PP3PPP/3RKB1R b K' => {
			eco => 'D98j',
			# TRANSLATORS: D98j: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 Bg4 8. Be3 Nfd7 9. Rd1
			variation => N__('Grünfeld: Russian, Smyslov, 8. Be3 Nfd7 9. Rd1'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r2q1rk1/pppnppbp/2n3p1/8/2QPP1b1/2N1BN2/PP3PPP/3RKB1R w K' => {
			eco => 'D98k',
			# TRANSLATORS: D98k: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 Bg4 8. Be3 Nfd7 9. Rd1 Nc6
			variation => N__('Grünfeld: Russian, Smyslov, 8. Be3 Nfd7 9. Rd1 Nc6'),
			moves => {
			},
		},
		'rn1q1rk1/pppnppbp/6p1/8/3PP1b1/1QN1BN2/PP3PPP/R3KB1R b KQ' => {
			eco => 'D99a',
			# TRANSLATORS: D99a: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 Bg4 8. Be3 Nfd7 9. Qb3
			variation => N__('Grünfeld: Russian, Smyslov, Main Line'),
			moves => {
				'c7c5' => 1,
				'd7b6' => 1,
			},
		},
		'rn1q1rk1/pp1nppbp/6p1/2p5/3PP1b1/1QN1BN2/PP3PPP/R3KB1R w KQ' => {
			eco => 'D99b',
			# TRANSLATORS: D99b: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 Bg4 8. Be3 Nfd7 9. Qb3 c5
			variation => N__('Grünfeld: Russian, Smyslov, Yugoslav'),
			moves => {
			},
		},
		'rn1q1rk1/ppp1ppbp/1n4p1/8/3PP1b1/1QN1BN2/PP3PPP/R3KB1R w KQ' => {
			eco => 'D99c',
			# TRANSLATORS: D99c: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 Bg4 8. Be3 Nfd7 9. Qb3 Nb6
			variation => N__('Grünfeld: Russian, Smyslov, Main Line, 9... Nb6'),
			moves => {
				'a1d1' => 1,
			},
		},
		'rn1q1rk1/ppp1ppbp/1n4p1/8/3PP1b1/1QN1BN2/PP3PPP/3RKB1R b K' => {
			eco => 'D99d',
			# TRANSLATORS: D99d: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 Bg4 8. Be3 Nfd7 9. Qb3 Nb6 10. Rd1
			variation => N__('Grünfeld: Russian, Smyslov, Main Line, 9... Nb6 10. Rd1'),
			moves => {
				'b8c6' => 1,
				'e7e6' => 1,
			},
		},
		'rn1q1rk1/ppp2pbp/1n2p1p1/8/3PP1b1/1QN1BN2/PP3PPP/3RKB1R w K' => {
			eco => 'D99e',
			# TRANSLATORS: D99e: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 Bg4 8. Be3 Nfd7 9. Qb3 Nb6 10. Rd1 e6
			variation => N__('Grünfeld: Russian, Smyslov, Main Line, 9... Nb6 10. Rd1 e6'),
			moves => {
			},
		},
		'r2q1rk1/ppp1ppbp/1nn3p1/8/3PP1b1/1QN1BN2/PP3PPP/3RKB1R w K' => {
			eco => 'D99f',
			# TRANSLATORS: D99f: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 Bg4 8. Be3 Nfd7 9. Qb3 Nb6 10. Rd1 Nc6
			variation => N__('Grünfeld: Russian, Smyslov, Main Line, 9... Nb6 10. Rd1 Nc6'),
			moves => {
				'd4d5' => 1,
			},
		},
		'r2q1rk1/ppp1ppbp/1nn3p1/3P4/4P1b1/1QN1BN2/PP3PPP/3RKB1R b K' => {
			eco => 'D99f',
			# TRANSLATORS: D99f: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 Bg4 8. Be3 Nfd7 9. Qb3 Nb6 10. Rd1 Nc6 11. d5
			variation => N__('Grünfeld: Russian, Smyslov, Main Line, 9... Nb6 10. Rd1 Nc6'),
			moves => {
				'c6e5' => 1,
			},
		},
		'r2q1rk1/ppp1ppbp/1n4p1/3Pn3/4P1b1/1QN1BN2/PP3PPP/3RKB1R w K' => {
			eco => 'D99g',
			# TRANSLATORS: D99g: 1. d4 Nf6 2. c4 g6 3. Nc3 d5 4. Nf3 Bg7 5. Qb3 dxc4 6. Qxc4 O-O 7. e4 Bg4 8. Be3 Nfd7 9. Qb3 Nb6 10. Rd1 Nc6 11. d5 Ne5
			variation => N__('Grünfeld: Russian, Smyslov, Main Line, 9... Nb6 10. Rd1 Nc6 11. d5 Ne5'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/4pn2/8/2PP4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'E00a',
			# TRANSLATORS: E00a: 1. d4 Nf6 2. c4 e6
			variation => N__('Queen\'s Pawn: Neo-Indian'),
			moves => {
				'a2a3' => 1,
				'b1c3' => 1,
				'c1g5' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
				'g2g4' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/4pn2/8/2PP2P1/8/PP2PP1P/RNBQKBNR b KQkq' => {
			eco => 'E00a',
			# TRANSLATORS: E00a: 1. d4 Nf6 2. c4 e6 3. g4
			variation => N__('Queen\'s Pawn: Neo-Indian, Devin Gambit'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/4pn2/8/2PP4/P7/1P2PPPP/RNBQKBNR b KQkq' => {
			eco => 'E00b',
			# TRANSLATORS: E00b: 1. d4 Nf6 2. c4 e6 3. a3
			variation => N__('Queen\'s Pawn: Anti-Nimzo-Indian'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p4/2PP4/P7/1P2PPPP/RNBQKBNR w KQkq' => {
			eco => 'E00b',
			# TRANSLATORS: E00b: 1. d4 Nf6 2. c4 e6 3. a3 d5
			variation => N__('Queen\'s Pawn: Anti-Nimzo-Indian, 3... d5'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/4pn2/6B1/2PP4/8/PP2PPPP/RN1QKBNR b KQkq' => {
			eco => 'E00c',
			# TRANSLATORS: E00c: 1. d4 Nf6 2. c4 e6 3. Bg5
			variation => N__('Neo-Indian (Seirawan) Attack'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/4pn2/8/2PP4/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'E00d',
			# TRANSLATORS: E00d: 1. d4 Nf6 2. c4 e6 3. Nc3
			variation => N__('Queen\'s Pawn: Neo-Indian'),
			moves => {
				'b7b6' => 1,
				'c7c5' => 1,
				'f8b4' => 1,
			},
		},
		'rnbqkb1r/p1pp1ppp/1p2pn2/8/2PP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'E00e',
			# TRANSLATORS: E00e: 1. d4 Nf6 2. c4 e6 3. Nc3 b6
			variation => N__('Queen\'s Pawn: Neo-Indian, 3... b6'),
			moves => {
				'e2e4' => 1,
			},
		},
		'rnbqkb1r/p1pp1ppp/1p2pn2/8/2PPP3/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'E00e',
			# TRANSLATORS: E00e: 1. d4 Nf6 2. c4 e6 3. Nc3 b6 4. e4
			variation => N__('Queen\'s Pawn: Neo-Indian, 3... b6'),
			moves => {
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/2p5/2PP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'E00f',
			# TRANSLATORS: E00f: 1. d4 Nf6 2. c4 e6 3. Nc3 c5
			variation => N__('Queen\'s Pawn: Neo-Indian, 3... c5'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/4pn2/8/2PP4/6P1/PP2PP1P/RNBQKBNR b KQkq' => {
			eco => 'E00g',
			# TRANSLATORS: E00g: 1. d4 Nf6 2. c4 e6 3. g3
			variation => N__('Catalan'),
			moves => {
				'c7c5' => 1,
				'c7c6' => 1,
				'd7d5' => 1,
				'e6e5' => 1,
				'f8b4' => 1,
			},
		},
		'rnbqkb1r/pp1p1ppp/2p1pn2/8/2PP4/6P1/PP2PP1P/RNBQKBNR w KQkq' => {
			eco => 'E00g',
			# TRANSLATORS: E00g: 1. d4 Nf6 2. c4 e6 3. g3 c6
			variation => N__('Catalan: 3... c6'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/5n2/4p3/2PP4/6P1/PP2PP1P/RNBQKBNR w KQkq' => {
			eco => 'E00g',
			# TRANSLATORS: E00g: 1. d4 Nf6 2. c4 e6 3. g3 e5
			variation => N__('Catalan: Hungarian Gambit'),
			moves => {
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/2p5/2PP4/6P1/PP2PP1P/RNBQKBNR w KQkq' => {
			eco => 'E00h',
			# TRANSLATORS: E00h: 1. d4 Nf6 2. c4 e6 3. g3 c5
			variation => N__('Catalan: 3... c5'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/2p5/2PP4/5NP1/PP2PP1P/RNBQKB1R b KQkq' => {
			eco => 'E00h',
			# TRANSLATORS: E00h: 1. d4 Nf6 2. c4 e6 3. g3 c5 4. Nf3
			variation => N__('Catalan: 3... c5 4. Nf3'),
			moves => {
			},
		},
		'rnbqk2r/pppp1ppp/4pn2/8/1bPP4/6P1/PP2PP1P/RNBQKBNR w KQkq' => {
			eco => 'E00i',
			# TRANSLATORS: E00i: 1. d4 Nf6 2. c4 e6 3. g3 Bb4+
			variation => N__('Catalan: 3... Bb4+'),
			moves => {
				'b1d2' => 1,
				'c1d2' => 1,
			},
		},
		'rnbqk2r/pppp1ppp/4pn2/8/1bPP4/6P1/PP1NPP1P/R1BQKBNR b KQkq' => {
			eco => 'E00i',
			# TRANSLATORS: E00i: 1. d4 Nf6 2. c4 e6 3. g3 Bb4+ 4. Nd2
			variation => N__('Catalan: 3... Bb4+ 4. Nd2'),
			moves => {
			},
		},
		'rnbqk2r/pppp1ppp/4pn2/8/1bPP4/6P1/PP1BPP1P/RN1QKBNR b KQkq' => {
			eco => 'E00j',
			# TRANSLATORS: E00j: 1. d4 Nf6 2. c4 e6 3. g3 Bb4+ 4. Bd2
			variation => N__('Catalan: 3... Bb4+ 4. Bd2'),
			moves => {
				'b4d2' => 1,
				'b4e7' => 1,
				'd8e7' => 1,
			},
		},
		'rnbqk2r/pppp1ppp/4pn2/8/2PP4/6P1/PP1bPP1P/RN1QKBNR w KQkq' => {
			eco => 'E00k',
			# TRANSLATORS: E00k: 1. d4 Nf6 2. c4 e6 3. g3 Bb4+ 4. Bd2 Bxd2+
			variation => N__('Catalan: 3... Bb4+ 4. Bd2 Bxd2+'),
			moves => {
			},
		},
		'rnbqk2r/ppppbppp/4pn2/8/2PP4/6P1/PP1BPP1P/RN1QKBNR w KQkq' => {
			eco => 'E00l',
			# TRANSLATORS: E00l: 1. d4 Nf6 2. c4 e6 3. g3 Bb4+ 4. Bd2 Be7
			variation => N__('Catalan: 3... Bb4+ 4. Bd2 Be7'),
			moves => {
			},
		},
		'rnb1k2r/ppppqppp/4pn2/8/1bPP4/6P1/PP1BPP1P/RN1QKBNR w KQkq' => {
			eco => 'E00m',
			# TRANSLATORS: E00m: 1. d4 Nf6 2. c4 e6 3. g3 Bb4+ 4. Bd2 Qe7
			variation => N__('Catalan: 3... Bb4+ 4. Bd2 Qe7'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnb1k2r/ppppqppp/4pn2/8/1bPP4/6P1/PP1BPPBP/RN1QK1NR b KQkq' => {
			eco => 'E00m',
			# TRANSLATORS: E00m: 1. d4 Nf6 2. c4 e6 3. g3 Bb4+ 4. Bd2 Qe7 5. Bg2
			variation => N__('Catalan: 3... Bb4+ 4. Bd2 Qe7'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p4/2PP4/6P1/PP2PP1P/RNBQKBNR w KQkq' => {
			eco => 'E00n',
			# TRANSLATORS: E00n: 1. d4 Nf6 2. c4 e6 3. g3 d5
			variation => N__('Catalan: 3... d5'),
			moves => {
				'f1g2' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p4/2PP4/5NP1/PP2PP1P/RNBQKB1R b KQkq' => {
			eco => 'E00o',
			# TRANSLATORS: E00o: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Nf3
			variation => N__('Catalan: 4. Nf3'),
			moves => {
				'c7c5' => 1,
				'c7c6' => 1,
				'd5c4' => 1,
				'f8b4' => 1,
				'f8e7' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/2p1pn2/3p4/2PP4/5NP1/PP2PP1P/RNBQKB1R w KQkq' => {
			eco => 'E00p',
			# TRANSLATORS: E00p: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Nf3 c6
			variation => N__('Catalan: 4. Nf3 c6'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2pp4/2PP4/5NP1/PP2PP1P/RNBQKB1R w KQkq' => {
			eco => 'E00q',
			# TRANSLATORS: E00q: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Nf3 c5
			variation => N__('Catalan: 4. Nf3 c5'),
			moves => {
			},
		},
		'rnbqk2r/ppp2ppp/4pn2/3p4/1bPP4/5NP1/PP2PP1P/RNBQKB1R w KQkq' => {
			eco => 'E00r',
			# TRANSLATORS: E00r: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Nf3 Bb4+
			variation => N__('Catalan: 4. Nf3 Bb4+'),
			moves => {
				'c1d2' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/4pn2/3p4/1bPP4/5NP1/PP1BPP1P/RN1QKB1R b KQkq' => {
			eco => 'E00r',
			# TRANSLATORS: E00r: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Nf3 Bb4+ 5. Bd2
			variation => N__('Catalan: 4. Nf3 Bb4+ 5. Bd2'),
			moves => {
			},
		},
		'rnbqk2r/ppp1bppp/4pn2/3p4/2PP4/5NP1/PP2PP1P/RNBQKB1R w KQkq' => {
			eco => 'E00s',
			# TRANSLATORS: E00s: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Nf3 Be7
			variation => N__('Catalan: 4. Nf3 Be7'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/8/2pP4/5NP1/PP2PP1P/RNBQKB1R w KQkq' => {
			eco => 'E00t',
			# TRANSLATORS: E00t: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Nf3 dxc4
			variation => N__('Catalan: 4. Nf3 dxc4'),
			moves => {
				'd1a4' => 1,
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/8/Q1pP4/5NP1/PP2PP1P/RNB1KB1R b KQkq' => {
			eco => 'E00u',
			# TRANSLATORS: E00u: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Nf3 dxc4 5. Qa4+
			variation => N__('Catalan: 4. Nf3 dxc4 5. Qa4+'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r1bqkb1r/pppn1ppp/4pn2/8/Q1pP4/5NP1/PP2PP1P/RNB1KB1R w KQkq' => {
			eco => 'E00v',
			# TRANSLATORS: E00v: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Nf3 dxc4 5. Qa4+ Nbd7
			variation => N__('Catalan: 4. Nf3 dxc4 5. Qa4+ Nbd7'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/3p4/2PP4/6P1/PP2PPBP/RNBQK1NR b KQkq' => {
			eco => 'E01',
			# TRANSLATORS: E01: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2
			variation => N__('Catalan: 4. Bg2'),
			moves => {
				'c7c5' => 1,
				'c7c6' => 1,
				'd5c4' => 1,
				'f8b4' => 1,
				'f8e7' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2pp4/2PP4/6P1/PP2PPBP/RNBQK1NR w KQkq' => {
			eco => 'E01',
			# TRANSLATORS: E01: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 c5
			variation => N__('Catalan: 4... c5'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2pp4/2PP4/5NP1/PP2PPBP/RNBQK2R b KQkq' => {
			eco => 'E01',
			# TRANSLATORS: E01: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 c5 5. Nf3
			variation => N__('Catalan: 4... c5 5. Nf3'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/2p1pn2/3p4/2PP4/6P1/PP2PPBP/RNBQK1NR w KQkq' => {
			eco => 'E01',
			# TRANSLATORS: E01: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 c6
			variation => N__('Catalan: 4... c6'),
			moves => {
				'd1c2' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/2p1pn2/3p4/2PP4/6P1/PPQ1PPBP/RNB1K1NR b KQkq' => {
			eco => 'E01',
			# TRANSLATORS: E01: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 c6 5. Qc2
			variation => N__('Catalan: 4... c6 5. Qc2'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/2p1pn2/3p4/2PP4/5NP1/PP2PPBP/RNBQK2R b KQkq' => {
			eco => 'E01',
			# TRANSLATORS: E01: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 c6 5. Nf3
			variation => N__('Catalan: 4... c6 5. Nf3'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/2p1pn2/3p4/2PP4/5NP1/PP2PPBP/RNBQK2R w KQkq' => {
			eco => 'E01',
			# TRANSLATORS: E01: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 c6 5. Nf3 Nbd7
			variation => N__('Catalan: 4... c6 5. Nf3 Nbd7'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/8/2pP4/6P1/PP2PPBP/RNBQK1NR w KQkq' => {
			eco => 'E01',
			# TRANSLATORS: E01: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4
			variation => N__('Catalan: Open'),
			moves => {
				'd1a4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/4pn2/3p4/1bPP4/6P1/PP2PPBP/RNBQK1NR w KQkq' => {
			eco => 'E01',
			# TRANSLATORS: E01: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Bb4+
			variation => N__('Catalan: 4... Bb4+'),
			moves => {
				'b1d2' => 1,
				'c1d2' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/4pn2/3p4/1bPP4/6P1/PP1NPPBP/R1BQK1NR b KQkq' => {
			eco => 'E01',
			# TRANSLATORS: E01: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Bb4+ 5. Nd2
			variation => N__('Catalan: 4... Bb4+ 5. Nd2'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppp2ppp/4pn2/3p4/1bPP4/6P1/PP1NPPBP/R1BQK1NR w KQ' => {
			eco => 'E01',
			# TRANSLATORS: E01: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Bb4+ 5. Nd2 O-O
			variation => N__('Catalan: 4... Bb4+ 5. Nd2 O-O'),
			moves => {
			},
		},
		'rnbqk2r/ppp2ppp/4pn2/3p4/1bPP4/6P1/PP1BPPBP/RN1QK1NR b KQkq' => {
			eco => 'E01',
			# TRANSLATORS: E01: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Bb4+ 5. Bd2
			variation => N__('Catalan: 4... Bb4+ 5. Bd2'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/8/Q1pP4/6P1/PP2PPBP/RNB1K1NR b KQkq' => {
			eco => 'E02',
			# TRANSLATORS: E02: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Qa4+
			variation => N__('Catalan: Open, 5. Qa4+'),
			moves => {
				'b8d7' => 1,
				'c8d7' => 1,
			},
		},
		'r1bqkb1r/pppn1ppp/4pn2/8/Q1pP4/6P1/PP2PPBP/RNB1K1NR w KQkq' => {
			eco => 'E02',
			# TRANSLATORS: E02: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Qa4+ Nbd7
			variation => N__('Catalan: Open, 5. Qa4+ Nbd7'),
			moves => {
				'a4c4' => 1,
				'g1f3' => 1,
			},
		},
		'r1bqkb1r/pppn1ppp/4pn2/8/Q1pP4/5NP1/PP2PPBP/RNB1K2R b KQkq' => {
			eco => 'E02',
			# TRANSLATORS: E02: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Qa4+ Nbd7 6. Nf3
			variation => N__('Catalan: Open, 5. Qa4+ Nbd7 6. Nf3'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r1bqkb1r/1ppn1ppp/p3pn2/8/Q1pP4/5NP1/PP2PPBP/RNB1K2R w KQkq' => {
			eco => 'E02',
			# TRANSLATORS: E02: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Qa4+ Nbd7 6. Nf3 a6
			variation => N__('Catalan: Open, 5. Qa4+ Nbd7 6. Nf3 a6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r1bqkb1r/1ppn1ppp/p3pn2/8/Q1pP4/2N2NP1/PP2PPBP/R1B1K2R b KQkq' => {
			eco => 'E02',
			# TRANSLATORS: E02: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Qa4+ Nbd7 6. Nf3 a6 7. Nc3
			variation => N__('Catalan: Open, 5. Qa4+ Nbd7 6. Nf3 a6 7. Nc3'),
			moves => {
			},
		},
		'rn1qkb1r/pppb1ppp/4pn2/8/Q1pP4/6P1/PP2PPBP/RNB1K1NR w KQkq' => {
			eco => 'E02',
			# TRANSLATORS: E02: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Qa4+ Bd7
			variation => N__('Catalan: Open, 5. Qa4+ Bd7'),
			moves => {
				'a4c4' => 1,
			},
		},
		'rn1qkb1r/pppb1ppp/4pn2/8/2QP4/6P1/PP2PPBP/RNB1K1NR b KQkq' => {
			eco => 'E02',
			# TRANSLATORS: E02: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Qa4+ Bd7 6. Qxc4
			variation => N__('Catalan: Open, 5. Qa4+ Bd7 6.Qxc4'),
			moves => {
			},
		},
		'r1bqkb1r/pppn1ppp/4pn2/8/2QP4/6P1/PP2PPBP/RNB1K1NR b KQkq' => {
			eco => 'E03',
			# TRANSLATORS: E03: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Qa4+ Nbd7 6. Qxc4
			variation => N__('Catalan: Open, 5. Qa4+ Nbd7 6.Qxc4'),
			moves => {
				'a7a6' => 1,
				'c7c5' => 1,
			},
		},
		'r1bqkb1r/1ppn1ppp/p3pn2/8/2QP4/6P1/PP2PPBP/RNB1K1NR w KQkq' => {
			eco => 'E03',
			# TRANSLATORS: E03: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Qa4+ Nbd7 6. Qxc4 a6
			variation => N__('Catalan: Open, 5. Qa4+ Nbd7 6.Qxc4 a6'),
			moves => {
				'c4c2' => 1,
				'g1f3' => 1,
			},
		},
		'r1bqkb1r/1ppn1ppp/p3pn2/8/3P4/6P1/PPQ1PPBP/RNB1K1NR b KQkq' => {
			eco => 'E03',
			# TRANSLATORS: E03: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Qa4+ Nbd7 6. Qxc4 a6 7. Qc2
			variation => N__('Catalan: Open, Alekhine Variation'),
			moves => {
			},
		},
		'r1bqkb1r/1ppn1ppp/p3pn2/8/2QP4/5NP1/PP2PPBP/RNB1K2R b KQkq' => {
			eco => 'E03',
			# TRANSLATORS: E03: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Qa4+ Nbd7 6. Qxc4 a6 7. Nf3
			variation => N__('Catalan: Open, 5. Qa4+ Nbd7 6.Qxc4 a6 7. Nf3'),
			moves => {
				'b7b5' => 1,
			},
		},
		'r1bqkb1r/2pn1ppp/p3pn2/1p6/2QP4/5NP1/PP2PPBP/RNB1K2R w KQkq' => {
			eco => 'E03',
			# TRANSLATORS: E03: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Qa4+ Nbd7 6. Qxc4 a6 7. Nf3 b5
			variation => N__('Catalan: Open, 5. Qa4+ Nbd7 6.Qxc4 a6 7. Nf3 b5'),
			moves => {
				'c4c2' => 1,
				'c4c6' => 1,
			},
		},
		'r1bqkb1r/2pn1ppp/p3pn2/1p6/3P4/5NP1/PPQ1PPBP/RNB1K2R b KQkq' => {
			eco => 'E03',
			# TRANSLATORS: E03: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Qa4+ Nbd7 6. Qxc4 a6 7. Nf3 b5 8. Qc2
			variation => N__('Catalan: Open, 5. Qa4+ Nbd7 6.Qxc4 a6 7. Nf3 b5 8. Qc2'),
			moves => {
			},
		},
		'r1bqkb1r/2pn1ppp/p1Q1pn2/1p6/3P4/5NP1/PP2PPBP/RNB1K2R b KQkq' => {
			eco => 'E03',
			# TRANSLATORS: E03: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Qa4+ Nbd7 6. Qxc4 a6 7. Nf3 b5 8. Qc6
			variation => N__('Catalan: Open, 5. Qa4+ Nbd7 6.Qxc4 a6 7. Nf3 b5 8. Qc6'),
			moves => {
			},
		},
		'r1bqkb1r/pp1n1ppp/4pn2/2p5/2QP4/6P1/PP2PPBP/RNB1K1NR w KQkq' => {
			eco => 'E03',
			# TRANSLATORS: E03: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Qa4+ Nbd7 6. Qxc4 c5
			variation => N__('Catalan: Open, 5. Qa4+ Nbd7 6.Qxc4 c5'),
			moves => {
				'g1f3' => 1,
			},
		},
		'r1bqkb1r/pp1n1ppp/4pn2/2p5/2QP4/5NP1/PP2PPBP/RNB1K2R b KQkq' => {
			eco => 'E03',
			# TRANSLATORS: E03: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Qa4+ Nbd7 6. Qxc4 c5 7. Nf3
			variation => N__('Catalan: Open, 5. Qa4+ Nbd7 6.Qxc4 c5 7. Nf3'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r1bqkb1r/1p1n1ppp/p3pn2/2p5/2QP4/5NP1/PP2PPBP/RNB1K2R w KQkq' => {
			eco => 'E03',
			# TRANSLATORS: E03: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Qa4+ Nbd7 6. Qxc4 c5 7. Nf3 a6
			variation => N__('Catalan: Open, 5. Qa4+ Nbd7 6.Qxc4 c5 7. Nf3 a6'),
			moves => {
				'c4c2' => 1,
				'e1g1' => 1,
			},
		},
		'r1bqkb1r/1p1n1ppp/p3pn2/2p5/3P4/5NP1/PPQ1PPBP/RNB1K2R b KQkq' => {
			eco => 'E03',
			# TRANSLATORS: E03: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Qa4+ Nbd7 6. Qxc4 c5 7. Nf3 a6 8. Qc2
			variation => N__('Catalan: Open, 5. Qa4+ Nbd7 6.Qxc4 c5 7. Nf3 a6 8. Qc2'),
			moves => {
				'b7b6' => 1,
			},
		},
		'r1bqkb1r/3n1ppp/pp2pn2/2p5/3P4/5NP1/PPQ1PPBP/RNB1K2R w KQkq' => {
			eco => 'E03',
			# TRANSLATORS: E03: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Qa4+ Nbd7 6. Qxc4 c5 7. Nf3 a6 8. Qc2 b6
			variation => N__('Catalan: Open, 5. Qa4+ Nbd7 6.Qxc4 c5 7. Nf3 a6 8. Qc2 b6'),
			moves => {
			},
		},
		'r1bqkb1r/1p1n1ppp/p3pn2/2p5/2QP4/5NP1/PP2PPBP/RNB2RK1 b kq' => {
			eco => 'E03',
			# TRANSLATORS: E03: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Qa4+ Nbd7 6. Qxc4 c5 7. Nf3 a6 8. O-O
			variation => N__('Catalan: Open, 5. Qa4+ Nbd7 6.Qxc4 c5 7. Nf3 a6 8.O-O'),
			moves => {
			},
		},
		'rnbqkb1r/ppp2ppp/4pn2/8/2pP4/5NP1/PP2PPBP/RNBQK2R b KQkq' => {
			eco => 'E04a',
			# TRANSLATORS: E04a: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3
			variation => N__('Catalan: Open, 5. Nf3'),
			moves => {
				'a7a6' => 1,
				'b7b5' => 1,
				'b8c6' => 1,
				'b8d7' => 1,
				'c7c5' => 1,
				'c8d7' => 1,
				'f8b4' => 1,
				'f8e7' => 1,
			},
		},
		'rn1qkb1r/pppb1ppp/4pn2/8/2pP4/5NP1/PP2PPBP/RNBQK2R w KQkq' => {
			eco => 'E04a',
			# TRANSLATORS: E04a: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Bd7
			variation => N__('Catalan: Open, 5. Nf3 Bd7'),
			moves => {
			},
		},
		'rnbqk2r/ppp2ppp/4pn2/8/1bpP4/5NP1/PP2PPBP/RNBQK2R w KQkq' => {
			eco => 'E04b',
			# TRANSLATORS: E04b: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Bb4+
			variation => N__('Catalan: Open, 5. Nf3 Bb4+'),
			moves => {
			},
		},
		'r1bqkb1r/pppn1ppp/4pn2/8/2pP4/5NP1/PP2PPBP/RNBQK2R w KQkq' => {
			eco => 'E04c',
			# TRANSLATORS: E04c: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Nbd7
			variation => N__('Catalan: Open, 5. Nf3 Nbd7'),
			moves => {
			},
		},
		'rnbqkb1r/p1p2ppp/4pn2/1p6/2pP4/5NP1/PP2PPBP/RNBQK2R w KQkq' => {
			eco => 'E04d',
			# TRANSLATORS: E04d: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 b5
			variation => N__('Catalan: Open, 5. Nf3 b5'),
			moves => {
			},
		},
		'rnbqkb1r/1pp2ppp/p3pn2/8/2pP4/5NP1/PP2PPBP/RNBQK2R w KQkq' => {
			eco => 'E04e',
			# TRANSLATORS: E04e: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 a6
			variation => N__('Catalan: Open, 5. Nf3 a6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbqkb1r/1pp2ppp/p3pn2/8/2pP4/5NP1/PP2PPBP/RNBQ1RK1 b kq' => {
			eco => 'E04f',
			# TRANSLATORS: E04f: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 a6 6. O-O
			variation => N__('Catalan: Open, 5. Nf3 a6 6.O-O'),
			moves => {
				'b7b5' => 1,
				'b8c6' => 1,
			},
		},
		'rnbqkb1r/2p2ppp/p3pn2/1p6/2pP4/5NP1/PP2PPBP/RNBQ1RK1 w kq' => {
			eco => 'E04g',
			# TRANSLATORS: E04g: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 a6 6. O-O b5
			variation => N__('Catalan: Open, 5. Nf3 a6 6.O-O b5'),
			moves => {
				'f3e5' => 1,
			},
		},
		'rnbqkb1r/2p2ppp/p3pn2/1p2N3/2pP4/6P1/PP2PPBP/RNBQ1RK1 b kq' => {
			eco => 'E04g',
			# TRANSLATORS: E04g: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 a6 6. O-O b5 7. Ne5
			variation => N__('Catalan: Open, 5. Nf3 a6 6.O-O b5 7. Ne5'),
			moves => {
				'f6d5' => 1,
			},
		},
		'rnbqkb1r/2p2ppp/p3p3/1p1nN3/2pP4/6P1/PP2PPBP/RNBQ1RK1 w kq' => {
			eco => 'E04g',
			# TRANSLATORS: E04g: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 a6 6. O-O b5 7. Ne5 Nd5
			variation => N__('Catalan: Open, 5. Nf3 a6 6.O-O b5 7. Ne5'),
			moves => {
				'a2a4' => 1,
			},
		},
		'rnbqkb1r/2p2ppp/p3p3/1p1nN3/P1pP4/6P1/1P2PPBP/RNBQ1RK1 b kq' => {
			eco => 'E04h',
			# TRANSLATORS: E04h: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 a6 6. O-O b5 7. Ne5 Nd5 8. a4
			variation => N__('Catalan: Open, 5. Nf3 a6 6.O-O b5 7. Ne5 Nd5 8. a4'),
			moves => {
			},
		},
		'r1bqkb1r/1pp2ppp/p1n1pn2/8/2pP4/5NP1/PP2PPBP/RNBQ1RK1 w kq' => {
			eco => 'E04i',
			# TRANSLATORS: E04i: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 a6 6. O-O Nc6
			variation => N__('Catalan: Open, 5. Nf3 a6 6.O-O Nc6'),
			moves => {
				'e2e3' => 1,
			},
		},
		'r1bqkb1r/1pp2ppp/p1n1pn2/8/2pP4/4PNP1/PP3PBP/RNBQ1RK1 b kq' => {
			eco => 'E04j',
			# TRANSLATORS: E04j: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 a6 6. O-O Nc6 7. e3
			variation => N__('Catalan: Open, 5. Nf3 a6 6.O-O Nc6 7. e3'),
			moves => {
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2p5/2pP4/5NP1/PP2PPBP/RNBQK2R w KQkq' => {
			eco => 'E04k',
			# TRANSLATORS: E04k: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 c5
			variation => N__('Catalan: Open, 5. Nf3 c5'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbqkb1r/pp3ppp/4pn2/2p5/2pP4/5NP1/PP2PPBP/RNBQ1RK1 b kq' => {
			eco => 'E04k',
			# TRANSLATORS: E04k: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 c5 6. O-O
			variation => N__('Catalan: Open, 5. Nf3 c5 6.O-O'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2n1pn2/2p5/2pP4/5NP1/PP2PPBP/RNBQ1RK1 w kq' => {
			eco => 'E04l',
			# TRANSLATORS: E04l: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 c5 6. O-O Nc6
			variation => N__('Catalan: Open, 5. Nf3 c5 6.O-O Nc6'),
			moves => {
				'd1a4' => 1,
				'f3e5' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2n1pn2/2p1N3/2pP4/6P1/PP2PPBP/RNBQ1RK1 b kq' => {
			eco => 'E04m',
			# TRANSLATORS: E04m: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 c5 6. O-O Nc6 7. Ne5
			variation => N__('Catalan: Open, 5. Nf3 c5 6.O-O Nc6 7. Ne5'),
			moves => {
				'c8d7' => 1,
			},
		},
		'r2qkb1r/pp1b1ppp/2n1pn2/2p1N3/2pP4/6P1/PP2PPBP/RNBQ1RK1 w kq' => {
			eco => 'E04m',
			# TRANSLATORS: E04m: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 c5 6. O-O Nc6 7. Ne5 Bd7
			variation => N__('Catalan: Open, 5. Nf3 c5 6.O-O Nc6 7. Ne5'),
			moves => {
				'b1a3' => 1,
			},
		},
		'r2qkb1r/pp1b1ppp/2n1pn2/2p1N3/2pP4/N5P1/PP2PPBP/R1BQ1RK1 b kq' => {
			eco => 'E04n',
			# TRANSLATORS: E04n: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 c5 6. O-O Nc6 7. Ne5 Bd7 8. Na3
			variation => N__('Catalan: Open, 5. Nf3 c5 6.O-O Nc6 7. Ne5 Bd7 8. Na3'),
			moves => {
				'c5d4' => 1,
			},
		},
		'r2qkb1r/pp1b1ppp/2n1pn2/4N3/2pp4/N5P1/PP2PPBP/R1BQ1RK1 w kq' => {
			eco => 'E04n',
			# TRANSLATORS: E04n: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 c5 6. O-O Nc6 7. Ne5 Bd7 8. Na3 cxd4
			variation => N__('Catalan: Open, 5. Nf3 c5 6.O-O Nc6 7. Ne5 Bd7 8. Na3'),
			moves => {
				'a3c4' => 1,
			},
		},
		'r2qkb1r/pp1b1ppp/2n1pn2/4N3/2Np4/6P1/PP2PPBP/R1BQ1RK1 b kq' => {
			eco => 'E04n',
			# TRANSLATORS: E04n: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 c5 6. O-O Nc6 7. Ne5 Bd7 8. Na3 cxd4 9. Naxc4
			variation => N__('Catalan: Open, 5. Nf3 c5 6.O-O Nc6 7. Ne5 Bd7 8. Na3'),
			moves => {
			},
		},
		'r1bqkb1r/pp3ppp/2n1pn2/2p5/Q1pP4/5NP1/PP2PPBP/RNB2RK1 b kq' => {
			eco => 'E04o',
			# TRANSLATORS: E04o: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 c5 6. O-O Nc6 7. Qa4
			variation => N__('Catalan: Open, 5. Nf3 c5 6.O-O Nc6 7. Qa4'),
			moves => {
				'c5d4' => 1,
				'c8d7' => 1,
			},
		},
		'r1bqkb1r/pp3ppp/2n1pn2/8/Q1pp4/5NP1/PP2PPBP/RNB2RK1 w kq' => {
			eco => 'E04o',
			# TRANSLATORS: E04o: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 c5 6. O-O Nc6 7. Qa4 cxd4
			variation => N__('Catalan: Open, 5. Nf3 c5 6.O-O Nc6 7. Qa4 cxd4'),
			moves => {
			},
		},
		'r2qkb1r/pp1b1ppp/2n1pn2/2p5/Q1pP4/5NP1/PP2PPBP/RNB2RK1 w kq' => {
			eco => 'E04p',
			# TRANSLATORS: E04p: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 c5 6. O-O Nc6 7. Qa4 Bd7
			variation => N__('Catalan: Open, 5. Nf3 c5 6.O-O Nc6 7. Qa4 Bd7'),
			moves => {
				'a4c4' => 1,
			},
		},
		'r2qkb1r/pp1b1ppp/2n1pn2/2p5/2QP4/5NP1/PP2PPBP/RNB2RK1 b kq' => {
			eco => 'E04q',
			# TRANSLATORS: E04q: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 c5 6. O-O Nc6 7. Qa4 Bd7 8. Qxc4
			variation => N__('Catalan: Open, 5. Nf3 c5 6.O-O Nc6 7. Qa4 Bd7 8.Qxc4'),
			moves => {
				'b7b5' => 1,
			},
		},
		'r2qkb1r/p2b1ppp/2n1pn2/1pp5/2QP4/5NP1/PP2PPBP/RNB2RK1 w kq' => {
			eco => 'E04r',
			# TRANSLATORS: E04r: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 c5 6. O-O Nc6 7. Qa4 Bd7 8. Qxc4 b5
			variation => N__('Catalan: Open, 5. Nf3 c5 6.O-O Nc6 7. Qa4 Bd7 8.Qxc4 b5'),
			moves => {
			},
		},
		'r1bqkb1r/ppp2ppp/2n1pn2/8/2pP4/5NP1/PP2PPBP/RNBQK2R w KQkq' => {
			eco => 'E04s',
			# TRANSLATORS: E04s: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Nc6
			variation => N__('Catalan: Open, 5. Nf3 Nc6'),
			moves => {
				'd1a4' => 1,
				'e1g1' => 1,
			},
		},
		'r1bqkb1r/ppp2ppp/2n1pn2/8/2pP4/5NP1/PP2PPBP/RNBQ1RK1 b kq' => {
			eco => 'E04s',
			# TRANSLATORS: E04s: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Nc6 6. O-O
			variation => N__('Catalan: Open, 5. Nf3 Nc6 6.O-O'),
			moves => {
				'a8b8' => 1,
			},
		},
		'1rbqkb1r/ppp2ppp/2n1pn2/8/2pP4/5NP1/PP2PPBP/RNBQ1RK1 w k' => {
			eco => 'E04t',
			# TRANSLATORS: E04t: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Nc6 6. O-O Rb8
			variation => N__('Catalan: Open, 5. Nf3 Nc6 6.O-O Rb8'),
			moves => {
				'b1c3' => 1,
			},
		},
		'1rbqkb1r/ppp2ppp/2n1pn2/8/2pP4/2N2NP1/PP2PPBP/R1BQ1RK1 b k' => {
			eco => 'E04u',
			# TRANSLATORS: E04u: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Nc6 6. O-O Rb8 7. Nc3
			variation => N__('Catalan: Open, 5. Nf3 Nc6 6.O-O Rb8 7. Nc3'),
			moves => {
			},
		},
		'r1bqkb1r/ppp2ppp/2n1pn2/8/Q1pP4/5NP1/PP2PPBP/RNB1K2R b KQkq' => {
			eco => 'E04v',
			# TRANSLATORS: E04v: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Nc6 6. Qa4
			variation => N__('Catalan: Open, 5. Nf3 Nc6 6. Qa4'),
			moves => {
				'f8b4' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2n1pn2/8/QbpP4/5NP1/PP2PPBP/RNB1K2R w KQkq' => {
			eco => 'E04w',
			# TRANSLATORS: E04w: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Nc6 6. Qa4 Bb4+
			variation => N__('Catalan: Open, 5. Nf3 Nc6 6. Qa4 Bb4+'),
			moves => {
				'c1d2' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2n1pn2/8/QbpP4/5NP1/PP1BPPBP/RN2K2R b KQkq' => {
			eco => 'E04w',
			# TRANSLATORS: E04w: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Nc6 6. Qa4 Bb4+ 7. Bd2
			variation => N__('Catalan: Open, 5. Nf3 Nc6 6. Qa4 Bb4+'),
			moves => {
				'f6d5' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2n1p3/3n4/QbpP4/5NP1/PP1BPPBP/RN2K2R w KQkq' => {
			eco => 'E04x',
			# TRANSLATORS: E04x: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Nc6 6. Qa4 Bb4+ 7. Bd2 Nd5
			variation => N__('Catalan: Open, 5. Nf3 Nc6 6. Qa4 Bb4+ 7. Bd2 Nd5'),
			moves => {
			},
		},
		'rnbqk2r/ppp1bppp/4pn2/8/2pP4/5NP1/PP2PPBP/RNBQK2R w KQkq' => {
			eco => 'E05a',
			# TRANSLATORS: E05a: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Be7
			variation => N__('Catalan: Open, Classical'),
			moves => {
				'b1c3' => 1,
				'e1g1' => 1,
			},
		},
		'rnbqk2r/ppp1bppp/4pn2/8/2pP4/2N2NP1/PP2PPBP/R1BQK2R b KQkq' => {
			eco => 'E05b',
			# TRANSLATORS: E05b: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Be7 6. Nc3
			variation => N__('Catalan: Open, Classical, 6. Nc3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppp1bppp/4pn2/8/2pP4/2N2NP1/PP2PPBP/R1BQK2R w KQ' => {
			eco => 'E05c',
			# TRANSLATORS: E05c: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Be7 6. Nc3 O-O
			variation => N__('Catalan: Open, Classical, 6. Nc3 O-O'),
			moves => {
				'f3e5' => 1,
			},
		},
		'rnbq1rk1/ppp1bppp/4pn2/4N3/2pP4/2N3P1/PP2PPBP/R1BQK2R b KQ' => {
			eco => 'E05d',
			# TRANSLATORS: E05d: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Be7 6. Nc3 O-O 7. Ne5
			variation => N__('Catalan: Open, Classical, 6. Nc3 O-O 7. Ne5'),
			moves => {
			},
		},
		'rnbqk2r/ppp1bppp/4pn2/8/2pP4/5NP1/PP2PPBP/RNBQ1RK1 b kq' => {
			eco => 'E05e',
			# TRANSLATORS: E05e: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Be7 6. O-O
			variation => N__('Catalan: Open, Classical, 6.O-O'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppp1bppp/4pn2/8/2pP4/5NP1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'E05f',
			# TRANSLATORS: E05f: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Be7 6. O-O O-O
			variation => N__('Catalan: Open, Classical, 6.O-O O-O'),
			moves => {
				'd1c2' => 1,
				'f3e5' => 1,
			},
		},
		'rnbq1rk1/ppp1bppp/4pn2/4N3/2pP4/6P1/PP2PPBP/RNBQ1RK1 b -' => {
			eco => 'E05g',
			# TRANSLATORS: E05g: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Be7 6. O-O O-O 7. Ne5
			variation => N__('Catalan: Open, Classical, 7. Ne5'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bq1rk1/ppp1bppp/2n1pn2/4N3/2pP4/6P1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'E05g',
			# TRANSLATORS: E05g: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Be7 6. O-O O-O 7. Ne5 Nc6
			variation => N__('Catalan: Open, Classical, 7. Ne5'),
			moves => {
				'e5c6' => 1,
			},
		},
		'r1bq1rk1/ppp1bppp/2N1pn2/8/2pP4/6P1/PP2PPBP/RNBQ1RK1 b -' => {
			eco => 'E05h',
			# TRANSLATORS: E05h: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Be7 6. O-O O-O 7. Ne5 Nc6 8. Nxc6
			variation => N__('Catalan: Open, Classical, 7. Ne5 Nc6 8.Nxc6'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1bppp/4pn2/8/2pP4/5NP1/PPQ1PPBP/RNB2RK1 b -' => {
			eco => 'E05i',
			# TRANSLATORS: E05i: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Be7 6. O-O O-O 7. Qc2
			variation => N__('Catalan: Open, Classical, 7. Qc2'),
			moves => {
				'a7a6' => 1,
			},
		},
		'rnbq1rk1/1pp1bppp/p3pn2/8/2pP4/5NP1/PPQ1PPBP/RNB2RK1 w -' => {
			eco => 'E05j',
			# TRANSLATORS: E05j: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Be7 6. O-O O-O 7. Qc2 a6
			variation => N__('Catalan: Open, Classical Main Line'),
			moves => {
				'a2a4' => 1,
				'c2c4' => 1,
			},
		},
		'rnbq1rk1/1pp1bppp/p3pn2/8/P1pP4/5NP1/1PQ1PPBP/RNB2RK1 b -' => {
			eco => 'E05k',
			# TRANSLATORS: E05k: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Be7 6. O-O O-O 7. Qc2 a6 8. a4
			variation => N__('Catalan: Open, Classical, 8. a4'),
			moves => {
				'c8d7' => 1,
			},
		},
		'rn1q1rk1/1ppbbppp/p3pn2/8/P1pP4/5NP1/1PQ1PPBP/RNB2RK1 w -' => {
			eco => 'E05l',
			# TRANSLATORS: E05l: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Be7 6. O-O O-O 7. Qc2 a6 8. a4 Bd7
			variation => N__('Catalan: Open, Classical, 8. a4 Bd7'),
			moves => {
				'c2c4' => 1,
			},
		},
		'rn1q1rk1/1ppbbppp/p3pn2/8/P1QP4/5NP1/1P2PPBP/RNB2RK1 b -' => {
			eco => 'E05m',
			# TRANSLATORS: E05m: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Be7 6. O-O O-O 7. Qc2 a6 8. a4 Bd7 9. Qxc4
			variation => N__('Catalan: Open, Classical, 8. a4 Bd7 9.Qxc4'),
			moves => {
				'd7c6' => 1,
			},
		},
		'rn1q1rk1/1pp1bppp/p1b1pn2/8/P1QP4/5NP1/1P2PPBP/RNB2RK1 w -' => {
			eco => 'E05m',
			# TRANSLATORS: E05m: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Be7 6. O-O O-O 7. Qc2 a6 8. a4 Bd7 9. Qxc4 Bc6
			variation => N__('Catalan: Open, Classical, 8. a4 Bd7 9.Qxc4'),
			moves => {
				'c1g5' => 1,
			},
		},
		'rn1q1rk1/1pp1bppp/p1b1pn2/6B1/P1QP4/5NP1/1P2PPBP/RN3RK1 b -' => {
			eco => 'E05m',
			# TRANSLATORS: E05m: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Be7 6. O-O O-O 7. Qc2 a6 8. a4 Bd7 9. Qxc4 Bc6 10. Bg5
			variation => N__('Catalan: Open, Classical, 8. a4 Bd7 9.Qxc4'),
			moves => {
				'a6a5' => 1,
				'c6d5' => 1,
			},
		},
		'rn1q1rk1/1pp1bppp/p3pn2/3b2B1/P1QP4/5NP1/1P2PPBP/RN3RK1 w -' => {
			eco => 'E05n',
			# TRANSLATORS: E05n: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Be7 6. O-O O-O 7. Qc2 a6 8. a4 Bd7 9. Qxc4 Bc6 10. Bg5 Bd5
			variation => N__('Catalan: Open, Classical, 8. a4, 10. Bg5 Bd5'),
			moves => {
			},
		},
		'rn1q1rk1/1pp1bppp/2b1pn2/p5B1/P1QP4/5NP1/1P2PPBP/RN3RK1 w -' => {
			eco => 'E05o',
			# TRANSLATORS: E05o: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Be7 6. O-O O-O 7. Qc2 a6 8. a4 Bd7 9. Qxc4 Bc6 10. Bg5 a5
			variation => N__('Catalan: Open, Classical, 8. a4, 10. Bg5 a5'),
			moves => {
			},
		},
		'rnbq1rk1/1pp1bppp/p3pn2/8/2QP4/5NP1/PP2PPBP/RNB2RK1 b -' => {
			eco => 'E05p',
			# TRANSLATORS: E05p: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Be7 6. O-O O-O 7. Qc2 a6 8. Qxc4
			variation => N__('Catalan: Open, Classical, 8.Qxc4'),
			moves => {
				'b7b5' => 1,
			},
		},
		'rnbq1rk1/2p1bppp/p3pn2/1p6/2QP4/5NP1/PP2PPBP/RNB2RK1 w -' => {
			eco => 'E05p',
			# TRANSLATORS: E05p: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Be7 6. O-O O-O 7. Qc2 a6 8. Qxc4 b5
			variation => N__('Catalan: Open, Classical, 8.Qxc4'),
			moves => {
				'c4c2' => 1,
			},
		},
		'rnbq1rk1/2p1bppp/p3pn2/1p6/3P4/5NP1/PPQ1PPBP/RNB2RK1 b -' => {
			eco => 'E05p',
			# TRANSLATORS: E05p: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Be7 6. O-O O-O 7. Qc2 a6 8. Qxc4 b5 9. Qc2
			variation => N__('Catalan: Open, Classical, 8.Qxc4'),
			moves => {
				'c8b7' => 1,
			},
		},
		'rn1q1rk1/1bp1bppp/p3pn2/1p6/3P4/5NP1/PPQ1PPBP/RNB2RK1 w -' => {
			eco => 'E05q',
			# TRANSLATORS: E05q: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Be7 6. O-O O-O 7. Qc2 a6 8. Qxc4 b5 9. Qc2 Bb7
			variation => N__('Catalan: Open, Classical, 8.Qxc4 b5 9. Qc2 Bb7'),
			moves => {
				'c1d2' => 1,
				'c1f4' => 1,
				'c1g5' => 1,
			},
		},
		'rn1q1rk1/1bp1bppp/p3pn2/1p4B1/3P4/5NP1/PPQ1PPBP/RN3RK1 b -' => {
			eco => 'E05r',
			# TRANSLATORS: E05r: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Be7 6. O-O O-O 7. Qc2 a6 8. Qxc4 b5 9. Qc2 Bb7 10. Bg5
			variation => N__('Catalan: Open, Classical, 8.Qxc4, 10. Bg5'),
			moves => {
			},
		},
		'rn1q1rk1/1bp1bppp/p3pn2/1p6/3P4/5NP1/PPQBPPBP/RN3RK1 b -' => {
			eco => 'E05s',
			# TRANSLATORS: E05s: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Be7 6. O-O O-O 7. Qc2 a6 8. Qxc4 b5 9. Qc2 Bb7 10. Bd2
			variation => N__('Catalan: Open, Classical, 8.Qxc4, 10. Bd2'),
			moves => {
				'b7e4' => 1,
			},
		},
		'rn1q1rk1/2p1bppp/p3pn2/1p6/3Pb3/5NP1/PPQBPPBP/RN3RK1 w -' => {
			eco => 'E05t',
			# TRANSLATORS: E05t: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Be7 6. O-O O-O 7. Qc2 a6 8. Qxc4 b5 9. Qc2 Bb7 10. Bd2 Be4
			variation => N__('Catalan: Open, Classical, 8.Qxc4, 10. Bd2 Be4'),
			moves => {
			},
		},
		'rn1q1rk1/1bp1bppp/p3pn2/1p6/3P1B2/5NP1/PPQ1PPBP/RN3RK1 b -' => {
			eco => 'E05u',
			# TRANSLATORS: E05u: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Be7 6. O-O O-O 7. Qc2 a6 8. Qxc4 b5 9. Qc2 Bb7 10. Bf4
			variation => N__('Catalan: Open, Classical, 8.Qxc4, 10. Bf4'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r2q1rk1/1bp1bppp/p1n1pn2/1p6/3P1B2/5NP1/PPQ1PPBP/RN3RK1 w -' => {
			eco => 'E05v',
			# TRANSLATORS: E05v: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Be7 6. O-O O-O 7. Qc2 a6 8. Qxc4 b5 9. Qc2 Bb7 10. Bf4 Nc6
			variation => N__('Catalan: Open, Classical, 8.Qxc4, 10. Bf4 Nc6'),
			moves => {
				'f1d1' => 1,
			},
		},
		'r2q1rk1/1bp1bppp/p1n1pn2/1p6/3P1B2/5NP1/PPQ1PPBP/RN1R2K1 b -' => {
			eco => 'E05v',
			# TRANSLATORS: E05v: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 dxc4 5. Nf3 Be7 6. O-O O-O 7. Qc2 a6 8. Qxc4 b5 9. Qc2 Bb7 10. Bf4 Nc6 11. Rd1
			variation => N__('Catalan: Open, Classical, 8.Qxc4, 10. Bf4 Nc6 11. Rd1'),
			moves => {
			},
		},
		'rnbqk2r/ppp1bppp/4pn2/3p4/2PP4/6P1/PP2PPBP/RNBQK1NR w KQkq' => {
			eco => 'E06',
			# TRANSLATORS: E06: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7
			variation => N__('Catalan: Closed'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqk2r/ppp1bppp/4pn2/3p4/2PP4/5NP1/PP2PPBP/RNBQK2R b KQkq' => {
			eco => 'E06',
			# TRANSLATORS: E06: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3
			variation => N__('Catalan: Closed, 5. Nf3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppp1bppp/4pn2/3p4/2PP4/5NP1/PP2PPBP/RNBQK2R w KQ' => {
			eco => 'E06',
			# TRANSLATORS: E06: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O
			variation => N__('Catalan: Closed, 5. Nf3 O-O'),
			moves => {
				'd1c2' => 1,
				'e1g1' => 1,
			},
		},
		'rnbq1rk1/ppp1bppp/4pn2/3p4/2PP4/5NP1/PPQ1PPBP/RNB1K2R b KQ' => {
			eco => 'E06',
			# TRANSLATORS: E06: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. Qc2
			variation => N__('Catalan: Closed, 6. Qc2'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1bppp/4pn2/3p4/2PP4/5NP1/PP2PPBP/RNBQ1RK1 b -' => {
			eco => 'E06',
			# TRANSLATORS: E06: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O
			variation => N__('Catalan: Closed, 6.O-O'),
			moves => {
				'b8d7' => 1,
				'c7c5' => 1,
				'c7c6' => 1,
			},
		},
		'rnbq1rk1/pp2bppp/4pn2/2pp4/2PP4/5NP1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'E06',
			# TRANSLATORS: E06: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O c5
			variation => N__('Catalan: Closed, 6.O-O c5'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rnbq1rk1/pp2bppp/4pn2/2pP4/3P4/5NP1/PP2PPBP/RNBQ1RK1 b -' => {
			eco => 'E06',
			# TRANSLATORS: E06: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O c5 7. cxd5
			variation => N__('Catalan: Closed, 6.O-O c5 7.cxd5'),
			moves => {
			},
		},
		'rnbq1rk1/pp2bppp/2p1pn2/3p4/2PP4/5NP1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'E06',
			# TRANSLATORS: E06: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O c6
			variation => N__('Catalan: Closed, 6.O-O c6'),
			moves => {
				'b1c3' => 1,
				'b1d2' => 1,
				'b2b3' => 1,
				'd1c2' => 1,
			},
		},
		'rnbq1rk1/pp2bppp/2p1pn2/3p4/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'E06',
			# TRANSLATORS: E06: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O c6 7. Nc3
			variation => N__('Catalan: Closed, 6.O-O c6 7. Nc3'),
			moves => {
				'b7b6' => 1,
			},
		},
		'rnbq1rk1/p3bppp/1pp1pn2/3p4/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'E06',
			# TRANSLATORS: E06: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O c6 7. Nc3 b6
			variation => N__('Catalan: Closed, 6.O-O c6 7. Nc3 b6'),
			moves => {
				'f3e5' => 1,
			},
		},
		'rnbq1rk1/p3bppp/1pp1pn2/3pN3/2PP4/2N3P1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'E06',
			# TRANSLATORS: E06: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O c6 7. Nc3 b6 8. Ne5
			variation => N__('Catalan: Closed, 6.O-O c6 7. Nc3 b6 8. Ne5'),
			moves => {
			},
		},
		'rnbq1rk1/pp2bppp/2p1pn2/3p4/2PP4/5NP1/PP1NPPBP/R1BQ1RK1 b -' => {
			eco => 'E06',
			# TRANSLATORS: E06: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O c6 7. Nbd2
			variation => N__('Catalan: Closed, 6.O-O c6 7.Nbd2'),
			moves => {
			},
		},
		'rnbq1rk1/pp2bppp/2p1pn2/3p4/2PP4/1P3NP1/P3PPBP/RNBQ1RK1 b -' => {
			eco => 'E06',
			# TRANSLATORS: E06: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O c6 7. b3
			variation => N__('Catalan: Closed, 6.O-O c6 7. b3'),
			moves => {
			},
		},
		'rnbq1rk1/pp2bppp/2p1pn2/3p4/2PP4/5NP1/PPQ1PPBP/RNB2RK1 b -' => {
			eco => 'E06',
			# TRANSLATORS: E06: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O c6 7. Qc2
			variation => N__('Catalan: Closed, 6.O-O c6 7. Qc2'),
			moves => {
				'b7b6' => 1,
			},
		},
		'rnbq1rk1/p3bppp/1pp1pn2/3p4/2PP4/5NP1/PPQ1PPBP/RNB2RK1 w -' => {
			eco => 'E06',
			# TRANSLATORS: E06: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O c6 7. Qc2 b6
			variation => N__('Catalan: Closed, 6.O-O c6 7. Qc2 b6'),
			moves => {
			},
		},
		'r1bq1rk1/pppnbppp/4pn2/3p4/2PP4/5NP1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'E07',
			# TRANSLATORS: E07: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7
			variation => N__('Catalan: Closed, 6...Nbd7'),
			moves => {
				'b1c3' => 1,
				'b1d2' => 1,
				'b2b3' => 1,
				'd1c2' => 1,
				'd1d3' => 1,
			},
		},
		'r1bq1rk1/pppnbppp/4pn2/3p4/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'E07',
			# TRANSLATORS: E07: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Nc3
			variation => N__('Catalan: Closed, 6...Nbd7 7. Nc3'),
			moves => {
				'c7c6' => 1,
				'd5c4' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/2p1pn2/3p4/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'E07',
			# TRANSLATORS: E07: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Nc3 c6
			variation => N__('Catalan: Closed, 6...Nbd7 7. Nc3 c6'),
			moves => {
				'b2b3' => 1,
				'd1b3' => 1,
				'd1d3' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/2p1pn2/3p4/2PP4/1PN2NP1/P3PPBP/R1BQ1RK1 b -' => {
			eco => 'E07',
			# TRANSLATORS: E07: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Nc3 c6 8. b3
			variation => N__('Catalan: Closed, 6...Nbd7 7. Nc3 c6 8. b3'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nbppp/2p1pn2/3p4/2PP4/1QN2NP1/PP2PPBP/R1B2RK1 b -' => {
			eco => 'E07',
			# TRANSLATORS: E07: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Nc3 c6 8. Qb3
			variation => N__('Catalan: Closed, 6...Nbd7 7. Nc3 c6 8. Qb3'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nbppp/2p1pn2/3p4/2PP4/2NQ1NP1/PP2PPBP/R1B2RK1 b -' => {
			eco => 'E07',
			# TRANSLATORS: E07: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Nc3 c6 8. Qd3
			variation => N__('Catalan: Closed, Botvinnik Variation'),
			moves => {
			},
		},
		'r1bq1rk1/pppnbppp/4pn2/8/2pP4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'E07',
			# TRANSLATORS: E07: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Nc3 dxc4
			variation => N__('Catalan: Closed, 6...Nbd7 7. Nc3 dxc4'),
			moves => {
				'e2e4' => 1,
			},
		},
		'r1bq1rk1/pppnbppp/4pn2/8/2pPP3/2N2NP1/PP3PBP/R1BQ1RK1 b -' => {
			eco => 'E07',
			# TRANSLATORS: E07: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Nc3 dxc4 8. e4
			variation => N__('Catalan: Closed, 6...Nbd7 7. Nc3 dxc4'),
			moves => {
			},
		},
		'r1bq1rk1/pppnbppp/4pn2/3p4/2PP4/5NP1/PP1NPPBP/R1BQ1RK1 b -' => {
			eco => 'E07',
			# TRANSLATORS: E07: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Nbd2
			variation => N__('Catalan: Closed, 6...Nbd7 7.Nbd2'),
			moves => {
			},
		},
		'r1bq1rk1/pppnbppp/4pn2/3p4/2PP4/1P3NP1/P3PPBP/RNBQ1RK1 b -' => {
			eco => 'E07',
			# TRANSLATORS: E07: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. b3
			variation => N__('Catalan: Closed, 6...Nbd7 7. b3'),
			moves => {
				'c7c6' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/2p1pn2/3p4/2PP4/1P3NP1/P3PPBP/RNBQ1RK1 w -' => {
			eco => 'E07',
			# TRANSLATORS: E07: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. b3 c6
			variation => N__('Catalan: Closed, 6...Nbd7 7. b3'),
			moves => {
				'c1a3' => 1,
				'c1b2' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/2p1pn2/3p4/2PP4/BP3NP1/P3PPBP/RN1Q1RK1 b -' => {
			eco => 'E07',
			# TRANSLATORS: E07: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. b3 c6 8. Ba3
			variation => N__('Catalan: Closed, 6...Nbd7 7. b3'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nbppp/2p1pn2/3p4/2PP4/1P3NP1/PB2PPBP/RN1Q1RK1 b -' => {
			eco => 'E07',
			# TRANSLATORS: E07: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. b3 c6 8. Bb2
			variation => N__('Catalan: Closed, 6...Nbd7 7. b3'),
			moves => {
			},
		},
		'r1bq1rk1/pppnbppp/4pn2/3p4/2PP4/3Q1NP1/PP2PPBP/RNB2RK1 b -' => {
			eco => 'E07',
			# TRANSLATORS: E07: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qd3
			variation => N__('Catalan: Closed, 6...Nbd7 7. Qd3'),
			moves => {
			},
		},
		'r1bq1rk1/pppnbppp/4pn2/3p4/2PP4/5NP1/PPQ1PPBP/RNB2RK1 b -' => {
			eco => 'E08a',
			# TRANSLATORS: E08a: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2
			variation => N__('Catalan: Closed, 7. Qc2'),
			moves => {
				'b7b6' => 1,
				'c7c5' => 1,
				'c7c6' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/4pn2/2pp4/2PP4/5NP1/PPQ1PPBP/RNB2RK1 w -' => {
			eco => 'E08b',
			# TRANSLATORS: E08b: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c5
			variation => N__('Catalan: Closed, 7. Qc2 c5'),
			moves => {
			},
		},
		'r1bq1rk1/p1pnbppp/1p2pn2/3p4/2PP4/5NP1/PPQ1PPBP/RNB2RK1 w -' => {
			eco => 'E08c',
			# TRANSLATORS: E08c: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 b6
			variation => N__('Catalan: Closed, 7. Qc2 b6'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nbppp/2p1pn2/3p4/2PP4/5NP1/PPQ1PPBP/RNB2RK1 w -' => {
			eco => 'E08d',
			# TRANSLATORS: E08d: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6
			variation => N__('Catalan: Closed, 7. Qc2 c6'),
			moves => {
				'b1d2' => 1,
				'b2b3' => 1,
				'c1f4' => 1,
				'f1d1' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/2p1pn2/3p4/2PP4/5NP1/PPQ1PPBP/RNBR2K1 b -' => {
			eco => 'E08e',
			# TRANSLATORS: E08e: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. Rd1
			variation => N__('Catalan: Closed, 7. Qc2 c6 8. Rd1'),
			moves => {
				'b7b6' => 1,
			},
		},
		'r1bq1rk1/p2nbppp/1pp1pn2/3p4/2PP4/5NP1/PPQ1PPBP/RNBR2K1 w -' => {
			eco => 'E08f',
			# TRANSLATORS: E08f: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. Rd1 b6
			variation => N__('Catalan: Closed, 7. Qc2 c6 8. Rd1 b6'),
			moves => {
				'a2a4' => 1,
			},
		},
		'r1bq1rk1/p2nbppp/1pp1pn2/3p4/P1PP4/5NP1/1PQ1PPBP/RNBR2K1 b -' => {
			eco => 'E08f',
			# TRANSLATORS: E08f: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. Rd1 b6 9. a4
			variation => N__('Catalan: Closed, Zagoryansky Variation'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nbppp/2p1pn2/3p4/2PP1B2/5NP1/PPQ1PPBP/RN3RK1 b -' => {
			eco => 'E08g',
			# TRANSLATORS: E08g: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. Bf4
			variation => N__('Catalan: Closed, 7. Qc2 c6 8. Bf4'),
			moves => {
				'b7b6' => 1,
				'f6e4' => 1,
				'f6h5' => 1,
			},
		},
		'r1bq1rk1/pp1nbppp/2p1p3/3p3n/2PP1B2/5NP1/PPQ1PPBP/RN3RK1 w -' => {
			eco => 'E08h',
			# TRANSLATORS: E08h: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. Bf4 Nh5
			variation => N__('Catalan: Closed, 7. Qc2 c6 8. Bf4 Nh5'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nbppp/2p1p3/3p4/2PPnB2/5NP1/PPQ1PPBP/RN3RK1 w -' => {
			eco => 'E08i',
			# TRANSLATORS: E08i: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. Bf4 Ne4
			variation => N__('Catalan: Closed, 7. Qc2 c6 8. Bf4 Ne4'),
			moves => {
			},
		},
		'r1bq1rk1/p2nbppp/1pp1pn2/3p4/2PP1B2/5NP1/PPQ1PPBP/RN3RK1 w -' => {
			eco => 'E08j',
			# TRANSLATORS: E08j: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. Bf4 b6
			variation => N__('Catalan: Closed, 7. Qc2 c6 8. Bf4 b6'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nbppp/2p1pn2/3p4/2PP4/1P3NP1/P1Q1PPBP/RNB2RK1 b -' => {
			eco => 'E08k',
			# TRANSLATORS: E08k: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. b3
			variation => N__('Catalan: Closed, 7. Qc2 c6 8. b3'),
			moves => {
				'b7b5' => 1,
				'b7b6' => 1,
			},
		},
		'r1bq1rk1/p2nbppp/2p1pn2/1p1p4/2PP4/1P3NP1/P1Q1PPBP/RNB2RK1 w -' => {
			eco => 'E08l',
			# TRANSLATORS: E08l: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. b3 b5
			variation => N__('Catalan: Closed, 7. Qc2 c6 8. b3 b5'),
			moves => {
			},
		},
		'r1bq1rk1/p2nbppp/1pp1pn2/3p4/2PP4/1P3NP1/P1Q1PPBP/RNB2RK1 w -' => {
			eco => 'E08m',
			# TRANSLATORS: E08m: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. b3 b6
			variation => N__('Catalan: Closed, 7. Qc2 c6 8. b3 b6'),
			moves => {
				'f1d1' => 1,
			},
		},
		'r1bq1rk1/p2nbppp/1pp1pn2/3p4/2PP4/1P3NP1/P1Q1PPBP/RNBR2K1 b -' => {
			eco => 'E08n',
			# TRANSLATORS: E08n: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. b3 b6 9. Rd1
			variation => N__('Catalan: Closed, 7. Qc2 c6 8. b3 b6 9. Rd1'),
			moves => {
				'c8a6' => 1,
				'c8b7' => 1,
			},
		},
		'r2q1rk1/p2nbppp/bpp1pn2/3p4/2PP4/1P3NP1/P1Q1PPBP/RNBR2K1 w -' => {
			eco => 'E08n',
			# TRANSLATORS: E08n: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. b3 b6 9. Rd1 Ba6
			variation => N__('Catalan: Closed, 7. Qc2 c6 8. b3 b6 9. Rd1 Ba6'),
			moves => {
				'b1d2' => 1,
			},
		},
		'r2q1rk1/p2nbppp/bpp1pn2/3p4/2PP4/1P3NP1/P1QNPPBP/R1BR2K1 b -' => {
			eco => 'E08o',
			# TRANSLATORS: E08o: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. b3 b6 9. Rd1 Ba6 10. Nbd2
			variation => N__('Catalan: Closed, 7. Qc2 c6 8. b3 b6 9. Rd1 Ba6 10.Nbd2'),
			moves => {
			},
		},
		'r2q1rk1/pb1nbppp/1pp1pn2/3p4/2PP4/1P3NP1/P1Q1PPBP/RNBR2K1 w -' => {
			eco => 'E08p',
			# TRANSLATORS: E08p: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. b3 b6 9. Rd1 Bb7
			variation => N__('Catalan: Closed, 7. Qc2 c6 8. b3 b6 9. Rd1 Bb7'),
			moves => {
				'b1c3' => 1,
			},
		},
		'r2q1rk1/pb1nbppp/1pp1pn2/3p4/2PP4/1PN2NP1/P1Q1PPBP/R1BR2K1 b -' => {
			eco => 'E08p',
			# TRANSLATORS: E08p: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. b3 b6 9. Rd1 Bb7 10. Nc3
			variation => N__('Catalan: Closed, 7. Qc2 c6 8. b3 b6 9. Rd1 Bb7 10. Nc3'),
			moves => {
				'a8c8' => 1,
				'b6b5' => 1,
			},
		},
		'r2q1rk1/pb1nbppp/2p1pn2/1p1p4/2PP4/1PN2NP1/P1Q1PPBP/R1BR2K1 w -' => {
			eco => 'E08p',
			# TRANSLATORS: E08p: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. b3 b6 9. Rd1 Bb7 10. Nc3 b5
			variation => N__('Catalan: Closed, Spassky Gambit'),
			moves => {
			},
		},
		'2rq1rk1/pb1nbppp/1pp1pn2/3p4/2PP4/1PN2NP1/P1Q1PPBP/R1BR2K1 w -' => {
			eco => 'E08q',
			# TRANSLATORS: E08q: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. b3 b6 9. Rd1 Bb7 10. Nc3 Rc8
			variation => N__('Catalan: Closed, 7. Qc2 c6 8. b3 b6 9. Rd1 Bb7 10. Nc3 Rc8'),
			moves => {
				'e2e4' => 1,
			},
		},
		'2rq1rk1/pb1nbppp/1pp1pn2/3p4/2PPP3/1PN2NP1/P1Q2PBP/R1BR2K1 b -' => {
			eco => 'E08q',
			# TRANSLATORS: E08q: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. b3 b6 9. Rd1 Bb7 10. Nc3 Rc8 11. e4
			variation => N__('Catalan: Closed, 7. Qc2 c6 8. b3 b6 9. Rd1 Bb7 10. Nc3 Rc8 11. e4'),
			moves => {
				'd5e4' => 1,
			},
		},
		'2rq1rk1/pb1nbppp/1pp1pn2/8/2PPp3/1PN2NP1/P1Q2PBP/R1BR2K1 w -' => {
			eco => 'E08r',
			# TRANSLATORS: E08r: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. b3 b6 9. Rd1 Bb7 10. Nc3 Rc8 11. e4 dxe4
			variation => N__('Catalan: Closed, 7. Qc2 c6 8. b3 b6 9. Rd1 Bb7 10. Nc3 Rc8 11. e4 dxe4'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nbppp/2p1pn2/3p4/2PP4/5NP1/PPQNPPBP/R1B2RK1 b -' => {
			eco => 'E09a',
			# TRANSLATORS: E09a: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. Nbd2
			variation => N__('Catalan: Closed, Main Line'),
			moves => {
				'b7b5' => 1,
				'b7b6' => 1,
				'f8e8' => 1,
			},
		},
		'r1bq1rk1/p2nbppp/2p1pn2/1p1p4/2PP4/5NP1/PPQNPPBP/R1B2RK1 w -' => {
			eco => 'E09b',
			# TRANSLATORS: E09b: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. Nbd2 b5
			variation => N__('Catalan: Closed, Main Line, 8... b5'),
			moves => {
			},
		},
		'r1bqr1k1/pp1nbppp/2p1pn2/3p4/2PP4/5NP1/PPQNPPBP/R1B2RK1 w -' => {
			eco => 'E09c',
			# TRANSLATORS: E09c: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. Nbd2 Re8
			variation => N__('Catalan: Closed, Main Line, 8... Re8'),
			moves => {
			},
		},
		'r1bq1rk1/p2nbppp/1pp1pn2/3p4/2PP4/5NP1/PPQNPPBP/R1B2RK1 w -' => {
			eco => 'E09d',
			# TRANSLATORS: E09d: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. Nbd2 b6
			variation => N__('Catalan: Closed, Main Line, 8... b6'),
			moves => {
				'b2b3' => 1,
				'e2e4' => 1,
			},
		},
		'r1bq1rk1/p2nbppp/1pp1pn2/3p4/2PP4/1P3NP1/P1QNPPBP/R1B2RK1 b -' => {
			eco => 'E09e',
			# TRANSLATORS: E09e: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. Nbd2 b6 9. b3
			variation => N__('Catalan: Closed, Main Line, 9. b3'),
			moves => {
				'a7a5' => 1,
				'c8b7' => 1,
			},
		},
		'r1bq1rk1/3nbppp/1pp1pn2/p2p4/2PP4/1P3NP1/P1QNPPBP/R1B2RK1 w -' => {
			eco => 'E09e',
			# TRANSLATORS: E09e: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. Nbd2 b6 9. b3 a5
			variation => N__('Catalan: Closed, Main Line, 9. b3'),
			moves => {
				'c1b2' => 1,
			},
		},
		'r1bq1rk1/3nbppp/1pp1pn2/p2p4/2PP4/1P3NP1/PBQNPPBP/R4RK1 b -' => {
			eco => 'E09e',
			# TRANSLATORS: E09e: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. Nbd2 b6 9. b3 a5 10. Bb2
			variation => N__('Catalan: Closed, Main Line, 9. b3'),
			moves => {
				'c8a6' => 1,
			},
		},
		'r2q1rk1/3nbppp/bpp1pn2/p2p4/2PP4/1P3NP1/PBQNPPBP/R4RK1 w -' => {
			eco => 'E09e',
			# TRANSLATORS: E09e: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. Nbd2 b6 9. b3 a5 10. Bb2 Ba6
			variation => N__('Catalan: Closed, Main Line, Sokolsky Variation'),
			moves => {
			},
		},
		'r2q1rk1/pb1nbppp/1pp1pn2/3p4/2PP4/1P3NP1/P1QNPPBP/R1B2RK1 w -' => {
			eco => 'E09e',
			# TRANSLATORS: E09e: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. Nbd2 b6 9. b3 Bb7
			variation => N__('Catalan: Closed, Main Line, 9. b3 Bb7'),
			moves => {
				'c1b2' => 1,
			},
		},
		'r2q1rk1/pb1nbppp/1pp1pn2/3p4/2PP4/1P3NP1/PBQNPPBP/R4RK1 b -' => {
			eco => 'E09f',
			# TRANSLATORS: E09f: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. Nbd2 b6 9. b3 Bb7 10. Bb2
			variation => N__('Catalan: Closed, Main Line, 9. b3 Bb7 10. Bb2'),
			moves => {
				'a8c8' => 1,
			},
		},
		'2rq1rk1/pb1nbppp/1pp1pn2/3p4/2PP4/1P3NP1/PBQNPPBP/R4RK1 w -' => {
			eco => 'E09g',
			# TRANSLATORS: E09g: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. Nbd2 b6 9. b3 Bb7 10. Bb2 Rc8
			variation => N__('Catalan: Closed, Main Line, 9. b3 Bb7 10. Bb2 Rc8'),
			moves => {
			},
		},
		'r1bq1rk1/p2nbppp/1pp1pn2/3p4/2PPP3/5NP1/PPQN1PBP/R1B2RK1 b -' => {
			eco => 'E09h',
			# TRANSLATORS: E09h: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. Nbd2 b6 9. e4
			variation => N__('Catalan: Closed, Main Line, 9. e4'),
			moves => {
				'c8a6' => 1,
				'c8b7' => 1,
				'd5e4' => 1,
			},
		},
		'r2q1rk1/p2nbppp/bpp1pn2/3p4/2PPP3/5NP1/PPQN1PBP/R1B2RK1 w -' => {
			eco => 'E09i',
			# TRANSLATORS: E09i: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. Nbd2 b6 9. e4 Ba6
			variation => N__('Catalan: Closed, Main Line, 9. e4 Ba6'),
			moves => {
				'b2b3' => 1,
			},
		},
		'r2q1rk1/p2nbppp/bpp1pn2/3p4/2PPP3/1P3NP1/P1QN1PBP/R1B2RK1 b -' => {
			eco => 'E09i',
			# TRANSLATORS: E09i: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. Nbd2 b6 9. e4 Ba6 10. b3
			variation => N__('Catalan: Closed, Main Line, 9. e4 Ba6 10. b3'),
			moves => {
			},
		},
		'r1bq1rk1/p2nbppp/1pp1pn2/8/2PPp3/5NP1/PPQN1PBP/R1B2RK1 w -' => {
			eco => 'E09j',
			# TRANSLATORS: E09j: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. Nbd2 b6 9. e4 dxe4
			variation => N__('Catalan: Closed, Main Line, 9. e4 dxe4'),
			moves => {
				'd2e4' => 1,
			},
		},
		'r1bq1rk1/p2nbppp/1pp1pn2/8/2PPN3/5NP1/PPQ2PBP/R1B2RK1 b -' => {
			eco => 'E09j',
			# TRANSLATORS: E09j: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. Nbd2 b6 9. e4 dxe4 10. Nxe4
			variation => N__('Catalan: Closed, Main Line, 9. e4 dxe4'),
			moves => {
				'f6e4' => 1,
			},
		},
		'r1bq1rk1/p2nbppp/1pp1p3/8/2PPn3/5NP1/PPQ2PBP/R1B2RK1 w -' => {
			eco => 'E09j',
			# TRANSLATORS: E09j: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. Nbd2 b6 9. e4 dxe4 10. Nxe4 Nxe4
			variation => N__('Catalan: Closed, Main Line, 9. e4 dxe4'),
			moves => {
				'c2e4' => 1,
			},
		},
		'r1bq1rk1/p2nbppp/1pp1p3/8/2PPQ3/5NP1/PP3PBP/R1B2RK1 b -' => {
			eco => 'E09k',
			# TRANSLATORS: E09k: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. Nbd2 b6 9. e4 dxe4 10. Nxe4 Nxe4 11. Qxe4
			variation => N__('Catalan: Closed, Main Line, 9. e4 dxe4 10.Nxe4 Nxe4 11.Qxe4'),
			moves => {
			},
		},
		'r2q1rk1/pb1nbppp/1pp1pn2/3p4/2PPP3/5NP1/PPQN1PBP/R1B2RK1 w -' => {
			eco => 'E09l',
			# TRANSLATORS: E09l: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. Nbd2 b6 9. e4 Bb7
			variation => N__('Catalan: Closed, Main Line, 9. e4 Bb7'),
			moves => {
				'b2b3' => 1,
				'e4e5' => 1,
			},
		},
		'r2q1rk1/pb1nbppp/1pp1pn2/3pP3/2PP4/5NP1/PPQN1PBP/R1B2RK1 b -' => {
			eco => 'E09m',
			# TRANSLATORS: E09m: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. Nbd2 b6 9. e4 Bb7 10. e5
			variation => N__('Catalan: Closed, Main Line, 9. e4 Bb7 10. e5'),
			moves => {
			},
		},
		'r2q1rk1/pb1nbppp/1pp1pn2/3p4/2PPP3/1P3NP1/P1QN1PBP/R1B2RK1 b -' => {
			eco => 'E09n',
			# TRANSLATORS: E09n: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. Nbd2 b6 9. e4 Bb7 10. b3
			variation => N__('Catalan: Closed, Main Line, 9. e4 Bb7 10. b3'),
			moves => {
				'a8c8' => 1,
			},
		},
		'2rq1rk1/pb1nbppp/1pp1pn2/3p4/2PPP3/1P3NP1/P1QN1PBP/R1B2RK1 w -' => {
			eco => 'E09n',
			# TRANSLATORS: E09n: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. Nbd2 b6 9. e4 Bb7 10. b3 Rc8
			variation => N__('Catalan: Closed, Main Line, 9. e4 Bb7 10. b3'),
			moves => {
				'c1b2' => 1,
			},
		},
		'2rq1rk1/pb1nbppp/1pp1pn2/3p4/2PPP3/1P3NP1/PBQN1PBP/R4RK1 b -' => {
			eco => 'E09o',
			# TRANSLATORS: E09o: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. Nbd2 b6 9. e4 Bb7 10. b3 Rc8 11. Bb2
			variation => N__('Catalan: Closed, Main Line, 9. e4 Bb7 10. b3 Rc8 11. Bb2'),
			moves => {
				'c6c5' => 1,
				'd8c7' => 1,
			},
		},
		'2r2rk1/pbqnbppp/1pp1pn2/3p4/2PPP3/1P3NP1/PBQN1PBP/R4RK1 w -' => {
			eco => 'E09p',
			# TRANSLATORS: E09p: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. Nbd2 b6 9. e4 Bb7 10. b3 Rc8 11. Bb2 Qc7
			variation => N__('Catalan: Closed, Main Line, 9. e4 Bb7 10. b3 Rc8 11. Bb2 Qc7'),
			moves => {
			},
		},
		'2rq1rk1/pb1nbppp/1p2pn2/2pp4/2PPP3/1P3NP1/PBQN1PBP/R4RK1 w -' => {
			eco => 'E09q',
			# TRANSLATORS: E09q: 1. d4 Nf6 2. c4 e6 3. g3 d5 4. Bg2 Be7 5. Nf3 O-O 6. O-O Nbd7 7. Qc2 c6 8. Nbd2 b6 9. e4 Bb7 10. b3 Rc8 11. Bb2 c5
			variation => N__('Catalan: Closed, Main Line, 9. e4 Bb7 10. b3 Rc8 11. Bb2 c5'),
			moves => {
			},
		},
		'rnbqkb1r/pppp1ppp/4pn2/8/2PP4/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'E10a',
			# TRANSLATORS: E10a: 1. d4 Nf6 2. c4 e6 3. Nf3
			variation => N__('Neo-Indian: 3. Nf3'),
			moves => {
				'a7a6' => 1,
				'b7b6' => 1,
				'c7c5' => 1,
				'f6e4' => 1,
				'f8b4' => 1,
				'f8e7' => 1,
			},
		},
		'rnbqkb1r/pppp1ppp/4p3/8/2PPn3/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'E10b',
			# TRANSLATORS: E10b: 1. d4 Nf6 2. c4 e6 3. Nf3 Ne4
			variation => N__('Neo-Indian: Döry Defence'),
			moves => {
			},
		},
		'rnbqk2r/ppppbppp/4pn2/8/2PP4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'E10c',
			# TRANSLATORS: E10c: 1. d4 Nf6 2. c4 e6 3. Nf3 Be7
			variation => N__('Neo-Indian: 3. Nf3 Be7'),
			moves => {
			},
		},
		'rnbqkb1r/1ppp1ppp/p3pn2/8/2PP4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'E10d',
			# TRANSLATORS: E10d: 1. d4 Nf6 2. c4 e6 3. Nf3 a6
			variation => N__('Neo-Indian: 3. Nf3 a6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbqkb1r/1ppp1ppp/p3pn2/8/2PP4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'E10e',
			# TRANSLATORS: E10e: 1. d4 Nf6 2. c4 e6 3. Nf3 a6 4. Nc3
			variation => N__('Neo-Indian: 3. Nf3 a6 4. Nc3'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqkb1r/1p1p1ppp/p3pn2/2p5/2PP4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'E10f',
			# TRANSLATORS: E10f: 1. d4 Nf6 2. c4 e6 3. Nf3 a6 4. Nc3 c5
			variation => N__('Neo-Indian: 3. Nf3 a6 4. Nc3 c5'),
			moves => {
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/2p5/2PP4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'E10g',
			# TRANSLATORS: E10g: 1. d4 Nf6 2. c4 e6 3. Nf3 c5
			variation => N__('Neo-Indian: Blumenfeld/Benoni'),
			moves => {
				'd4d5' => 1,
				'e2e3' => 1,
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/2p5/2PP4/4PN2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'E10h',
			# TRANSLATORS: E10h: 1. d4 Nf6 2. c4 e6 3. Nf3 c5 4. e3
			variation => N__('Neo-Indian: Blumenfeld/Benoni, 4. e3'),
			moves => {
				'b7b6' => 1,
				'c5d4' => 1,
			},
		},
		'rnbqkb1r/p2p1ppp/1p2pn2/2p5/2PP4/4PN2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'E10i',
			# TRANSLATORS: E10i: 1. d4 Nf6 2. c4 e6 3. Nf3 c5 4. e3 b6
			variation => N__('Neo-Indian: Blumenfeld/Benoni, 4. e3 b6'),
			moves => {
			},
		},
		'rnbqkb1r/pp1p1ppp/4pn2/8/2Pp4/4PN2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'E10j',
			# TRANSLATORS: E10j: 1. d4 Nf6 2. c4 e6 3. Nf3 c5 4. e3 cxd4
			variation => N__('Neo-Indian: Blumenfeld/Benoni, 4. e3 cxd4'),
			moves => {
			},
		},
		'rnbqkb1r/p2p1ppp/4pn2/1ppP4/2P5/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'E10k',
			# TRANSLATORS: E10k: 1. d4 Nf6 2. c4 e6 3. Nf3 c5 4. d5 b5
			variation => N__('Blumenfeld Countergambit'),
			moves => {
				'c1g5' => 1,
				'd5e6' => 1,
			},
		},
		'rnbqkb1r/p2p1ppp/4Pn2/1pp5/2P5/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'E10k',
			# TRANSLATORS: E10k: 1. d4 Nf6 2. c4 e6 3. Nf3 c5 4. d5 b5 5. dxe6
			variation => N__('Blumenfeld: 5.dxe6'),
			moves => {
				'f7e6' => 1,
			},
		},
		'rnbqkb1r/p2p2pp/4pn2/1pp5/2P5/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'E10k',
			# TRANSLATORS: E10k: 1. d4 Nf6 2. c4 e6 3. Nf3 c5 4. d5 b5 5. dxe6 fxe6
			variation => N__('Blumenfeld: 5.dxe6'),
			moves => {
				'c4b5' => 1,
			},
		},
		'rnbqkb1r/p2p2pp/4pn2/1Pp5/8/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'E10k',
			# TRANSLATORS: E10k: 1. d4 Nf6 2. c4 e6 3. Nf3 c5 4. d5 b5 5. dxe6 fxe6 6. cxb5
			variation => N__('Blumenfeld: 5.dxe6 fxe6 6.cxb5'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqkb1r/p5pp/4pn2/1Ppp4/8/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'E10l',
			# TRANSLATORS: E10l: 1. d4 Nf6 2. c4 e6 3. Nf3 c5 4. d5 b5 5. dxe6 fxe6 6. cxb5 d5
			variation => N__('Blumenfeld: 5.dxe6 fxe6 6.cxb5 d5'),
			moves => {
			},
		},
		'rnbqkb1r/p2p1ppp/4pn2/1ppP2B1/2P5/5N2/PP2PPPP/RN1QKB1R b KQkq' => {
			eco => 'E10m',
			# TRANSLATORS: E10m: 1. d4 Nf6 2. c4 e6 3. Nf3 c5 4. d5 b5 5. Bg5
			variation => N__('Blumenfeld: 5. Bg5'),
			moves => {
				'd8a5' => 1,
				'e6d5' => 1,
				'h7h6' => 1,
			},
		},
		'rnbqkb1r/p2p1pp1/4pn1p/1ppP2B1/2P5/5N2/PP2PPPP/RN1QKB1R w KQkq' => {
			eco => 'E10n',
			# TRANSLATORS: E10n: 1. d4 Nf6 2. c4 e6 3. Nf3 c5 4. d5 b5 5. Bg5 h6
			variation => N__('Blumenfeld: 5. Bg5 h6'),
			moves => {
			},
		},
		'rnb1kb1r/p2p1ppp/4pn2/qppP2B1/2P5/5N2/PP2PPPP/RN1QKB1R w KQkq' => {
			eco => 'E10o',
			# TRANSLATORS: E10o: 1. d4 Nf6 2. c4 e6 3. Nf3 c5 4. d5 b5 5. Bg5 Qa5+
			variation => N__('Blumenfeld: 5. Bg5 Qa5+'),
			moves => {
			},
		},
		'rnbqkb1r/p2p1ppp/5n2/1ppp2B1/2P5/5N2/PP2PPPP/RN1QKB1R w KQkq' => {
			eco => 'E10p',
			# TRANSLATORS: E10p: 1. d4 Nf6 2. c4 e6 3. Nf3 c5 4. d5 b5 5. Bg5 exd5
			variation => N__('Blumenfeld: 5. Bg5 exd5'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rnbqkb1r/p2p1ppp/5n2/1ppP2B1/8/5N2/PP2PPPP/RN1QKB1R b KQkq' => {
			eco => 'E10p',
			# TRANSLATORS: E10p: 1. d4 Nf6 2. c4 e6 3. Nf3 c5 4. d5 b5 5. Bg5 exd5 6. cxd5
			variation => N__('Blumenfeld: 5. Bg5 exd5'),
			moves => {
				'h7h6' => 1,
			},
		},
		'rnbqkb1r/p2p1pp1/5n1p/1ppP2B1/8/5N2/PP2PPPP/RN1QKB1R w KQkq' => {
			eco => 'E10q',
			# TRANSLATORS: E10q: 1. d4 Nf6 2. c4 e6 3. Nf3 c5 4. d5 b5 5. Bg5 exd5 6. cxd5 h6
			variation => N__('Blumenfeld: Spielmann Variation'),
			moves => {
			},
		},
		'rnbqk2r/pppp1ppp/4pn2/8/1bPP4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'E11a',
			# TRANSLATORS: E11a: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+
			variation => N__('Bogo-Indian'),
			moves => {
				'b1d2' => 1,
				'c1d2' => 1,
			},
		},
		'rnbqk2r/pppp1ppp/4pn2/8/1bPP4/5N2/PP1NPPPP/R1BQKB1R b KQkq' => {
			eco => 'E11a',
			# TRANSLATORS: E11a: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Nbd2
			variation => N__('Bogo-Indian: 4.Nbd2'),
			moves => {
				'b7b6' => 1,
				'd7d5' => 1,
				'e8g8' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/4pn2/3p4/1bPP4/5N2/PP1NPPPP/R1BQKB1R w KQkq' => {
			eco => 'E11b',
			# TRANSLATORS: E11b: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Nbd2 d5
			variation => N__('Bogo-Indian: 4.Nbd2 d5'),
			moves => {
			},
		},
		'rnbqk2r/p1pp1ppp/1p2pn2/8/1bPP4/5N2/PP1NPPPP/R1BQKB1R w KQkq' => {
			eco => 'E11c',
			# TRANSLATORS: E11c: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Nbd2 b6
			variation => N__('Bogo-Indian: 4.Nbd2 b6'),
			moves => {
				'a2a3' => 1,
			},
		},
		'rnbqk2r/p1pp1ppp/1p2pn2/8/1bPP4/P4N2/1P1NPPPP/R1BQKB1R b KQkq' => {
			eco => 'E11c',
			# TRANSLATORS: E11c: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Nbd2 b6 5. a3
			variation => N__('Bogo-Indian: 4.Nbd2 b6 5. a3'),
			moves => {
				'b4d2' => 1,
			},
		},
		'rnbqk2r/p1pp1ppp/1p2pn2/8/2PP4/P4N2/1P1bPPPP/R1BQKB1R w KQkq' => {
			eco => 'E11c',
			# TRANSLATORS: E11c: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Nbd2 b6 5. a3 Bxd2+
			variation => N__('Bogo-Indian: 4.Nbd2 b6 5. a3 Bxd2+'),
			moves => {
				'c1d2' => 1,
			},
		},
		'rnbqk2r/p1pp1ppp/1p2pn2/8/2PP4/P4N2/1P1BPPPP/R2QKB1R b KQkq' => {
			eco => 'E11d',
			# TRANSLATORS: E11d: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Nbd2 b6 5. a3 Bxd2+ 6. Bxd2
			variation => N__('Bogo-Indian: 4.Nbd2 b6 5. a3 Bxd2+ 6.Bxd2'),
			moves => {
				'c8b7' => 1,
			},
		},
		'rn1qk2r/pbpp1ppp/1p2pn2/8/2PP4/P4N2/1P1BPPPP/R2QKB1R w KQkq' => {
			eco => 'E11d',
			# TRANSLATORS: E11d: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Nbd2 b6 5. a3 Bxd2+ 6. Bxd2 Bb7
			variation => N__('Bogo-Indian: 4.Nbd2 b6 5. a3 Bxd2+ 6.Bxd2 Bb7'),
			moves => {
			},
		},
		'rnbq1rk1/pppp1ppp/4pn2/8/1bPP4/5N2/PP1NPPPP/R1BQKB1R w KQ' => {
			eco => 'E11e',
			# TRANSLATORS: E11e: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Nbd2 O-O
			variation => N__('Bogo-Indian: 4.Nbd2 O-O'),
			moves => {
				'a2a3' => 1,
			},
		},
		'rnbq1rk1/pppp1ppp/4pn2/8/1bPP4/P4N2/1P1NPPPP/R1BQKB1R b KQ' => {
			eco => 'E11f',
			# TRANSLATORS: E11f: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Nbd2 O-O 5. a3
			variation => N__('Bogo-Indian: 4.Nbd2 O-O 5. a3'),
			moves => {
				'b4d2' => 1,
				'b4e7' => 1,
			},
		},
		'rnbq1rk1/pppp1ppp/4pn2/8/2PP4/P4N2/1P1bPPPP/R1BQKB1R w KQ' => {
			eco => 'E11f',
			# TRANSLATORS: E11f: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Nbd2 O-O 5. a3 Bxd2+
			variation => N__('Bogo-Indian: 4.Nbd2 O-O 5. a3 Bxd2+'),
			moves => {
			},
		},
		'rnbq1rk1/ppppbppp/4pn2/8/2PP4/P4N2/1P1NPPPP/R1BQKB1R w KQ' => {
			eco => 'E11f',
			# TRANSLATORS: E11f: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Nbd2 O-O 5. a3 Be7
			variation => N__('Bogo-Indian: 4.Nbd2 O-O 5. a3 Be7'),
			moves => {
				'e2e4' => 1,
			},
		},
		'rnbq1rk1/ppppbppp/4pn2/8/2PPP3/P4N2/1P1N1PPP/R1BQKB1R b KQ' => {
			eco => 'E11f',
			# TRANSLATORS: E11f: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Nbd2 O-O 5. a3 Be7 6. e4
			variation => N__('Bogo-Indian: 4.Nbd2 O-O 5. a3 Be7'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbq1rk1/ppp1bppp/4pn2/3p4/2PPP3/P4N2/1P1N1PPP/R1BQKB1R w KQ' => {
			eco => 'E11f',
			# TRANSLATORS: E11f: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Nbd2 O-O 5. a3 Be7 6. e4 d5
			variation => N__('Bogo-Indian: Grünfeld Variation'),
			moves => {
			},
		},
		'rnbqk2r/pppp1ppp/4pn2/8/1bPP4/5N2/PP1BPPPP/RN1QKB1R b KQkq' => {
			eco => 'E11g',
			# TRANSLATORS: E11g: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2
			variation => N__('Bogo-Indian: 4. Bd2'),
			moves => {
				'a7a5' => 1,
				'b4d2' => 1,
				'b4e7' => 1,
				'c7c5' => 1,
				'd8e7' => 1,
			},
		},
		'rnbqk2r/ppppbppp/4pn2/8/2PP4/5N2/PP1BPPPP/RN1QKB1R w KQkq' => {
			eco => 'E11g',
			# TRANSLATORS: E11g: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Be7
			variation => N__('Bogo-Indian: 4. Bd2 Be7'),
			moves => {
				'g2g3' => 1,
			},
		},
		'rnbqk2r/ppppbppp/4pn2/8/2PP4/5NP1/PP1BPP1P/RN1QKB1R b KQkq' => {
			eco => 'E11g',
			# TRANSLATORS: E11g: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Be7 5. g3
			variation => N__('Bogo-Indian: 4. Bd2 Be7 5. g3'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqk2r/ppp1bppp/4pn2/3p4/2PP4/5NP1/PP1BPP1P/RN1QKB1R w KQkq' => {
			eco => 'E11g',
			# TRANSLATORS: E11g: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Be7 5. g3 d5
			variation => N__('Bogo-Indian: 4. Bd2 Be7 5. g3 d5'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqk2r/ppp1bppp/4pn2/3p4/2PP4/5NP1/PP1BPPBP/RN1QK2R b KQkq' => {
			eco => 'E11g',
			# TRANSLATORS: E11g: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Be7 5. g3 d5 6. Bg2
			variation => N__('Bogo-Indian: 4. Bd2 Be7 5. g3 d5 6. Bg2'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppp1bppp/4pn2/3p4/2PP4/5NP1/PP1BPPBP/RN1QK2R w KQ' => {
			eco => 'E11h',
			# TRANSLATORS: E11h: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Be7 5. g3 d5 6. Bg2 O-O
			variation => N__('Bogo-Indian: 4. Bd2 Be7 5. g3 d5 6. Bg2 O-O'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbq1rk1/ppp1bppp/4pn2/3p4/2PP4/5NP1/PP1BPPBP/RN1Q1RK1 b -' => {
			eco => 'E11h',
			# TRANSLATORS: E11h: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Be7 5. g3 d5 6. Bg2 O-O 7. O-O
			variation => N__('Bogo-Indian: 4. Bd2 Be7 5. g3 d5 6. Bg2 O-O'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rnbq1rk1/pp2bppp/2p1pn2/3p4/2PP4/5NP1/PP1BPPBP/RN1Q1RK1 w -' => {
			eco => 'E11h',
			# TRANSLATORS: E11h: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Be7 5. g3 d5 6. Bg2 O-O 7. O-O c6
			variation => N__('Bogo-Indian: 4. Bd2 Be7 5. g3 d5 6. Bg2 O-O 7.O-O c6'),
			moves => {
				'd1c2' => 1,
			},
		},
		'rnbq1rk1/pp2bppp/2p1pn2/3p4/2PP4/5NP1/PPQBPPBP/RN3RK1 b -' => {
			eco => 'E11i',
			# TRANSLATORS: E11i: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Be7 5. g3 d5 6. Bg2 O-O 7. O-O c6 8. Qc2
			variation => N__('Bogo-Indian: 4. Bd2 Be7 5. g3 d5 6. Bg2 O-O 7.O-O c6 8. Qc2'),
			moves => {
				'b7b6' => 1,
			},
		},
		'rnbq1rk1/p3bppp/1pp1pn2/3p4/2PP4/5NP1/PPQBPPBP/RN3RK1 w -' => {
			eco => 'E11i',
			# TRANSLATORS: E11i: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Be7 5. g3 d5 6. Bg2 O-O 7. O-O c6 8. Qc2 b6
			variation => N__('Bogo-Indian: 4. Bd2 Be7 5. g3 d5 6. Bg2 O-O 7.O-O c6 8. Qc2 b6'),
			moves => {
				'd2f4' => 1,
			},
		},
		'rnbq1rk1/p3bppp/1pp1pn2/3p4/2PP1B2/5NP1/PPQ1PPBP/RN3RK1 b -' => {
			eco => 'E11i',
			# TRANSLATORS: E11i: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Be7 5. g3 d5 6. Bg2 O-O 7. O-O c6 8. Qc2 b6 9. Bf4
			variation => N__('Bogo-Indian: 4. Bd2 Be7 5. g3 d5 6. Bg2 O-O 7.O-O c6 8. Qc2 b6 9. Bf4'),
			moves => {
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/2p5/1bPP4/5N2/PP1BPPPP/RN1QKB1R w KQkq' => {
			eco => 'E11j',
			# TRANSLATORS: E11j: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 c5
			variation => N__('Bogo-Indian: Vitolins Variation'),
			moves => {
				'd2b4' => 1,
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/2p5/1BPP4/5N2/PP2PPPP/RN1QKB1R b KQkq' => {
			eco => 'E11j',
			# TRANSLATORS: E11j: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 c5 5. Bxb4
			variation => N__('Bogo-Indian: Vitolins Variation'),
			moves => {
				'c5b4' => 1,
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/8/1pPP4/5N2/PP2PPPP/RN1QKB1R w KQkq' => {
			eco => 'E11j',
			# TRANSLATORS: E11j: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 c5 5. Bxb4 cxb4
			variation => N__('Bogo-Indian: Vitolins Variation'),
			moves => {
				'g2g3' => 1,
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/8/1pPP4/5NP1/PP2PP1P/RN1QKB1R b KQkq' => {
			eco => 'E11k',
			# TRANSLATORS: E11k: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 c5 5. Bxb4 cxb4 6. g3
			variation => N__('Bogo-Indian: Vitolins, 6. g3'),
			moves => {
			},
		},
		'rnbqk2r/1ppp1ppp/4pn2/p7/1bPP4/5N2/PP1BPPPP/RN1QKB1R w KQkq' => {
			eco => 'E11l',
			# TRANSLATORS: E11l: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 a5
			variation => N__('Bogo-Indian: 4. Bd2 a5'),
			moves => {
				'b1c3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqk2r/1ppp1ppp/4pn2/p7/1bPP4/2N2N2/PP1BPPPP/R2QKB1R b KQkq' => {
			eco => 'E11l',
			# TRANSLATORS: E11l: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 a5 5. Nc3
			variation => N__('Bogo-Indian: 4. Bd2 a5 5. Nc3'),
			moves => {
			},
		},
		'rnbqk2r/1ppp1ppp/4pn2/p7/1bPP4/5NP1/PP1BPP1P/RN1QKB1R b KQkq' => {
			eco => 'E11m',
			# TRANSLATORS: E11m: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 a5 5. g3
			variation => N__('Bogo-Indian: 4. Bd2 a5 5. g3'),
			moves => {
			},
		},
		'rnb1k2r/ppppqppp/4pn2/8/1bPP4/5N2/PP1BPPPP/RN1QKB1R w KQkq' => {
			eco => 'E11n',
			# TRANSLATORS: E11n: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Qe7
			variation => N__('Bogo-Indian: Nimzowitsch Variation'),
			moves => {
				'b1c3' => 1,
				'g2g3' => 1,
			},
		},
		'rnb1k2r/ppppqppp/4pn2/8/1bPP4/2N2N2/PP1BPPPP/R2QKB1R b KQkq' => {
			eco => 'E11o',
			# TRANSLATORS: E11o: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Qe7 5. Nc3
			variation => N__('Bogo-Indian: Nimzowitsch, 5. Nc3'),
			moves => {
			},
		},
		'rnb1k2r/ppppqppp/4pn2/8/1bPP4/5NP1/PP1BPP1P/RN1QKB1R b KQkq' => {
			eco => 'E11p',
			# TRANSLATORS: E11p: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Qe7 5. g3
			variation => N__('Bogo-Indian: Nimzowitsch, 5. g3'),
			moves => {
				'b8c6' => 1,
				'e8g8' => 1,
			},
		},
		'rnb2rk1/ppppqppp/4pn2/8/1bPP4/5NP1/PP1BPP1P/RN1QKB1R w KQ' => {
			eco => 'E11q',
			# TRANSLATORS: E11q: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Qe7 5. g3 O-O
			variation => N__('Bogo-Indian: Nimzowitsch, 5. g3 O-O'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnb2rk1/ppppqppp/4pn2/8/1bPP4/5NP1/PP1BPPBP/RN1QK2R b KQ' => {
			eco => 'E11q',
			# TRANSLATORS: E11q: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Qe7 5. g3 O-O 6. Bg2
			variation => N__('Bogo-Indian: Nimzowitsch, 5. g3 O-O'),
			moves => {
			},
		},
		'r1b1k2r/ppppqppp/2n1pn2/8/1bPP4/5NP1/PP1BPP1P/RN1QKB1R w KQkq' => {
			eco => 'E11r',
			# TRANSLATORS: E11r: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Qe7 5. g3 Nc6
			variation => N__('Bogo-Indian: Nimzowitsch, 5. g3 Nc6'),
			moves => {
				'b1c3' => 1,
				'f1g2' => 1,
			},
		},
		'r1b1k2r/ppppqppp/2n1pn2/8/1bPP4/2N2NP1/PP1BPP1P/R2QKB1R b KQkq' => {
			eco => 'E11r',
			# TRANSLATORS: E11r: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Qe7 5. g3 Nc6 6. Nc3
			variation => N__('Bogo-Indian: Nimzowitsch, 5. g3 Nc6 6. Nc3'),
			moves => {
				'b4c3' => 1,
			},
		},
		'r1b1k2r/ppppqppp/2n1pn2/8/2PP4/2b2NP1/PP1BPP1P/R2QKB1R w KQkq' => {
			eco => 'E11s',
			# TRANSLATORS: E11s: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Qe7 5. g3 Nc6 6. Nc3 Bxc3
			variation => N__('Bogo-Indian: Nimzowitsch, 5. g3 Nc6 6. Nc3 Bxc3'),
			moves => {
				'd2c3' => 1,
			},
		},
		'r1b1k2r/ppppqppp/2n1pn2/8/2PP4/2B2NP1/PP2PP1P/R2QKB1R b KQkq' => {
			eco => 'E11s',
			# TRANSLATORS: E11s: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Qe7 5. g3 Nc6 6. Nc3 Bxc3 7. Bxc3
			variation => N__('Bogo-Indian: Nimzowitsch, 5. g3 Nc6 6. Nc3 Bxc3 7.Bxc3'),
			moves => {
				'f6e4' => 1,
			},
		},
		'r1b1k2r/ppppqppp/2n1p3/8/2PPn3/2B2NP1/PP2PP1P/R2QKB1R w KQkq' => {
			eco => 'E11s',
			# TRANSLATORS: E11s: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Qe7 5. g3 Nc6 6. Nc3 Bxc3 7. Bxc3 Ne4
			variation => N__('Bogo-Indian: Nimzowitsch, 5. g3 Nc6 6. Nc3 Bxc3 7.Bxc3 Ne4'),
			moves => {
				'a1c1' => 1,
			},
		},
		'r1b1k2r/ppppqppp/2n1p3/8/2PPn3/2B2NP1/PP2PP1P/2RQKB1R b Kkq' => {
			eco => 'E11s',
			# TRANSLATORS: E11s: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Qe7 5. g3 Nc6 6. Nc3 Bxc3 7. Bxc3 Ne4 8. Rc1
			variation => N__('Bogo-Indian: Nimzowitsch, 5. g3 Nc6 6. Nc3 Bxc3 7.Bxc3 Ne4 8. Rc1'),
			moves => {
			},
		},
		'r1b1k2r/ppppqppp/2n1pn2/8/1bPP4/5NP1/PP1BPPBP/RN1QK2R b KQkq' => {
			eco => 'E11t',
			# TRANSLATORS: E11t: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Qe7 5. g3 Nc6 6. Bg2
			variation => N__('Bogo-Indian: Nimzowitsch, 5. g3 Nc6 6. Bg2'),
			moves => {
				'b4d2' => 1,
			},
		},
		'r1b1k2r/ppppqppp/2n1pn2/8/2PP4/5NP1/PP1bPPBP/RN1QK2R w KQkq' => {
			eco => 'E11t',
			# TRANSLATORS: E11t: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Qe7 5. g3 Nc6 6. Bg2 Bxd2+
			variation => N__('Bogo-Indian: Nimzowitsch, 5. g3 Nc6 6. Bg2 Bxd2+'),
			moves => {
				'b1d2' => 1,
			},
		},
		'r1b1k2r/ppppqppp/2n1pn2/8/2PP4/5NP1/PP1NPPBP/R2QK2R b KQkq' => {
			eco => 'E11u',
			# TRANSLATORS: E11u: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Qe7 5. g3 Nc6 6. Bg2 Bxd2+ 7. Nbxd2
			variation => N__('Bogo-Indian: Nimzowitsch, 5. g3 Nc6 6. Bg2 Bxd2+ 7.Nbxd2'),
			moves => {
				'd7d6' => 1,
			},
		},
		'r1b1k2r/ppp1qppp/2nppn2/8/2PP4/5NP1/PP1NPPBP/R2QK2R w KQkq' => {
			eco => 'E11u',
			# TRANSLATORS: E11u: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Qe7 5. g3 Nc6 6. Bg2 Bxd2+ 7. Nbxd2 d6
			variation => N__('Bogo-Indian: Nimzowitsch, 5. g3 Nc6 6. Bg2 Bxd2+ 7.Nbxd2'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1b1k2r/ppp1qppp/2nppn2/8/2PP4/5NP1/PP1NPPBP/R2Q1RK1 b kq' => {
			eco => 'E11v',
			# TRANSLATORS: E11v: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Qe7 5. g3 Nc6 6. Bg2 Bxd2+ 7. Nbxd2 d6 8. O-O
			variation => N__('Bogo-Indian: Nimzowitsch, 5. g3 Nc6 Main Line'),
			moves => {
				'a7a5' => 1,
				'e8g8' => 1,
			},
		},
		'r1b2rk1/ppp1qppp/2nppn2/8/2PP4/5NP1/PP1NPPBP/R2Q1RK1 w -' => {
			eco => 'E11v',
			# TRANSLATORS: E11v: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Qe7 5. g3 Nc6 6. Bg2 Bxd2+ 7. Nbxd2 d6 8. O-O O-O
			variation => N__('Bogo-Indian: Nimzowitsch, 5. g3 Nc6 Main Line, 8...O-O'),
			moves => {
			},
		},
		'r1b1k2r/1pp1qppp/2nppn2/p7/2PP4/5NP1/PP1NPPBP/R2Q1RK1 w kq' => {
			eco => 'E11w',
			# TRANSLATORS: E11w: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Qe7 5. g3 Nc6 6. Bg2 Bxd2+ 7. Nbxd2 d6 8. O-O a5
			variation => N__('Bogo-Indian: Nimzowitsch, 5. g3 Nc6 Main Line, 8... a5'),
			moves => {
				'e2e4' => 1,
			},
		},
		'r1b1k2r/1pp1qppp/2nppn2/p7/2PPP3/5NP1/PP1N1PBP/R2Q1RK1 b kq' => {
			eco => 'E11w',
			# TRANSLATORS: E11w: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Qe7 5. g3 Nc6 6. Bg2 Bxd2+ 7. Nbxd2 d6 8. O-O a5 9. e4
			variation => N__('Bogo-Indian: Nimzowitsch, 5. g3 Nc6 Main Line, 8... a5 9. e4'),
			moves => {
				'e6e5' => 1,
			},
		},
		'r1b1k2r/1pp1qppp/2np1n2/p3p3/2PPP3/5NP1/PP1N1PBP/R2Q1RK1 w kq' => {
			eco => 'E11w',
			# TRANSLATORS: E11w: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Qe7 5. g3 Nc6 6. Bg2 Bxd2+ 7. Nbxd2 d6 8. O-O a5 9. e4 e5
			variation => N__('Bogo-Indian: Nimzowitsch, 5. g3 Nc6 Main Line, 8... a5 9. e4'),
			moves => {
				'd4d5' => 1,
			},
		},
		'r1b1k2r/1pp1qppp/2np1n2/p2Pp3/2P1P3/5NP1/PP1N1PBP/R2Q1RK1 b kq' => {
			eco => 'E11w',
			# TRANSLATORS: E11w: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Qe7 5. g3 Nc6 6. Bg2 Bxd2+ 7. Nbxd2 d6 8. O-O a5 9. e4 e5 10. d5
			variation => N__('Bogo-Indian: Nimzowitsch, 5. g3 Nc6 Main Line, 8... a5 9. e4'),
			moves => {
				'c6b8' => 1,
			},
		},
		'rnb1k2r/1pp1qppp/3p1n2/p2Pp3/2P1P3/5NP1/PP1N1PBP/R2Q1RK1 w kq' => {
			eco => 'E11w',
			# TRANSLATORS: E11w: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Qe7 5. g3 Nc6 6. Bg2 Bxd2+ 7. Nbxd2 d6 8. O-O a5 9. e4 e5 10. d5 Nb8
			variation => N__('Bogo-Indian: Nimzowitsch, 5. g3 Nc6 Main Line, 8... a5 9. e4 e5 10. d5 Nb8'),
			moves => {
			},
		},
		'rnbqk2r/pppp1ppp/4pn2/8/2PP4/5N2/PP1bPPPP/RN1QKB1R w KQkq' => {
			eco => 'E11x',
			# TRANSLATORS: E11x: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Bxd2+
			variation => N__('Bogo-Indian: 4. Bd2 Bxd2+'),
			moves => {
				'b1d2' => 1,
				'd1d2' => 1,
			},
		},
		'rnbqk2r/pppp1ppp/4pn2/8/2PP4/5N2/PP1NPPPP/R2QKB1R b KQkq' => {
			eco => 'E11x',
			# TRANSLATORS: E11x: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Bxd2+ 5. Nbxd2
			variation => N__('Bogo-Indian: 4. Bd2 Bxd2+ 5.Nbxd2'),
			moves => {
			},
		},
		'rnbqk2r/pppp1ppp/4pn2/8/2PP4/5N2/PP1QPPPP/RN2KB1R b KQkq' => {
			eco => 'E11y',
			# TRANSLATORS: E11y: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Bxd2+ 5. Qxd2
			variation => N__('Bogo-Indian: 4. Bd2 Bxd2+ 5.Qxd2'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/pppp1ppp/4pn2/8/2PP4/5N2/PP1QPPPP/RN2KB1R w KQ' => {
			eco => 'E11y',
			# TRANSLATORS: E11y: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Bxd2+ 5. Qxd2 O-O
			variation => N__('Bogo-Indian: 4. Bd2 Bxd2+ 5.Qxd2 O-O'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rnbq1rk1/pppp1ppp/4pn2/8/2PP4/2N2N2/PP1QPPPP/R3KB1R b KQ' => {
			eco => 'E11y',
			# TRANSLATORS: E11y: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Bxd2+ 5. Qxd2 O-O 6. Nc3
			variation => N__('Bogo-Indian: 4. Bd2 Bxd2+ 5.Qxd2 O-O 6. Nc3'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbq1rk1/ppp2ppp/4pn2/3p4/2PP4/2N2N2/PP1QPPPP/R3KB1R w KQ' => {
			eco => 'E11y',
			# TRANSLATORS: E11y: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Bxd2+ 5. Qxd2 O-O 6. Nc3 d5
			variation => N__('Bogo-Indian: 4. Bd2 Bxd2+ 5.Qxd2 O-O 6. Nc3 d5'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbq1rk1/ppp2ppp/4pn2/3p4/2PP4/2N1PN2/PP1Q1PPP/R3KB1R b KQ' => {
			eco => 'E11z',
			# TRANSLATORS: E11z: 1. d4 Nf6 2. c4 e6 3. Nf3 Bb4+ 4. Bd2 Bxd2+ 5. Qxd2 O-O 6. Nc3 d5 7. e3
			variation => N__('Bogo-Indian: 4. Bd2 Bxd2+ 5.Qxd2 O-O 6. Nc3 d5 7. e3'),
			moves => {
			},
		},
		'rnbqkb1r/p1pp1ppp/1p2pn2/8/2PP4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'E12a',
			# TRANSLATORS: E12a: 1. d4 Nf6 2. c4 e6 3. Nf3 b6
			variation => N__('Queen\'s Indian'),
			moves => {
				'a2a3' => 1,
				'b1c3' => 1,
				'c1f4' => 1,
				'c1g5' => 1,
				'e2e3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/p1pp1ppp/1p2pn2/8/2PP1B2/5N2/PP2PPPP/RN1QKB1R b KQkq' => {
			eco => 'E12b',
			# TRANSLATORS: E12b: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Bf4
			variation => N__('Queen\'s Indian: Miles Variation'),
			moves => {
				'c8b7' => 1,
			},
		},
		'rn1qkb1r/pbpp1ppp/1p2pn2/8/2PP1B2/5N2/PP2PPPP/RN1QKB1R w KQkq' => {
			eco => 'E12b',
			# TRANSLATORS: E12b: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Bf4 Bb7
			variation => N__('Queen\'s Indian: Miles Variation'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rn1qkb1r/pbpp1ppp/1p2pn2/8/2PP1B2/4PN2/PP3PPP/RN1QKB1R b KQkq' => {
			eco => 'E12b',
			# TRANSLATORS: E12b: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Bf4 Bb7 5. e3
			variation => N__('Queen\'s Indian: Miles Variation'),
			moves => {
				'f8b4' => 1,
				'f8e7' => 1,
			},
		},
		'rn1qk2r/pbppbppp/1p2pn2/8/2PP1B2/4PN2/PP3PPP/RN1QKB1R w KQkq' => {
			eco => 'E12b',
			# TRANSLATORS: E12b: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Bf4 Bb7 5. e3 Be7
			variation => N__('Queen\'s Indian: Miles, 5. e3 Be7'),
			moves => {
				'h2h3' => 1,
			},
		},
		'rn1qk2r/pbppbppp/1p2pn2/8/2PP1B2/4PN1P/PP3PP1/RN1QKB1R b KQkq' => {
			eco => 'E12b',
			# TRANSLATORS: E12b: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Bf4 Bb7 5. e3 Be7 6. h3
			variation => N__('Queen\'s Indian: Miles, 5. e3 Be7 6. h3'),
			moves => {
			},
		},
		'rn1qk2r/pbpp1ppp/1p2pn2/8/1bPP1B2/4PN2/PP3PPP/RN1QKB1R w KQkq' => {
			eco => 'E12c',
			# TRANSLATORS: E12c: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Bf4 Bb7 5. e3 Bb4+
			variation => N__('Queen\'s Indian: Miles, 5. e3 Bb4+'),
			moves => {
				'b1d2' => 1,
				'f3d2' => 1,
			},
		},
		'rn1qk2r/pbpp1ppp/1p2pn2/8/1bPP1B2/4PN2/PP1N1PPP/R2QKB1R b KQkq' => {
			eco => 'E12c',
			# TRANSLATORS: E12c: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Bf4 Bb7 5. e3 Bb4+ 6. Nbd2
			variation => N__('Queen\'s Indian: Miles, 5. e3 Bb4+ 6.Nbd2'),
			moves => {
			},
		},
		'rn1qk2r/pbpp1ppp/1p2pn2/8/1bPP1B2/4P3/PP1N1PPP/RN1QKB1R b KQkq' => {
			eco => 'E12c',
			# TRANSLATORS: E12c: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Bf4 Bb7 5. e3 Bb4+ 6. Nfd2
			variation => N__('Queen\'s Indian: Miles, 5. e3 Bb4+ 6.Nfd2'),
			moves => {
			},
		},
		'rnbqkb1r/p1pp1ppp/1p2pn2/8/2PP4/P4N2/1P2PPPP/RNBQKB1R b KQkq' => {
			eco => 'E12d',
			# TRANSLATORS: E12d: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3
			variation => N__('Queen\'s Indian: Petrosian'),
			moves => {
				'c7c5' => 1,
				'c8a6' => 1,
				'c8b7' => 1,
			},
		},
		'rnbqkb1r/p2p1ppp/1p2pn2/2p5/2PP4/P4N2/1P2PPPP/RNBQKB1R w KQkq' => {
			eco => 'E12e',
			# TRANSLATORS: E12e: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 c5
			variation => N__('Queen\'s Indian: Petrosian, 4... c5'),
			moves => {
				'd4d5' => 1,
			},
		},
		'rnbqkb1r/p2p1ppp/1p2pn2/2pP4/2P5/P4N2/1P2PPPP/RNBQKB1R b KQkq' => {
			eco => 'E12e',
			# TRANSLATORS: E12e: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 c5 5. d5
			variation => N__('Queen\'s Indian: Petrosian, 4... c5 5. d5'),
			moves => {
				'c8a6' => 1,
			},
		},
		'rn1qkb1r/p2p1ppp/bp2pn2/2pP4/2P5/P4N2/1P2PPPP/RNBQKB1R w KQkq' => {
			eco => 'E12e',
			# TRANSLATORS: E12e: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 c5 5. d5 Ba6
			variation => N__('Queen\'s Indian: Petrosian, 4... c5 5. d5 Ba6'),
			moves => {
				'd1c2' => 1,
			},
		},
		'rn1qkb1r/p2p1ppp/bp2pn2/2pP4/2P5/P4N2/1PQ1PPPP/RNB1KB1R b KQkq' => {
			eco => 'E12f',
			# TRANSLATORS: E12f: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 c5 5. d5 Ba6 6. Qc2
			variation => N__('Queen\'s Indian: Petrosian, 4... c5 5. d5 Ba6 6. Qc2'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rn1qkb1r/p2p1ppp/bp3n2/2pp4/2P5/P4N2/1PQ1PPPP/RNB1KB1R w KQkq' => {
			eco => 'E12f',
			# TRANSLATORS: E12f: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 c5 5. d5 Ba6 6. Qc2 exd5
			variation => N__('Queen\'s Indian: Petrosian, 4... c5 5. d5 Ba6 6. Qc2'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rn1qkb1r/p2p1ppp/bp3n2/2pP4/8/P4N2/1PQ1PPPP/RNB1KB1R b KQkq' => {
			eco => 'E12f',
			# TRANSLATORS: E12f: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 c5 5. d5 Ba6 6. Qc2 exd5 7. cxd5
			variation => N__('Queen\'s Indian: Petrosian, 4... c5 5. d5 Ba6 6. Qc2'),
			moves => {
				'g7g6' => 1,
			},
		},
		'rn1qkb1r/p2p1p1p/bp3np1/2pP4/8/P4N2/1PQ1PPPP/RNB1KB1R w KQkq' => {
			eco => 'E12f',
			# TRANSLATORS: E12f: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 c5 5. d5 Ba6 6. Qc2 exd5 7. cxd5 g6
			variation => N__('Queen\'s Indian: Petrosian, 4... c5 5. d5 Ba6 6. Qc2 exd5 6.cxd5 g6'),
			moves => {
			},
		},
		'rn1qkb1r/p1pp1ppp/bp2pn2/8/2PP4/P4N2/1P2PPPP/RNBQKB1R w KQkq' => {
			eco => 'E12g',
			# TRANSLATORS: E12g: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Ba6
			variation => N__('Queen\'s Indian: Petrosian, 4... Ba6'),
			moves => {
				'd1c2' => 1,
				'e2e3' => 1,
			},
		},
		'rn1qkb1r/p1pp1ppp/bp2pn2/8/2PP4/P4N2/1PQ1PPPP/RNB1KB1R b KQkq' => {
			eco => 'E12g',
			# TRANSLATORS: E12g: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Ba6 5. Qc2
			variation => N__('Queen\'s Indian: Petrosian, 4... Ba6 5. Qc2'),
			moves => {
				'a6b7' => 1,
				'c7c5' => 1,
			},
		},
		'rn1qkb1r/p2p1ppp/bp2pn2/2p5/2PP4/P4N2/1PQ1PPPP/RNB1KB1R w KQkq' => {
			eco => 'E12g',
			# TRANSLATORS: E12g: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Ba6 5. Qc2 c5
			variation => N__('Queen\'s Indian: Petrosian, 4... Ba6 5. Qc2 c5'),
			moves => {
			},
		},
		'rn1qkb1r/p1pp1ppp/bp2pn2/8/2PP4/P3PN2/1P3PPP/RNBQKB1R b KQkq' => {
			eco => 'E12g',
			# TRANSLATORS: E12g: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Ba6 5. e3
			variation => N__('Queen\'s Indian: Petrosian, 4... Ba6 5. e3'),
			moves => {
			},
		},
		'rn1qkb1r/pbpp1ppp/1p2pn2/8/2PP4/P4N2/1PQ1PPPP/RNB1KB1R w KQkq' => {
			eco => 'E12h',
			# TRANSLATORS: E12h: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Ba6 5. Qc2 Bb7
			variation => N__('Queen\'s Indian: Petrosian, 4... Ba6 5. Qc2 Bb7'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rn1qkb1r/pbpp1ppp/1p2pn2/8/2PP4/P1N2N2/1PQ1PPPP/R1B1KB1R b KQkq' => {
			eco => 'E12h',
			# TRANSLATORS: E12h: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Ba6 5. Qc2 Bb7 6. Nc3
			variation => N__('Queen\'s Indian: Petrosian, 4... Ba6 5. Qc2 Bb7'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rn1qkb1r/pb1p1ppp/1p2pn2/2p5/2PP4/P1N2N2/1PQ1PPPP/R1B1KB1R w KQkq' => {
			eco => 'E12h',
			# TRANSLATORS: E12h: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Ba6 5. Qc2 Bb7 6. Nc3 c5
			variation => N__('Queen\'s Indian: Petrosian, 4... Ba6 5. Qc2 Bb7 6. Nc3 c5'),
			moves => {
				'e2e4' => 1,
			},
		},
		'rn1qkb1r/pb1p1ppp/1p2pn2/2p5/2PPP3/P1N2N2/1PQ2PPP/R1B1KB1R b KQkq' => {
			eco => 'E12i',
			# TRANSLATORS: E12i: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Ba6 5. Qc2 Bb7 6. Nc3 c5 7. e4
			variation => N__('Queen\'s Indian: Petrosian, 4... Ba6 5. Qc2 Bb7 6. Nc3 c5 7. e4'),
			moves => {
				'c5d4' => 1,
			},
		},
		'rn1qkb1r/pb1p1ppp/1p2pn2/8/2PpP3/P1N2N2/1PQ2PPP/R1B1KB1R w KQkq' => {
			eco => 'E12i',
			# TRANSLATORS: E12i: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Ba6 5. Qc2 Bb7 6. Nc3 c5 7. e4 cxd4
			variation => N__('Queen\'s Indian: Petrosian, 4... Ba6 5. Qc2 Bb7 6. Nc3 c5 7. e4'),
			moves => {
				'f3d4' => 1,
			},
		},
		'rn1qkb1r/pb1p1ppp/1p2pn2/8/2PNP3/P1N5/1PQ2PPP/R1B1KB1R b KQkq' => {
			eco => 'E12i',
			# TRANSLATORS: E12i: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Ba6 5. Qc2 Bb7 6. Nc3 c5 7. e4 cxd4 8. Nxd4
			variation => N__('Queen\'s Indian: Petrosian, 4... Ba6 5. Qc2 Bb7 6. Nc3 c5 7. e4'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r2qkb1r/pb1p1ppp/1pn1pn2/8/2PNP3/P1N5/1PQ2PPP/R1B1KB1R w KQkq' => {
			eco => 'E12i',
			# TRANSLATORS: E12i: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Ba6 5. Qc2 Bb7 6. Nc3 c5 7. e4 cxd4 8. Nxd4 Nc6
			variation => N__('Queen\'s Indian: Petrosian, 4... Ba6 5. Qc2 Bb7 6. Nc3 c5 7. e4 cd 8.Nxd4 Nc6'),
			moves => {
			},
		},
		'rn1qkb1r/pbpp1ppp/1p2pn2/8/2PP4/P4N2/1P2PPPP/RNBQKB1R w KQkq' => {
			eco => 'E12j',
			# TRANSLATORS: E12j: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Bb7
			variation => N__('Queen\'s Indian: Petrosian, 4... Bb7'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rn1qkb1r/pbpp1ppp/1p2pn2/8/2PP4/P1N2N2/1P2PPPP/R1BQKB1R b KQkq' => {
			eco => 'E12j',
			# TRANSLATORS: E12j: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Bb7 5. Nc3
			variation => N__('Queen\'s Indian: Petrosian, 5. Nc3'),
			moves => {
				'b7f3' => 1,
				'd7d5' => 1,
				'f6e4' => 1,
				'f8e7' => 1,
				'g7g6' => 1,
			},
		},
		'rn1qkb1r/p1pp1ppp/1p2pn2/8/2PP4/P1N2b2/1P2PPPP/R1BQKB1R w KQkq' => {
			eco => 'E12j',
			# TRANSLATORS: E12j: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Bb7 5. Nc3 Bxf3
			variation => N__('Queen\'s Indian: Petrosian, 5. Nc3 Bxf3'),
			moves => {
			},
		},
		'rn1qk2r/pbppbppp/1p2pn2/8/2PP4/P1N2N2/1P2PPPP/R1BQKB1R w KQkq' => {
			eco => 'E12j',
			# TRANSLATORS: E12j: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Bb7 5. Nc3 Be7
			variation => N__('Queen\'s Indian: Petrosian, 5. Nc3 Be7'),
			moves => {
			},
		},
		'rn1qkb1r/pbpp1ppp/1p2p3/8/2PPn3/P1N2N2/1P2PPPP/R1BQKB1R w KQkq' => {
			eco => 'E12k',
			# TRANSLATORS: E12k: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Bb7 5. Nc3 Ne4
			variation => N__('Queen\'s Indian: Petrosian, 5. Nc3 Ne4'),
			moves => {
			},
		},
		'rn1qkb1r/pbpp1p1p/1p2pnp1/8/2PP4/P1N2N2/1P2PPPP/R1BQKB1R w KQkq' => {
			eco => 'E12l',
			# TRANSLATORS: E12l: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Bb7 5. Nc3 g6
			variation => N__('Queen\'s Indian: Petrosian, 5. Nc3 g6'),
			moves => {
			},
		},
		'rn1qkb1r/pbp2ppp/1p2pn2/3p4/2PP4/P1N2N2/1P2PPPP/R1BQKB1R w KQkq' => {
			eco => 'E12m',
			# TRANSLATORS: E12m: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Bb7 5. Nc3 d5
			variation => N__('Queen\'s Indian: Petrosian, 5. Nc3 d5'),
			moves => {
				'c1g5' => 1,
				'c4d5' => 1,
			},
		},
		'rn1qkb1r/pbp2ppp/1p2pn2/3P4/3P4/P1N2N2/1P2PPPP/R1BQKB1R b KQkq' => {
			eco => 'E12m',
			# TRANSLATORS: E12m: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Bb7 5. Nc3 d5 6. cxd5
			variation => N__('Queen\'s Indian: Petrosian, 5. Nc3 d5'),
			moves => {
				'e6d5' => 1,
				'f6d5' => 1,
			},
		},
		'rn1qkb1r/pbp2ppp/1p2pn2/3p2B1/2PP4/P1N2N2/1P2PPPP/R2QKB1R b KQkq' => {
			eco => 'E12n',
			# TRANSLATORS: E12n: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Bb7 5. Nc3 d5 6. Bg5
			variation => N__('Queen\'s Indian: Petrosian, 5. Nc3 d5 6. Bg5'),
			moves => {
				'f8e7' => 1,
			},
		},
		'rn1qk2r/pbp1bppp/1p2pn2/3p2B1/2PP4/P1N2N2/1P2PPPP/R2QKB1R w KQkq' => {
			eco => 'E12n',
			# TRANSLATORS: E12n: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Bb7 5. Nc3 d5 6. Bg5 Be7
			variation => N__('Queen\'s Indian: Petrosian, 5. Nc3 d5 6. Bg5 Be7'),
			moves => {
				'd1a4' => 1,
			},
		},
		'rn1qk2r/pbp1bppp/1p2pn2/3p2B1/Q1PP4/P1N2N2/1P2PPPP/R3KB1R b KQkq' => {
			eco => 'E12o',
			# TRANSLATORS: E12o: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Bb7 5. Nc3 d5 6. Bg5 Be7 7. Qa4+
			variation => N__('Queen\'s Indian: Petrosian, 5. Nc3 d5 6. Bg5 Be7 7. Qa4+'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rn1qk2r/pb2bppp/1pp1pn2/3p2B1/Q1PP4/P1N2N2/1P2PPPP/R3KB1R w KQkq' => {
			eco => 'E12o',
			# TRANSLATORS: E12o: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Bb7 5. Nc3 d5 6. Bg5 Be7 7. Qa4+ c6
			variation => N__('Queen\'s Indian: Petrosian, 5. Nc3 d5 6. Bg5 Be7 7. Qa4+ c6'),
			moves => {
				'g5f6' => 1,
			},
		},
		'rn1qk2r/pb2bppp/1pp1pB2/3p4/Q1PP4/P1N2N2/1P2PPPP/R3KB1R b KQkq' => {
			eco => 'E12o',
			# TRANSLATORS: E12o: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Bb7 5. Nc3 d5 6. Bg5 Be7 7. Qa4+ c6 8. Bxf6
			variation => N__('Queen\'s Indian: Petrosian, 5. Nc3 d5 6. Bg5 Be7 7. Qa4+ c6'),
			moves => {
				'e7f6' => 1,
			},
		},
		'rn1qk2r/pb3ppp/1pp1pb2/3p4/Q1PP4/P1N2N2/1P2PPPP/R3KB1R w KQkq' => {
			eco => 'E12o',
			# TRANSLATORS: E12o: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Bb7 5. Nc3 d5 6. Bg5 Be7 7. Qa4+ c6 8. Bxf6 Bxf6
			variation => N__('Queen\'s Indian: Petrosian, 5. Nc3 d5 6. Bg5 Be7 7. Qa4+ c6'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rn1qk2r/pb3ppp/1pp1pb2/3P4/Q2P4/P1N2N2/1P2PPPP/R3KB1R b KQkq' => {
			eco => 'E12o',
			# TRANSLATORS: E12o: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Bb7 5. Nc3 d5 6. Bg5 Be7 7. Qa4+ c6 8. Bxf6 Bxf6 9. cxd5
			variation => N__('Queen\'s Indian: Petrosian, 5. Nc3 d5 6. Bg5 Be7 7. Qa4+ c6'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rn1qk2r/pb3ppp/1pp2b2/3p4/Q2P4/P1N2N2/1P2PPPP/R3KB1R w KQkq' => {
			eco => 'E12o',
			# TRANSLATORS: E12o: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Bb7 5. Nc3 d5 6. Bg5 Be7 7. Qa4+ c6 8. Bxf6 Bxf6 9. cxd5 exd5
			variation => N__('Queen\'s Indian: Petrosian, 5. Nc3 d5 6. Bg5 Be7 7. Qa4+ c6 8.Bxf6 Bxf6 9.cxd5 exd5'),
			moves => {
			},
		},
		'rn1qkb1r/pbp2ppp/1p3n2/3p4/3P4/P1N2N2/1P2PPPP/R1BQKB1R w KQkq' => {
			eco => 'E12p',
			# TRANSLATORS: E12p: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Bb7 5. Nc3 d5 6. cxd5 exd5
			variation => N__('Queen\'s Indian: Petrosian, 6.cxd5 exd5'),
			moves => {
				'c1g5' => 1,
				'g2g3' => 1,
			},
		},
		'rn1qkb1r/pbp2ppp/1p3n2/3p4/3P4/P1N2NP1/1P2PP1P/R1BQKB1R b KQkq' => {
			eco => 'E12p',
			# TRANSLATORS: E12p: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Bb7 5. Nc3 d5 6. cxd5 exd5 7. g3
			variation => N__('Queen\'s Indian: Petrosian, 6.cxd5 exd5 7. g3'),
			moves => {
			},
		},
		'rn1qkb1r/pbp2ppp/1p3n2/3p2B1/3P4/P1N2N2/1P2PPPP/R2QKB1R b KQkq' => {
			eco => 'E12q',
			# TRANSLATORS: E12q: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Bb7 5. Nc3 d5 6. cxd5 exd5 7. Bg5
			variation => N__('Queen\'s Indian: Petrosian, 6.cxd5 exd5 7. Bg5'),
			moves => {
			},
		},
		'rn1qkb1r/pbp2ppp/1p2p3/3n4/3P4/P1N2N2/1P2PPPP/R1BQKB1R w KQkq' => {
			eco => 'E12r',
			# TRANSLATORS: E12r: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Bb7 5. Nc3 d5 6. cxd5 Nxd5
			variation => N__('Queen\'s Indian: Petrosian, 6.cxd5 Nxd5'),
			moves => {
				'd1c2' => 1,
				'e2e3' => 1,
				'e2e4' => 1,
			},
		},
		'rn1qkb1r/pbp2ppp/1p2p3/3n4/3PP3/P1N2N2/1P3PPP/R1BQKB1R b KQkq' => {
			eco => 'E12r',
			# TRANSLATORS: E12r: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Bb7 5. Nc3 d5 6. cxd5 Nxd5 7. e4
			variation => N__('Queen\'s Indian: Petrosian, 6.cxd5 Nxd5 7. e4'),
			moves => {
			},
		},
		'rn1qkb1r/pbp2ppp/1p2p3/3n4/3P4/P1N1PN2/1P3PPP/R1BQKB1R b KQkq' => {
			eco => 'E12s',
			# TRANSLATORS: E12s: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Bb7 5. Nc3 d5 6. cxd5 Nxd5 7. e3
			variation => N__('Queen\'s Indian: Petrosian, 6.cxd5 Nxd5 7. e3'),
			moves => {
				'f8e7' => 1,
				'g7g6' => 1,
			},
		},
		'rn1qk2r/pbp1bppp/1p2p3/3n4/3P4/P1N1PN2/1P3PPP/R1BQKB1R w KQkq' => {
			eco => 'E12s',
			# TRANSLATORS: E12s: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Bb7 5. Nc3 d5 6. cxd5 Nxd5 7. e3 Be7
			variation => N__('Queen\'s Indian: Petrosian, 6.cxd5 Nxd5 7. e3 Be7'),
			moves => {
			},
		},
		'rn1qkb1r/pbp2p1p/1p2p1p1/3n4/3P4/P1N1PN2/1P3PPP/R1BQKB1R w KQkq' => {
			eco => 'E12s',
			# TRANSLATORS: E12s: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Bb7 5. Nc3 d5 6. cxd5 Nxd5 7. e3 g6
			variation => N__('Queen\'s Indian: Petrosian, 6.cxd5 Nxd5 7. e3 g6'),
			moves => {
			},
		},
		'rn1qkb1r/pbp2ppp/1p2p3/3n4/3P4/P1N2N2/1PQ1PPPP/R1B1KB1R b KQkq' => {
			eco => 'E12t',
			# TRANSLATORS: E12t: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Bb7 5. Nc3 d5 6. cxd5 Nxd5 7. Qc2
			variation => N__('Queen\'s Indian: Petrosian, Kasparov Variation'),
			moves => {
				'c7c5' => 1,
				'd5c3' => 1,
				'f8e7' => 1,
			},
		},
		'rn1qkb1r/pb3ppp/1p2p3/2pn4/3P4/P1N2N2/1PQ1PPPP/R1B1KB1R w KQkq' => {
			eco => 'E12t',
			# TRANSLATORS: E12t: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Bb7 5. Nc3 d5 6. cxd5 Nxd5 7. Qc2 c5
			variation => N__('Queen\'s Indian: Petrosian, Kasparov, 7... c5'),
			moves => {
			},
		},
		'rn1qkb1r/pbp2ppp/1p2p3/8/3P4/P1n2N2/1PQ1PPPP/R1B1KB1R w KQkq' => {
			eco => 'E12t',
			# TRANSLATORS: E12t: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Bb7 5. Nc3 d5 6. cxd5 Nxd5 7. Qc2 Nxc3
			variation => N__('Queen\'s Indian: Petrosian, Kasparov, 7...Nxc3'),
			moves => {
				'b2c3' => 1,
			},
		},
		'rn1qk2r/pbp1bppp/1p2p3/3n4/3P4/P1N2N2/1PQ1PPPP/R1B1KB1R w KQkq' => {
			eco => 'E12t',
			# TRANSLATORS: E12t: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Bb7 5. Nc3 d5 6. cxd5 Nxd5 7. Qc2 Be7
			variation => N__('Queen\'s Indian: Petrosian, Kasparov, 7... Be7'),
			moves => {
			},
		},
		'rn1qkb1r/pbp2ppp/1p2p3/8/3P4/P1P2N2/2Q1PPPP/R1B1KB1R b KQkq' => {
			eco => 'E12u',
			# TRANSLATORS: E12u: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Bb7 5. Nc3 d5 6. cxd5 Nxd5 7. Qc2 Nxc3 8. bxc3
			variation => N__('Queen\'s Indian: Petrosian, Kasparov, 7...Nxc3 8.bxc3'),
			moves => {
				'c7c5' => 1,
				'f8e7' => 1,
			},
		},
		'rn1qkb1r/pb3ppp/1p2p3/2p5/3P4/P1P2N2/2Q1PPPP/R1B1KB1R w KQkq' => {
			eco => 'E12u',
			# TRANSLATORS: E12u: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Bb7 5. Nc3 d5 6. cxd5 Nxd5 7. Qc2 Nxc3 8. bxc3 c5
			variation => N__('Queen\'s Indian: Petrosian, Kasparov, 7...Nxc3 8.bxc3 c5'),
			moves => {
				'e2e4' => 1,
			},
		},
		'rn1qkb1r/pb3ppp/1p2p3/2p5/3PP3/P1P2N2/2Q2PPP/R1B1KB1R b KQkq' => {
			eco => 'E12u',
			# TRANSLATORS: E12u: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Bb7 5. Nc3 d5 6. cxd5 Nxd5 7. Qc2 Nxc3 8. bxc3 c5 9. e4
			variation => N__('Queen\'s Indian: Petrosian, Kasparov, 7...Nxc3 8.bxc3 c5 9. e4'),
			moves => {
			},
		},
		'rn1qk2r/pbp1bppp/1p2p3/8/3P4/P1P2N2/2Q1PPPP/R1B1KB1R w KQkq' => {
			eco => 'E12u',
			# TRANSLATORS: E12u: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Bb7 5. Nc3 d5 6. cxd5 Nxd5 7. Qc2 Nxc3 8. bxc3 Be7
			variation => N__('Queen\'s Indian: Petrosian, Kasparov, 7...Nxc3 8.bxc3 Be7'),
			moves => {
				'e2e4' => 1,
			},
		},
		'rn1qk2r/pbp1bppp/1p2p3/8/3PP3/P1P2N2/2Q2PPP/R1B1KB1R b KQkq' => {
			eco => 'E12u',
			# TRANSLATORS: E12u: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. a3 Bb7 5. Nc3 d5 6. cxd5 Nxd5 7. Qc2 Nxc3 8. bxc3 Be7 9. e4
			variation => N__('Queen\'s Indian: Petrosian, Kasparov, 7...Nxc3 8.bxc3 Be7 9. e4'),
			moves => {
			},
		},
		'rnbqkb1r/p1pp1ppp/1p2pn2/6B1/2PP4/5N2/PP2PPPP/RN1QKB1R b KQkq' => {
			eco => 'E12v',
			# TRANSLATORS: E12v: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Bg5
			variation => N__('Queen\'s Indian: 4. Bg5'),
			moves => {
			},
		},
		'rnbqkb1r/p1pp1ppp/1p2pn2/8/2PP4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'E12w',
			# TRANSLATORS: E12w: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3
			variation => N__('Queen\'s Indian: 4. Nc3'),
			moves => {
				'c8b7' => 1,
			},
		},
		'rn1qkb1r/pbpp1ppp/1p2pn2/8/2PP4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'E12w',
			# TRANSLATORS: E12w: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7
			variation => N__('Queen\'s Indian: 4. Nc3 Bb7'),
			moves => {
				'c1g5' => 1,
			},
		},
		'rn1qkb1r/pbpp1ppp/1p2pn2/6B1/2PP4/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'E12w',
			# TRANSLATORS: E12w: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5
			variation => N__('Queen\'s Indian: 4. Nc3 Bb7 5. Bg5'),
			moves => {
				'h7h6' => 1,
			},
		},
		'rn1qkb1r/pbpp1pp1/1p2pn1p/6B1/2PP4/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'E12w',
			# TRANSLATORS: E12w: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5 h6
			variation => N__('Queen\'s Indian: 4. Nc3 Bb7 5. Bg5'),
			moves => {
				'g5h4' => 1,
			},
		},
		'rn1qkb1r/pbpp1pp1/1p2pn1p/8/2PP3B/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'E12w',
			# TRANSLATORS: E12w: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5 h6 6. Bh4
			variation => N__('Queen\'s Indian: 4. Nc3 Bb7 5. Bg5'),
			moves => {
				'f8b4' => 1,
				'f8e7' => 1,
				'g7g5' => 1,
			},
		},
		'rn1qk2r/pbppbpp1/1p2pn1p/8/2PP3B/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'E12x',
			# TRANSLATORS: E12x: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5 h6 6. Bh4 Be7
			variation => N__('Queen\'s Indian: 5. Bg5 h6 6. Bh4 Be7'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rn1qk2r/pbppbpp1/1p2pn1p/8/2PP3B/2N1PN2/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'E12x',
			# TRANSLATORS: E12x: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5 h6 6. Bh4 Be7 7. e3
			variation => N__('Queen\'s Indian: 5. Bg5 h6 6. Bh4 Be7'),
			moves => {
				'c7c5' => 1,
				'f6e4' => 1,
			},
		},
		'rn1qk2r/pb1pbpp1/1p2pn1p/2p5/2PP3B/2N1PN2/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'E12x',
			# TRANSLATORS: E12x: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5 h6 6. Bh4 Be7 7. e3 c5
			variation => N__('Queen\'s Indian: 5. Bg5 h6 6. Bh4 Be7 7. e3 c5'),
			moves => {
			},
		},
		'rn1qk2r/pbppbpp1/1p2p2p/8/2PPn2B/2N1PN2/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'E12x',
			# TRANSLATORS: E12x: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5 h6 6. Bh4 Be7 7. e3 Ne4
			variation => N__('Queen\'s Indian: 5. Bg5 h6 6. Bh4 Be7 7. e3 Ne4'),
			moves => {
			},
		},
		'rn1qkb1r/pbpp1p2/1p2pn1p/6p1/2PP3B/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'E12y',
			# TRANSLATORS: E12y: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5 h6 6. Bh4 g5
			variation => N__('Queen\'s Indian: Botvinnik Variation'),
			moves => {
				'h4g3' => 1,
			},
		},
		'rn1qkb1r/pbpp1p2/1p2pn1p/6p1/2PP4/2N2NB1/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'E12y',
			# TRANSLATORS: E12y: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5 h6 6. Bh4 g5 7. Bg3
			variation => N__('Queen\'s Indian: Botvinnik Variation'),
			moves => {
				'f6h5' => 1,
			},
		},
		'rn1qkb1r/pbpp1p2/1p2p2p/6pn/2PP4/2N2NB1/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'E12y',
			# TRANSLATORS: E12y: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5 h6 6. Bh4 g5 7. Bg3 Nh5
			variation => N__('Queen\'s Indian: Botvinnik Variation'),
			moves => {
				'd1c2' => 1,
				'e2e3' => 1,
			},
		},
		'rn1qkb1r/pbpp1p2/1p2p2p/6pn/2PP4/2N2NB1/PPQ1PPPP/R3KB1R b KQkq' => {
			eco => 'E12y',
			# TRANSLATORS: E12y: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5 h6 6. Bh4 g5 7. Bg3 Nh5 8. Qc2
			variation => N__('Queen\'s Indian: Botvinnik, 8. Qc2'),
			moves => {
			},
		},
		'rn1qkb1r/pbpp1p2/1p2p2p/6pn/2PP4/2N1PNB1/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'E12y',
			# TRANSLATORS: E12y: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5 h6 6. Bh4 g5 7. Bg3 Nh5 8. e3
			variation => N__('Queen\'s Indian: Botvinnik, 8. e3'),
			moves => {
			},
		},
		'rn1qk2r/pbpp1pp1/1p2pn1p/8/1bPP3B/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'E13a',
			# TRANSLATORS: E13a: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5 h6 6. Bh4 Bb4
			variation => N__('Queen\'s Indian: 5. Bg5 h6 6. Bh4 Bb4'),
			moves => {
				'd1c2' => 1,
				'e2e3' => 1,
				'f3d2' => 1,
			},
		},
		'rn1qk2r/pbpp1pp1/1p2pn1p/8/1bPP3B/2N2N2/PPQ1PPPP/R3KB1R b KQkq' => {
			eco => 'E13b',
			# TRANSLATORS: E13b: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5 h6 6. Bh4 Bb4 7. Qc2
			variation => N__('Queen\'s Indian: 5. Bg5 h6 6. Bh4 Bb4 7. Qc2'),
			moves => {
				'g7g5' => 1,
			},
		},
		'rn1qk2r/pbpp1p2/1p2pn1p/6p1/1bPP3B/2N2N2/PPQ1PPPP/R3KB1R w KQkq' => {
			eco => 'E13c',
			# TRANSLATORS: E13c: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5 h6 6. Bh4 Bb4 7. Qc2 g5
			variation => N__('Queen\'s Indian: 5. Bg5 h6 6. Bh4 Bb4 7. Qc2 g5'),
			moves => {
			},
		},
		'rn1qk2r/pbpp1pp1/1p2pn1p/8/1bPP3B/2N5/PP1NPPPP/R2QKB1R b KQkq' => {
			eco => 'E13d',
			# TRANSLATORS: E13d: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5 h6 6. Bh4 Bb4 7. Nd2
			variation => N__('Queen\'s Indian: 5. Bg5 h6 6. Bh4 Bb4 7. Nd2'),
			moves => {
				'b4c3' => 1,
			},
		},
		'rn1qk2r/pbpp1pp1/1p2pn1p/8/2PP3B/2b5/PP1NPPPP/R2QKB1R w KQkq' => {
			eco => 'E13e',
			# TRANSLATORS: E13e: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5 h6 6. Bh4 Bb4 7. Nd2 Bxc3
			variation => N__('Queen\'s Indian: 5. Bg5 h6 6. Bh4 Bb4 7. Nd2 Bxc3'),
			moves => {
				'b2c3' => 1,
			},
		},
		'rn1qk2r/pbpp1pp1/1p2pn1p/8/2PP3B/2P5/P2NPPPP/R2QKB1R b KQkq' => {
			eco => 'E13e',
			# TRANSLATORS: E13e: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5 h6 6. Bh4 Bb4 7. Nd2 Bxc3 8. bxc3
			variation => N__('Queen\'s Indian: 5. Bg5 h6 6. Bh4 Bb4 7. Nd2 Bxc3 8.bxc3'),
			moves => {
			},
		},
		'rn1qk2r/pbpp1pp1/1p2pn1p/8/1bPP3B/2N1PN2/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'E13f',
			# TRANSLATORS: E13f: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5 h6 6. Bh4 Bb4 7. e3
			variation => N__('Queen\'s Indian: 5. Bg5 h6 6. Bh4 Bb4 7. e3'),
			moves => {
				'b4c3' => 1,
				'c7c5' => 1,
				'g7g5' => 1,
			},
		},
		'rn1qk2r/pb1p1pp1/1p2pn1p/2p5/1bPP3B/2N1PN2/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'E13g',
			# TRANSLATORS: E13g: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5 h6 6. Bh4 Bb4 7. e3 c5
			variation => N__('Queen\'s Indian: 5. Bg5 h6 6. Bh4 Bb4 7. e3 c5'),
			moves => {
			},
		},
		'rn1qk2r/pbpp1pp1/1p2pn1p/8/2PP3B/2b1PN2/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'E13h',
			# TRANSLATORS: E13h: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5 h6 6. Bh4 Bb4 7. e3 Bxc3+
			variation => N__('Queen\'s Indian: 5. Bg5 h6 6. Bh4 Bb4 7. e3 Bxc3+'),
			moves => {
				'b2c3' => 1,
			},
		},
		'rn1qk2r/pbpp1pp1/1p2pn1p/8/2PP3B/2P1PN2/P4PPP/R2QKB1R b KQkq' => {
			eco => 'E13h',
			# TRANSLATORS: E13h: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5 h6 6. Bh4 Bb4 7. e3 Bxc3+ 8. bxc3
			variation => N__('Queen\'s Indian: 5. Bg5 h6 6. Bh4 Bb4 7. e3 Bxc3+ 8.bxc3'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rn1qk2r/pbp2pp1/1p1ppn1p/8/2PP3B/2P1PN2/P4PPP/R2QKB1R w KQkq' => {
			eco => 'E13i',
			# TRANSLATORS: E13i: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5 h6 6. Bh4 Bb4 7. e3 Bxc3+ 8. bxc3 d6
			variation => N__('Queen\'s Indian: 5. Bg5 h6 6. Bh4 Bb4 7. e3 Bxc3+ 8.bxc3 d6'),
			moves => {
				'f3d2' => 1,
			},
		},
		'rn1qk2r/pbp2pp1/1p1ppn1p/8/2PP3B/2P1P3/P2N1PPP/R2QKB1R b KQkq' => {
			eco => 'E13j',
			# TRANSLATORS: E13j: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5 h6 6. Bh4 Bb4 7. e3 Bxc3+ 8. bxc3 d6 9. Nd2
			variation => N__('Queen\'s Indian: 5. Bg5 h6 6. Bh4 Bb4 7. e3 Bxc3+ 8.bxc3 d6 9. Nd2'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r2qk2r/pbpn1pp1/1p1ppn1p/8/2PP3B/2P1P3/P2N1PPP/R2QKB1R w KQkq' => {
			eco => 'E13k',
			# TRANSLATORS: E13k: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5 h6 6. Bh4 Bb4 7. e3 Bxc3+ 8. bxc3 d6 9. Nd2 Nbd7
			variation => N__('Queen\'s Indian: 5. Bg5 h6 6. Bh4 Bb4 7. e3 Bxc3+ 8.bxc3 d6 9. Nd2 Nbd7'),
			moves => {
				'f2f3' => 1,
			},
		},
		'r2qk2r/pbpn1pp1/1p1ppn1p/8/2PP3B/2P1PP2/P2N2PP/R2QKB1R b KQkq' => {
			eco => 'E13k',
			# TRANSLATORS: E13k: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5 h6 6. Bh4 Bb4 7. e3 Bxc3+ 8. bxc3 d6 9. Nd2 Nbd7 10. f3
			variation => N__('Queen\'s Indian: 5. Bg5 h6 6. Bh4 Bb4 7. e3 Bxc3+ 8.bxc3 d6 9. Nd2 Nbd7 10. f3'),
			moves => {
				'd8e7' => 1,
			},
		},
		'r3k2r/pbpnqpp1/1p1ppn1p/8/2PP3B/2P1PP2/P2N2PP/R2QKB1R w KQkq' => {
			eco => 'E13l',
			# TRANSLATORS: E13l: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5 h6 6. Bh4 Bb4 7. e3 Bxc3+ 8. bxc3 d6 9. Nd2 Nbd7 10. f3 Qe7
			variation => N__('Queen\'s Indian: 5. Bg5 h6 6. Bh4 Bb4 7. e3 Bxc3+ 8.bxc3 d6 9. Nd2 Nbd7 10. f3 Qe7'),
			moves => {
			},
		},
		'rn1qk2r/pbpp1p2/1p2pn1p/6p1/1bPP3B/2N1PN2/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'E13m',
			# TRANSLATORS: E13m: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5 h6 6. Bh4 Bb4 7. e3 g5
			variation => N__('Queen\'s Indian: 5. Bg5 h6 6. Bh4 Bb4 7. e3 g5'),
			moves => {
				'h4g3' => 1,
			},
		},
		'rn1qk2r/pbpp1p2/1p2pn1p/6p1/1bPP4/2N1PNB1/PP3PPP/R2QKB1R b KQkq' => {
			eco => 'E13m',
			# TRANSLATORS: E13m: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5 h6 6. Bh4 Bb4 7. e3 g5 8. Bg3
			variation => N__('Queen\'s Indian: 5. Bg5 h6 6. Bh4 Bb4 7. e3 g5'),
			moves => {
				'f6e4' => 1,
			},
		},
		'rn1qk2r/pbpp1p2/1p2p2p/6p1/1bPPn3/2N1PNB1/PP3PPP/R2QKB1R w KQkq' => {
			eco => 'E13m',
			# TRANSLATORS: E13m: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5 h6 6. Bh4 Bb4 7. e3 g5 8. Bg3 Ne4
			variation => N__('Queen\'s Indian: 5. Bg5 h6 6. Bh4 Bb4 7. e3 g5 8. Bg3 Ne4'),
			moves => {
				'd1c2' => 1,
			},
		},
		'rn1qk2r/pbpp1p2/1p2p2p/6p1/1bPPn3/2N1PNB1/PPQ2PPP/R3KB1R b KQkq' => {
			eco => 'E13n',
			# TRANSLATORS: E13n: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5 h6 6. Bh4 Bb4 7. e3 g5 8. Bg3 Ne4 9. Qc2
			variation => N__('Queen\'s Indian: 5. Bg5 h6 6. Bh4 Bb4 7. e3 g5 8. Bg3 Ne4 9. Qc2'),
			moves => {
				'b4c3' => 1,
			},
		},
		'rn1qk2r/pbpp1p2/1p2p2p/6p1/2PPn3/2b1PNB1/PPQ2PPP/R3KB1R w KQkq' => {
			eco => 'E13o',
			# TRANSLATORS: E13o: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5 h6 6. Bh4 Bb4 7. e3 g5 8. Bg3 Ne4 9. Qc2 Bxc3+
			variation => N__('Queen\'s Indian: 5. Bg5 h6 6. Bh4 Bb4 7. e3 g5 8. Bg3 Ne4 9. Qc2 Bxc3+'),
			moves => {
				'b2c3' => 1,
			},
		},
		'rn1qk2r/pbpp1p2/1p2p2p/6p1/2PPn3/2P1PNB1/P1Q2PPP/R3KB1R b KQkq' => {
			eco => 'E13o',
			# TRANSLATORS: E13o: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5 h6 6. Bh4 Bb4 7. e3 g5 8. Bg3 Ne4 9. Qc2 Bxc3+ 10. bxc3
			variation => N__('Queen\'s Indian: 5. Bg5 h6 6. Bh4 Bb4 7. e3 g5 8. Bg3 Ne4 9. Qc2 Bxc3+'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rn1qk2r/pbp2p2/1p1pp2p/6p1/2PPn3/2P1PNB1/P1Q2PPP/R3KB1R w KQkq' => {
			eco => 'E13p',
			# TRANSLATORS: E13p: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5 h6 6. Bh4 Bb4 7. e3 g5 8. Bg3 Ne4 9. Qc2 Bxc3+ 10. bxc3 d6
			variation => N__('Queen\'s Indian: 5. Bg5 h6 6. Bh4 Bb4 7. e3 g5 8. Bg3 Ne4 9. Qc2 Bxc3+ 10.bxc3 d6'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rn1qk2r/pbp2p2/1p1pp2p/6p1/2PPn3/2PBPNB1/P1Q2PPP/R3K2R b KQkq' => {
			eco => 'E13p',
			# TRANSLATORS: E13p: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5 h6 6. Bh4 Bb4 7. e3 g5 8. Bg3 Ne4 9. Qc2 Bxc3+ 10. bxc3 d6 11. Bd3
			variation => N__('Queen\'s Indian: 5. Bg5 h6 6. Bh4 Bb4 7. e3 g5 8. Bg3 Ne4 9. Qc2 Bxc3+ 10.bxc3 d6 11. Bd3'),
			moves => {
				'f7f5' => 1,
			},
		},
		'rn1qk2r/pbp5/1p1pp2p/5pp1/2PPn3/2PBPNB1/P1Q2PPP/R3K2R w KQkq' => {
			eco => 'E13q',
			# TRANSLATORS: E13q: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. Nc3 Bb7 5. Bg5 h6 6. Bh4 Bb4 7. e3 g5 8. Bg3 Ne4 9. Qc2 Bxc3+ 10. bxc3 d6 11. Bd3 f5
			variation => N__('Queen\'s Indian: 5. Bg5 h6 6. Bh4 Bb4 7. e3 g5 8. Bg3 Ne4 9. Qc2 Bxc3+ 10.bxc3 d6 11. Bd3 f5'),
			moves => {
			},
		},
		'rnbqkb1r/p1pp1ppp/1p2pn2/8/2PP4/4PN2/PP3PPP/RNBQKB1R b KQkq' => {
			eco => 'E14a',
			# TRANSLATORS: E14a: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3
			variation => N__('Queen\'s Indian: 4. e3'),
			moves => {
				'c8b7' => 1,
				'f8b4' => 1,
			},
		},
		'rnbqk2r/p1pp1ppp/1p2pn2/8/1bPP4/4PN2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'E14a',
			# TRANSLATORS: E14a: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb4+
			variation => N__('Queen\'s Indian: 4. e3 Bb4+'),
			moves => {
			},
		},
		'rn1qkb1r/pbpp1ppp/1p2pn2/8/2PP4/4PN2/PP3PPP/RNBQKB1R w KQkq' => {
			eco => 'E14b',
			# TRANSLATORS: E14b: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7
			variation => N__('Queen\'s Indian: 4. e3 Bb7'),
			moves => {
				'b1c3' => 1,
				'f1d3' => 1,
			},
		},
		'rn1qkb1r/pbpp1ppp/1p2pn2/8/2PP4/2N1PN2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'E14c',
			# TRANSLATORS: E14c: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Nc3
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Nc3'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rn1qkb1r/pbp2ppp/1p2pn2/3p4/2PP4/2N1PN2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'E14d',
			# TRANSLATORS: E14d: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Nc3 d5
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Nc3 d5'),
			moves => {
			},
		},
		'rn1qkb1r/pbpp1ppp/1p2pn2/8/2PP4/3BPN2/PP3PPP/RNBQK2R b KQkq' => {
			eco => 'E14e',
			# TRANSLATORS: E14e: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3'),
			moves => {
				'c7c5' => 1,
				'd7d5' => 1,
				'f8b4' => 1,
				'f8e7' => 1,
			},
		},
		'rn1qk2r/pbpp1ppp/1p2pn2/8/1bPP4/3BPN2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'E14f',
			# TRANSLATORS: E14f: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 Bb4+
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 Bb4+'),
			moves => {
				'b1d2' => 1,
			},
		},
		'rn1qk2r/pbpp1ppp/1p2pn2/8/1bPP4/3BPN2/PP1N1PPP/R1BQK2R b KQkq' => {
			eco => 'E14g',
			# TRANSLATORS: E14g: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 Bb4+ 6. Nbd2
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 Bb4+ 6.Nbd2'),
			moves => {
				'c7c5' => 1,
				'e8g8' => 1,
			},
		},
		'rn1qk2r/pb1p1ppp/1p2pn2/2p5/1bPP4/3BPN2/PP1N1PPP/R1BQK2R w KQkq' => {
			eco => 'E14g',
			# TRANSLATORS: E14g: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 Bb4+ 6. Nbd2 c5
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 Bb4+ 6.Nbd2 c5'),
			moves => {
			},
		},
		'rn1q1rk1/pbpp1ppp/1p2pn2/8/1bPP4/3BPN2/PP1N1PPP/R1BQK2R w KQ' => {
			eco => 'E14h',
			# TRANSLATORS: E14h: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 Bb4+ 6. Nbd2 O-O
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 Bb4+ 6.Nbd2 O-O'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rn1q1rk1/pbpp1ppp/1p2pn2/8/1bPP4/3BPN2/PP1N1PPP/R1BQ1RK1 b -' => {
			eco => 'E14h',
			# TRANSLATORS: E14h: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 Bb4+ 6. Nbd2 O-O 7. O-O
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 Bb4+ 6.Nbd2 O-O'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rn1q1rk1/pbp2ppp/1p2pn2/3p4/1bPP4/3BPN2/PP1N1PPP/R1BQ1RK1 w -' => {
			eco => 'E14i',
			# TRANSLATORS: E14i: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 Bb4+ 6. Nbd2 O-O 7. O-O d5
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 Bb4+ 6.Nbd2 O-O 7.O-O d5'),
			moves => {
				'a2a3' => 1,
			},
		},
		'rn1q1rk1/pbp2ppp/1p2pn2/3p4/1bPP4/P2BPN2/1P1N1PPP/R1BQ1RK1 b -' => {
			eco => 'E14i',
			# TRANSLATORS: E14i: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 Bb4+ 6. Nbd2 O-O 7. O-O d5 8. a3
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 Bb4+ 6.Nbd2 O-O 7.O-O d5 8. a3'),
			moves => {
				'b4e7' => 1,
			},
		},
		'rn1q1rk1/pbp1bppp/1p2pn2/3p4/2PP4/P2BPN2/1P1N1PPP/R1BQ1RK1 w -' => {
			eco => 'E14i',
			# TRANSLATORS: E14i: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 Bb4+ 6. Nbd2 O-O 7. O-O d5 8. a3 Be7
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 Bb4+ 6.Nbd2 O-O 7.O-O d5 8. a3 Be7'),
			moves => {
				'b2b4' => 1,
			},
		},
		'rn1q1rk1/pbp1bppp/1p2pn2/3p4/1PPP4/P2BPN2/3N1PPP/R1BQ1RK1 b -' => {
			eco => 'E14i',
			# TRANSLATORS: E14i: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 Bb4+ 6. Nbd2 O-O 7. O-O d5 8. a3 Be7 9. b4
			variation => N__('Queen\'s Indian: Dreev Variation'),
			moves => {
			},
		},
		'rn1qk2r/pbppbppp/1p2pn2/8/2PP4/3BPN2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'E14j',
			# TRANSLATORS: E14j: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 Be7
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 Be7'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rn1qk2r/pbppbppp/1p2pn2/8/2PP4/3BPN2/PP3PPP/RNBQ1RK1 b kq' => {
			eco => 'E14k',
			# TRANSLATORS: E14k: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 Be7 6. O-O
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 Be7 6.O-O'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rn1q1rk1/pbppbppp/1p2pn2/8/2PP4/3BPN2/PP3PPP/RNBQ1RK1 w -' => {
			eco => 'E14k',
			# TRANSLATORS: E14k: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 Be7 6. O-O O-O
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 Be7 6.O-O O-O'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rn1q1rk1/pbppbppp/1p2pn2/8/2PP4/2NBPN2/PP3PPP/R1BQ1RK1 b -' => {
			eco => 'E14l',
			# TRANSLATORS: E14l: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 Be7 6. O-O O-O 7. Nc3
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 Be7 6.O-O O-O 7. Nc3'),
			moves => {
			},
		},
		'rn1qkb1r/pbp2ppp/1p2pn2/3p4/2PP4/3BPN2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'E14m',
			# TRANSLATORS: E14m: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 d5
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 d5'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rn1qkb1r/pbp2ppp/1p2pn2/3p4/2PP4/3BPN2/PP3PPP/RNBQ1RK1 b kq' => {
			eco => 'E14n',
			# TRANSLATORS: E14n: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 d5 6. O-O
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 d5 6.O-O'),
			moves => {
				'f8d6' => 1,
			},
		},
		'rn1qk2r/pbp2ppp/1p1bpn2/3p4/2PP4/3BPN2/PP3PPP/RNBQ1RK1 w kq' => {
			eco => 'E14n',
			# TRANSLATORS: E14n: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 d5 6. O-O Bd6
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 d5 6.O-O Bd6'),
			moves => {
				'b1c3' => 1,
				'b2b3' => 1,
			},
		},
		'rn1qk2r/pbp2ppp/1p1bpn2/3p4/2PP4/1P1BPN2/P4PPP/RNBQ1RK1 b kq' => {
			eco => 'E14o',
			# TRANSLATORS: E14o: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 d5 6. O-O Bd6 7. b3
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 d5 6.O-O Bd6 7. b3'),
			moves => {
			},
		},
		'rn1qk2r/pbp2ppp/1p1bpn2/3p4/2PP4/2NBPN2/PP3PPP/R1BQ1RK1 b kq' => {
			eco => 'E14p',
			# TRANSLATORS: E14p: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 d5 6. O-O Bd6 7. Nc3
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 d5 6.O-O Bd6 7. Nc3'),
			moves => {
			},
		},
		'rn1qkb1r/pb1p1ppp/1p2pn2/2p5/2PP4/3BPN2/PP3PPP/RNBQK2R w KQkq' => {
			eco => 'E14q',
			# TRANSLATORS: E14q: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 c5
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 c5'),
			moves => {
				'b1c3' => 1,
				'e1g1' => 1,
			},
		},
		'rn1qkb1r/pb1p1ppp/1p2pn2/2p5/2PP4/2NBPN2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'E14q',
			# TRANSLATORS: E14q: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 c5 6. Nc3
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 c5 6. Nc3'),
			moves => {
			},
		},
		'rn1qkb1r/pb1p1ppp/1p2pn2/2p5/2PP4/3BPN2/PP3PPP/RNBQ1RK1 b kq' => {
			eco => 'E14r',
			# TRANSLATORS: E14r: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 c5 6. O-O
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 c5 6.O-O'),
			moves => {
				'c5d4' => 1,
				'f8e7' => 1,
			},
		},
		'rn1qkb1r/pb1p1ppp/1p2pn2/8/2Pp4/3BPN2/PP3PPP/RNBQ1RK1 w kq' => {
			eco => 'E14s',
			# TRANSLATORS: E14s: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 c5 6. O-O cxd4
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 c5 6.O-O cxd4'),
			moves => {
				'e3d4' => 1,
			},
		},
		'rn1qkb1r/pb1p1ppp/1p2pn2/8/2PP4/3B1N2/PP3PPP/RNBQ1RK1 b kq' => {
			eco => 'E14s',
			# TRANSLATORS: E14s: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 c5 6. O-O cxd4 7. exd4
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 c5 6.O-O cxd4 7.exd4'),
			moves => {
			},
		},
		'rn1qk2r/pb1pbppp/1p2pn2/2p5/2PP4/3BPN2/PP3PPP/RNBQ1RK1 w kq' => {
			eco => 'E14t',
			# TRANSLATORS: E14t: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 c5 6. O-O Be7
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 c5 6.O-O Be7'),
			moves => {
				'b1c3' => 1,
				'b1d2' => 1,
				'b2b3' => 1,
			},
		},
		'rn1qk2r/pb1pbppp/1p2pn2/2p5/2PP4/3BPN2/PP1N1PPP/R1BQ1RK1 b kq' => {
			eco => 'E14t',
			# TRANSLATORS: E14t: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 c5 6. O-O Be7 7. Nbd2
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 c5 6.O-O Be7 7.Nbd2'),
			moves => {
			},
		},
		'rn1qk2r/pb1pbppp/1p2pn2/2p5/2PP4/1P1BPN2/P4PPP/RNBQ1RK1 b kq' => {
			eco => 'E14u',
			# TRANSLATORS: E14u: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 c5 6. O-O Be7 7. b3
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 c5 6.O-O Be7 7. b3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rn1q1rk1/pb1pbppp/1p2pn2/2p5/2PP4/1P1BPN2/P4PPP/RNBQ1RK1 w -' => {
			eco => 'E14u',
			# TRANSLATORS: E14u: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 c5 6. O-O Be7 7. b3 O-O
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 c5 6.O-O Be7 7. b3'),
			moves => {
				'c1b2' => 1,
			},
		},
		'rn1q1rk1/pb1pbppp/1p2pn2/2p5/2PP4/1P1BPN2/PB3PPP/RN1Q1RK1 b -' => {
			eco => 'E14u',
			# TRANSLATORS: E14u: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 c5 6. O-O Be7 7. b3 O-O 8. Bb2
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 c5 6.O-O Be7 7. b3'),
			moves => {
				'c5d4' => 1,
				'd7d5' => 1,
			},
		},
		'rn1q1rk1/pb2bppp/1p2pn2/2pp4/2PP4/1P1BPN2/PB3PPP/RN1Q1RK1 w -' => {
			eco => 'E14v',
			# TRANSLATORS: E14v: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 c5 6. O-O Be7 7. b3 O-O 8. Bb2 d5
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 c5 6.O-O Be7 7. b3 O-O 8. Bb2 d5'),
			moves => {
			},
		},
		'rn1q1rk1/pb1pbppp/1p2pn2/8/2Pp4/1P1BPN2/PB3PPP/RN1Q1RK1 w -' => {
			eco => 'E14w',
			# TRANSLATORS: E14w: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 c5 6. O-O Be7 7. b3 O-O 8. Bb2 cxd4
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 c5 6.O-O Be7 7. b3 O-O 8. Bb2 cxd4'),
			moves => {
				'e3d4' => 1,
				'f3d4' => 1,
			},
		},
		'rn1q1rk1/pb1pbppp/1p2pn2/8/2PP4/1P1B1N2/PB3PPP/RN1Q1RK1 b -' => {
			eco => 'E14w',
			# TRANSLATORS: E14w: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 c5 6. O-O Be7 7. b3 O-O 8. Bb2 cxd4 9. exd4
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 c5 6.O-O Be7 7. b3 O-O 8. Bb2 cxd4 9.exd4'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rn1q1rk1/pb2bppp/1p2pn2/3p4/2PP4/1P1B1N2/PB3PPP/RN1Q1RK1 w -' => {
			eco => 'E14w',
			# TRANSLATORS: E14w: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 c5 6. O-O Be7 7. b3 O-O 8. Bb2 cxd4 9. exd4 d5
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 c5 6.O-O Be7 7. b3 O-O 8. Bb2 cxd4 9.exd4 d5'),
			moves => {
			},
		},
		'rn1q1rk1/pb1pbppp/1p2pn2/8/2PN4/1P1BP3/PB3PPP/RN1Q1RK1 b -' => {
			eco => 'E14w',
			# TRANSLATORS: E14w: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 c5 6. O-O Be7 7. b3 O-O 8. Bb2 cxd4 9. Nxd4
			variation => N__('Queen\'s Indian: Averbakh Variation'),
			moves => {
			},
		},
		'rn1qk2r/pb1pbppp/1p2pn2/2p5/2PP4/2NBPN2/PP3PPP/R1BQ1RK1 b kq' => {
			eco => 'E14x',
			# TRANSLATORS: E14x: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 c5 6. O-O Be7 7. Nc3
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 c5 6.O-O Be7 7. Nc3'),
			moves => {
				'c5d4' => 1,
				'e8g8' => 1,
			},
		},
		'rn1qk2r/pb1pbppp/1p2pn2/8/2Pp4/2NBPN2/PP3PPP/R1BQ1RK1 w kq' => {
			eco => 'E14x',
			# TRANSLATORS: E14x: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 c5 6. O-O Be7 7. Nc3 cxd4
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 c5 6.O-O Be7 7. Nc3 cxd4'),
			moves => {
				'e3d4' => 1,
			},
		},
		'rn1q1rk1/pb1pbppp/1p2pn2/2p5/2PP4/2NBPN2/PP3PPP/R1BQ1RK1 w -' => {
			eco => 'E14x',
			# TRANSLATORS: E14x: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 c5 6. O-O Be7 7. Nc3 O-O
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 c5 6.O-O Be7 7. Nc3 O-O'),
			moves => {
			},
		},
		'rn1qk2r/pb1pbppp/1p2pn2/8/2PP4/2NB1N2/PP3PPP/R1BQ1RK1 b kq' => {
			eco => 'E14y',
			# TRANSLATORS: E14y: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 c5 6. O-O Be7 7. Nc3 cxd4 8. exd4
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 c5 6.O-O Be7 7. Nc3 cxd4 8.exd4'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rn1qk2r/pb2bppp/1p2pn2/3p4/2PP4/2NB1N2/PP3PPP/R1BQ1RK1 w kq' => {
			eco => 'E14z',
			# TRANSLATORS: E14z: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. e3 Bb7 5. Bd3 c5 6. O-O Be7 7. Nc3 cxd4 8. exd4 d5
			variation => N__('Queen\'s Indian: 4. e3 Bb7 5. Bd3 c5 6.O-O Be7 7. Nc3 cxd4 8.exd4 d5'),
			moves => {
			},
		},
		'rnbqkb1r/p1pp1ppp/1p2pn2/8/2PP4/5NP1/PP2PP1P/RNBQKB1R b KQkq' => {
			eco => 'E15a',
			# TRANSLATORS: E15a: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3
			variation => N__('Queen\'s Indian: 4. g3'),
			moves => {
				'c8a6' => 1,
				'c8b7' => 1,
				'f8b4' => 1,
			},
		},
		'rnbqk2r/p1pp1ppp/1p2pn2/8/1bPP4/5NP1/PP2PP1P/RNBQKB1R w KQkq' => {
			eco => 'E15b',
			# TRANSLATORS: E15b: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb4+
			variation => N__('Queen\'s Indian: 4. g3 Bb4+'),
			moves => {
				'c1d2' => 1,
			},
		},
		'rnbqk2r/p1pp1ppp/1p2pn2/8/1bPP4/5NP1/PP1BPP1P/RN1QKB1R b KQkq' => {
			eco => 'E15b',
			# TRANSLATORS: E15b: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb4+ 5. Bd2
			variation => N__('Queen\'s Indian: 4. g3 Bb4+'),
			moves => {
				'b4d2' => 1,
			},
		},
		'rnbqk2r/p1pp1ppp/1p2pn2/8/2PP4/5NP1/PP1bPP1P/RN1QKB1R w KQkq' => {
			eco => 'E15c',
			# TRANSLATORS: E15c: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb4+ 5. Bd2 Bxd2+
			variation => N__('Queen\'s Indian: 4. g3 Bb4+ 5. Bd2 Bxd2+'),
			moves => {
				'd1d2' => 1,
			},
		},
		'rnbqk2r/p1pp1ppp/1p2pn2/8/2PP4/5NP1/PP1QPP1P/RN2KB1R b KQkq' => {
			eco => 'E15c',
			# TRANSLATORS: E15c: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb4+ 5. Bd2 Bxd2+ 6. Qxd2
			variation => N__('Queen\'s Indian: 4. g3 Bb4+ 5. Bd2 Bxd2+'),
			moves => {
				'c8a6' => 1,
			},
		},
		'rn1qk2r/p1pp1ppp/bp2pn2/8/2PP4/5NP1/PP1QPP1P/RN2KB1R w KQkq' => {
			eco => 'E15c',
			# TRANSLATORS: E15c: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb4+ 5. Bd2 Bxd2+ 6. Qxd2 Ba6
			variation => N__('Queen\'s Indian: 4. g3 Bb4+ 5. Bd2 Bxd2+ 6.Qxd2 Ba6'),
			moves => {
			},
		},
		'rn1qkb1r/p1pp1ppp/bp2pn2/8/2PP4/5NP1/PP2PP1P/RNBQKB1R w KQkq' => {
			eco => 'E15d',
			# TRANSLATORS: E15d: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6
			variation => N__('Queen\'s Indian: Nimzowitsch Variation (4. g3 Ba6)'),
			moves => {
				'b1d2' => 1,
				'b2b3' => 1,
				'd1a4' => 1,
				'd1b3' => 1,
				'd1c2' => 1,
			},
		},
		'rn1qkb1r/p1pp1ppp/bp2pn2/8/2PP4/1Q3NP1/PP2PP1P/RNB1KB1R b KQkq' => {
			eco => 'E15d',
			# TRANSLATORS: E15d: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. Qb3
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. Qb3'),
			moves => {
			},
		},
		'rn1qkb1r/p1pp1ppp/bp2pn2/8/2PP4/5NP1/PPQ1PP1P/RNB1KB1R b KQkq' => {
			eco => 'E15d',
			# TRANSLATORS: E15d: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. Qc2
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. Qc2'),
			moves => {
			},
		},
		'rn1qkb1r/p1pp1ppp/bp2pn2/8/2PP4/5NP1/PP1NPP1P/R1BQKB1R b KQkq' => {
			eco => 'E15e',
			# TRANSLATORS: E15e: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. Nbd2
			variation => N__('Queen\'s Indian: Nimzowitsch, 5.Nbd2'),
			moves => {
				'a6b7' => 1,
				'c7c5' => 1,
				'f8b4' => 1,
			},
		},
		'rn1qkb1r/p2p1ppp/bp2pn2/2p5/2PP4/5NP1/PP1NPP1P/R1BQKB1R w KQkq' => {
			eco => 'E15e',
			# TRANSLATORS: E15e: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. Nbd2 c5
			variation => N__('Queen\'s Indian: Nimzowitsch, 5.Nbd2 c5'),
			moves => {
			},
		},
		'rn1qkb1r/pbpp1ppp/1p2pn2/8/2PP4/5NP1/PP1NPP1P/R1BQKB1R w KQkq' => {
			eco => 'E15f',
			# TRANSLATORS: E15f: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. Nbd2 Bb7
			variation => N__('Queen\'s Indian: Nimzowitsch, 5.Nbd2 Bb7'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rn1qkb1r/pbpp1ppp/1p2pn2/8/2PP4/5NP1/PP1NPPBP/R1BQK2R b KQkq' => {
			eco => 'E15f',
			# TRANSLATORS: E15f: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. Nbd2 Bb7 6. Bg2
			variation => N__('Queen\'s Indian: Nimzowitsch, 5.Nbd2 Bb7 6. Bg2'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rn1qkb1r/pb1p1ppp/1p2pn2/2p5/2PP4/5NP1/PP1NPPBP/R1BQK2R w KQkq' => {
			eco => 'E15f',
			# TRANSLATORS: E15f: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. Nbd2 Bb7 6. Bg2 c5
			variation => N__('Queen\'s Indian: Nimzowitsch, 5.Nbd2 Bb7 6. Bg2 c5'),
			moves => {
			},
		},
		'rn1qk2r/p1pp1ppp/bp2pn2/8/1bPP4/5NP1/PP1NPP1P/R1BQKB1R w KQkq' => {
			eco => 'E15g',
			# TRANSLATORS: E15g: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. Nbd2 Bb4
			variation => N__('Queen\'s Indian: Nimzowitsch, 5.Nbd2 Bb4'),
			moves => {
			},
		},
		'rn1qkb1r/p1pp1ppp/bp2pn2/8/Q1PP4/5NP1/PP2PP1P/RNB1KB1R b KQkq' => {
			eco => 'E15h',
			# TRANSLATORS: E15h: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. Qa4
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. Qa4'),
			moves => {
				'c7c5' => 1,
				'c7c6' => 1,
				'f8e7' => 1,
			},
		},
		'rn1qk2r/p1ppbppp/bp2pn2/8/Q1PP4/5NP1/PP2PP1P/RNB1KB1R w KQkq' => {
			eco => 'E15h',
			# TRANSLATORS: E15h: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. Qa4 Be7
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. Qa4 Be7'),
			moves => {
			},
		},
		'rn1qkb1r/p2p1ppp/bpp1pn2/8/Q1PP4/5NP1/PP2PP1P/RNB1KB1R w KQkq' => {
			eco => 'E15i',
			# TRANSLATORS: E15i: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. Qa4 c6
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. Qa4 c6'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rn1qkb1r/p2p1ppp/bpp1pn2/8/Q1PP4/2N2NP1/PP2PP1P/R1B1KB1R b KQkq' => {
			eco => 'E15i',
			# TRANSLATORS: E15i: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. Qa4 c6 6. Nc3
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. Qa4 c6'),
			moves => {
				'b6b5' => 1,
			},
		},
		'rn1qkb1r/p2p1ppp/b1p1pn2/1p6/Q1PP4/2N2NP1/PP2PP1P/R1B1KB1R w KQkq' => {
			eco => 'E15i',
			# TRANSLATORS: E15i: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. Qa4 c6 6. Nc3 b5
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. Qa4 c6 6. Nc3 b5'),
			moves => {
			},
		},
		'rn1qkb1r/p2p1ppp/bp2pn2/2p5/Q1PP4/5NP1/PP2PP1P/RNB1KB1R w KQkq' => {
			eco => 'E15j',
			# TRANSLATORS: E15j: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. Qa4 c5
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. Qa4 c5'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rn1qkb1r/p2p1ppp/bp2pn2/2p5/Q1PP4/5NP1/PP2PPBP/RNB1K2R b KQkq' => {
			eco => 'E15j',
			# TRANSLATORS: E15j: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. Qa4 c5 6. Bg2
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. Qa4 c5'),
			moves => {
				'a6b7' => 1,
			},
		},
		'rn1qkb1r/pb1p1ppp/1p2pn2/2p5/Q1PP4/5NP1/PP2PPBP/RNB1K2R w KQkq' => {
			eco => 'E15j',
			# TRANSLATORS: E15j: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. Qa4 c5 6. Bg2 Bb7
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. Qa4 c5 6. Bg2 Bb7'),
			moves => {
				'd4c5' => 1,
				'e1g1' => 1,
			},
		},
		'rn1qkb1r/pb1p1ppp/1p2pn2/2P5/Q1P5/5NP1/PP2PPBP/RNB1K2R b KQkq' => {
			eco => 'E15j',
			# TRANSLATORS: E15j: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. Qa4 c5 6. Bg2 Bb7 7. dxc5
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. Qa4 c5 6. Bg2 Bb7 7.dxc5'),
			moves => {
			},
		},
		'rn1qkb1r/pb1p1ppp/1p2pn2/2p5/Q1PP4/5NP1/PP2PPBP/RNB2RK1 b kq' => {
			eco => 'E15k',
			# TRANSLATORS: E15k: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. Qa4 c5 6. Bg2 Bb7 7. O-O
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. Qa4 c5 6. Bg2 Bb7 7.O-O'),
			moves => {
			},
		},
		'rn1qkb1r/p1pp1ppp/bp2pn2/8/2PP4/1P3NP1/P3PP1P/RNBQKB1R b KQkq' => {
			eco => 'E15l',
			# TRANSLATORS: E15l: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. b3
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. b3 '),
			moves => {
				'a6b7' => 1,
				'b6b5' => 1,
				'd7d5' => 1,
				'f8b4' => 1,
			},
		},
		'rn1qkb1r/p1pp1ppp/b3pn2/1p6/2PP4/1P3NP1/P3PP1P/RNBQKB1R w KQkq' => {
			eco => 'E15l',
			# TRANSLATORS: E15l: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. b3 b5
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. b3 b5'),
			moves => {
				'c4b5' => 1,
			},
		},
		'rn1qkb1r/p1pp1ppp/b3pn2/1P6/3P4/1P3NP1/P3PP1P/RNBQKB1R b KQkq' => {
			eco => 'E15l',
			# TRANSLATORS: E15l: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. b3 b5 6. cxb5
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. b3 b5 6.cxb5'),
			moves => {
			},
		},
		'rn1qkb1r/p1p2ppp/bp2pn2/3p4/2PP4/1P3NP1/P3PP1P/RNBQKB1R w KQkq' => {
			eco => 'E15m',
			# TRANSLATORS: E15m: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. b3 d5
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. b3 d5'),
			moves => {
				'c4d5' => 1,
				'f1g2' => 1,
			},
		},
		'rn1qkb1r/p1p2ppp/bp2pn2/3P4/3P4/1P3NP1/P3PP1P/RNBQKB1R b KQkq' => {
			eco => 'E15m',
			# TRANSLATORS: E15m: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. b3 d5 6. cxd5
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. b3 d5 6.cxd5'),
			moves => {
			},
		},
		'rn1qkb1r/p1p2ppp/bp2pn2/3p4/2PP4/1P3NP1/P3PPBP/RNBQK2R b KQkq' => {
			eco => 'E15m',
			# TRANSLATORS: E15m: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. b3 d5 6. Bg2
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. b3 d5 6. Bg2'),
			moves => {
			},
		},
		'rn1qkb1r/pbpp1ppp/1p2pn2/8/2PP4/1P3NP1/P3PP1P/RNBQKB1R w KQkq' => {
			eco => 'E15n',
			# TRANSLATORS: E15n: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. b3 Bb7
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. b3 Bb7'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rn1qkb1r/pbpp1ppp/1p2pn2/8/2PP4/1P3NP1/P3PPBP/RNBQK2R b KQkq' => {
			eco => 'E15n',
			# TRANSLATORS: E15n: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. b3 Bb7 6. Bg2
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. b3 Bb7 6. Bg2'),
			moves => {
				'f8b4' => 1,
			},
		},
		'rn1qk2r/pbpp1ppp/1p2pn2/8/1bPP4/1P3NP1/P3PPBP/RNBQK2R w KQkq' => {
			eco => 'E15n',
			# TRANSLATORS: E15n: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. b3 Bb7 6. Bg2 Bb4+
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. b3 Bb7 6. Bg2'),
			moves => {
				'c1d2' => 1,
			},
		},
		'rn1qk2r/pbpp1ppp/1p2pn2/8/1bPP4/1P3NP1/P2BPPBP/RN1QK2R b KQkq' => {
			eco => 'E15n',
			# TRANSLATORS: E15n: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. b3 Bb7 6. Bg2 Bb4+ 7. Bd2
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. b3 Bb7 6. Bg2'),
			moves => {
				'a7a5' => 1,
			},
		},
		'rn1qk2r/1bpp1ppp/1p2pn2/p7/1bPP4/1P3NP1/P2BPPBP/RN1QK2R w KQkq' => {
			eco => 'E15n',
			# TRANSLATORS: E15n: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. b3 Bb7 6. Bg2 Bb4+ 7. Bd2 a5
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. b3 Bb7, 7... a5'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rn1qk2r/1bpp1ppp/1p2pn2/p7/1bPP4/1P3NP1/P2BPPBP/RN1Q1RK1 b kq' => {
			eco => 'E15n',
			# TRANSLATORS: E15n: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. b3 Bb7 6. Bg2 Bb4+ 7. Bd2 a5 8. O-O
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. b3 Bb7, 7... a5'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rn1q1rk1/1bpp1ppp/1p2pn2/p7/1bPP4/1P3NP1/P2BPPBP/RN1Q1RK1 w -' => {
			eco => 'E15n',
			# TRANSLATORS: E15n: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. b3 Bb7 6. Bg2 Bb4+ 7. Bd2 a5 8. O-O O-O
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. b3 Bb7, 7... a5 8.O-O O-O'),
			moves => {
			},
		},
		'rn1qk2r/p1pp1ppp/bp2pn2/8/1bPP4/1P3NP1/P3PP1P/RNBQKB1R w KQkq' => {
			eco => 'E15o',
			# TRANSLATORS: E15o: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. b3 Bb4+
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. b3 Bb4+'),
			moves => {
				'c1d2' => 1,
			},
		},
		'rn1qk2r/p1pp1ppp/bp2pn2/8/1bPP4/1P3NP1/P2BPP1P/RN1QKB1R b KQkq' => {
			eco => 'E15o',
			# TRANSLATORS: E15o: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. b3 Bb4+ 6. Bd2
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. b3 Bb4+'),
			moves => {
				'b4e7' => 1,
			},
		},
		'rn1qk2r/p1ppbppp/bp2pn2/8/2PP4/1P3NP1/P2BPP1P/RN1QKB1R w KQkq' => {
			eco => 'E15o',
			# TRANSLATORS: E15o: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. b3 Bb4+ 6. Bd2 Be7
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. b3 Bb4+ 6. Bd2 Be7'),
			moves => {
				'b1c3' => 1,
				'f1g2' => 1,
			},
		},
		'rn1qk2r/p1ppbppp/bp2pn2/8/2PP4/1PN2NP1/P2BPP1P/R2QKB1R b KQkq' => {
			eco => 'E15o',
			# TRANSLATORS: E15o: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. b3 Bb4+ 6. Bd2 Be7 7. Nc3
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. b3 Bb4+ 6. Bd2 Be7 7. Nc3'),
			moves => {
			},
		},
		'rn1qk2r/p1ppbppp/bp2pn2/8/2PP4/1P3NP1/P2BPPBP/RN1QK2R b KQkq' => {
			eco => 'E15p',
			# TRANSLATORS: E15p: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. b3 Bb4+ 6. Bd2 Be7 7. Bg2
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. b3 Bb4+ 6. Bd2 Be7 7. Bg2'),
			moves => {
				'c7c6' => 1,
				'd7d5' => 1,
			},
		},
		'rn1qk2r/p1p1bppp/bp2pn2/3p4/2PP4/1P3NP1/P2BPPBP/RN1QK2R w KQkq' => {
			eco => 'E15p',
			# TRANSLATORS: E15p: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. b3 Bb4+ 6. Bd2 Be7 7. Bg2 d5
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. b3 Bb4+ 6. Bd2 Be7 7. Bg2 d5'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rn1qk2r/p1p1bppp/bp2pn2/3P4/3P4/1P3NP1/P2BPPBP/RN1QK2R b KQkq' => {
			eco => 'E15p',
			# TRANSLATORS: E15p: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. b3 Bb4+ 6. Bd2 Be7 7. Bg2 d5 8. cxd5
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. b3 Bb4+ 6. Bd2 Be7 7. Bg2 d5'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rn1qk2r/p1p1bppp/bp3n2/3p4/3P4/1P3NP1/P2BPPBP/RN1QK2R w KQkq' => {
			eco => 'E15p',
			# TRANSLATORS: E15p: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. b3 Bb4+ 6. Bd2 Be7 7. Bg2 d5 8. cxd5 exd5
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. b3 Bb4+ 6. Bd2 Be7 7. Bg2 d5'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rn1qk2r/p1p1bppp/bp3n2/3p4/3P4/1P3NP1/P2BPPBP/RN1Q1RK1 b kq' => {
			eco => 'E15p',
			# TRANSLATORS: E15p: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. b3 Bb4+ 6. Bd2 Be7 7. Bg2 d5 8. cxd5 exd5 9. O-O
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. b3 Bb4+ 6. Bd2 Be7 7. Bg2 d5'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rn1q1rk1/p1p1bppp/bp3n2/3p4/3P4/1P3NP1/P2BPPBP/RN1Q1RK1 w -' => {
			eco => 'E15p',
			# TRANSLATORS: E15p: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. b3 Bb4+ 6. Bd2 Be7 7. Bg2 d5 8. cxd5 exd5 9. O-O O-O
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. b3 Bb4+ 6. Bd2 Be7 7. Bg2 d5'),
			moves => {
			},
		},
		'rn1qk2r/p2pbppp/bpp1pn2/8/2PP4/1P3NP1/P2BPPBP/RN1QK2R w KQkq' => {
			eco => 'E15q',
			# TRANSLATORS: E15q: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. b3 Bb4+ 6. Bd2 Be7 7. Bg2 c6
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. b3 Bb4+ 6. Bd2 Be7 7. Bg2 c6'),
			moves => {
				'd2c3' => 1,
				'e1g1' => 1,
			},
		},
		'rn1qk2r/p2pbppp/bpp1pn2/8/2PP4/1P3NP1/P2BPPBP/RN1Q1RK1 b kq' => {
			eco => 'E15q',
			# TRANSLATORS: E15q: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. b3 Bb4+ 6. Bd2 Be7 7. Bg2 c6 8. O-O
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. b3 Bb4+ 6. Bd2 Be7 7. Bg2 c6 8.O-O'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rn1qk2r/p3bppp/bpp1pn2/3p4/2PP4/1P3NP1/P2BPPBP/RN1Q1RK1 w kq' => {
			eco => 'E15q',
			# TRANSLATORS: E15q: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. b3 Bb4+ 6. Bd2 Be7 7. Bg2 c6 8. O-O d5
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. b3 Bb4+ 6. Bd2 Be7 7. Bg2 c6 8.O-O d5'),
			moves => {
			},
		},
		'rn1qk2r/p2pbppp/bpp1pn2/8/2PP4/1PB2NP1/P3PPBP/RN1QK2R b KQkq' => {
			eco => 'E15r',
			# TRANSLATORS: E15r: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. b3 Bb4+ 6. Bd2 Be7 7. Bg2 c6 8. Bc3
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. b3 Bb4+, Main Line'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rn1qk2r/p3bppp/bpp1pn2/3p4/2PP4/1PB2NP1/P3PPBP/RN1QK2R w KQkq' => {
			eco => 'E15r',
			# TRANSLATORS: E15r: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. b3 Bb4+ 6. Bd2 Be7 7. Bg2 c6 8. Bc3 d5
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. b3 Bb4+, Main Line'),
			moves => {
				'f3e5' => 1,
			},
		},
		'rn1qk2r/p3bppp/bpp1pn2/3pN3/2PP4/1PB3P1/P3PPBP/RN1QK2R b KQkq' => {
			eco => 'E15s',
			# TRANSLATORS: E15s: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. b3 Bb4+ 6. Bd2 Be7 7. Bg2 c6 8. Bc3 d5 9. Ne5
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. b3 Bb4+, Main Line, 9. Ne5'),
			moves => {
				'f6d7' => 1,
			},
		},
		'rn1qk2r/p2nbppp/bpp1p3/3pN3/2PP4/1PB3P1/P3PPBP/RN1QK2R w KQkq' => {
			eco => 'E15s',
			# TRANSLATORS: E15s: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Ba6 5. b3 Bb4+ 6. Bd2 Be7 7. Bg2 c6 8. Bc3 d5 9. Ne5 Nfd7
			variation => N__('Queen\'s Indian: Nimzowitsch, 5. b3 Bb4+, Main Line, 9. Ne5 Nfd7'),
			moves => {
			},
		},
		'rn1qkb1r/pbpp1ppp/1p2pn2/8/2PP4/5NP1/PP2PP1P/RNBQKB1R w KQkq' => {
			eco => 'E15t',
			# TRANSLATORS: E15t: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7
			variation => N__('Queen\'s Indian: 4. g3 Bb7'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rn1qkb1r/pbpp1ppp/1p2pn2/8/2PP4/5NP1/PP2PPBP/RNBQK2R b KQkq' => {
			eco => 'E15t',
			# TRANSLATORS: E15t: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2
			variation => N__('Queen\'s Indian: 4. g3 Bb7'),
			moves => {
				'c7c5' => 1,
				'd8c8' => 1,
				'f8b4' => 1,
				'f8e7' => 1,
			},
		},
		'rnq1kb1r/pbpp1ppp/1p2pn2/8/2PP4/5NP1/PP2PPBP/RNBQK2R w KQkq' => {
			eco => 'E15t',
			# TRANSLATORS: E15t: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Qc8
			variation => N__('Queen\'s Indian: 4. g3 Bb7 5. Bg2 Qc8'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnq1kb1r/pbpp1ppp/1p2pn2/8/2PP4/5NP1/PP2PPBP/RNBQ1RK1 b kq' => {
			eco => 'E15t',
			# TRANSLATORS: E15t: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Qc8 6. O-O
			variation => N__('Queen\'s Indian: 4. g3 Bb7 5. Bg2 Qc8'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnq1kb1r/pb1p1ppp/1p2pn2/2p5/2PP4/5NP1/PP2PPBP/RNBQ1RK1 w kq' => {
			eco => 'E15t',
			# TRANSLATORS: E15t: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Qc8 6. O-O c5
			variation => N__('Queen\'s Indian: 4. g3 Bb7 5. Bg2 Qc8'),
			moves => {
				'd4d5' => 1,
			},
		},
		'rnq1kb1r/pb1p1ppp/1p2pn2/2pP4/2P5/5NP1/PP2PPBP/RNBQ1RK1 b kq' => {
			eco => 'E15t',
			# TRANSLATORS: E15t: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Qc8 6. O-O c5 7. d5
			variation => N__('Queen\'s Indian: 4. g3 Bb7 5. Bg2 Qc8 6.O-O c5 7. d5'),
			moves => {
			},
		},
		'rn1qkb1r/pb1p1ppp/1p2pn2/2p5/2PP4/5NP1/PP2PPBP/RNBQK2R w KQkq' => {
			eco => 'E15u',
			# TRANSLATORS: E15u: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 c5
			variation => N__('Queen\'s Indian: 4. g3 Bb7 5. Bg2 c5'),
			moves => {
				'd4d5' => 1,
			},
		},
		'rn1qkb1r/pb1p1ppp/1p2pn2/2pP4/2P5/5NP1/PP2PPBP/RNBQK2R b KQkq' => {
			eco => 'E15u',
			# TRANSLATORS: E15u: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 c5 6. d5
			variation => N__('Queen\'s Indian: 4. g3 Bb7 5. Bg2 c5'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rn1qkb1r/pb1p1ppp/1p3n2/2pp4/2P5/5NP1/PP2PPBP/RNBQK2R w KQkq' => {
			eco => 'E15u',
			# TRANSLATORS: E15u: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 c5 6. d5 exd5
			variation => N__('Queen\'s Indian: 4. g3 Bb7 5. Bg2 c5'),
			moves => {
				'f3g5' => 1,
				'f3h4' => 1,
			},
		},
		'rn1qkb1r/pb1p1ppp/1p3n2/2pp2N1/2P5/6P1/PP2PPBP/RNBQK2R b KQkq' => {
			eco => 'E15u',
			# TRANSLATORS: E15u: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 c5 6. d5 exd5 7. Ng5
			variation => N__('Queen\'s Indian: Buerger Variation'),
			moves => {
			},
		},
		'rn1qkb1r/pb1p1ppp/1p3n2/2pp4/2P4N/6P1/PP2PPBP/RNBQK2R b KQkq' => {
			eco => 'E15v',
			# TRANSLATORS: E15v: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 c5 6. d5 exd5 7. Nh4
			variation => N__('Queen\'s Indian: Rubinstein Variation'),
			moves => {
			},
		},
		'rn1qk2r/pbpp1ppp/1p2pn2/8/1bPP4/5NP1/PP2PPBP/RNBQK2R w KQkq' => {
			eco => 'E16a',
			# TRANSLATORS: E16a: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Bb4+
			variation => N__('Queen\'s Indian: Capablanca Variation'),
			moves => {
				'b1d2' => 1,
				'c1d2' => 1,
			},
		},
		'rn1qk2r/pbpp1ppp/1p2pn2/8/1bPP4/5NP1/PP1NPPBP/R1BQK2R b KQkq' => {
			eco => 'E16b',
			# TRANSLATORS: E16b: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Bb4+ 6. Nbd2
			variation => N__('Queen\'s Indian: Capablanca, 6.Nbd2'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rn1q1rk1/pbpp1ppp/1p2pn2/8/1bPP4/5NP1/PP1NPPBP/R1BQK2R w KQ' => {
			eco => 'E16c',
			# TRANSLATORS: E16c: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Bb4+ 6. Nbd2 O-O
			variation => N__('Queen\'s Indian: Capablanca, 6.Nbd2 O-O'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rn1q1rk1/pbpp1ppp/1p2pn2/8/1bPP4/5NP1/PP1NPPBP/R1BQ1RK1 b -' => {
			eco => 'E16c',
			# TRANSLATORS: E16c: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Bb4+ 6. Nbd2 O-O 7. O-O
			variation => N__('Queen\'s Indian: Capablanca, 6.Nbd2 O-O'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rn1q1rk1/pbp2ppp/1p2pn2/3p4/1bPP4/5NP1/PP1NPPBP/R1BQ1RK1 w -' => {
			eco => 'E16d',
			# TRANSLATORS: E16d: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Bb4+ 6. Nbd2 O-O 7. O-O d5
			variation => N__('Queen\'s Indian: Capablanca, 6.Nbd2 O-O 7.O-O d5'),
			moves => {
			},
		},
		'rn1qk2r/pbpp1ppp/1p2pn2/8/1bPP4/5NP1/PP1BPPBP/RN1QK2R b KQkq' => {
			eco => 'E16e',
			# TRANSLATORS: E16e: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Bb4+ 6. Bd2
			variation => N__('Queen\'s Indian: Capablanca, 6. Bd2'),
			moves => {
				'a7a5' => 1,
				'b4d2' => 1,
				'b4e7' => 1,
				'c7c5' => 1,
				'd8e7' => 1,
			},
		},
		'rn1qk2r/pb1p1ppp/1p2pn2/2p5/1bPP4/5NP1/PP1BPPBP/RN1QK2R w KQkq' => {
			eco => 'E16e',
			# TRANSLATORS: E16e: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Bb4+ 6. Bd2 c5
			variation => N__('Queen\'s Indian: Capablanca, 6. Bd2 c5'),
			moves => {
			},
		},
		'rn1qk2r/1bpp1ppp/1p2pn2/p7/1bPP4/5NP1/PP1BPPBP/RN1QK2R w KQkq' => {
			eco => 'E16f',
			# TRANSLATORS: E16f: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Bb4+ 6. Bd2 a5
			variation => N__('Queen\'s Indian: Capablanca, Yates Variation'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rn1qk2r/1bpp1ppp/1p2pn2/p7/1bPP4/5NP1/PP1BPPBP/RN1Q1RK1 b kq' => {
			eco => 'E16f',
			# TRANSLATORS: E16f: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Bb4+ 6. Bd2 a5 7. O-O
			variation => N__('Queen\'s Indian: Capablanca, Yates Variation'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rn1q1rk1/1bpp1ppp/1p2pn2/p7/1bPP4/5NP1/PP1BPPBP/RN1Q1RK1 w -' => {
			eco => 'E16g',
			# TRANSLATORS: E16g: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Bb4+ 6. Bd2 a5 7. O-O O-O
			variation => N__('Queen\'s Indian: Capablanca, Yates, 7.O-O O-O'),
			moves => {
			},
		},
		'rn2k2r/pbppqppp/1p2pn2/8/1bPP4/5NP1/PP1BPPBP/RN1QK2R w KQkq' => {
			eco => 'E16h',
			# TRANSLATORS: E16h: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Bb4+ 6. Bd2 Qe7
			variation => N__('Queen\'s Indian: Capablanca, Nimzowitsch Variation'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rn2k2r/pbppqppp/1p2pn2/8/1bPP4/5NP1/PP1BPPBP/RN1Q1RK1 b kq' => {
			eco => 'E16h',
			# TRANSLATORS: E16h: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Bb4+ 6. Bd2 Qe7 7. O-O
			variation => N__('Queen\'s Indian: Capablanca, Nimzowitsch Variation'),
			moves => {
				'b4d2' => 1,
			},
		},
		'rn2k2r/pbppqppp/1p2pn2/8/2PP4/5NP1/PP1bPPBP/RN1Q1RK1 w kq' => {
			eco => 'E16h',
			# TRANSLATORS: E16h: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Bb4+ 6. Bd2 Qe7 7. O-O Bxd2
			variation => N__('Queen\'s Indian: Capablanca, Nimzowitsch Variation'),
			moves => {
				'd1d2' => 1,
			},
		},
		'rn2k2r/pbppqppp/1p2pn2/8/2PP4/5NP1/PP1QPPBP/RN3RK1 b kq' => {
			eco => 'E16i',
			# TRANSLATORS: E16i: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Bb4+ 6. Bd2 Qe7 7. O-O Bxd2 8. Qxd2
			variation => N__('Queen\'s Indian: Capablanca, Nimzowitsch, 7.O-O Bxd2 8.Qxd2'),
			moves => {
			},
		},
		'rn1qk2r/pbppbppp/1p2pn2/8/2PP4/5NP1/PP1BPPBP/RN1QK2R w KQkq' => {
			eco => 'E16j',
			# TRANSLATORS: E16j: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Bb4+ 6. Bd2 Be7
			variation => N__('Queen\'s Indian: Capablanca, Riumin Variation'),
			moves => {
				'b1c3' => 1,
			},
		},
		'rn1qk2r/pbppbppp/1p2pn2/8/2PP4/2N2NP1/PP1BPPBP/R2QK2R b KQkq' => {
			eco => 'E16k',
			# TRANSLATORS: E16k: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Bb4+ 6. Bd2 Be7 7. Nc3
			variation => N__('Queen\'s Indian: Capablanca, Riumin, 7. Nc3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rn1q1rk1/pbppbppp/1p2pn2/8/2PP4/2N2NP1/PP1BPPBP/R2QK2R w KQ' => {
			eco => 'E16l',
			# TRANSLATORS: E16l: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Bb4+ 6. Bd2 Be7 7. Nc3 O-O
			variation => N__('Queen\'s Indian: Capablanca, Riumin, 7. Nc3 O-O'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rn1q1rk1/pbppbppp/1p2pn2/8/2PP4/2N2NP1/PP1BPPBP/R2Q1RK1 b -' => {
			eco => 'E16m',
			# TRANSLATORS: E16m: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Bb4+ 6. Bd2 Be7 7. Nc3 O-O 8. O-O
			variation => N__('Queen\'s Indian: Capablanca, Riumin, 7. Nc3 O-O 8.O-O'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rn1q1rk1/pbp1bppp/1p2pn2/3p4/2PP4/2N2NP1/PP1BPPBP/R2Q1RK1 w -' => {
			eco => 'E16n',
			# TRANSLATORS: E16n: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Bb4+ 6. Bd2 Be7 7. Nc3 O-O 8. O-O d5
			variation => N__('Queen\'s Indian: Capablanca, Riumin, 7. Nc3 O-O 8.O-O d5'),
			moves => {
			},
		},
		'rn1qk2r/pbpp1ppp/1p2pn2/8/2PP4/5NP1/PP1bPPBP/RN1QK2R w KQkq' => {
			eco => 'E16o',
			# TRANSLATORS: E16o: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Bb4+ 6. Bd2 Bxd2+
			variation => N__('Queen\'s Indian: Capablanca, 6...Bxd2+'),
			moves => {
				'b1d2' => 1,
				'd1d2' => 1,
			},
		},
		'rn1qk2r/pbpp1ppp/1p2pn2/8/2PP4/5NP1/PP1NPPBP/R2QK2R b KQkq' => {
			eco => 'E16o',
			# TRANSLATORS: E16o: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Bb4+ 6. Bd2 Bxd2+ 7. Nbxd2
			variation => N__('Queen\'s Indian: Capablanca, 6...Bxd2+ 7.Nbxd2'),
			moves => {
			},
		},
		'rn1qk2r/pbpp1ppp/1p2pn2/8/2PP4/5NP1/PP1QPPBP/RN2K2R b KQkq' => {
			eco => 'E16p',
			# TRANSLATORS: E16p: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Bb4+ 6. Bd2 Bxd2+ 7. Qxd2
			variation => N__('Queen\'s Indian: Capablanca, 6...Bxd2+ 7.Qxd2'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rn1q1rk1/pbpp1ppp/1p2pn2/8/2PP4/5NP1/PP1QPPBP/RN2K2R w KQ' => {
			eco => 'E16q',
			# TRANSLATORS: E16q: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Bb4+ 6. Bd2 Bxd2+ 7. Qxd2 O-O
			variation => N__('Queen\'s Indian: Capablanca, 6...Bxd2+ 7.Qxd2 O-O'),
			moves => {
				'b1c3' => 1,
				'e1g1' => 1,
			},
		},
		'rn1q1rk1/pbpp1ppp/1p2pn2/8/2PP4/5NP1/PP1QPPBP/RN3RK1 b -' => {
			eco => 'E16q',
			# TRANSLATORS: E16q: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Bb4+ 6. Bd2 Bxd2+ 7. Qxd2 O-O 8. O-O
			variation => N__('Queen\'s Indian: Capablanca, 6...Bxd2+ 7.Qxd2 O-O 8.O-O'),
			moves => {
			},
		},
		'rn1q1rk1/pbpp1ppp/1p2pn2/8/2PP4/2N2NP1/PP1QPPBP/R3K2R b KQ' => {
			eco => 'E16r',
			# TRANSLATORS: E16r: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Bb4+ 6. Bd2 Bxd2+ 7. Qxd2 O-O 8. Nc3
			variation => N__('Queen\'s Indian: Capablanca, 6...Bxd2+ 7.Qxd2 O-O 8. Nc3'),
			moves => {
			},
		},
		'rn1qk2r/pbppbppp/1p2pn2/8/2PP4/5NP1/PP2PPBP/RNBQK2R w KQkq' => {
			eco => 'E17a',
			# TRANSLATORS: E17a: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7
			variation => N__('Queen\'s Indian: 5. Bg2 Be7'),
			moves => {
				'b1c3' => 1,
				'e1g1' => 1,
			},
		},
		'rn1qk2r/pbppbppp/1p2pn2/8/2PP4/2N2NP1/PP2PPBP/R1BQK2R b KQkq' => {
			eco => 'E17b',
			# TRANSLATORS: E17b: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. Nc3
			variation => N__('Queen\'s Indian: 6. Nc3'),
			moves => {
				'd7d5' => 1,
				'e8g8' => 1,
				'f6e4' => 1,
			},
		},
		'rn1qk2r/pbp1bppp/1p2pn2/3p4/2PP4/2N2NP1/PP2PPBP/R1BQK2R w KQkq' => {
			eco => 'E17b',
			# TRANSLATORS: E17b: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. Nc3 d5
			variation => N__('Queen\'s Indian: 6. Nc3 d5'),
			moves => {
			},
		},
		'rn1q1rk1/pbppbppp/1p2pn2/8/2PP4/2N2NP1/PP2PPBP/R1BQK2R w KQ' => {
			eco => 'E17c',
			# TRANSLATORS: E17c: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. Nc3 O-O
			variation => N__('Queen\'s Indian: 6. Nc3 O-O'),
			moves => {
				'd1c2' => 1,
			},
		},
		'rn1q1rk1/pbppbppp/1p2pn2/8/2PP4/2N2NP1/PPQ1PPBP/R1B1K2R b KQ' => {
			eco => 'E17d',
			# TRANSLATORS: E17d: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. Nc3 O-O 7. Qc2
			variation => N__('Queen\'s Indian: 6. Nc3 O-O 7. Qc2'),
			moves => {
				'c7c5' => 1,
				'd7d5' => 1,
			},
		},
		'rn1q1rk1/pb1pbppp/1p2pn2/2p5/2PP4/2N2NP1/PPQ1PPBP/R1B1K2R w KQ' => {
			eco => 'E17e',
			# TRANSLATORS: E17e: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. Nc3 O-O 7. Qc2 c5
			variation => N__('Queen\'s Indian: 6. Nc3 O-O 7. Qc2 c5'),
			moves => {
			},
		},
		'rn1q1rk1/pbp1bppp/1p2pn2/3p4/2PP4/2N2NP1/PPQ1PPBP/R1B1K2R w KQ' => {
			eco => 'E17f',
			# TRANSLATORS: E17f: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. Nc3 O-O 7. Qc2 d5
			variation => N__('Queen\'s Indian: 6. Nc3 O-O 7. Qc2 d5'),
			moves => {
			},
		},
		'rn1qk2r/pbppbppp/1p2p3/8/2PPn3/2N2NP1/PP2PPBP/R1BQK2R w KQkq' => {
			eco => 'E17g',
			# TRANSLATORS: E17g: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. Nc3 Ne4
			variation => N__('Queen\'s Indian: 6. Nc3 Ne4'),
			moves => {
				'c1d2' => 1,
				'd1c2' => 1,
			},
		},
		'rn1qk2r/pbppbppp/1p2p3/8/2PPn3/2N2NP1/PPQ1PPBP/R1B1K2R b KQkq' => {
			eco => 'E17g',
			# TRANSLATORS: E17g: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. Nc3 Ne4 7. Qc2
			variation => N__('Queen\'s Indian: 6. Nc3 Ne4 7. Qc2'),
			moves => {
			},
		},
		'rn1qk2r/pbppbppp/1p2p3/8/2PPn3/2N2NP1/PP1BPPBP/R2QK2R b KQkq' => {
			eco => 'E17h',
			# TRANSLATORS: E17h: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. Nc3 Ne4 7. Bd2
			variation => N__('Queen\'s Indian: Opovcensky Variation'),
			moves => {
				'e7f6' => 1,
				'e8g8' => 1,
				'f7f5' => 1,
			},
		},
		'rn1q1rk1/pbppbppp/1p2p3/8/2PPn3/2N2NP1/PP1BPPBP/R2QK2R w KQ' => {
			eco => 'E17i',
			# TRANSLATORS: E17i: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. Nc3 Ne4 7. Bd2 O-O
			variation => N__('Queen\'s Indian: Opovcensky, 7...O-O'),
			moves => {
			},
		},
		'rn1qk2r/pbppb1pp/1p2p3/5p2/2PPn3/2N2NP1/PP1BPPBP/R2QK2R w KQkq' => {
			eco => 'E17j',
			# TRANSLATORS: E17j: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. Nc3 Ne4 7. Bd2 f5
			variation => N__('Queen\'s Indian: Opovcensky, 7... f5'),
			moves => {
			},
		},
		'rn1qk2r/pbpp1ppp/1p2pb2/8/2PPn3/2N2NP1/PP1BPPBP/R2QK2R w KQkq' => {
			eco => 'E17k',
			# TRANSLATORS: E17k: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. Nc3 Ne4 7. Bd2 Bf6
			variation => N__('Queen\'s Indian: Opovcensky, 7... Bf6'),
			moves => {
			},
		},
		'rn1qk2r/pbppbppp/1p2pn2/8/2PP4/5NP1/PP2PPBP/RNBQ1RK1 b kq' => {
			eco => 'E17l',
			# TRANSLATORS: E17l: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O
			variation => N__('Queen\'s Indian: 6.O-O'),
			moves => {
				'd7d5' => 1,
				'e8g8' => 1,
			},
		},
		'rn1qk2r/pbp1bppp/1p2pn2/3p4/2PP4/5NP1/PP2PPBP/RNBQ1RK1 w kq' => {
			eco => 'E17m',
			# TRANSLATORS: E17m: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O d5
			variation => N__('Queen\'s Indian: 6.O-O d5'),
			moves => {
			},
		},
		'rn1q1rk1/pbppbppp/1p2pn2/8/2PP4/5NP1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'E17n',
			# TRANSLATORS: E17n: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O
			variation => N__('Queen\'s Indian: 6.O-O O-O'),
			moves => {
				'b1c3' => 1,
				'b2b3' => 1,
				'd1c2' => 1,
				'd4d5' => 1,
				'f1e1' => 1,
			},
		},
		'rn1q1rk1/pbppbppp/1p2pn2/8/2PP4/5NP1/PPQ1PPBP/RNB2RK1 b -' => {
			eco => 'E17o',
			# TRANSLATORS: E17o: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Qc2
			variation => N__('Queen\'s Indian: 6.O-O O-O 7. Qc2'),
			moves => {
			},
		},
		'rn1q1rk1/pbppbppp/1p2pn2/8/2PP4/5NP1/PP2PPBP/RNBQR1K1 b -' => {
			eco => 'E17p',
			# TRANSLATORS: E17p: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Re1
			variation => N__('Queen\'s Indian: 6.O-O O-O 7. Re1'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rn1q1rk1/pbp1bppp/1p2pn2/3p4/2PP4/5NP1/PP2PPBP/RNBQR1K1 w -' => {
			eco => 'E17q',
			# TRANSLATORS: E17q: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Re1 d5
			variation => N__('Queen\'s Indian: 6.O-O O-O 7. Re1 d5'),
			moves => {
			},
		},
		'rn1q1rk1/pbppbppp/1p2pn2/8/2PP4/1P3NP1/P3PPBP/RNBQ1RK1 b -' => {
			eco => 'E17r',
			# TRANSLATORS: E17r: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. b3
			variation => N__('Queen\'s Indian: Euwe Variation'),
			moves => {
				'c7c5' => 1,
				'd7d5' => 1,
			},
		},
		'rn1q1rk1/pb1pbppp/1p2pn2/2p5/2PP4/1P3NP1/P3PPBP/RNBQ1RK1 w -' => {
			eco => 'E17s',
			# TRANSLATORS: E17s: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. b3 c5
			variation => N__('Queen\'s Indian: Euwe, 7... c5'),
			moves => {
			},
		},
		'rn1q1rk1/pbp1bppp/1p2pn2/3p4/2PP4/1P3NP1/P3PPBP/RNBQ1RK1 w -' => {
			eco => 'E17t',
			# TRANSLATORS: E17t: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. b3 d5
			variation => N__('Queen\'s Indian: Euwe, 7... d5'),
			moves => {
			},
		},
		'rn1q1rk1/pbppbppp/1p2pn2/3P4/2P5/5NP1/PP2PPBP/RNBQ1RK1 b -' => {
			eco => 'E17u',
			# TRANSLATORS: E17u: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. d5
			variation => N__('Queen\'s Indian: Pomar Variation'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rn1q1rk1/pbppbppp/1p3n2/3p4/2P5/5NP1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'E17u',
			# TRANSLATORS: E17u: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. d5 exd5
			variation => N__('Queen\'s Indian: Pomar, 7...exd5'),
			moves => {
				'f3d4' => 1,
				'f3h4' => 1,
			},
		},
		'rn1q1rk1/pbppbppp/1p3n2/3p4/2PN4/6P1/PP2PPBP/RNBQ1RK1 b -' => {
			eco => 'E17v',
			# TRANSLATORS: E17v: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. d5 exd5 8. Nd4
			variation => N__('Queen\'s Indian: Pomar, Taimanov Variation'),
			moves => {
			},
		},
		'rn1q1rk1/pbppbppp/1p3n2/3p4/2P4N/6P1/PP2PPBP/RNBQ1RK1 b -' => {
			eco => 'E17w',
			# TRANSLATORS: E17w: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. d5 exd5 8. Nh4
			variation => N__('Queen\'s Indian: Pomar, Polugaevsky Variation'),
			moves => {
				'c7c6' => 1,
			},
		},
		'rn1q1rk1/pb1pbppp/1pp2n2/3p4/2P4N/6P1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'E17w',
			# TRANSLATORS: E17w: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. d5 exd5 8. Nh4 c6
			variation => N__('Queen\'s Indian: Pomar, Polugaevsky, 8... c6'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rn1q1rk1/pb1pbppp/1pp2n2/3P4/7N/6P1/PP2PPBP/RNBQ1RK1 b -' => {
			eco => 'E17w',
			# TRANSLATORS: E17w: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. d5 exd5 8. Nh4 c6 9. cxd5
			variation => N__('Queen\'s Indian: Pomar, Polugaevsky, 8... c6'),
			moves => {
				'f6d5' => 1,
			},
		},
		'rn1q1rk1/pb1pbppp/1pp5/3n4/7N/6P1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'E17x',
			# TRANSLATORS: E17x: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. d5 exd5 8. Nh4 c6 9. cxd5 Nxd5
			variation => N__('Queen\'s Indian: Pomar, Polugaevsky, 8... c6 9.cxd5 Nxd5'),
			moves => {
				'h4f5' => 1,
			},
		},
		'rn1q1rk1/pb1pbppp/1pp5/3n1N2/8/6P1/PP2PPBP/RNBQ1RK1 b -' => {
			eco => 'E17x',
			# TRANSLATORS: E17x: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. d5 exd5 8. Nh4 c6 9. cxd5 Nxd5 10. Nf5
			variation => N__('Queen\'s Indian: Pomar, Polugaevsky, 8... c6 9.cxd5 Nxd5'),
			moves => {
				'd5c7' => 1,
			},
		},
		'rn1q1rk1/pbnpbppp/1pp5/5N2/8/6P1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'E17y',
			# TRANSLATORS: E17y: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. d5 exd5 8. Nh4 c6 9. cxd5 Nxd5 10. Nf5 Nc7
			variation => N__('Queen\'s Indian: Pomar, Polugaevsky, 8... c6 9.cxd5 Nxd5 10. Nf5 Nc7'),
			moves => {
				'e2e4' => 1,
			},
		},
		'rn1q1rk1/pbnpbppp/1pp5/5N2/4P3/6P1/PP3PBP/RNBQ1RK1 b -' => {
			eco => 'E17z',
			# TRANSLATORS: E17z: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. d5 exd5 8. Nh4 c6 9. cxd5 Nxd5 10. Nf5 Nc7 11. e4
			variation => N__('Queen\'s Indian: Pomar, Polugaevsky, 8... c6 9.cxd5 Nxd5 10. Nf5 Nc7 11. e4'),
			moves => {
			},
		},
		'rn1q1rk1/pbppbppp/1p2pn2/8/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'E18a',
			# TRANSLATORS: E18a: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3
			variation => N__('Queen\'s Indian: 7. Nc3'),
			moves => {
				'b8a6' => 1,
				'c7c5' => 1,
				'd7d5' => 1,
				'd7d6' => 1,
				'f6e4' => 1,
			},
		},
		'rn1q1rk1/pb1pbppp/1p2pn2/2p5/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'E18b',
			# TRANSLATORS: E18b: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 c5
			variation => N__('Queen\'s Indian: 7. Nc3 c5'),
			moves => {
			},
		},
		'rn1q1rk1/pbp1bppp/1p1ppn2/8/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'E18c',
			# TRANSLATORS: E18c: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 d6
			variation => N__('Queen\'s Indian: 7. Nc3 d6'),
			moves => {
			},
		},
		'r2q1rk1/pbppbppp/np2pn2/8/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'E18d',
			# TRANSLATORS: E18d: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Na6
			variation => N__('Queen\'s Indian: 7. Nc3 Na6'),
			moves => {
			},
		},
		'rn1q1rk1/pbp1bppp/1p2pn2/3p4/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'E18e',
			# TRANSLATORS: E18e: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 d5
			variation => N__('Queen\'s Indian: 7. Nc3 d5'),
			moves => {
				'c4d5' => 1,
				'f3e5' => 1,
			},
		},
		'rn1q1rk1/pbp1bppp/1p2pn2/3P4/3P4/2N2NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'E18e',
			# TRANSLATORS: E18e: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 d5 8. cxd5
			variation => N__('Queen\'s Indian: 7. Nc3 d5 8.cxd5'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rn1q1rk1/pbp1bppp/1p3n2/3p4/3P4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'E18f',
			# TRANSLATORS: E18f: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 d5 8. cxd5 exd5
			variation => N__('Queen\'s Indian: 7. Nc3 d5 8.cxd5 exd5'),
			moves => {
			},
		},
		'rn1q1rk1/pbp1bppp/1p2pn2/3pN3/2PP4/2N3P1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'E18g',
			# TRANSLATORS: E18g: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 d5 8. Ne5
			variation => N__('Queen\'s Indian: 7. Nc3 d5 8. Ne5'),
			moves => {
				'b8a6' => 1,
				'b8d7' => 1,
				'c7c6' => 1,
			},
		},
		'rn1q1rk1/pb2bppp/1pp1pn2/3pN3/2PP4/2N3P1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'E18h',
			# TRANSLATORS: E18h: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 d5 8. Ne5 c6
			variation => N__('Queen\'s Indian: 7. Nc3 d5 8. Ne5 c6'),
			moves => {
			},
		},
		'r2q1rk1/pbpnbppp/1p2pn2/3pN3/2PP4/2N3P1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'E18i',
			# TRANSLATORS: E18i: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 d5 8. Ne5 Nbd7
			variation => N__('Queen\'s Indian: 7. Nc3 d5 8. Ne5 Nbd7'),
			moves => {
			},
		},
		'r2q1rk1/pbp1bppp/np2pn2/3pN3/2PP4/2N3P1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'E18j',
			# TRANSLATORS: E18j: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 d5 8. Ne5 Na6
			variation => N__('Queen\'s Indian: 7. Nc3 d5 8. Ne5 Na6'),
			moves => {
				'c4d5' => 1,
			},
		},
		'r2q1rk1/pbp1bppp/np2pn2/3PN3/3P4/2N3P1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'E18j',
			# TRANSLATORS: E18j: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 d5 8. Ne5 Na6 9. cxd5
			variation => N__('Queen\'s Indian: 7. Nc3 d5 8. Ne5 Na6'),
			moves => {
				'e6d5' => 1,
			},
		},
		'r2q1rk1/pbp1bppp/np3n2/3pN3/3P4/2N3P1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'E18k',
			# TRANSLATORS: E18k: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 d5 8. Ne5 Na6 9. cxd5 exd5
			variation => N__('Queen\'s Indian: 7. Nc3 d5 8. Ne5 Na6 9.cxd5 exd5'),
			moves => {
			},
		},
		'rn1q1rk1/pbppbppp/1p2p3/8/2PPn3/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'E18l',
			# TRANSLATORS: E18l: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4
			variation => N__('Queen\'s Indian: 7. Nc3 Ne4'),
			moves => {
				'c1d2' => 1,
				'c3e4' => 1,
				'd1c2' => 1,
			},
		},
		'rn1q1rk1/pbppbppp/1p2p3/8/2PPn3/2N2NP1/PP1BPPBP/R2Q1RK1 b -' => {
			eco => 'E18m',
			# TRANSLATORS: E18m: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Bd2
			variation => N__('Queen\'s Indian: 7. Nc3 Ne4 8. Bd2'),
			moves => {
				'd7d5' => 1,
				'e7f6' => 1,
				'f7f5' => 1,
			},
		},
		'rn1q1rk1/pbp1bppp/1p2p3/3p4/2PPn3/2N2NP1/PP1BPPBP/R2Q1RK1 w -' => {
			eco => 'E18n',
			# TRANSLATORS: E18n: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Bd2 d5
			variation => N__('Queen\'s Indian: 7. Nc3 Ne4 8. Bd2 d5'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rn1q1rk1/pbp1bppp/1p2p3/3P4/3Pn3/2N2NP1/PP1BPPBP/R2Q1RK1 b -' => {
			eco => 'E18n',
			# TRANSLATORS: E18n: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Bd2 d5 9. cxd5
			variation => N__('Queen\'s Indian: 7. Nc3 Ne4 8. Bd2 d5'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rn1q1rk1/pbp1bppp/1p6/3p4/3Pn3/2N2NP1/PP1BPPBP/R2Q1RK1 w -' => {
			eco => 'E18n',
			# TRANSLATORS: E18n: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Bd2 d5 9. cxd5 exd5
			variation => N__('Queen\'s Indian: 7. Nc3 Ne4 8. Bd2 d5 9.cxd5 exd5'),
			moves => {
			},
		},
		'rn1q1rk1/pbppb1pp/1p2p3/5p2/2PPn3/2N2NP1/PP1BPPBP/R2Q1RK1 w -' => {
			eco => 'E18o',
			# TRANSLATORS: E18o: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Bd2 f5
			variation => N__('Queen\'s Indian: 7. Nc3 Ne4 8. Bd2 f5'),
			moves => {
				'd4d5' => 1,
			},
		},
		'rn1q1rk1/pbppb1pp/1p2p3/3P1p2/2P1n3/2N2NP1/PP1BPPBP/R2Q1RK1 b -' => {
			eco => 'E18p',
			# TRANSLATORS: E18p: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Bd2 f5 9. d5
			variation => N__('Queen\'s Indian: 7. Nc3 Ne4 8. Bd2 f5 9. d5'),
			moves => {
				'e7f6' => 1,
			},
		},
		'rn1q1rk1/pbpp2pp/1p2pb2/3P1p2/2P1n3/2N2NP1/PP1BPPBP/R2Q1RK1 w -' => {
			eco => 'E18p',
			# TRANSLATORS: E18p: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Bd2 f5 9. d5 Bf6
			variation => N__('Queen\'s Indian: 7. Nc3 Ne4 8. Bd2 f5 9. d5 Bf6'),
			moves => {
				'a1c1' => 1,
			},
		},
		'rn1q1rk1/pbpp2pp/1p2pb2/3P1p2/2P1n3/2N2NP1/PP1BPPBP/2RQ1RK1 b -' => {
			eco => 'E18p',
			# TRANSLATORS: E18p: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Bd2 f5 9. d5 Bf6 10. Rc1
			variation => N__('Queen\'s Indian: 7. Nc3 Ne4 8. Bd2 f5 9. d5 Bf6 10. Rc1'),
			moves => {
			},
		},
		'rn1q1rk1/pbpp1ppp/1p2pb2/8/2PPn3/2N2NP1/PP1BPPBP/R2Q1RK1 w -' => {
			eco => 'E18q',
			# TRANSLATORS: E18q: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Bd2 Bf6
			variation => N__('Queen\'s Indian: 7. Nc3 Ne4 8. Bd2 Bf6'),
			moves => {
				'a1c1' => 1,
			},
		},
		'rn1q1rk1/pbpp1ppp/1p2pb2/8/2PPn3/2N2NP1/PP1BPPBP/2RQ1RK1 b -' => {
			eco => 'E18r',
			# TRANSLATORS: E18r: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Bd2 Bf6 9. Rc1
			variation => N__('Queen\'s Indian: 7. Nc3 Ne4 8. Bd2 Bf6 9. Rc1'),
			moves => {
			},
		},
		'rn1q1rk1/pbppbppp/1p2p3/8/2PPN3/5NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'E18s',
			# TRANSLATORS: E18s: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Nxe4
			variation => N__('Queen\'s Indian: 7. Nc3 Ne4 8.Nxe4'),
			moves => {
				'b7e4' => 1,
			},
		},
		'rn1q1rk1/p1ppbppp/1p2p3/8/2PPb3/5NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'E18s',
			# TRANSLATORS: E18s: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Nxe4 Bxe4
			variation => N__('Queen\'s Indian: 7. Nc3 Ne4 8.Nxe4'),
			moves => {
				'c1f4' => 1,
				'd4d5' => 1,
				'f3e1' => 1,
				'f3h4' => 1,
			},
		},
		'rn1q1rk1/p1ppbppp/1p2p3/8/2PPbB2/5NP1/PP2PPBP/R2Q1RK1 b -' => {
			eco => 'E18s',
			# TRANSLATORS: E18s: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Nxe4 Bxe4 9. Bf4
			variation => N__('Queen\'s Indian: 7. Nc3 Ne4 8.Nxe4 Bxe4 9. Bf4'),
			moves => {
			},
		},
		'rn1q1rk1/p1ppbppp/1p2p3/3P4/2P1b3/5NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'E18s',
			# TRANSLATORS: E18s: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Nxe4 Bxe4 9. d5
			variation => N__('Queen\'s Indian: 7. Nc3 Ne4 8.Nxe4 Bxe4 9. d5'),
			moves => {
			},
		},
		'rn1q1rk1/p1ppbppp/1p2p3/8/2PPb2N/6P1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'E18s',
			# TRANSLATORS: E18s: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Nxe4 Bxe4 9. Nh4
			variation => N__('Queen\'s Indian: 7. Nc3 Ne4 8.Nxe4 Bxe4 9. Nh4'),
			moves => {
			},
		},
		'rn1q1rk1/p1ppbppp/1p2p3/8/2PPb3/6P1/PP2PPBP/R1BQNRK1 b -' => {
			eco => 'E18t',
			# TRANSLATORS: E18t: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Nxe4 Bxe4 9. Ne1
			variation => N__('Queen\'s Indian: 7. Nc3 Ne4 8.Nxe4 Bxe4 9. Ne1'),
			moves => {
				'e4g2' => 1,
			},
		},
		'rn1q1rk1/p1ppbppp/1p2p3/8/2PP4/6P1/PP2PPbP/R1BQNRK1 w -' => {
			eco => 'E18t',
			# TRANSLATORS: E18t: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Nxe4 Bxe4 9. Ne1 Bxg2
			variation => N__('Queen\'s Indian: 7. Nc3 Ne4 8.Nxe4 Bxe4 9. Ne1'),
			moves => {
				'e1g2' => 1,
			},
		},
		'rn1q1rk1/p1ppbppp/1p2p3/8/2PP4/6P1/PP2PPNP/R1BQ1RK1 b -' => {
			eco => 'E18u',
			# TRANSLATORS: E18u: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Nxe4 Bxe4 9. Ne1 Bxg2 10. Nxg2
			variation => N__('Queen\'s Indian: 7. Nc3 Ne4 8.Nxe4 Bxe4 9. Ne1 Bxg2 10.Nxg2'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rn1q1rk1/p1p1bppp/1p2p3/3p4/2PP4/6P1/PP2PPNP/R1BQ1RK1 w -' => {
			eco => 'E18u',
			# TRANSLATORS: E18u: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Nxe4 Bxe4 9. Ne1 Bxg2 10. Nxg2 d5
			variation => N__('Queen\'s Indian: 7. Nc3 Ne4 8.Nxe4 Bxe4 9. Ne1 Bxg2 10.Nxg2 d5'),
			moves => {
				'd1a4' => 1,
			},
		},
		'rn1q1rk1/p1p1bppp/1p2p3/3p4/Q1PP4/6P1/PP2PPNP/R1B2RK1 b -' => {
			eco => 'E18v',
			# TRANSLATORS: E18v: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Nxe4 Bxe4 9. Ne1 Bxg2 10. Nxg2 d5 11. Qa4
			variation => N__('Queen\'s Indian: 7. Nc3 Ne4 8.Nxe4 Bxe4 9. Ne1 Bxg2 10.Nxg2 d5 11. Qa4'),
			moves => {
				'd5c4' => 1,
				'd8d7' => 1,
			},
		},
		'rn3rk1/p1pqbppp/1p2p3/3p4/Q1PP4/6P1/PP2PPNP/R1B2RK1 w -' => {
			eco => 'E18w',
			# TRANSLATORS: E18w: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Nxe4 Bxe4 9. Ne1 Bxg2 10. Nxg2 d5 11. Qa4 Qd7
			variation => N__('Queen\'s Indian: 7. Nc3 Ne4 8.Nxe4 Bxe4 9. Ne1 Bxg2 10.Nxg2 d5 11. Qa4 Qd7'),
			moves => {
			},
		},
		'rn1q1rk1/p1p1bppp/1p2p3/8/Q1pP4/6P1/PP2PPNP/R1B2RK1 w -' => {
			eco => 'E18x',
			# TRANSLATORS: E18x: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Nxe4 Bxe4 9. Ne1 Bxg2 10. Nxg2 d5 11. Qa4 dxc4
			variation => N__('Queen\'s Indian: 7. Nc3 Ne4 8.Nxe4 Bxe4 9. Ne1 Bxg2 10.Nxg2 d5 11. Qa4 dxc4'),
			moves => {
			},
		},
		'rn1q1rk1/pbppbppp/1p2p3/8/2PPn3/2N2NP1/PPQ1PPBP/R1B2RK1 b -' => {
			eco => 'E18y',
			# TRANSLATORS: E18y: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Qc2
			variation => N__('Queen\'s Indian: Old Main Line, 8. Qc2'),
			moves => {
				'e4c3' => 1,
			},
		},
		'rn1q1rk1/pbppbppp/1p2p3/8/2PP4/2n2NP1/PPQ1PPBP/R1B2RK1 w -' => {
			eco => 'E18y',
			# TRANSLATORS: E18y: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Qc2 Nxc3
			variation => N__('Queen\'s Indian: Old Main Line, 8. Qc2 Nxc3'),
			moves => {
				'b2c3' => 1,
				'c2c3' => 1,
			},
		},
		'rn1q1rk1/pbppbppp/1p2p3/8/2PP4/2P2NP1/P1Q1PPBP/R1B2RK1 b -' => {
			eco => 'E18z',
			# TRANSLATORS: E18z: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Qc2 Nxc3 9. bxc3
			variation => N__('Queen\'s Indian: Old Main Line, 8. Qc2 Nxc3 9.bxc3'),
			moves => {
			},
		},
		'rn1q1rk1/pbppbppp/1p2p3/8/2PP4/2Q2NP1/PP2PPBP/R1B2RK1 b -' => {
			eco => 'E19a',
			# TRANSLATORS: E19a: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Qc2 Nxc3 9. Qxc3
			variation => N__('Queen\'s Indian: Old Main Line, 9.Qxc3'),
			moves => {
				'b7e4' => 1,
				'c7c5' => 1,
				'd7d6' => 1,
				'f7f5' => 1,
			},
		},
		'rn1q1rk1/pbp1bppp/1p1pp3/8/2PP4/2Q2NP1/PP2PPBP/R1B2RK1 w -' => {
			eco => 'E19b',
			# TRANSLATORS: E19b: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Qc2 Nxc3 9. Qxc3 d6
			variation => N__('Queen\'s Indian: Old Main Line, 9.Qxc3 d6'),
			moves => {
				'b2b3' => 1,
			},
		},
		'rn1q1rk1/pbp1bppp/1p1pp3/8/2PP4/1PQ2NP1/P3PPBP/R1B2RK1 b -' => {
			eco => 'E19c',
			# TRANSLATORS: E19c: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Qc2 Nxc3 9. Qxc3 d6 10. b3
			variation => N__('Queen\'s Indian: Old Main Line, 9.Qxc3 d6 10. b3'),
			moves => {
			},
		},
		'rn1q1rk1/p1ppbppp/1p2p3/8/2PPb3/2Q2NP1/PP2PPBP/R1B2RK1 w -' => {
			eco => 'E19d',
			# TRANSLATORS: E19d: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Qc2 Nxc3 9. Qxc3 Be4
			variation => N__('Queen\'s Indian: Old Main Line, 9.Qxc3 Be4'),
			moves => {
				'f3e1' => 1,
			},
		},
		'rn1q1rk1/p1ppbppp/1p2p3/8/2PPb3/2Q3P1/PP2PPBP/R1B1NRK1 b -' => {
			eco => 'E19e',
			# TRANSLATORS: E19e: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Qc2 Nxc3 9. Qxc3 Be4 10. Ne1
			variation => N__('Queen\'s Indian: Old Main Line, 9.Qxc3 Be4 10. Ne1'),
			moves => {
			},
		},
		'rn1q1rk1/pbppb1pp/1p2p3/5p2/2PP4/2Q2NP1/PP2PPBP/R1B2RK1 w -' => {
			eco => 'E19f',
			# TRANSLATORS: E19f: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Qc2 Nxc3 9. Qxc3 f5
			variation => N__('Queen\'s Indian: Old Main Line, 9.Qxc3 f5'),
			moves => {
				'b2b3' => 1,
				'f1d1' => 1,
			},
		},
		'rn1q1rk1/pbppb1pp/1p2p3/5p2/2PP4/2Q2NP1/PP2PPBP/R1BR2K1 b -' => {
			eco => 'E19g',
			# TRANSLATORS: E19g: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Qc2 Nxc3 9. Qxc3 f5 10. Rd1
			variation => N__('Queen\'s Indian: Old Main Line, 9.Qxc3 f5 10. Rd1'),
			moves => {
			},
		},
		'rn1q1rk1/pbppb1pp/1p2p3/5p2/2PP4/1PQ2NP1/P3PPBP/R1B2RK1 b -' => {
			eco => 'E19h',
			# TRANSLATORS: E19h: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Qc2 Nxc3 9. Qxc3 f5 10. b3
			variation => N__('Queen\'s Indian: Old Main Line, 9.Qxc3 f5 10. b3'),
			moves => {
				'e7f6' => 1,
			},
		},
		'rn1q1rk1/pbpp2pp/1p2pb2/5p2/2PP4/1PQ2NP1/P3PPBP/R1B2RK1 w -' => {
			eco => 'E19h',
			# TRANSLATORS: E19h: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Qc2 Nxc3 9. Qxc3 f5 10. b3 Bf6
			variation => N__('Queen\'s Indian: Old Main Line, 9.Qxc3 f5 10. b3'),
			moves => {
				'c1b2' => 1,
			},
		},
		'rn1q1rk1/pbpp2pp/1p2pb2/5p2/2PP4/1PQ2NP1/PB2PPBP/R4RK1 b -' => {
			eco => 'E19h',
			# TRANSLATORS: E19h: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Qc2 Nxc3 9. Qxc3 f5 10. b3 Bf6 11. Bb2
			variation => N__('Queen\'s Indian: Old Main Line, 9.Qxc3 f5 10. b3'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rn1q1rk1/pbp3pp/1p1ppb2/5p2/2PP4/1PQ2NP1/PB2PPBP/R4RK1 w -' => {
			eco => 'E19i',
			# TRANSLATORS: E19i: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Qc2 Nxc3 9. Qxc3 f5 10. b3 Bf6 11. Bb2 d6
			variation => N__('Queen\'s Indian: Old Main Line, 9.Qxc3 f5 10. b3 Bf6 11. Bb2 d6'),
			moves => {
			},
		},
		'rn1q1rk1/pb1pbppp/1p2p3/2p5/2PP4/2Q2NP1/PP2PPBP/R1B2RK1 w -' => {
			eco => 'E19j',
			# TRANSLATORS: E19j: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Qc2 Nxc3 9. Qxc3 c5
			variation => N__('Queen\'s Indian: Old Main Line, 9.Qxc3 c5'),
			moves => {
				'b2b3' => 1,
				'f1d1' => 1,
			},
		},
		'rn1q1rk1/pb1pbppp/1p2p3/2p5/2PP4/1PQ2NP1/P3PPBP/R1B2RK1 b -' => {
			eco => 'E19k',
			# TRANSLATORS: E19k: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Qc2 Nxc3 9. Qxc3 c5 10. b3
			variation => N__('Queen\'s Indian: Old Main Line, 9.Qxc3 c5 10. b3'),
			moves => {
			},
		},
		'rn1q1rk1/pb1pbppp/1p2p3/2p5/2PP4/2Q2NP1/PP2PPBP/R1BR2K1 b -' => {
			eco => 'E19l',
			# TRANSLATORS: E19l: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Qc2 Nxc3 9. Qxc3 c5 10. Rd1
			variation => N__('Queen\'s Indian: Old Main Line, 9.Qxc3 c5 10. Rd1'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rn1q1rk1/pb2bppp/1p1pp3/2p5/2PP4/2Q2NP1/PP2PPBP/R1BR2K1 w -' => {
			eco => 'E19m',
			# TRANSLATORS: E19m: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Qc2 Nxc3 9. Qxc3 c5 10. Rd1 d6
			variation => N__('Queen\'s Indian: Old Main Line, 9.Qxc3 c5 10. Rd1 d6'),
			moves => {
				'b2b3' => 1,
			},
		},
		'rn1q1rk1/pb2bppp/1p1pp3/2p5/2PP4/1PQ2NP1/P3PPBP/R1BR2K1 b -' => {
			eco => 'E19n',
			# TRANSLATORS: E19n: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Qc2 Nxc3 9. Qxc3 c5 10. Rd1 d6 11. b3
			variation => N__('Queen\'s Indian: Old Main Line, 9.Qxc3 c5 10. Rd1 d6 11. b3'),
			moves => {
				'e7f6' => 1,
			},
		},
		'rn1q1rk1/pb3ppp/1p1ppb2/2p5/2PP4/1PQ2NP1/P3PPBP/R1BR2K1 w -' => {
			eco => 'E19o',
			# TRANSLATORS: E19o: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Qc2 Nxc3 9. Qxc3 c5 10. Rd1 d6 11. b3 Bf6
			variation => N__('Queen\'s Indian: Old Main Line, 9.Qxc3 c5 10. Rd1 d6 11. b3 Bf6'),
			moves => {
				'c1b2' => 1,
			},
		},
		'rn1q1rk1/pb3ppp/1p1ppb2/2p5/2PP4/1PQ2NP1/PB2PPBP/R2R2K1 b -' => {
			eco => 'E19o',
			# TRANSLATORS: E19o: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Qc2 Nxc3 9. Qxc3 c5 10. Rd1 d6 11. b3 Bf6 12. Bb2
			variation => N__('Queen\'s Indian: Old Main Line, 9.Qxc3 c5 10. Rd1 d6 11. b3 Bf6'),
			moves => {
				'd8e7' => 1,
			},
		},
		'rn3rk1/pb2qppp/1p1ppb2/2p5/2PP4/1PQ2NP1/PB2PPBP/R2R2K1 w -' => {
			eco => 'E19p',
			# TRANSLATORS: E19p: 1. d4 Nf6 2. c4 e6 3. Nf3 b6 4. g3 Bb7 5. Bg2 Be7 6. O-O O-O 7. Nc3 Ne4 8. Qc2 Nxc3 9. Qxc3 c5 10. Rd1 d6 11. b3 Bf6 12. Bb2 Qe7
			variation => N__('Queen\'s Indian: Old Main Line, 9.Qxc3 c5 10. Rd1 d6 11. b3 Bf6 12. Bb2 Qe7'),
			moves => {
			},
		},
		'rnbqk2r/pppp1ppp/4pn2/8/1bPP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'E20',
			# TRANSLATORS: E20: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4
			variation => N__('Nimzo-Indian Defence'),
			moves => {
				'a2a3' => 1,
				'c1d2' => 1,
				'c1g5' => 1,
				'd1b3' => 1,
				'd1c2' => 1,
				'd1d3' => 1,
				'e2e3' => 1,
				'f2f3' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqk2r/pppp1ppp/4pn2/8/1bPP4/2N5/PP1BPPPP/R2QKBNR b KQkq' => {
			eco => 'E20',
			# TRANSLATORS: E20: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bd2
			variation => N__('Nimzo-Indian: 4. Bd2'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/pppp1ppp/4pn2/8/1bPP4/2N5/PP1BPPPP/R2QKBNR w KQ' => {
			eco => 'E20',
			# TRANSLATORS: E20: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bd2 O-O
			variation => N__('Nimzo-Indian: 4. Bd2 O-O'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbq1rk1/pppp1ppp/4pn2/8/1bPP4/2N2N2/PP1BPPPP/R2QKB1R b KQ' => {
			eco => 'E20',
			# TRANSLATORS: E20: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bd2 O-O 5. Nf3
			variation => N__('Nimzo-Indian: 4. Bd2 O-O 5. Nf3'),
			moves => {
			},
		},
		'rnbqk2r/pppp1ppp/4pn2/8/1bPP4/2NQ4/PP2PPPP/R1B1KBNR b KQkq' => {
			eco => 'E20',
			# TRANSLATORS: E20: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qd3
			variation => N__('Nimzo-Indian: Mikenas Attack'),
			moves => {
			},
		},
		'rnbqk2r/pppp1ppp/4pn2/8/1bPP4/2N2P2/PP2P1PP/R1BQKBNR b KQkq' => {
			eco => 'E20',
			# TRANSLATORS: E20: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. f3
			variation => N__('Nimzo-Indian: 4. f3 (Kmoch)'),
			moves => {
				'c7c5' => 1,
				'd7d5' => 1,
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/2p5/1bPP4/2N2P2/PP2P1PP/R1BQKBNR w KQkq' => {
			eco => 'E20',
			# TRANSLATORS: E20: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. f3 c5
			variation => N__('Nimzo-Indian: 4. f3 c5'),
			moves => {
				'd4d5' => 1,
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/2pP4/1bP5/2N2P2/PP2P1PP/R1BQKBNR b KQkq' => {
			eco => 'E20',
			# TRANSLATORS: E20: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. f3 c5 5. d5
			variation => N__('Nimzo-Indian: 4. f3 c5 5. d5'),
			moves => {
			},
		},
		'rnbqk2r/ppp2ppp/4pn2/3p4/1bPP4/2N2P2/PP2P1PP/R1BQKBNR w KQkq' => {
			eco => 'E20',
			# TRANSLATORS: E20: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. f3 d5
			variation => N__('Nimzo-Indian: 4. f3 d5'),
			moves => {
				'a2a3' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/4pn2/3p4/1bPP4/P1N2P2/1P2P1PP/R1BQKBNR b KQkq' => {
			eco => 'E20',
			# TRANSLATORS: E20: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. f3 d5 5. a3
			variation => N__('Nimzo-Indian: 4. f3 d5'),
			moves => {
				'b4e7' => 1,
			},
		},
		'rnbqk2r/ppp1bppp/4pn2/3p4/2PP4/P1N2P2/1P2P1PP/R1BQKBNR w KQkq' => {
			eco => 'E20',
			# TRANSLATORS: E20: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. f3 d5 5. a3 Be7
			variation => N__('Nimzo-Indian: 4. f3 d5 5. a3 Be7'),
			moves => {
			},
		},
		'rnbqk2r/pppp1ppp/4pn2/8/1bPP4/2N3P1/PP2PP1P/R1BQKBNR b KQkq' => {
			eco => 'E20',
			# TRANSLATORS: E20: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. g3
			variation => N__('Nimzo-Indian: Romanishin'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/2p5/1bPP4/2N3P1/PP2PP1P/R1BQKBNR w KQkq' => {
			eco => 'E20',
			# TRANSLATORS: E20: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. g3 c5
			variation => N__('Nimzo-Indian: Romanishin, 4... c5'),
			moves => {
				'd4d5' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/2pP4/1bP5/2N3P1/PP2PP1P/R1BQKBNR b KQkq' => {
			eco => 'E20',
			# TRANSLATORS: E20: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. g3 c5 5. d5
			variation => N__('Nimzo-Indian: Romanishin, 4... c5 5. d5'),
			moves => {
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/2p5/1bPP4/2N2NP1/PP2PP1P/R1BQKB1R b KQkq' => {
			eco => 'E20',
			# TRANSLATORS: E20: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. g3 c5 5. Nf3
			variation => N__('Nimzo-Indian: Romanishin, 4... c5 5. Nf3'),
			moves => {
				'b8c6' => 1,
				'c5d4' => 1,
				'e8g8' => 1,
				'f6e4' => 1,
			},
		},
		'r1bqk2r/pp1p1ppp/2n1pn2/2p5/1bPP4/2N2NP1/PP2PP1P/R1BQKB1R w KQkq' => {
			eco => 'E20',
			# TRANSLATORS: E20: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. g3 c5 5. Nf3 Nc6
			variation => N__('Nimzo-Indian: Romanishin, 4... c5 5. Nf3 Nc6'),
			moves => {
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/8/1bPp4/2N2NP1/PP2PP1P/R1BQKB1R w KQkq' => {
			eco => 'E20',
			# TRANSLATORS: E20: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. g3 c5 5. Nf3 cxd4
			variation => N__('Nimzo-Indian: Romanishin, 4... c5 5. Nf3 cxd4'),
			moves => {
				'f3d4' => 1,
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/8/1bPN4/2N3P1/PP2PP1P/R1BQKB1R b KQkq' => {
			eco => 'E20',
			# TRANSLATORS: E20: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. g3 c5 5. Nf3 cxd4 6. Nxd4
			variation => N__('Nimzo-Indian: Romanishin, 6.Nxd4'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/pp1p1ppp/4pn2/8/1bPN4/2N3P1/PP2PP1P/R1BQKB1R w KQ' => {
			eco => 'E20',
			# TRANSLATORS: E20: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. g3 c5 5. Nf3 cxd4 6. Nxd4 O-O
			variation => N__('Nimzo-Indian: Romanishin, 6.Nxd4 O-O'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbq1rk1/pp1p1ppp/4pn2/8/1bPN4/2N3P1/PP2PPBP/R1BQK2R b KQ' => {
			eco => 'E20',
			# TRANSLATORS: E20: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. g3 c5 5. Nf3 cxd4 6. Nxd4 O-O 7. Bg2
			variation => N__('Nimzo-Indian: Romanishin, 6.Nxd4 O-O 7. Bg2'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbq1rk1/pp3ppp/4pn2/3p4/1bPN4/2N3P1/PP2PPBP/R1BQK2R w KQ' => {
			eco => 'E20',
			# TRANSLATORS: E20: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. g3 c5 5. Nf3 cxd4 6. Nxd4 O-O 7. Bg2 d5
			variation => N__('Nimzo-Indian: Romanishin, 6.Nxd4 O-O 7. Bg2 d5'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rnbq1rk1/pp3ppp/4pn2/3P4/1b1N4/2N3P1/PP2PPBP/R1BQK2R b KQ' => {
			eco => 'E20',
			# TRANSLATORS: E20: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. g3 c5 5. Nf3 cxd4 6. Nxd4 O-O 7. Bg2 d5 8. cxd5
			variation => N__('Nimzo-Indian: Romanishin, 8.cxd5'),
			moves => {
			},
		},
		'rnbq1rk1/pp1p1ppp/4pn2/2p5/1bPP4/2N2NP1/PP2PP1P/R1BQKB1R w KQ' => {
			eco => 'E20',
			# TRANSLATORS: E20: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. g3 c5 5. Nf3 O-O
			variation => N__('Nimzo-Indian: Romanishin, 4... c5 5. Nf3 O-O'),
			moves => {
			},
		},
		'rnbqk2r/pp1p1ppp/4p3/2p5/1bPPn3/2N2NP1/PP2PP1P/R1BQKB1R w KQkq' => {
			eco => 'E20',
			# TRANSLATORS: E20: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. g3 c5 5. Nf3 Ne4
			variation => N__('Nimzo-Indian: Romanishin, 4... c5 5. Nf3 Ne4'),
			moves => {
			},
		},
		'rnbqk2r/pppp1ppp/4pn2/8/1bPP4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'E21',
			# TRANSLATORS: E21: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Nf3
			variation => N__('Nimzo-Indian: Three Knights'),
			moves => {
				'b4c3' => 1,
				'b7b6' => 1,
				'c7c5' => 1,
				'e8g8' => 1,
			},
		},
		'rnbqk2r/pppp1ppp/4pn2/8/2PP4/2b2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'E21',
			# TRANSLATORS: E21: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Nf3 Bxc3+
			variation => N__('Nimzo-Indian: Three Knights, 4...Bxc3+'),
			moves => {
			},
		},
		'rnbqk2r/p1pp1ppp/1p2pn2/8/1bPP4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'E21',
			# TRANSLATORS: E21: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Nf3 b6
			variation => N__('Nimzo-Indian: Nimzo-Queen\'s Hybrid'),
			moves => {
				'c1g5' => 1,
				'd1b3' => 1,
				'd1c2' => 1,
			},
		},
		'rnbqk2r/p1pp1ppp/1p2pn2/6B1/1bPP4/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'E21',
			# TRANSLATORS: E21: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Nf3 b6 5. Bg5
			variation => N__('Nimzo-Indian: Nimzo-Queen\'s Hybrid, 5. Bg5'),
			moves => {
				'c8b7' => 1,
			},
		},
		'rn1qk2r/pbpp1ppp/1p2pn2/6B1/1bPP4/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'E21',
			# TRANSLATORS: E21: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Nf3 b6 5. Bg5 Bb7
			variation => N__('Nimzo-Indian: Nimzo-Queen\'s Hybrid, 5. Bg5 Bb7'),
			moves => {
			},
		},
		'rnbqk2r/p1pp1ppp/1p2pn2/8/1bPP4/1QN2N2/PP2PPPP/R1B1KB1R b KQkq' => {
			eco => 'E21',
			# TRANSLATORS: E21: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Nf3 b6 5. Qb3
			variation => N__('Nimzo-Indian: Nimzo-Queen\'s Hybrid, 5. Qb3'),
			moves => {
				'a7a5' => 1,
				'c7c5' => 1,
			},
		},
		'rnbqk2r/2pp1ppp/1p2pn2/p7/1bPP4/1QN2N2/PP2PPPP/R1B1KB1R w KQkq' => {
			eco => 'E21',
			# TRANSLATORS: E21: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Nf3 b6 5. Qb3 a5
			variation => N__('Nimzo-Indian: Nimzo-Queen\'s Hybrid, 5. Qb3 a5'),
			moves => {
			},
		},
		'rnbqk2r/p2p1ppp/1p2pn2/2p5/1bPP4/1QN2N2/PP2PPPP/R1B1KB1R w KQkq' => {
			eco => 'E21',
			# TRANSLATORS: E21: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Nf3 b6 5. Qb3 c5
			variation => N__('Nimzo-Indian: Nimzo-Queen\'s Hybrid, 5. Qb3 c5'),
			moves => {
			},
		},
		'rnbqk2r/p1pp1ppp/1p2pn2/8/1bPP4/2N2N2/PPQ1PPPP/R1B1KB1R b KQkq' => {
			eco => 'E21',
			# TRANSLATORS: E21: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Nf3 b6 5. Qc2
			variation => N__('Nimzo-Indian: Nimzo-Queen\'s Hybrid, 5. Qc2'),
			moves => {
				'c8b7' => 1,
			},
		},
		'rn1qk2r/pbpp1ppp/1p2pn2/8/1bPP4/2N2N2/PPQ1PPPP/R1B1KB1R w KQkq' => {
			eco => 'E21',
			# TRANSLATORS: E21: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Nf3 b6 5. Qc2 Bb7
			variation => N__('Nimzo-Indian: Nimzo-Queen\'s Hybrid, 5. Qc2 Bb7'),
			moves => {
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/2p5/1bPP4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'E21',
			# TRANSLATORS: E21: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Nf3 c5
			variation => N__('Nimzo-Indian: Three Knights, 4... c5'),
			moves => {
				'd4d5' => 1,
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/2pP4/1bP5/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'E21',
			# TRANSLATORS: E21: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Nf3 c5 5. d5
			variation => N__('Nimzo-Indian: Three Knights, 4... c5'),
			moves => {
				'f6e4' => 1,
			},
		},
		'rnbqk2r/pp1p1ppp/4p3/2pP4/1bP1n3/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'E21',
			# TRANSLATORS: E21: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Nf3 c5 5. d5 Ne4
			variation => N__('Nimzo-Indian: Three Knights, Euwe Variation'),
			moves => {
			},
		},
		'rnbq1rk1/pppp1ppp/4pn2/8/1bPP4/2N2N2/PP2PPPP/R1BQKB1R w KQ' => {
			eco => 'E21',
			# TRANSLATORS: E21: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Nf3 O-O
			variation => N__('Nimzo-Indian: Three Knights, 4...O-O'),
			moves => {
			},
		},
		'rnbqk2r/pppp1ppp/4pn2/8/1bPP4/1QN5/PP2PPPP/R1B1KBNR b KQkq' => {
			eco => 'E22',
			# TRANSLATORS: E22: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qb3
			variation => N__('Nimzo-Indian: Spielmann Variation'),
			moves => {
				'b8c6' => 1,
				'c7c5' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n1pn2/8/1bPP4/1QN5/PP2PPPP/R1B1KBNR w KQkq' => {
			eco => 'E22',
			# TRANSLATORS: E22: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qb3 Nc6
			variation => N__('Nimzo-Indian: Spielmann, 4... Nc6'),
			moves => {
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/2p5/1bPP4/1QN5/PP2PPPP/R1B1KBNR w KQkq' => {
			eco => 'E22',
			# TRANSLATORS: E22: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qb3 c5
			variation => N__('Nimzo-Indian: Spielmann, 4... c5'),
			moves => {
				'd4c5' => 1,
				'e2e3' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/2P5/1bP5/1QN5/PP2PPPP/R1B1KBNR b KQkq' => {
			eco => 'E22',
			# TRANSLATORS: E22: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qb3 c5 5. dxc5
			variation => N__('Nimzo-Indian: Spielmann, 4... c5 5.dxc5'),
			moves => {
				'b8a6' => 1,
				'b8c6' => 1,
			},
		},
		'r1bqk2r/pp1p1ppp/n3pn2/2P5/1bP5/1QN5/PP2PPPP/R1B1KBNR w KQkq' => {
			eco => 'E22',
			# TRANSLATORS: E22: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qb3 c5 5. dxc5 Na6
			variation => N__('Nimzo-Indian: Spielmann, 4... c5 5.dxc5 Na6'),
			moves => {
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/2p5/1bPP4/1QN1P3/PP3PPP/R1B1KBNR b KQkq' => {
			eco => 'E22',
			# TRANSLATORS: E22: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qb3 c5 5. e3
			variation => N__('Nimzo-Indian: Spielmann, 4... c5 5. e3'),
			moves => {
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/2p5/1bPP4/1QN2N2/PP2PPPP/R1B1KB1R b KQkq' => {
			eco => 'E22',
			# TRANSLATORS: E22: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qb3 c5 5. Nf3
			variation => N__('Nimzo-Indian: Spielmann, 4... c5 5. Nf3'),
			moves => {
			},
		},
		'r1bqk2r/pp1p1ppp/2n1pn2/2P5/1bP5/1QN5/PP2PPPP/R1B1KBNR w KQkq' => {
			eco => 'E23',
			# TRANSLATORS: E23: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qb3 c5 5. dxc5 Nc6
			variation => N__('Nimzo-Indian: Spielmann, 4... c5 5.dxc5 Nc6'),
			moves => {
				'c1g5' => 1,
				'g1f3' => 1,
			},
		},
		'r1bqk2r/pp1p1ppp/2n1pn2/2P3B1/1bP5/1QN5/PP2PPPP/R3KBNR b KQkq' => {
			eco => 'E23',
			# TRANSLATORS: E23: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qb3 c5 5. dxc5 Nc6 6. Bg5
			variation => N__('Nimzo-Indian: Spielmann, 4... c5 5.dxc5 Nc6 6. Bg5'),
			moves => {
			},
		},
		'r1bqk2r/pp1p1ppp/2n1pn2/2P5/1bP5/1QN2N2/PP2PPPP/R1B1KB1R b KQkq' => {
			eco => 'E23',
			# TRANSLATORS: E23: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qb3 c5 5. dxc5 Nc6 6. Nf3
			variation => N__('Nimzo-Indian: Spielmann, 4... c5 5.dxc5 Nc6 6. Nf3'),
			moves => {
				'f6e4' => 1,
			},
		},
		'r1bqk2r/pp1p1ppp/2n1p3/2P5/1bP1n3/1QN2N2/PP2PPPP/R1B1KB1R w KQkq' => {
			eco => 'E23',
			# TRANSLATORS: E23: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qb3 c5 5. dxc5 Nc6 6. Nf3 Ne4
			variation => N__('Nimzo-Indian: Spielmann, 4... c5 5.dxc5 Nc6 6. Nf3 Ne4'),
			moves => {
				'c1d2' => 1,
			},
		},
		'r1bqk2r/pp1p1ppp/2n1p3/2P5/1bP1n3/1QN2N2/PP1BPPPP/R3KB1R b KQkq' => {
			eco => 'E23',
			# TRANSLATORS: E23: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qb3 c5 5. dxc5 Nc6 6. Nf3 Ne4 7. Bd2
			variation => N__('Nimzo-Indian: Spielmann, 4... c5 5.dxc5 Nc6 6. Nf3 Ne4'),
			moves => {
				'e4c5' => 1,
				'e4d2' => 1,
			},
		},
		'r1bqk2r/pp1p1ppp/2n1p3/2n5/1bP5/1QN2N2/PP1BPPPP/R3KB1R w KQkq' => {
			eco => 'E23',
			# TRANSLATORS: E23: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qb3 c5 5. dxc5 Nc6 6. Nf3 Ne4 7. Bd2 Nxc5
			variation => N__('Nimzo-Indian: Spielmann, San Remo Variation'),
			moves => {
				'b3c2' => 1,
			},
		},
		'r1bqk2r/pp1p1ppp/2n1p3/2n5/1bP5/2N2N2/PPQBPPPP/R3KB1R b KQkq' => {
			eco => 'E23',
			# TRANSLATORS: E23: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qb3 c5 5. dxc5 Nc6 6. Nf3 Ne4 7. Bd2 Nxc5 8. Qc2
			variation => N__('Nimzo-Indian: Spielmann, San Remo Variation'),
			moves => {
				'f7f5' => 1,
			},
		},
		'r1bqk2r/pp1p2pp/2n1p3/2n2p2/1bP5/2N2N2/PPQBPPPP/R3KB1R w KQkq' => {
			eco => 'E23',
			# TRANSLATORS: E23: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qb3 c5 5. dxc5 Nc6 6. Nf3 Ne4 7. Bd2 Nxc5 8. Qc2 f5
			variation => N__('Nimzo-Indian: Spielmann, San Remo Variation'),
			moves => {
				'g2g3' => 1,
			},
		},
		'r1bqk2r/pp1p2pp/2n1p3/2n2p2/1bP5/2N2NP1/PPQBPP1P/R3KB1R b KQkq' => {
			eco => 'E23',
			# TRANSLATORS: E23: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qb3 c5 5. dxc5 Nc6 6. Nf3 Ne4 7. Bd2 Nxc5 8. Qc2 f5 9. g3
			variation => N__('Nimzo-Indian: Spielmann, Stahlberg Variation'),
			moves => {
			},
		},
		'r1bqk2r/pp1p1ppp/2n1p3/2P5/1bP5/1QN2N2/PP1nPPPP/R3KB1R w KQkq' => {
			eco => 'E23',
			# TRANSLATORS: E23: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qb3 c5 5. dxc5 Nc6 6. Nf3 Ne4 7. Bd2 Nxd2
			variation => N__('Nimzo-Indian: Spielmann, Carlsbad Variation'),
			moves => {
			},
		},
		'rnbqk2r/pppp1ppp/4pn2/8/1bPP4/P1N5/1P2PPPP/R1BQKBNR b KQkq' => {
			eco => 'E24',
			# TRANSLATORS: E24: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3
			variation => N__('Nimzo-Indian: Sämisch'),
			moves => {
				'b4c3' => 1,
			},
		},
		'rnbqk2r/pppp1ppp/4pn2/8/2PP4/P1b5/1P2PPPP/R1BQKBNR w KQkq' => {
			eco => 'E24',
			# TRANSLATORS: E24: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+
			variation => N__('Nimzo-Indian: Sämisch'),
			moves => {
				'b2c3' => 1,
			},
		},
		'rnbqk2r/pppp1ppp/4pn2/8/2PP4/P1P5/4PPPP/R1BQKBNR b KQkq' => {
			eco => 'E24',
			# TRANSLATORS: E24: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3
			variation => N__('Nimzo-Indian: Sämisch'),
			moves => {
				'b7b6' => 1,
				'c7c5' => 1,
				'd7d5' => 1,
				'e8g8' => 1,
			},
		},
		'rnbqk2r/p1pp1ppp/1p2pn2/8/2PP4/P1P5/4PPPP/R1BQKBNR w KQkq' => {
			eco => 'E24',
			# TRANSLATORS: E24: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 b6
			variation => N__('Nimzo-Indian: Sämisch, 5... b6'),
			moves => {
				'f2f3' => 1,
			},
		},
		'rnbqk2r/p1pp1ppp/1p2pn2/8/2PP4/P1P2P2/4P1PP/R1BQKBNR b KQkq' => {
			eco => 'E24',
			# TRANSLATORS: E24: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 b6 6. f3
			variation => N__('Nimzo-Indian: Sämisch, 5... b6 6. f3'),
			moves => {
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/2p5/2PP4/P1P5/4PPPP/R1BQKBNR w KQkq' => {
			eco => 'E24',
			# TRANSLATORS: E24: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 c5
			variation => N__('Nimzo-Indian: Sämisch, 5... c5'),
			moves => {
				'e2e3' => 1,
				'f2f3' => 1,
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/2p5/2PP4/P1P2P2/4P1PP/R1BQKBNR b KQkq' => {
			eco => 'E24',
			# TRANSLATORS: E24: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 c5 6. f3
			variation => N__('Nimzo-Indian: Sämisch, 5... c5 6. f3'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqk2r/pp3ppp/4pn2/2pp4/2PP4/P1P2P2/4P1PP/R1BQKBNR w KQkq' => {
			eco => 'E24',
			# TRANSLATORS: E24: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 c5 6. f3 d5
			variation => N__('Nimzo-Indian: Sämisch, 5... c5 6. f3 d5'),
			moves => {
				'c4d5' => 1,
				'e2e3' => 1,
			},
		},
		'rnbqk2r/pp3ppp/4pn2/2pp4/2PP4/P1P1PP2/6PP/R1BQKBNR b KQkq' => {
			eco => 'E24',
			# TRANSLATORS: E24: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 c5 6. f3 d5 7. e3
			variation => N__('Nimzo-Indian: Sämisch, 5... c5 6. f3 d5'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/pp3ppp/4pn2/2pp4/2PP4/P1P1PP2/6PP/R1BQKBNR w KQ' => {
			eco => 'E24',
			# TRANSLATORS: E24: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 c5 6. f3 d5 7. e3 O-O
			variation => N__('Nimzo-Indian: Sämisch, 5... c5 6. f3 d5'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rnbq1rk1/pp3ppp/4pn2/2pP4/3P4/P1P1PP2/6PP/R1BQKBNR b KQ' => {
			eco => 'E24',
			# TRANSLATORS: E24: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 c5 6. f3 d5 7. e3 O-O 8. cxd5
			variation => N__('Nimzo-Indian: Sämisch, 5... c5 6. f3 d5'),
			moves => {
				'f6d5' => 1,
			},
		},
		'rnbq1rk1/pp3ppp/4p3/2pn4/3P4/P1P1PP2/6PP/R1BQKBNR w KQ' => {
			eco => 'E24',
			# TRANSLATORS: E24: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 c5 6. f3 d5 7. e3 O-O 8. cxd5 Nxd5
			variation => N__('Nimzo-Indian: Sämisch, Botvinnik Variation'),
			moves => {
			},
		},
		'rnbqk2r/ppp2ppp/4pn2/3p4/2PP4/P1P5/4PPPP/R1BQKBNR w KQkq' => {
			eco => 'E24',
			# TRANSLATORS: E24: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 d5
			variation => N__('Nimzo-Indian: Sämisch, 5... d5'),
			moves => {
				'f2f3' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/4pn2/3p4/2PP4/P1P2P2/4P1PP/R1BQKBNR b KQkq' => {
			eco => 'E24',
			# TRANSLATORS: E24: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 d5 6. f3
			variation => N__('Nimzo-Indian: Sämisch, 5... d5 6. f3'),
			moves => {
			},
		},
		'rnbqk2r/pp3ppp/4pn2/2pP4/3P4/P1P2P2/4P1PP/R1BQKBNR b KQkq' => {
			eco => 'E25',
			# TRANSLATORS: E25: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 c5 6. f3 d5 7. cxd5
			variation => N__('Nimzo-Indian: Sämisch, 5... c5 6. f3 d5 7.cxd5'),
			moves => {
				'f6d5' => 1,
			},
		},
		'rnbqk2r/pp3ppp/4p3/2pn4/3P4/P1P2P2/4P1PP/R1BQKBNR w KQkq' => {
			eco => 'E25',
			# TRANSLATORS: E25: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 c5 6. f3 d5 7. cxd5 Nxd5
			variation => N__('Nimzo-Indian: Sämisch, 5... c5 6. f3 d5 7.cxd5 Nxd5'),
			moves => {
				'd1d3' => 1,
				'd4c5' => 1,
			},
		},
		'rnbqk2r/pp3ppp/4p3/2pn4/3P4/P1PQ1P2/4P1PP/R1B1KBNR b KQkq' => {
			eco => 'E25',
			# TRANSLATORS: E25: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 c5 6. f3 d5 7. cxd5 Nxd5 8. Qd3
			variation => N__('Nimzo-Indian: Sämisch, 5... c5 6. f3 d5 7.cxd5 Nxd5 8. Qd3'),
			moves => {
			},
		},
		'rnbqk2r/pp3ppp/4p3/2Pn4/8/P1P2P2/4P1PP/R1BQKBNR b KQkq' => {
			eco => 'E25',
			# TRANSLATORS: E25: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 c5 6. f3 d5 7. cxd5 Nxd5 8. dxc5
			variation => N__('Nimzo-Indian: Sämisch, Keres Variation'),
			moves => {
				'f7f5' => 1,
			},
		},
		'rnbqk2r/pp4pp/4p3/2Pn1p2/8/P1P2P2/4P1PP/R1BQKBNR w KQkq' => {
			eco => 'E25',
			# TRANSLATORS: E25: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 c5 6. f3 d5 7. cxd5 Nxd5 8. dxc5 f5
			variation => N__('Nimzo-Indian: Sämisch, Keres, Romanovsky Variation'),
			moves => {
				'e2e4' => 1,
				'g1h3' => 1,
			},
		},
		'rnbqk2r/pp4pp/4p3/2Pn1p2/4P3/P1P2P2/6PP/R1BQKBNR b KQkq' => {
			eco => 'E25',
			# TRANSLATORS: E25: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 c5 6. f3 d5 7. cxd5 Nxd5 8. dxc5 f5 9. e4
			variation => N__('Nimzo-Indian: Sämisch, Keres, Romanovsky, 9. e4'),
			moves => {
			},
		},
		'rnbqk2r/pp4pp/4p3/2Pn1p2/8/P1P2P1N/4P1PP/R1BQKB1R b KQkq' => {
			eco => 'E25',
			# TRANSLATORS: E25: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 c5 6. f3 d5 7. cxd5 Nxd5 8. dxc5 f5 9. Nh3
			variation => N__('Nimzo-Indian: Sämisch, Keres, Romanovsky, 9. Nh3'),
			moves => {
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/2p5/2PP4/P1P1P3/5PPP/R1BQKBNR b KQkq' => {
			eco => 'E26',
			# TRANSLATORS: E26: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 c5 6. e3
			variation => N__('Nimzo-Indian: Sämisch, 5... c5 6. e3'),
			moves => {
				'b7b6' => 1,
				'b8c6' => 1,
				'd7d6' => 1,
				'd8a5' => 1,
			},
		},
		'rnbqk2r/p2p1ppp/1p2pn2/2p5/2PP4/P1P1P3/5PPP/R1BQKBNR w KQkq' => {
			eco => 'E26',
			# TRANSLATORS: E26: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 c5 6. e3 b6
			variation => N__('Nimzo-Indian: Sämisch, O\'Kelly Variation'),
			moves => {
			},
		},
		'r1bqk2r/pp1p1ppp/2n1pn2/2p5/2PP4/P1P1P3/5PPP/R1BQKBNR w KQkq' => {
			eco => 'E26',
			# TRANSLATORS: E26: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 c5 6. e3 Nc6
			variation => N__('Nimzo-Indian: Sämisch, 5... c5 6. e3 Nc6'),
			moves => {
				'f1d3' => 1,
			},
		},
		'r1bqk2r/pp1p1ppp/2n1pn2/2p5/2PP4/P1PBP3/5PPP/R1BQK1NR b KQkq' => {
			eco => 'E26',
			# TRANSLATORS: E26: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 c5 6. e3 Nc6 7. Bd3
			variation => N__('Nimzo-Indian: Sämisch, 5... c5 6. e3 Nc6 7. Bd3'),
			moves => {
			},
		},
		'rnbqk2r/pp3ppp/3ppn2/2p5/2PP4/P1P1P3/5PPP/R1BQKBNR w KQkq' => {
			eco => 'E26',
			# TRANSLATORS: E26: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 c5 6. e3 d6
			variation => N__('Nimzo-Indian: Sämisch, 5... c5 6. e3 d6'),
			moves => {
			},
		},
		'rnb1k2r/pp1p1ppp/4pn2/q1p5/2PP4/P1P1P3/5PPP/R1BQKBNR w KQkq' => {
			eco => 'E26',
			# TRANSLATORS: E26: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 c5 6. e3 Qa5
			variation => N__('Nimzo-Indian: Sämisch, 5... c5 6. e3 Qa5'),
			moves => {
			},
		},
		'rnbq1rk1/pppp1ppp/4pn2/8/2PP4/P1P5/4PPPP/R1BQKBNR w KQ' => {
			eco => 'E27',
			# TRANSLATORS: E27: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 O-O
			variation => N__('Nimzo-Indian: Sämisch, 5...O-O'),
			moves => {
				'e2e3' => 1,
				'f2f3' => 1,
			},
		},
		'rnbq1rk1/pppp1ppp/4pn2/8/2PP4/P1P2P2/4P1PP/R1BQKBNR b KQ' => {
			eco => 'E27',
			# TRANSLATORS: E27: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 O-O 6. f3
			variation => N__('Nimzo-Indian: Sämisch, 5...O-O 6. f3'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbq1rk1/ppp2ppp/4pn2/3p4/2PP4/P1P2P2/4P1PP/R1BQKBNR w KQ' => {
			eco => 'E27',
			# TRANSLATORS: E27: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 O-O 6. f3 d5
			variation => N__('Nimzo-Indian: Sämisch, 5...O-O 6. f3 d5'),
			moves => {
				'c4d5' => 1,
				'e2e3' => 1,
			},
		},
		'rnbq1rk1/ppp2ppp/4pn2/3P4/3P4/P1P2P2/4P1PP/R1BQKBNR b KQ' => {
			eco => 'E27',
			# TRANSLATORS: E27: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 O-O 6. f3 d5 7. cxd5
			variation => N__('Nimzo-Indian: Sämisch, 5...O-O 6. f3 d5 7.cxd5'),
			moves => {
			},
		},
		'rnbq1rk1/ppp2ppp/4pn2/3p4/2PP4/P1P1PP2/6PP/R1BQKBNR b KQ' => {
			eco => 'E27',
			# TRANSLATORS: E27: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 O-O 6. f3 d5 7. e3
			variation => N__('Nimzo-Indian: Sämisch, 5...O-O 6. f3 d5 7. e3'),
			moves => {
			},
		},
		'rnbq1rk1/pppp1ppp/4pn2/8/2PP4/P1P1P3/5PPP/R1BQKBNR b KQ' => {
			eco => 'E28',
			# TRANSLATORS: E28: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 O-O 6. e3
			variation => N__('Nimzo-Indian: Sämisch, 5...O-O 6. e3'),
			moves => {
				'b7b6' => 1,
				'c7c5' => 1,
			},
		},
		'rnbq1rk1/p1pp1ppp/1p2pn2/8/2PP4/P1P1P3/5PPP/R1BQKBNR w KQ' => {
			eco => 'E28',
			# TRANSLATORS: E28: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 O-O 6. e3 b6
			variation => N__('Nimzo-Indian: Sämisch, 5...O-O 6. e3'),
			moves => {
			},
		},
		'rnbq1rk1/pp1p1ppp/4pn2/2p5/2PP4/P1P1P3/5PPP/R1BQKBNR w KQ' => {
			eco => 'E28',
			# TRANSLATORS: E28: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 O-O 6. e3 c5
			variation => N__('Nimzo-Indian: Sämisch, 5...O-O 6. e3 c5'),
			moves => {
				'f1d3' => 1,
				'g1e2' => 1,
			},
		},
		'rnbq1rk1/pp1p1ppp/4pn2/2p5/2PP4/P1PBP3/5PPP/R1BQK1NR b KQ' => {
			eco => 'E28',
			# TRANSLATORS: E28: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 O-O 6. e3 c5 7. Bd3
			variation => N__('Nimzo-Indian: Sämisch, 5...O-O 6. e3 c5 7. Bd3'),
			moves => {
				'b7b6' => 1,
				'b8c6' => 1,
			},
		},
		'rnbq1rk1/p2p1ppp/1p2pn2/2p5/2PP4/P1PBP3/5PPP/R1BQK1NR w KQ' => {
			eco => 'E28',
			# TRANSLATORS: E28: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 O-O 6. e3 c5 7. Bd3 b6
			variation => N__('Nimzo-Indian: Sämisch, 5...O-O 6. e3 c5 7. Bd3 b6'),
			moves => {
			},
		},
		'rnbq1rk1/pp1p1ppp/4pn2/2p5/2PP4/P1P1P3/4NPPP/R1BQKB1R b KQ' => {
			eco => 'E28',
			# TRANSLATORS: E28: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 O-O 6. e3 c5 7. Ne2
			variation => N__('Nimzo-Indian: Sämisch, 5...O-O 6. e3 c5 7. Ne2'),
			moves => {
			},
		},
		'r1bq1rk1/pp1p1ppp/2n1pn2/2p5/2PP4/P1PBP3/5PPP/R1BQK1NR w KQ' => {
			eco => 'E29',
			# TRANSLATORS: E29: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 O-O 6. e3 c5 7. Bd3 Nc6
			variation => N__('Nimzo-Indian: Sämisch, 5...O-O 6. e3 c5 7. Bd3 Nc6'),
			moves => {
				'g1e2' => 1,
				'g1f3' => 1,
			},
		},
		'r1bq1rk1/pp1p1ppp/2n1pn2/2p5/2PP4/P1PBP3/4NPPP/R1BQK2R b KQ' => {
			eco => 'E29',
			# TRANSLATORS: E29: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 O-O 6. e3 c5 7. Bd3 Nc6 8. Ne2
			variation => N__('Nimzo-Indian: Sämisch, 5...O-O 6. e3 c5 7. Bd3 Nc6 8. Ne2'),
			moves => {
				'b7b6' => 1,
				'd7d6' => 1,
				'e6e5' => 1,
			},
		},
		'r1bq1rk1/p2p1ppp/1pn1pn2/2p5/2PP4/P1PBP3/4NPPP/R1BQK2R w KQ' => {
			eco => 'E29',
			# TRANSLATORS: E29: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 O-O 6. e3 c5 7. Bd3 Nc6 8. Ne2 b6
			variation => N__('Nimzo-Indian: Sämisch, 5...O-O 6. e3 c5 7. Bd3 Nc6 8. Ne2 b6'),
			moves => {
				'e3e4' => 1,
			},
		},
		'r1bq1rk1/p2p1ppp/1pn1pn2/2p5/2PPP3/P1PB4/4NPPP/R1BQK2R b KQ' => {
			eco => 'E29',
			# TRANSLATORS: E29: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 O-O 6. e3 c5 7. Bd3 Nc6 8. Ne2 b6 9. e4
			variation => N__('Nimzo-Indian: Sämisch, 5...O-O 6. e3 c5 7. Bd3 Nc6 8. Ne2 b6 9. e4'),
			moves => {
				'f6e8' => 1,
			},
		},
		'r1bqnrk1/p2p1ppp/1pn1p3/2p5/2PPP3/P1PB4/4NPPP/R1BQK2R w KQ' => {
			eco => 'E29',
			# TRANSLATORS: E29: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 O-O 6. e3 c5 7. Bd3 Nc6 8. Ne2 b6 9. e4 Ne8
			variation => N__('Nimzo-Indian: Sämisch, Capablanca Variation'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bqnrk1/p2p1ppp/1pn1p3/2p5/2PPP3/P1PB4/4NPPP/R1BQ1RK1 b -' => {
			eco => 'E29',
			# TRANSLATORS: E29: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 O-O 6. e3 c5 7. Bd3 Nc6 8. Ne2 b6 9. e4 Ne8 10. O-O
			variation => N__('Nimzo-Indian: Sämisch, Capablanca, 10.O-O'),
			moves => {
			},
		},
		'r1bq1rk1/pp3ppp/2nppn2/2p5/2PP4/P1PBP3/4NPPP/R1BQK2R w KQ' => {
			eco => 'E29',
			# TRANSLATORS: E29: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 O-O 6. e3 c5 7. Bd3 Nc6 8. Ne2 d6
			variation => N__('Nimzo-Indian: Sämisch, 5...O-O 6. e3 c5 7. Bd3 Nc6 8. Ne2 d6'),
			moves => {
			},
		},
		'r1bq1rk1/pp1p1ppp/2n2n2/2p1p3/2PP4/P1PBP3/4NPPP/R1BQK2R w KQ' => {
			eco => 'E29',
			# TRANSLATORS: E29: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 O-O 6. e3 c5 7. Bd3 Nc6 8. Ne2 e5
			variation => N__('Nimzo-Indian: Sämisch, 5...O-O 6. e3 c5 7. Bd3 Nc6 8. Ne2 e5'),
			moves => {
			},
		},
		'r1bq1rk1/pp1p1ppp/2n1pn2/2p5/2PP4/P1PBPN2/5PPP/R1BQK2R b KQ' => {
			eco => 'E29',
			# TRANSLATORS: E29: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. a3 Bxc3+ 5. bxc3 O-O 6. e3 c5 7. Bd3 Nc6 8. Nf3
			variation => N__('Nimzo-Indian: Sämisch, 5...O-O 6. e3 c5 7. Bd3 Nc6 8. Nf3'),
			moves => {
			},
		},
		'rnbqk2r/pppp1ppp/4pn2/6B1/1bPP4/2N5/PP2PPPP/R2QKBNR b KQkq' => {
			eco => 'E30',
			# TRANSLATORS: E30: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bg5
			variation => N__('Nimzo-Indian: Leningrad'),
			moves => {
				'c7c5' => 1,
				'e8g8' => 1,
				'h7h6' => 1,
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/2p3B1/1bPP4/2N5/PP2PPPP/R2QKBNR w KQkq' => {
			eco => 'E30',
			# TRANSLATORS: E30: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bg5 c5
			variation => N__('Nimzo-Indian: Leningrad, 4... c5'),
			moves => {
				'd4d5' => 1,
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/2pP2B1/1bP5/2N5/PP2PPPP/R2QKBNR b KQkq' => {
			eco => 'E30',
			# TRANSLATORS: E30: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bg5 c5 5. d5
			variation => N__('Nimzo-Indian: Leningrad, 4... c5 5. d5'),
			moves => {
				'b4c3' => 1,
				'd7d6' => 1,
				'e6d5' => 1,
				'h7h6' => 1,
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/2pP2B1/2P5/2b5/PP2PPPP/R2QKBNR w KQkq' => {
			eco => 'E30',
			# TRANSLATORS: E30: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bg5 c5 5. d5 Bxc3+
			variation => N__('Nimzo-Indian: Leningrad, 4... c5 5. d5 Bxc3+'),
			moves => {
			},
		},
		'rnbqk2r/pp3ppp/3ppn2/2pP2B1/1bP5/2N5/PP2PPPP/R2QKBNR w KQkq' => {
			eco => 'E30',
			# TRANSLATORS: E30: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bg5 c5 5. d5 d6
			variation => N__('Nimzo-Indian: Leningrad, 4... c5 5. d5 d6'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbqk2r/pp3ppp/3ppn2/2pP2B1/1bP5/2N1P3/PP3PPP/R2QKBNR b KQkq' => {
			eco => 'E30',
			# TRANSLATORS: E30: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bg5 c5 5. d5 d6 6. e3
			variation => N__('Nimzo-Indian: Leningrad, 4... c5 5. d5 d6 6. e3'),
			moves => {
			},
		},
		'rnbqk2r/pp1p1ppp/5n2/2pp2B1/1bP5/2N5/PP2PPPP/R2QKBNR w KQkq' => {
			eco => 'E30',
			# TRANSLATORS: E30: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bg5 c5 5. d5 exd5
			variation => N__('Nimzo-Indian: Leningrad, 4... c5 5. d5 exd5'),
			moves => {
			},
		},
		'rnbqk2r/pp1p1pp1/4pn1p/2pP2B1/1bP5/2N5/PP2PPPP/R2QKBNR w KQkq' => {
			eco => 'E30',
			# TRANSLATORS: E30: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bg5 c5 5. d5 h6
			variation => N__('Nimzo-Indian: Leningrad, 4... c5 5. d5 h6'),
			moves => {
			},
		},
		'rnbq1rk1/pppp1ppp/4pn2/6B1/1bPP4/2N5/PP2PPPP/R2QKBNR w KQ' => {
			eco => 'E30',
			# TRANSLATORS: E30: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bg5 O-O
			variation => N__('Nimzo-Indian: Leningrad, 4...O-O'),
			moves => {
			},
		},
		'rnbqk2r/pppp1pp1/4pn1p/6B1/1bPP4/2N5/PP2PPPP/R2QKBNR w KQkq' => {
			eco => 'E30',
			# TRANSLATORS: E30: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bg5 h6
			variation => N__('Nimzo-Indian: Leningrad, 4... h6'),
			moves => {
				'g5f6' => 1,
				'g5h4' => 1,
			},
		},
		'rnbqk2r/pppp1pp1/4pB1p/8/1bPP4/2N5/PP2PPPP/R2QKBNR b KQkq' => {
			eco => 'E30',
			# TRANSLATORS: E30: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bg5 h6 5. Bxf6
			variation => N__('Nimzo-Indian: Leningrad, 4... h6 5.Bxf6'),
			moves => {
			},
		},
		'rnbqk2r/pppp1pp1/4pn1p/8/1bPP3B/2N5/PP2PPPP/R2QKBNR b KQkq' => {
			eco => 'E30',
			# TRANSLATORS: E30: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bg5 h6 5. Bh4
			variation => N__('Nimzo-Indian: Leningrad, 4... h6 5. Bh4'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqk2r/pp1p1pp1/4pn1p/2p5/1bPP3B/2N5/PP2PPPP/R2QKBNR w KQkq' => {
			eco => 'E30',
			# TRANSLATORS: E30: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bg5 h6 5. Bh4 c5
			variation => N__('Nimzo-Indian: Leningrad, 4... h6 5. Bh4 c5'),
			moves => {
				'd4d5' => 1,
			},
		},
		'rnbqk2r/pp1p1pp1/4pn1p/2pP4/1bP4B/2N5/PP2PPPP/R2QKBNR b KQkq' => {
			eco => 'E30',
			# TRANSLATORS: E30: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bg5 h6 5. Bh4 c5 6. d5
			variation => N__('Nimzo-Indian: Leningrad, 6. d5'),
			moves => {
				'b4c3' => 1,
				'b7b5' => 1,
				'd7d6' => 1,
				'e6d5' => 1,
			},
		},
		'rnbqk2r/pp1p1pp1/4pn1p/2pP4/2P4B/2b5/PP2PPPP/R2QKBNR w KQkq' => {
			eco => 'E30',
			# TRANSLATORS: E30: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bg5 h6 5. Bh4 c5 6. d5 Bxc3+
			variation => N__('Nimzo-Indian: Leningrad, 6. d5 Bxc3+'),
			moves => {
			},
		},
		'rnbqk2r/p2p1pp1/4pn1p/1ppP4/1bP4B/2N5/PP2PPPP/R2QKBNR w KQkq' => {
			eco => 'E30',
			# TRANSLATORS: E30: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bg5 h6 5. Bh4 c5 6. d5 b5
			variation => N__('Nimzo-Indian: Leningrad, 6. d5 b5 Gambit'),
			moves => {
			},
		},
		'rnbqk2r/pp1p1pp1/5n1p/2pp4/1bP4B/2N5/PP2PPPP/R2QKBNR w KQkq' => {
			eco => 'E30',
			# TRANSLATORS: E30: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bg5 h6 5. Bh4 c5 6. d5 exd5
			variation => N__('Nimzo-Indian: Leningrad, 6. d5 exd5'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rnbqk2r/pp1p1pp1/5n1p/2pP4/1b5B/2N5/PP2PPPP/R2QKBNR b KQkq' => {
			eco => 'E30',
			# TRANSLATORS: E30: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bg5 h6 5. Bh4 c5 6. d5 exd5 7. cxd5
			variation => N__('Nimzo-Indian: Leningrad, 6. d5 exd5'),
			moves => {
			},
		},
		'rnbqk2r/pp3pp1/3ppn1p/2pP4/1bP4B/2N5/PP2PPPP/R2QKBNR w KQkq' => {
			eco => 'E31a',
			# TRANSLATORS: E31a: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bg5 h6 5. Bh4 c5 6. d5 d6
			variation => N__('Nimzo-Indian: Leningrad, Main Line'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbqk2r/pp3pp1/3ppn1p/2pP4/1bP4B/2N1P3/PP3PPP/R2QKBNR b KQkq' => {
			eco => 'E31b',
			# TRANSLATORS: E31b: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bg5 h6 5. Bh4 c5 6. d5 d6 7. e3
			variation => N__('Nimzo-Indian: Leningrad, Main Line, 7. e3'),
			moves => {
				'b4c3' => 1,
				'd8e7' => 1,
				'e6d5' => 1,
				'e6e5' => 1,
				'e8g8' => 1,
				'g7g5' => 1,
			},
		},
		'rnbqk2r/pp3p2/3ppn1p/2pP2p1/1bP4B/2N1P3/PP3PPP/R2QKBNR w KQkq' => {
			eco => 'E31c',
			# TRANSLATORS: E31c: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bg5 h6 5. Bh4 c5 6. d5 d6 7. e3 g5
			variation => N__('Nimzo-Indian: Leningrad, Main Line, 7. e3 g5'),
			moves => {
			},
		},
		'rnbqk2r/pp3pp1/3p1n1p/2pp4/1bP4B/2N1P3/PP3PPP/R2QKBNR w KQkq' => {
			eco => 'E31d',
			# TRANSLATORS: E31d: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bg5 h6 5. Bh4 c5 6. d5 d6 7. e3 exd5
			variation => N__('Nimzo-Indian: Leningrad, Main Line, 7. e3 exd5'),
			moves => {
			},
		},
		'rnbqk2r/pp3pp1/3p1n1p/2pPp3/1bP4B/2N1P3/PP3PPP/R2QKBNR w KQkq' => {
			eco => 'E31e',
			# TRANSLATORS: E31e: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bg5 h6 5. Bh4 c5 6. d5 d6 7. e3 e5
			variation => N__('Nimzo-Indian: Leningrad, Main Line, 7. e3 e5'),
			moves => {
			},
		},
		'rnb1k2r/pp2qpp1/3ppn1p/2pP4/1bP4B/2N1P3/PP3PPP/R2QKBNR w KQkq' => {
			eco => 'E31f',
			# TRANSLATORS: E31f: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bg5 h6 5. Bh4 c5 6. d5 d6 7. e3 Qe7
			variation => N__('Nimzo-Indian: Leningrad, Main Line, 7. e3 Qe7'),
			moves => {
			},
		},
		'rnbq1rk1/pp3pp1/3ppn1p/2pP4/1bP4B/2N1P3/PP3PPP/R2QKBNR w KQ' => {
			eco => 'E31g',
			# TRANSLATORS: E31g: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bg5 h6 5. Bh4 c5 6. d5 d6 7. e3 O-O
			variation => N__('Nimzo-Indian: Leningrad, Main Line, 7. e3 O-O'),
			moves => {
			},
		},
		'rnbqk2r/pp3pp1/3ppn1p/2pP4/2P4B/2b1P3/PP3PPP/R2QKBNR w KQkq' => {
			eco => 'E31h',
			# TRANSLATORS: E31h: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bg5 h6 5. Bh4 c5 6. d5 d6 7. e3 Bxc3+
			variation => N__('Nimzo-Indian: Leningrad, Main Line, 7. e3 Bxc3+'),
			moves => {
				'b2c3' => 1,
			},
		},
		'rnbqk2r/pp3pp1/3ppn1p/2pP4/2P4B/2P1P3/P4PPP/R2QKBNR b KQkq' => {
			eco => 'E31h',
			# TRANSLATORS: E31h: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bg5 h6 5. Bh4 c5 6. d5 d6 7. e3 Bxc3+ 8. bxc3
			variation => N__('Nimzo-Indian: Leningrad, Main Line, 7. e3 Bxc3+'),
			moves => {
				'd8e7' => 1,
				'e6e5' => 1,
			},
		},
		'rnb1k2r/pp2qpp1/3ppn1p/2pP4/2P4B/2P1P3/P4PPP/R2QKBNR w KQkq' => {
			eco => 'E31i',
			# TRANSLATORS: E31i: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bg5 h6 5. Bh4 c5 6. d5 d6 7. e3 Bxc3+ 8. bxc3 Qe7
			variation => N__('Nimzo-Indian: Leningrad, Main Line, 8... Qe7'),
			moves => {
			},
		},
		'rnbqk2r/pp3pp1/3p1n1p/2pPp3/2P4B/2P1P3/P4PPP/R2QKBNR w KQkq' => {
			eco => 'E31j',
			# TRANSLATORS: E31j: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bg5 h6 5. Bh4 c5 6. d5 d6 7. e3 Bxc3+ 8. bxc3 e5
			variation => N__('Nimzo-Indian: Leningrad, Main Line, 8... e5'),
			moves => {
				'd1c2' => 1,
				'f1d3' => 1,
				'f2f3' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqk2r/pp3pp1/3p1n1p/2pPp3/2P4B/2P1PN2/P4PPP/R2QKB1R b KQkq' => {
			eco => 'E31k',
			# TRANSLATORS: E31k: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bg5 h6 5. Bh4 c5 6. d5 d6 7. e3 Bxc3+ 8. bxc3 e5 9. Nf3
			variation => N__('Nimzo-Indian: Leningrad, Main Line, 8... e5 9. Nf3'),
			moves => {
			},
		},
		'rnbqk2r/pp3pp1/3p1n1p/2pPp3/2P4B/2P1P3/P1Q2PPP/R3KBNR b KQkq' => {
			eco => 'E31l',
			# TRANSLATORS: E31l: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bg5 h6 5. Bh4 c5 6. d5 d6 7. e3 Bxc3+ 8. bxc3 e5 9. Qc2
			variation => N__('Nimzo-Indian: Leningrad, Main Line, 8... e5 9. Qc2'),
			moves => {
			},
		},
		'rnbqk2r/pp3pp1/3p1n1p/2pPp3/2P4B/2PBP3/P4PPP/R2QK1NR b KQkq' => {
			eco => 'E31m',
			# TRANSLATORS: E31m: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bg5 h6 5. Bh4 c5 6. d5 d6 7. e3 Bxc3+ 8. bxc3 e5 9. Bd3
			variation => N__('Nimzo-Indian: Leningrad, Main Line, 8... e5 9. Bd3'),
			moves => {
			},
		},
		'rnbqk2r/pp3pp1/3p1n1p/2pPp3/2P4B/2P1PP2/P5PP/R2QKBNR b KQkq' => {
			eco => 'E31n',
			# TRANSLATORS: E31n: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bg5 h6 5. Bh4 c5 6. d5 d6 7. e3 Bxc3+ 8. bxc3 e5 9. f3
			variation => N__('Nimzo-Indian: Leningrad, Main Line, 8... e5 9. f3'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r1bqk2r/pp1n1pp1/3p1n1p/2pPp3/2P4B/2P1PP2/P5PP/R2QKBNR w KQkq' => {
			eco => 'E31o',
			# TRANSLATORS: E31o: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Bg5 h6 5. Bh4 c5 6. d5 d6 7. e3 Bxc3+ 8. bxc3 e5 9. f3 Nbd7
			variation => N__('Nimzo-Indian: Leningrad, Main Line, 8... e5 9. f3 Nbd7'),
			moves => {
			},
		},
		'rnbqk2r/pppp1ppp/4pn2/8/1bPP4/2N5/PPQ1PPPP/R1B1KBNR b KQkq' => {
			eco => 'E32a',
			# TRANSLATORS: E32a: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2
			variation => N__('Nimzo-Indian: Classical Variation'),
			moves => {
				'b7b6' => 1,
				'b8c6' => 1,
				'c7c5' => 1,
				'd7d5' => 1,
				'd7d6' => 1,
				'e8g8' => 1,
			},
		},
		'rnbqk2r/p1pp1ppp/1p2pn2/8/1bPP4/2N5/PPQ1PPPP/R1B1KBNR w KQkq' => {
			eco => 'E32b',
			# TRANSLATORS: E32b: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 b6
			variation => N__('Nimzo-Indian: Classical, 4... b6'),
			moves => {
			},
		},
		'rnbqk2r/ppp2ppp/3ppn2/8/1bPP4/2N5/PPQ1PPPP/R1B1KBNR w KQkq' => {
			eco => 'E32c',
			# TRANSLATORS: E32c: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d6
			variation => N__('Nimzo-Indian: Classical, 4... d6'),
			moves => {
			},
		},
		'rnbq1rk1/pppp1ppp/4pn2/8/1bPP4/2N5/PPQ1PPPP/R1B1KBNR w KQ' => {
			eco => 'E32d',
			# TRANSLATORS: E32d: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 O-O
			variation => N__('Nimzo-Indian: Classical, 4...O-O'),
			moves => {
				'a2a3' => 1,
				'c1g5' => 1,
				'e2e4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbq1rk1/pppp1ppp/4pn2/6B1/1bPP4/2N5/PPQ1PPPP/R3KBNR b KQ' => {
			eco => 'E32e',
			# TRANSLATORS: E32e: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 O-O 5. Bg5
			variation => N__('Nimzo-Indian: Classical, 4...O-O 5. Bg5'),
			moves => {
			},
		},
		'rnbq1rk1/pppp1ppp/4pn2/8/1bPPP3/2N5/PPQ2PPP/R1B1KBNR b KQ' => {
			eco => 'E32f',
			# TRANSLATORS: E32f: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 O-O 5. e4
			variation => N__('Nimzo-Indian: Classical, 4...O-O 5. e4'),
			moves => {
			},
		},
		'rnbq1rk1/pppp1ppp/4pn2/8/1bPP4/2N2N2/PPQ1PPPP/R1B1KB1R b KQ' => {
			eco => 'E32g',
			# TRANSLATORS: E32g: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 O-O 5. Nf3
			variation => N__('Nimzo-Indian: Classical, 4...O-O 5. Nf3'),
			moves => {
			},
		},
		'rnbq1rk1/pppp1ppp/4pn2/8/1bPP4/P1N5/1PQ1PPPP/R1B1KBNR b KQ' => {
			eco => 'E32h',
			# TRANSLATORS: E32h: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 O-O 5. a3
			variation => N__('Nimzo-Indian: Classical, 4...O-O 5. a3'),
			moves => {
				'b4c3' => 1,
			},
		},
		'rnbq1rk1/pppp1ppp/4pn2/8/2PP4/P1b5/1PQ1PPPP/R1B1KBNR w KQ' => {
			eco => 'E32h',
			# TRANSLATORS: E32h: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 O-O 5. a3 Bxc3+
			variation => N__('Nimzo-Indian: Classical, 4...O-O 5. a3'),
			moves => {
				'c2c3' => 1,
			},
		},
		'rnbq1rk1/pppp1ppp/4pn2/8/2PP4/P1Q5/1P2PPPP/R1B1KBNR b KQ' => {
			eco => 'E32h',
			# TRANSLATORS: E32h: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 O-O 5. a3 Bxc3+ 6. Qxc3
			variation => N__('Nimzo-Indian: Classical, 4...O-O 5. a3'),
			moves => {
				'b7b5' => 1,
				'b7b6' => 1,
				'd7d6' => 1,
				'f6e4' => 1,
			},
		},
		'rnbq1rk1/p1pp1ppp/4pn2/1p6/2PP4/P1Q5/1P2PPPP/R1B1KBNR w KQ' => {
			eco => 'E32i',
			# TRANSLATORS: E32i: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 O-O 5. a3 Bxc3+ 6. Qxc3 b5
			variation => N__('Nimzo-Indian: Classical, Adorjan Gambit'),
			moves => {
			},
		},
		'rnbq1rk1/ppp2ppp/3ppn2/8/2PP4/P1Q5/1P2PPPP/R1B1KBNR w KQ' => {
			eco => 'E32j',
			# TRANSLATORS: E32j: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 O-O 5. a3 Bxc3+ 6. Qxc3 d6
			variation => N__('Nimzo-Indian: Classical, 4...O-O 5. a3, 6... d6'),
			moves => {
			},
		},
		'rnbq1rk1/pppp1ppp/4p3/8/2PPn3/P1Q5/1P2PPPP/R1B1KBNR w KQ' => {
			eco => 'E32k',
			# TRANSLATORS: E32k: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 O-O 5. a3 Bxc3+ 6. Qxc3 Ne4
			variation => N__('Nimzo-Indian: Classical, 4...O-O 5. a3, 6... Ne4'),
			moves => {
			},
		},
		'rnbq1rk1/p1pp1ppp/1p2pn2/8/2PP4/P1Q5/1P2PPPP/R1B1KBNR w KQ' => {
			eco => 'E32l',
			# TRANSLATORS: E32l: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 O-O 5. a3 Bxc3+ 6. Qxc3 b6
			variation => N__('Nimzo-Indian: Classical, 4...O-O 5. a3, 6... b6'),
			moves => {
				'c1g5' => 1,
				'g1f3' => 1,
			},
		},
		'rnbq1rk1/p1pp1ppp/1p2pn2/8/2PP4/P1Q2N2/1P2PPPP/R1B1KB1R b KQ' => {
			eco => 'E32m',
			# TRANSLATORS: E32m: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 O-O 5. a3 Bxc3+ 6. Qxc3 b6 7. Nf3
			variation => N__('Nimzo-Indian: Classical, 4...O-O 5. a3, 6... b6 7. Nf3'),
			moves => {
			},
		},
		'rnbq1rk1/p1pp1ppp/1p2pn2/6B1/2PP4/P1Q5/1P2PPPP/R3KBNR b KQ' => {
			eco => 'E32n',
			# TRANSLATORS: E32n: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 O-O 5. a3 Bxc3+ 6. Qxc3 b6 7. Bg5
			variation => N__('Nimzo-Indian: Classical, 4...O-O 5. a3, 6... b6 7. Bg5'),
			moves => {
				'c8a6' => 1,
				'c8b7' => 1,
			},
		},
		'rn1q1rk1/p1pp1ppp/bp2pn2/6B1/2PP4/P1Q5/1P2PPPP/R3KBNR w KQ' => {
			eco => 'E32o',
			# TRANSLATORS: E32o: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 O-O 5. a3 Bxc3+ 6. Qxc3 b6 7. Bg5 Ba6
			variation => N__('Nimzo-Indian: Classical, 4...O-O 5. a3, 6... b6 7. Bg5 Ba6'),
			moves => {
			},
		},
		'rn1q1rk1/pbpp1ppp/1p2pn2/6B1/2PP4/P1Q5/1P2PPPP/R3KBNR w KQ' => {
			eco => 'E32p',
			# TRANSLATORS: E32p: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 O-O 5. a3 Bxc3+ 6. Qxc3 b6 7. Bg5 Bb7
			variation => N__('Nimzo-Indian: Classical, 4...O-O 5. a3, 6... b6 7. Bg5 Bb7'),
			moves => {
				'e2e3' => 1,
				'f2f3' => 1,
			},
		},
		'rn1q1rk1/pbpp1ppp/1p2pn2/6B1/2PP4/P1Q2P2/1P2P1PP/R3KBNR b KQ' => {
			eco => 'E32q',
			# TRANSLATORS: E32q: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 O-O 5. a3 Bxc3+ 6. Qxc3 b6 7. Bg5 Bb7 8. f3
			variation => N__('Nimzo-Indian: Classical, 4...O-O 5. a3, 6... b6 7. Bg5 Bb7 8. f3'),
			moves => {
				'h7h6' => 1,
			},
		},
		'rn1q1rk1/pbpp1pp1/1p2pn1p/6B1/2PP4/P1Q2P2/1P2P1PP/R3KBNR w KQ' => {
			eco => 'E32r',
			# TRANSLATORS: E32r: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 O-O 5. a3 Bxc3+ 6. Qxc3 b6 7. Bg5 Bb7 8. f3 h6
			variation => N__('Nimzo-Indian: Classical, 4...O-O 5. a3, 6... b6 7. Bg5 Bb7 8. f3 h6'),
			moves => {
				'g5h4' => 1,
			},
		},
		'rn1q1rk1/pbpp1pp1/1p2pn1p/8/2PP3B/P1Q2P2/1P2P1PP/R3KBNR b KQ' => {
			eco => 'E32r',
			# TRANSLATORS: E32r: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 O-O 5. a3 Bxc3+ 6. Qxc3 b6 7. Bg5 Bb7 8. f3 h6 9. Bh4
			variation => N__('Nimzo-Indian: Classical, 4...O-O 5. a3, 6... b6 7. Bg5 Bb7 8. f3 h6 9. Bh4'),
			moves => {
			},
		},
		'rn1q1rk1/pbpp1ppp/1p2pn2/6B1/2PP4/P1Q1P3/1P3PPP/R3KBNR b KQ' => {
			eco => 'E32s',
			# TRANSLATORS: E32s: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 O-O 5. a3 Bxc3+ 6. Qxc3 b6 7. Bg5 Bb7 8. e3
			variation => N__('Nimzo-Indian: Classical, 4...O-O 5. a3, 6... b6 7. Bg5 Bb7 8. e3'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rn1q1rk1/pbp2ppp/1p1ppn2/6B1/2PP4/P1Q1P3/1P3PPP/R3KBNR w KQ' => {
			eco => 'E32t',
			# TRANSLATORS: E32t: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 O-O 5. a3 Bxc3+ 6. Qxc3 b6 7. Bg5 Bb7 8. e3 d6
			variation => N__('Nimzo-Indian: Classical, 4...O-O 5. a3, 6... b6 7. Bg5 Bb7 8. e3 d6'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n1pn2/8/1bPP4/2N5/PPQ1PPPP/R1B1KBNR w KQkq' => {
			eco => 'E33',
			# TRANSLATORS: E33: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 Nc6
			variation => N__('Nimzo-Indian: Classical, 4... Nc6'),
			moves => {
				'g1f3' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n1pn2/8/1bPP4/2N2N2/PPQ1PPPP/R1B1KB1R b KQkq' => {
			eco => 'E33',
			# TRANSLATORS: E33: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 Nc6 5. Nf3
			variation => N__('Nimzo-Indian: Classical, 4... Nc6 5. Nf3'),
			moves => {
				'd7d5' => 1,
				'd7d6' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2n1pn2/3p4/1bPP4/2N2N2/PPQ1PPPP/R1B1KB1R w KQkq' => {
			eco => 'E33',
			# TRANSLATORS: E33: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 Nc6 5. Nf3 d5
			variation => N__('Nimzo-Indian: Classical, 4... Nc6 5. Nf3 d5'),
			moves => {
			},
		},
		'r1bqk2r/ppp2ppp/2nppn2/8/1bPP4/2N2N2/PPQ1PPPP/R1B1KB1R w KQkq' => {
			eco => 'E33',
			# TRANSLATORS: E33: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 Nc6 5. Nf3 d6
			variation => N__('Nimzo-Indian: Classical, Milner-Barry (Zurich) Variation'),
			moves => {
				'a2a3' => 1,
				'c1d2' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2nppn2/8/1bPP4/P1N2N2/1PQ1PPPP/R1B1KB1R b KQkq' => {
			eco => 'E33',
			# TRANSLATORS: E33: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 Nc6 5. Nf3 d6 6. a3
			variation => N__('Nimzo-Indian: Classical, Milner-Barry (Zurich), 6. a3'),
			moves => {
				'b4c3' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2nppn2/8/2PP4/P1b2N2/1PQ1PPPP/R1B1KB1R w KQkq' => {
			eco => 'E33',
			# TRANSLATORS: E33: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 Nc6 5. Nf3 d6 6. a3 Bxc3+
			variation => N__('Nimzo-Indian: Classical, Milner-Barry (Zurich), 6. a3'),
			moves => {
				'c2c3' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2nppn2/8/2PP4/P1Q2N2/1P2PPPP/R1B1KB1R b KQkq' => {
			eco => 'E33',
			# TRANSLATORS: E33: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 Nc6 5. Nf3 d6 6. a3 Bxc3+ 7. Qxc3
			variation => N__('Nimzo-Indian: Classical, Milner-Barry (Zurich), 6. a3 Bxc3+ 7.Qxc3'),
			moves => {
			},
		},
		'r1bqk2r/ppp2ppp/2nppn2/8/1bPP4/2N2N2/PPQBPPPP/R3KB1R b KQkq' => {
			eco => 'E33',
			# TRANSLATORS: E33: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 Nc6 5. Nf3 d6 6. Bd2
			variation => N__('Nimzo-Indian: Classical, Milner-Barry (Zurich), 6. Bd2'),
			moves => {
				'e8g8' => 1,
			},
		},
		'r1bq1rk1/ppp2ppp/2nppn2/8/1bPP4/2N2N2/PPQBPPPP/R3KB1R w KQ' => {
			eco => 'E33',
			# TRANSLATORS: E33: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 Nc6 5. Nf3 d6 6. Bd2 O-O
			variation => N__('Nimzo-Indian: Classical, Milner-Barry (Zurich), 6. Bd2 O-O'),
			moves => {
			},
		},
		'rnbqk2r/ppp2ppp/4pn2/3p4/1bPP4/2N5/PPQ1PPPP/R1B1KBNR w KQkq' => {
			eco => 'E34',
			# TRANSLATORS: E34: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d5
			variation => N__('Nimzo-Indian: Classical, Noa Variation'),
			moves => {
				'a2a3' => 1,
				'c4d5' => 1,
				'e2e3' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/4pn2/3P4/1b1P4/2N5/PPQ1PPPP/R1B1KBNR b KQkq' => {
			eco => 'E34',
			# TRANSLATORS: E34: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d5 5. cxd5
			variation => N__('Nimzo-Indian: Classical, Noa, 5.cxd5'),
			moves => {
				'd8d5' => 1,
				'e6d5' => 1,
			},
		},
		'rnb1k2r/ppp2ppp/4pn2/3q4/1b1P4/2N5/PPQ1PPPP/R1B1KBNR w KQkq' => {
			eco => 'E34',
			# TRANSLATORS: E34: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d5 5. cxd5 Qxd5
			variation => N__('Nimzo-Indian: Classical, Noa, 5.cxd5 Qxd5'),
			moves => {
				'e2e3' => 1,
				'g1f3' => 1,
			},
		},
		'rnb1k2r/ppp2ppp/4pn2/3q4/1b1P4/2N1P3/PPQ2PPP/R1B1KBNR b KQkq' => {
			eco => 'E34',
			# TRANSLATORS: E34: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d5 5. cxd5 Qxd5 6. e3
			variation => N__('Nimzo-Indian: Classical, Noa, 5.cxd5 Qxd5 6. e3'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnb1k2r/pp3ppp/4pn2/2pq4/1b1P4/2N1P3/PPQ2PPP/R1B1KBNR w KQkq' => {
			eco => 'E34',
			# TRANSLATORS: E34: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d5 5. cxd5 Qxd5 6. e3 c5
			variation => N__('Nimzo-Indian: Classical, Noa, 5.cxd5 Qxd5 6. e3 c5'),
			moves => {
			},
		},
		'rnb1k2r/ppp2ppp/4pn2/3q4/1b1P4/2N2N2/PPQ1PPPP/R1B1KB1R b KQkq' => {
			eco => 'E34',
			# TRANSLATORS: E34: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d5 5. cxd5 Qxd5 6. Nf3
			variation => N__('Nimzo-Indian: Classical, Noa, 5.cxd5 Qxd5 6. Nf3'),
			moves => {
				'c7c5' => 1,
				'd5f5' => 1,
			},
		},
		'rnb1k2r/pp3ppp/4pn2/2pq4/1b1P4/2N2N2/PPQ1PPPP/R1B1KB1R w KQkq' => {
			eco => 'E34',
			# TRANSLATORS: E34: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d5 5. cxd5 Qxd5 6. Nf3 c5
			variation => N__('Nimzo-Indian: Classical, Noa, 5.cxd5 Qxd5 6. Nf3 c5'),
			moves => {
			},
		},
		'rnb1k2r/ppp2ppp/4pn2/5q2/1b1P4/2N2N2/PPQ1PPPP/R1B1KB1R w KQkq' => {
			eco => 'E34',
			# TRANSLATORS: E34: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d5 5. cxd5 Qxd5 6. Nf3 Qf5
			variation => N__('Nimzo-Indian: Classical, Noa, 5.cxd5 Qxd5 6. Nf3 Qf5'),
			moves => {
				'c2b3' => 1,
				'c2f5' => 1,
			},
		},
		'rnb1k2r/ppp2ppp/4pn2/5q2/1b1P4/1QN2N2/PP2PPPP/R1B1KB1R b KQkq' => {
			eco => 'E34',
			# TRANSLATORS: E34: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d5 5. cxd5 Qxd5 6. Nf3 Qf5 7. Qb3
			variation => N__('Nimzo-Indian: Classical, Noa, 5.cxd5 Qxd5 6. Nf3 Qf5 7. Qb3'),
			moves => {
			},
		},
		'rnb1k2r/ppp2ppp/4pn2/5Q2/1b1P4/2N2N2/PP2PPPP/R1B1KB1R b KQkq' => {
			eco => 'E34',
			# TRANSLATORS: E34: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d5 5. cxd5 Qxd5 6. Nf3 Qf5 7. Qxf5
			variation => N__('Nimzo-Indian: Classical, Noa, Queenswap'),
			moves => {
			},
		},
		'rnbqk2r/ppp2ppp/4pn2/3p4/1bPP4/2N1P3/PPQ2PPP/R1B1KBNR b KQkq' => {
			eco => 'E34',
			# TRANSLATORS: E34: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d5 5. e3
			variation => N__('Nimzo-Indian: Classical, Noa, 5. e3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppp2ppp/4pn2/3p4/1bPP4/2N1P3/PPQ2PPP/R1B1KBNR w KQ' => {
			eco => 'E34',
			# TRANSLATORS: E34: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d5 5. e3 O-O
			variation => N__('Nimzo-Indian: Classical, Noa, 5. e3 O-O'),
			moves => {
			},
		},
		'rnbqk2r/ppp2ppp/5n2/3p4/1b1P4/2N5/PPQ1PPPP/R1B1KBNR w KQkq' => {
			eco => 'E35',
			# TRANSLATORS: E35: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d5 5. cxd5 exd5
			variation => N__('Nimzo-Indian: Classical, Noa, Exchange'),
			moves => {
				'a2a3' => 1,
				'c1g5' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/5n2/3p4/1b1P4/P1N5/1PQ1PPPP/R1B1KBNR b KQkq' => {
			eco => 'E35',
			# TRANSLATORS: E35: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d5 5. cxd5 exd5 6. a3
			variation => N__('Nimzo-Indian: Classical, Noa, Exchange, 6. a3'),
			moves => {
			},
		},
		'rnbqk2r/ppp2ppp/5n2/3p2B1/1b1P4/2N5/PPQ1PPPP/R3KBNR b KQkq' => {
			eco => 'E35',
			# TRANSLATORS: E35: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d5 5. cxd5 exd5 6. Bg5
			variation => N__('Nimzo-Indian: Classical, Noa, Exchange, 6. Bg5'),
			moves => {
				'c7c5' => 1,
				'h7h6' => 1,
			},
		},
		'rnbqk2r/pp3ppp/5n2/2pp2B1/1b1P4/2N5/PPQ1PPPP/R3KBNR w KQkq' => {
			eco => 'E35',
			# TRANSLATORS: E35: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d5 5. cxd5 exd5 6. Bg5 c5
			variation => N__('Nimzo-Indian: Classical, Noa, Exchange, 6. Bg5 c5'),
			moves => {
			},
		},
		'rnbqk2r/ppp2pp1/5n1p/3p2B1/1b1P4/2N5/PPQ1PPPP/R3KBNR w KQkq' => {
			eco => 'E35',
			# TRANSLATORS: E35: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d5 5. cxd5 exd5 6. Bg5 h6
			variation => N__('Nimzo-Indian: Classical, Noa, Exchange, 6. Bg5 h6'),
			moves => {
				'g5f6' => 1,
				'g5h4' => 1,
			},
		},
		'rnbqk2r/ppp2pp1/5B1p/3p4/1b1P4/2N5/PPQ1PPPP/R3KBNR b KQkq' => {
			eco => 'E35',
			# TRANSLATORS: E35: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d5 5. cxd5 exd5 6. Bg5 h6 7. Bxf6
			variation => N__('Nimzo-Indian: Classical, Noa, Exchange, 6. Bg5 h6 7.Bxf6'),
			moves => {
			},
		},
		'rnbqk2r/ppp2pp1/5n1p/3p4/1b1P3B/2N5/PPQ1PPPP/R3KBNR b KQkq' => {
			eco => 'E35',
			# TRANSLATORS: E35: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d5 5. cxd5 exd5 6. Bg5 h6 7. Bh4
			variation => N__('Nimzo-Indian: Classical, Noa, Exchange, 6. Bg5 h6 7. Bh4'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbqk2r/pp3pp1/5n1p/2pp4/1b1P3B/2N5/PPQ1PPPP/R3KBNR w KQkq' => {
			eco => 'E35',
			# TRANSLATORS: E35: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d5 5. cxd5 exd5 6. Bg5 h6 7. Bh4 c5
			variation => N__('Nimzo-Indian: Classical, Noa, Exchange, 6. Bg5 h6 7. Bh4 c5'),
			moves => {
			},
		},
		'rnbqk2r/ppp2ppp/4pn2/3p4/1bPP4/P1N5/1PQ1PPPP/R1B1KBNR b KQkq' => {
			eco => 'E36',
			# TRANSLATORS: E36: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d5 5. a3
			variation => N__('Nimzo-Indian: Classical, Noa, 5. a3'),
			moves => {
				'b4c3' => 1,
				'b4e7' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/4pn2/3p4/2PP4/P1b5/1PQ1PPPP/R1B1KBNR w KQkq' => {
			eco => 'E36',
			# TRANSLATORS: E36: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d5 5. a3 Bxc3+
			variation => N__('Nimzo-Indian: Classical, Noa, 5. a3 Bxc3+'),
			moves => {
				'c2c3' => 1,
			},
		},
		'rnbqk2r/ppp2ppp/4pn2/3p4/2PP4/P1Q5/1P2PPPP/R1B1KBNR b KQkq' => {
			eco => 'E36',
			# TRANSLATORS: E36: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d5 5. a3 Bxc3+ 6. Qxc3
			variation => N__('Nimzo-Indian: Classical, Noa, 5. a3 Bxc3+'),
			moves => {
				'b8c6' => 1,
				'd5c4' => 1,
				'e8g8' => 1,
				'f6e4' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2n1pn2/3p4/2PP4/P1Q5/1P2PPPP/R1B1KBNR w KQkq' => {
			eco => 'E36',
			# TRANSLATORS: E36: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d5 5. a3 Bxc3+ 6. Qxc3 Nc6
			variation => N__('Nimzo-Indian: Classical, Noa, Botvinnik Variation'),
			moves => {
			},
		},
		'rnbqk2r/ppp2ppp/4pn2/8/2pP4/P1Q5/1P2PPPP/R1B1KBNR w KQkq' => {
			eco => 'E36',
			# TRANSLATORS: E36: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d5 5. a3 Bxc3+ 6. Qxc3 dxc4
			variation => N__('Nimzo-Indian: Classical, Noa, 5. a3 Bxc3+ 6.Qxc3 dxc4'),
			moves => {
			},
		},
		'rnbq1rk1/ppp2ppp/4pn2/3p4/2PP4/P1Q5/1P2PPPP/R1B1KBNR w KQ' => {
			eco => 'E36',
			# TRANSLATORS: E36: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d5 5. a3 Bxc3+ 6. Qxc3 O-O
			variation => N__('Nimzo-Indian: Classical, Noa, 5. a3 Bxc3+ 6.Qxc3 O-O'),
			moves => {
			},
		},
		'rnbqk2r/ppp2ppp/4p3/3p4/2PPn3/P1Q5/1P2PPPP/R1B1KBNR w KQkq' => {
			eco => 'E36',
			# TRANSLATORS: E36: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d5 5. a3 Bxc3+ 6. Qxc3 Ne4
			variation => N__('Nimzo-Indian: Classical, Noa, Main Line'),
			moves => {
				'c3c2' => 1,
			},
		},
		'rnbqk2r/ppp1bppp/4pn2/3p4/2PP4/P1N5/1PQ1PPPP/R1B1KBNR w KQkq' => {
			eco => 'E36',
			# TRANSLATORS: E36: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d5 5. a3 Be7
			variation => N__('Nimzo-Indian: Classical, Noa, 5. a3 Be7'),
			moves => {
			},
		},
		'rnbqk2r/ppp2ppp/4p3/3p4/2PPn3/P7/1PQ1PPPP/R1B1KBNR b KQkq' => {
			eco => 'E37',
			# TRANSLATORS: E37: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d5 5. a3 Bxc3+ 6. Qxc3 Ne4 7. Qc2
			variation => N__('Nimzo-Indian: Classical, Noa, Main Line, 7. Qc2'),
			moves => {
				'b8c6' => 1,
				'c7c5' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2n1p3/3p4/2PPn3/P7/1PQ1PPPP/R1B1KBNR w KQkq' => {
			eco => 'E37',
			# TRANSLATORS: E37: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d5 5. a3 Bxc3+ 6. Qxc3 Ne4 7. Qc2 Nc6
			variation => N__('Nimzo-Indian: Classical, Noa, Main Line, 7. Qc2 Nc6'),
			moves => {
				'e2e3' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2n1p3/3p4/2PPn3/P3P3/1PQ2PPP/R1B1KBNR b KQkq' => {
			eco => 'E37',
			# TRANSLATORS: E37: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d5 5. a3 Bxc3+ 6. Qxc3 Ne4 7. Qc2 Nc6 8. e3
			variation => N__('Nimzo-Indian: Classical, Noa, Main Line, 7. Qc2 Nc6'),
			moves => {
				'e6e5' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2n5/3pp3/2PPn3/P3P3/1PQ2PPP/R1B1KBNR w KQkq' => {
			eco => 'E37',
			# TRANSLATORS: E37: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d5 5. a3 Bxc3+ 6. Qxc3 Ne4 7. Qc2 Nc6 8. e3 e5
			variation => N__('Nimzo-Indian: Classical, Noa, San Remo Variation'),
			moves => {
			},
		},
		'rnbqk2r/pp3ppp/4p3/2pp4/2PPn3/P7/1PQ1PPPP/R1B1KBNR w KQkq' => {
			eco => 'E37',
			# TRANSLATORS: E37: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d5 5. a3 Bxc3+ 6. Qxc3 Ne4 7. Qc2 c5
			variation => N__('Nimzo-Indian: Classical, Noa, Main Line, 7. Qc2 c5'),
			moves => {
				'd4c5' => 1,
			},
		},
		'rnbqk2r/pp3ppp/4p3/2Pp4/2P1n3/P7/1PQ1PPPP/R1B1KBNR b KQkq' => {
			eco => 'E37',
			# TRANSLATORS: E37: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d5 5. a3 Bxc3+ 6. Qxc3 Ne4 7. Qc2 c5 8. dxc5
			variation => N__('Nimzo-Indian: Classical, Noa, Main Line, 7. Qc2 c5'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqk2r/pp3ppp/2n1p3/2Pp4/2P1n3/P7/1PQ1PPPP/R1B1KBNR w KQkq' => {
			eco => 'E37',
			# TRANSLATORS: E37: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 d5 5. a3 Bxc3+ 6. Qxc3 Ne4 7. Qc2 c5 8. dxc5 Nc6
			variation => N__('Nimzo-Indian: Classical, Noa, Main Line, 7. Qc2 c5 8.dxc5 Nc6'),
			moves => {
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/2p5/1bPP4/2N5/PPQ1PPPP/R1B1KBNR w KQkq' => {
			eco => 'E38a',
			# TRANSLATORS: E38a: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 c5
			variation => N__('Nimzo-Indian: Classical, 4... c5'),
			moves => {
				'd4c5' => 1,
				'e2e3' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/2p5/1bPP4/2N2N2/PPQ1PPPP/R1B1KB1R b KQkq' => {
			eco => 'E38b',
			# TRANSLATORS: E38b: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 c5 5. Nf3
			variation => N__('Nimzo-Indian: Classical, 4... c5 5. Nf3'),
			moves => {
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/2p5/1bPP4/2N1P3/PPQ2PPP/R1B1KBNR b KQkq' => {
			eco => 'E38c',
			# TRANSLATORS: E38c: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 c5 5. e3
			variation => N__('Nimzo-Indian: Classical, 4... c5 5. e3'),
			moves => {
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/2P5/1bP5/2N5/PPQ1PPPP/R1B1KBNR b KQkq' => {
			eco => 'E38d',
			# TRANSLATORS: E38d: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 c5 5. dxc5
			variation => N__('Nimzo-Indian: Classical, 4... c5 5.dxc5'),
			moves => {
				'b4c5' => 1,
				'b8a6' => 1,
				'b8c6' => 1,
				'd8c7' => 1,
				'e8g8' => 1,
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/2b5/2P5/2N5/PPQ1PPPP/R1B1KBNR w KQkq' => {
			eco => 'E38e',
			# TRANSLATORS: E38e: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 c5 5. dxc5 Bxc5
			variation => N__('Nimzo-Indian: Classical, 4... c5 5.dxc5 Bxc5'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/2b5/2P5/2N2N2/PPQ1PPPP/R1B1KB1R b KQkq' => {
			eco => 'E38e',
			# TRANSLATORS: E38e: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 c5 5. dxc5 Bxc5 6. Nf3
			variation => N__('Nimzo-Indian: Classical, 4... c5 5.dxc5 Bxc5 6. Nf3'),
			moves => {
				'd8b6' => 1,
			},
		},
		'rnb1k2r/pp1p1ppp/1q2pn2/2b5/2P5/2N2N2/PPQ1PPPP/R1B1KB1R w KQkq' => {
			eco => 'E38f',
			# TRANSLATORS: E38f: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 c5 5. dxc5 Bxc5 6. Nf3 Qb6
			variation => N__('Nimzo-Indian: Classical, 4... c5 5.dxc5 Bxc5 6. Nf3 Qb6'),
			moves => {
			},
		},
		'rnb1k2r/ppqp1ppp/4pn2/2P5/1bP5/2N5/PPQ1PPPP/R1B1KBNR w KQkq' => {
			eco => 'E38g',
			# TRANSLATORS: E38g: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 c5 5. dxc5 Qc7
			variation => N__('Nimzo-Indian: Classical, 4... c5 5.dxc5 Qc7'),
			moves => {
			},
		},
		'r1bqk2r/pp1p1ppp/2n1pn2/2P5/1bP5/2N5/PPQ1PPPP/R1B1KBNR w KQkq' => {
			eco => 'E38h',
			# TRANSLATORS: E38h: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 c5 5. dxc5 Nc6
			variation => N__('Nimzo-Indian: Classical, 4... c5 5.dxc5 Nc6'),
			moves => {
			},
		},
		'r1bqk2r/pp1p1ppp/n3pn2/2P5/1bP5/2N5/PPQ1PPPP/R1B1KBNR w KQkq' => {
			eco => 'E38i',
			# TRANSLATORS: E38i: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 c5 5. dxc5 Na6
			variation => N__('Nimzo-Indian: Classical, 4... c5 5.dxc5 Na6'),
			moves => {
				'a2a3' => 1,
			},
		},
		'r1bqk2r/pp1p1ppp/n3pn2/2P5/1bP5/P1N5/1PQ1PPPP/R1B1KBNR b KQkq' => {
			eco => 'E38i',
			# TRANSLATORS: E38i: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 c5 5. dxc5 Na6 6. a3
			variation => N__('Nimzo-Indian: Classical, 4... c5 5.dxc5 Na6'),
			moves => {
				'b4c3' => 1,
			},
		},
		'r1bqk2r/pp1p1ppp/n3pn2/2P5/2P5/P1b5/1PQ1PPPP/R1B1KBNR w KQkq' => {
			eco => 'E38i',
			# TRANSLATORS: E38i: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 c5 5. dxc5 Na6 6. a3 Bxc3+
			variation => N__('Nimzo-Indian: Classical, 4... c5 5.dxc5 Na6'),
			moves => {
				'c2c3' => 1,
			},
		},
		'r1bqk2r/pp1p1ppp/n3pn2/2P5/2P5/P1Q5/1P2PPPP/R1B1KBNR b KQkq' => {
			eco => 'E38j',
			# TRANSLATORS: E38j: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 c5 5. dxc5 Na6 6. a3 Bxc3+ 7. Qxc3
			variation => N__('Nimzo-Indian: Classical, 4... c5 5.dxc5 Na6 6. a3 Bxc3+ 7.Qxc3'),
			moves => {
				'a6c5' => 1,
			},
		},
		'r1bqk2r/pp1p1ppp/4pn2/2n5/2P5/P1Q5/1P2PPPP/R1B1KBNR w KQkq' => {
			eco => 'E38j',
			# TRANSLATORS: E38j: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 c5 5. dxc5 Na6 6. a3 Bxc3+ 7. Qxc3 Nxc5
			variation => N__('Nimzo-Indian: Classical, 4... c5 5.dxc5 Na6 6. a3 Bxc3+ 7.Qxc3'),
			moves => {
				'b2b4' => 1,
			},
		},
		'r1bqk2r/pp1p1ppp/4pn2/2n5/1PP5/P1Q5/4PPPP/R1B1KBNR b KQkq' => {
			eco => 'E38k',
			# TRANSLATORS: E38k: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 c5 5. dxc5 Na6 6. a3 Bxc3+ 7. Qxc3 Nxc5 8. b4
			variation => N__('Nimzo-Indian: Classical, 4... c5 5.dxc5 Na6: 8. b4'),
			moves => {
				'c5e4' => 1,
			},
		},
		'r1bqk2r/pp1p1ppp/4pn2/8/1PP1n3/P1Q5/4PPPP/R1B1KBNR w KQkq' => {
			eco => 'E38k',
			# TRANSLATORS: E38k: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 c5 5. dxc5 Na6 6. a3 Bxc3+ 7. Qxc3 Nxc5 8. b4 Nce4
			variation => N__('Nimzo-Indian: Classical, 4... c5 5.dxc5 Na6: 8. b4 Nce4'),
			moves => {
				'c3d4' => 1,
			},
		},
		'r1bqk2r/pp1p1ppp/4pn2/8/1PPQn3/P7/4PPPP/R1B1KBNR b KQkq' => {
			eco => 'E38l',
			# TRANSLATORS: E38l: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 c5 5. dxc5 Na6 6. a3 Bxc3+ 7. Qxc3 Nxc5 8. b4 Nce4 9. Qd4
			variation => N__('Nimzo-Indian: Classical, 4... c5 5.dxc5 Na6: 8. b4 Nce4 9. Qd4'),
			moves => {
				'd7d5' => 1,
			},
		},
		'r1bqk2r/pp3ppp/4pn2/3p4/1PPQn3/P7/4PPPP/R1B1KBNR w KQkq' => {
			eco => 'E38l',
			# TRANSLATORS: E38l: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 c5 5. dxc5 Na6 6. a3 Bxc3+ 7. Qxc3 Nxc5 8. b4 Nce4 9. Qd4 d5
			variation => N__('Nimzo-Indian: Classical, 4... c5 5.dxc5 Na6: 8. b4 Nce4 9. Qd4'),
			moves => {
				'c4c5' => 1,
			},
		},
		'r1bqk2r/pp3ppp/4pn2/2Pp4/1P1Qn3/P7/4PPPP/R1B1KBNR b KQkq' => {
			eco => 'E38l',
			# TRANSLATORS: E38l: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 c5 5. dxc5 Na6 6. a3 Bxc3+ 7. Qxc3 Nxc5 8. b4 Nce4 9. Qd4 d5 10. c5
			variation => N__('Nimzo-Indian: Classical, 4... c5 5.dxc5 Na6: 8. b4 Nce4 9. Qd4 d5 10. c5'),
			moves => {
			},
		},
		'rnbq1rk1/pp1p1ppp/4pn2/2P5/1bP5/2N5/PPQ1PPPP/R1B1KBNR w KQ' => {
			eco => 'E39a',
			# TRANSLATORS: E39a: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 c5 5. dxc5 O-O
			variation => N__('Nimzo-Indian: Classical, Pirc Variation'),
			moves => {
				'a2a3' => 1,
				'c1f4' => 1,
				'g1f3' => 1,
			},
		},
		'rnbq1rk1/pp1p1ppp/4pn2/2P5/1bP2B2/2N5/PPQ1PPPP/R3KBNR b KQ' => {
			eco => 'E39b',
			# TRANSLATORS: E39b: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 c5 5. dxc5 O-O 6. Bf4
			variation => N__('Nimzo-Indian: Classical, Pirc, 6. Bf4'),
			moves => {
			},
		},
		'rnbq1rk1/pp1p1ppp/4pn2/2P5/1bP5/2N2N2/PPQ1PPPP/R1B1KB1R b KQ' => {
			eco => 'E39c',
			# TRANSLATORS: E39c: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 c5 5. dxc5 O-O 6. Nf3
			variation => N__('Nimzo-Indian: Classical, Pirc, 6. Nf3'),
			moves => {
				'b4c5' => 1,
				'b8a6' => 1,
			},
		},
		'rnbq1rk1/pp1p1ppp/4pn2/2b5/2P5/2N2N2/PPQ1PPPP/R1B1KB1R w KQ' => {
			eco => 'E39d',
			# TRANSLATORS: E39d: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 c5 5. dxc5 O-O 6. Nf3 Bxc5
			variation => N__('Nimzo-Indian: Classical, Pirc, 6. Nf3 Bxc5'),
			moves => {
			},
		},
		'r1bq1rk1/pp1p1ppp/n3pn2/2P5/1bP5/2N2N2/PPQ1PPPP/R1B1KB1R w KQ' => {
			eco => 'E39e',
			# TRANSLATORS: E39e: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 c5 5. dxc5 O-O 6. Nf3 Na6
			variation => N__('Nimzo-Indian: Classical, Pirc, 6. Nf3 Na6'),
			moves => {
				'a2a3' => 1,
				'c1d2' => 1,
				'g2g3' => 1,
			},
		},
		'r1bq1rk1/pp1p1ppp/n3pn2/2P5/1bP5/2N2N2/PPQBPPPP/R3KB1R b KQ' => {
			eco => 'E39f',
			# TRANSLATORS: E39f: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 c5 5. dxc5 O-O 6. Nf3 Na6 7. Bd2
			variation => N__('Nimzo-Indian: Classical, Pirc, 6. Nf3 Na6 7. Bd2'),
			moves => {
			},
		},
		'r1bq1rk1/pp1p1ppp/n3pn2/2P5/1bP5/P1N2N2/1PQ1PPPP/R1B1KB1R b KQ' => {
			eco => 'E39g',
			# TRANSLATORS: E39g: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 c5 5. dxc5 O-O 6. Nf3 Na6 7. a3
			variation => N__('Nimzo-Indian: Classical, Pirc, 6. Nf3 Na6 7. a3'),
			moves => {
			},
		},
		'r1bq1rk1/pp1p1ppp/n3pn2/2P5/1bP5/2N2NP1/PPQ1PP1P/R1B1KB1R b KQ' => {
			eco => 'E39h',
			# TRANSLATORS: E39h: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 c5 5. dxc5 O-O 6. Nf3 Na6 7. g3
			variation => N__('Nimzo-Indian: Classical, Pirc, 6. Nf3 Na6 7. g3'),
			moves => {
			},
		},
		'rnbq1rk1/pp1p1ppp/4pn2/2P5/1bP5/P1N5/1PQ1PPPP/R1B1KBNR b KQ' => {
			eco => 'E39i',
			# TRANSLATORS: E39i: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 c5 5. dxc5 O-O 6. a3
			variation => N__('Nimzo-Indian: Classical, Pirc, 6. a3'),
			moves => {
				'b4c5' => 1,
			},
		},
		'rnbq1rk1/pp1p1ppp/4pn2/2b5/2P5/P1N5/1PQ1PPPP/R1B1KBNR w KQ' => {
			eco => 'E39i',
			# TRANSLATORS: E39i: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 c5 5. dxc5 O-O 6. a3 Bxc5
			variation => N__('Nimzo-Indian: Classical, Pirc, 6. a3'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbq1rk1/pp1p1ppp/4pn2/2b5/2P5/P1N2N2/1PQ1PPPP/R1B1KB1R b KQ' => {
			eco => 'E39j',
			# TRANSLATORS: E39j: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 c5 5. dxc5 O-O 6. a3 Bxc5 7. Nf3
			variation => N__('Nimzo-Indian: Classical, Pirc, 6. a3 Bxc5 7. Nf3'),
			moves => {
				'b7b6' => 1,
				'b8c6' => 1,
			},
		},
		'r1bq1rk1/pp1p1ppp/2n1pn2/2b5/2P5/P1N2N2/1PQ1PPPP/R1B1KB1R w KQ' => {
			eco => 'E39k',
			# TRANSLATORS: E39k: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 c5 5. dxc5 O-O 6. a3 Bxc5 7. Nf3 Nc6
			variation => N__('Nimzo-Indian: Classical, Pirc, 6. a3 Bxc5 7. Nf3 Nc6'),
			moves => {
			},
		},
		'rnbq1rk1/p2p1ppp/1p2pn2/2b5/2P5/P1N2N2/1PQ1PPPP/R1B1KB1R w KQ' => {
			eco => 'E39l',
			# TRANSLATORS: E39l: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 c5 5. dxc5 O-O 6. a3 Bxc5 7. Nf3 b6
			variation => N__('Nimzo-Indian: Classical, Pirc, 6. a3 Bxc5 7. Nf3 b6'),
			moves => {
				'c1g5' => 1,
			},
		},
		'rnbq1rk1/p2p1ppp/1p2pn2/2b3B1/2P5/P1N2N2/1PQ1PPPP/R3KB1R b KQ' => {
			eco => 'E39m',
			# TRANSLATORS: E39m: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. Qc2 c5 5. dxc5 O-O 6. a3 Bxc5 7. Nf3 b6 8. Bg5
			variation => N__('Nimzo-Indian: Classical, Pirc, 6. a3 Bxc5 7. Nf3 b6 8. Bg5'),
			moves => {
			},
		},
		'rnbqk2r/pppp1ppp/4pn2/8/1bPP4/2N1P3/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'E40',
			# TRANSLATORS: E40: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3
			variation => N__('Nimzo-Indian: Rubinstein'),
			moves => {
				'b7b6' => 1,
				'b8c6' => 1,
				'c7c5' => 1,
				'e8g8' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n1pn2/8/1bPP4/2N1P3/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'E40',
			# TRANSLATORS: E40: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 Nc6
			variation => N__('Nimzo-Indian: Taimanov'),
			moves => {
				'f1d3' => 1,
				'g1e2' => 1,
			},
		},
		'r1bqk2r/pppp1ppp/2n1pn2/8/1bPP4/2NBP3/PP3PPP/R1BQK1NR b KQkq' => {
			eco => 'E40',
			# TRANSLATORS: E40: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 Nc6 5. Bd3
			variation => N__('Nimzo-Indian: Taimanov, 5. Bd3'),
			moves => {
			},
		},
		'r1bqk2r/pppp1ppp/2n1pn2/8/1bPP4/2N1P3/PP2NPPP/R1BQKB1R b KQkq' => {
			eco => 'E40',
			# TRANSLATORS: E40: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 Nc6 5. Ne2
			variation => N__('Nimzo-Indian: Taimanov, 5. Ne2'),
			moves => {
				'd7d5' => 1,
			},
		},
		'r1bqk2r/ppp2ppp/2n1pn2/3p4/1bPP4/2N1P3/PP2NPPP/R1BQKB1R w KQkq' => {
			eco => 'E40',
			# TRANSLATORS: E40: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 Nc6 5. Ne2 d5
			variation => N__('Nimzo-Indian: Taimanov, 5. Ne2 d5'),
			moves => {
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/2p5/1bPP4/2N1P3/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'E41',
			# TRANSLATORS: E41: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 c5
			variation => N__('Nimzo-Indian: 4. e3 c5'),
			moves => {
				'f1d3' => 1,
				'g1e2' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/2p5/1bPP4/2NBP3/PP3PPP/R1BQK1NR b KQkq' => {
			eco => 'E41',
			# TRANSLATORS: E41: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 c5 5. Bd3
			variation => N__('Nimzo-Indian: 4. e3 c5 5. Bd3'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bqk2r/pp1p1ppp/2n1pn2/2p5/1bPP4/2NBP3/PP3PPP/R1BQK1NR w KQkq' => {
			eco => 'E41',
			# TRANSLATORS: E41: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 c5 5. Bd3 Nc6
			variation => N__('Nimzo-Indian: 4. e3 c5 5. Bd3 Nc6'),
			moves => {
				'g1e2' => 1,
				'g1f3' => 1,
			},
		},
		'r1bqk2r/pp1p1ppp/2n1pn2/2p5/1bPP4/2NBP3/PP2NPPP/R1BQK2R b KQkq' => {
			eco => 'E41',
			# TRANSLATORS: E41: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 c5 5. Bd3 Nc6 6. Ne2
			variation => N__('Nimzo-Indian: 4. e3 c5 5. Bd3 Nc6 6. Ne2'),
			moves => {
			},
		},
		'r1bqk2r/pp1p1ppp/2n1pn2/2p5/1bPP4/2NBPN2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'E41',
			# TRANSLATORS: E41: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 c5 5. Bd3 Nc6 6. Nf3
			variation => N__('Nimzo-Indian: 4. e3 c5 5. Bd3 Nc6 6. Nf3'),
			moves => {
				'b4c3' => 1,
			},
		},
		'r1bqk2r/pp1p1ppp/2n1pn2/2p5/2PP4/2bBPN2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'E41',
			# TRANSLATORS: E41: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 c5 5. Bd3 Nc6 6. Nf3 Bxc3+
			variation => N__('Nimzo-Indian: 4. e3 c5 5. Bd3 Nc6 6. Nf3'),
			moves => {
				'b2c3' => 1,
			},
		},
		'r1bqk2r/pp1p1ppp/2n1pn2/2p5/2PP4/2PBPN2/P4PPP/R1BQK2R b KQkq' => {
			eco => 'E41',
			# TRANSLATORS: E41: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 c5 5. Bd3 Nc6 6. Nf3 Bxc3+ 7. bxc3
			variation => N__('Nimzo-Indian: 4. e3 c5 5. Bd3 Nc6 6. Nf3'),
			moves => {
				'd7d6' => 1,
			},
		},
		'r1bqk2r/pp3ppp/2nppn2/2p5/2PP4/2PBPN2/P4PPP/R1BQK2R w KQkq' => {
			eco => 'E41',
			# TRANSLATORS: E41: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 c5 5. Bd3 Nc6 6. Nf3 Bxc3+ 7. bxc3 d6
			variation => N__('Nimzo-Indian: 4. e3 c5, Hübner Variation'),
			moves => {
				'e1g1' => 1,
				'e3e4' => 1,
			},
		},
		'r1bqk2r/pp3ppp/2nppn2/2p5/2PP4/2PBPN2/P4PPP/R1BQ1RK1 b kq' => {
			eco => 'E41',
			# TRANSLATORS: E41: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 c5 5. Bd3 Nc6 6. Nf3 Bxc3+ 7. bxc3 d6 8. O-O
			variation => N__('Nimzo-Indian: Hübner, 8.O-O'),
			moves => {
				'e6e5' => 1,
			},
		},
		'r1bqk2r/pp3ppp/2np1n2/2p1p3/2PP4/2PBPN2/P4PPP/R1BQ1RK1 w kq' => {
			eco => 'E41',
			# TRANSLATORS: E41: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 c5 5. Bd3 Nc6 6. Nf3 Bxc3+ 7. bxc3 d6 8. O-O e5
			variation => N__('Nimzo-Indian: Hübner, 8.O-O e5'),
			moves => {
				'f3d2' => 1,
			},
		},
		'r1bqk2r/pp3ppp/2np1n2/2p1p3/2PP4/2PBP3/P2N1PPP/R1BQ1RK1 b kq' => {
			eco => 'E41',
			# TRANSLATORS: E41: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 c5 5. Bd3 Nc6 6. Nf3 Bxc3+ 7. bxc3 d6 8. O-O e5 9. Nd2
			variation => N__('Nimzo-Indian: Hübner, 8.O-O e5 9. Nd2'),
			moves => {
			},
		},
		'r1bqk2r/pp3ppp/2nppn2/2p5/2PPP3/2PB1N2/P4PPP/R1BQK2R b KQkq' => {
			eco => 'E41',
			# TRANSLATORS: E41: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 c5 5. Bd3 Nc6 6. Nf3 Bxc3+ 7. bxc3 d6 8. e4
			variation => N__('Nimzo-Indian: Hübner, 8. e4'),
			moves => {
				'e6e5' => 1,
			},
		},
		'r1bqk2r/pp3ppp/2np1n2/2p1p3/2PPP3/2PB1N2/P4PPP/R1BQK2R w KQkq' => {
			eco => 'E41',
			# TRANSLATORS: E41: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 c5 5. Bd3 Nc6 6. Nf3 Bxc3+ 7. bxc3 d6 8. e4 e5
			variation => N__('Nimzo-Indian: Hübner, 8. e4'),
			moves => {
				'd4d5' => 1,
			},
		},
		'r1bqk2r/pp3ppp/2np1n2/2pPp3/2P1P3/2PB1N2/P4PPP/R1BQK2R b KQkq' => {
			eco => 'E41',
			# TRANSLATORS: E41: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 c5 5. Bd3 Nc6 6. Nf3 Bxc3+ 7. bxc3 d6 8. e4 e5 9. d5
			variation => N__('Nimzo-Indian: Hübner, 8. e4'),
			moves => {
				'c6e7' => 1,
			},
		},
		'r1bqk2r/pp2nppp/3p1n2/2pPp3/2P1P3/2PB1N2/P4PPP/R1BQK2R w KQkq' => {
			eco => 'E41',
			# TRANSLATORS: E41: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 c5 5. Bd3 Nc6 6. Nf3 Bxc3+ 7. bxc3 d6 8. e4 e5 9. d5 Ne7
			variation => N__('Nimzo-Indian: Hübner, 8. e4 e5 9. d5 Ne7'),
			moves => {
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/2p5/1bPP4/2N1PN2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'E41',
			# TRANSLATORS: E41: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 c5 5. Nf3
			variation => N__('Nimzo-Indian: 4. e3 c5 5. Nf3'),
			moves => {
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/2p5/1bPP4/2N1P3/PP2NPPP/R1BQKB1R b KQkq' => {
			eco => 'E42',
			# TRANSLATORS: E42: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 c5 5. Ne2
			variation => N__('Nimzo-Indian: 4. e3 c5 5. Ne2'),
			moves => {
				'c5d4' => 1,
				'd7d5' => 1,
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/8/1bPp4/2N1P3/PP2NPPP/R1BQKB1R w KQkq' => {
			eco => 'E42',
			# TRANSLATORS: E42: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 c5 5. Ne2 cxd4
			variation => N__('Nimzo-Indian: 4. e3 c5 5. Ne2'),
			moves => {
				'e3d4' => 1,
			},
		},
		'rnbqk2r/pp1p1ppp/4pn2/8/1bPP4/2N5/PP2NPPP/R1BQKB1R b KQkq' => {
			eco => 'E42',
			# TRANSLATORS: E42: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 c5 5. Ne2 cxd4 6. exd4
			variation => N__('Nimzo-Indian: 4. e3 c5 5. Ne2 cxd4 6.exd4'),
			moves => {
				'd7d5' => 1,
				'e8g8' => 1,
			},
		},
		'rnbqk2r/pp3ppp/4pn2/3p4/1bPP4/2N5/PP2NPPP/R1BQKB1R w KQkq' => {
			eco => 'E42',
			# TRANSLATORS: E42: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 c5 5. Ne2 cxd4 6. exd4 d5
			variation => N__('Nimzo-Indian: 4. e3 c5 5. Ne2 cxd4 6.exd4 d5'),
			moves => {
			},
		},
		'rnbq1rk1/pp1p1ppp/4pn2/8/1bPP4/2N5/PP2NPPP/R1BQKB1R w KQ' => {
			eco => 'E42',
			# TRANSLATORS: E42: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 c5 5. Ne2 cxd4 6. exd4 O-O
			variation => N__('Nimzo-Indian: 4. e3 c5 5. Ne2 cxd4 6.exd4 O-O'),
			moves => {
				'a2a3' => 1,
			},
		},
		'rnbq1rk1/pp1p1ppp/4pn2/8/1bPP4/P1N5/1P2NPPP/R1BQKB1R b KQ' => {
			eco => 'E42',
			# TRANSLATORS: E42: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 c5 5. Ne2 cxd4 6. exd4 O-O 7. a3
			variation => N__('Nimzo-Indian: 4. e3 c5 5. Ne2 cxd4 6.exd4 O-O'),
			moves => {
				'b4e7' => 1,
			},
		},
		'rnbq1rk1/pp1pbppp/4pn2/8/2PP4/P1N5/1P2NPPP/R1BQKB1R w KQ' => {
			eco => 'E42',
			# TRANSLATORS: E42: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 c5 5. Ne2 cxd4 6. exd4 O-O 7. a3 Be7
			variation => N__('Nimzo-Indian: 4. e3 c5 5. Ne2 cxd4 6.exd4 O-O 7. a3 Be7'),
			moves => {
			},
		},
		'rnbqk2r/pp3ppp/4pn2/2pp4/1bPP4/2N1P3/PP2NPPP/R1BQKB1R w KQkq' => {
			eco => 'E42',
			# TRANSLATORS: E42: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 c5 5. Ne2 d5
			variation => N__('Nimzo-Indian: 4. e3 c5 5. Ne2 d5'),
			moves => {
			},
		},
		'rnbqk2r/p1pp1ppp/1p2pn2/8/1bPP4/2N1P3/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'E43',
			# TRANSLATORS: E43: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 b6
			variation => N__('Nimzo-Indian: Nimzowitsch (Fischer) Variation'),
			moves => {
				'f1d3' => 1,
				'g1e2' => 1,
				'g1f3' => 1,
			},
		},
		'rnbqk2r/p1pp1ppp/1p2pn2/8/1bPP4/2NBP3/PP3PPP/R1BQK1NR b KQkq' => {
			eco => 'E43',
			# TRANSLATORS: E43: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 b6 5. Bd3
			variation => N__('Nimzo-Indian: Nimzowitsch, 5. Bd3'),
			moves => {
			},
		},
		'rnbqk2r/p1pp1ppp/1p2pn2/8/1bPP4/2N1PN2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'E43',
			# TRANSLATORS: E43: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 b6 5. Nf3
			variation => N__('Nimzo-Indian: Nimzowitsch, 5. Nf3'),
			moves => {
				'c8b7' => 1,
			},
		},
		'rn1qk2r/pbpp1ppp/1p2pn2/8/1bPP4/2N1PN2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'E43',
			# TRANSLATORS: E43: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 b6 5. Nf3 Bb7
			variation => N__('Nimzo-Indian: Nimzowitsch, 5. Nf3 Bb7'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rn1qk2r/pbpp1ppp/1p2pn2/8/1bPP4/2NBPN2/PP3PPP/R1BQK2R b KQkq' => {
			eco => 'E43',
			# TRANSLATORS: E43: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 b6 5. Nf3 Bb7 6. Bd3
			variation => N__('Nimzo-Indian: Nimzowitsch, 5. Nf3 Bb7 6. Bd3'),
			moves => {
				'e8g8' => 1,
				'f6e4' => 1,
			},
		},
		'rn1q1rk1/pbpp1ppp/1p2pn2/8/1bPP4/2NBPN2/PP3PPP/R1BQK2R w KQ' => {
			eco => 'E43',
			# TRANSLATORS: E43: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 b6 5. Nf3 Bb7 6. Bd3 O-O
			variation => N__('Nimzo-Indian: Nimzowitsch, 5. Nf3 Bb7 6. Bd3 O-O'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rn1q1rk1/pbpp1ppp/1p2pn2/8/1bPP4/2NBPN2/PP3PPP/R1BQ1RK1 b -' => {
			eco => 'E43',
			# TRANSLATORS: E43: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 b6 5. Nf3 Bb7 6. Bd3 O-O 7. O-O
			variation => N__('Nimzo-Indian: Nimzowitsch, 5. Nf3 Bb7 6. Bd3 O-O 7.O-O'),
			moves => {
			},
		},
		'rn1qk2r/pbpp1ppp/1p2p3/8/1bPPn3/2NBPN2/PP3PPP/R1BQK2R w KQkq' => {
			eco => 'E43',
			# TRANSLATORS: E43: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 b6 5. Nf3 Bb7 6. Bd3 Ne4
			variation => N__('Nimzo-Indian: Nimzowitsch, 5. Nf3 Bb7 6. Bd3 Ne4'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rn1qk2r/pbpp1ppp/1p2p3/8/1bPPn3/2NBPN2/PP3PPP/R1BQ1RK1 b kq' => {
			eco => 'E43',
			# TRANSLATORS: E43: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 b6 5. Nf3 Bb7 6. Bd3 Ne4 7. O-O
			variation => N__('Nimzo-Indian: Nimzowitsch, 5. Nf3 Bb7 6. Bd3 Ne4 7.O-O'),
			moves => {
				'f7f5' => 1,
			},
		},
		'rn1qk2r/pbpp2pp/1p2p3/5p2/1bPPn3/2NBPN2/PP3PPP/R1BQ1RK1 w kq' => {
			eco => 'E43',
			# TRANSLATORS: E43: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 b6 5. Nf3 Bb7 6. Bd3 Ne4 7. O-O f5
			variation => N__('Nimzo-Indian: Nimzowitsch, Keene Variation'),
			moves => {
			},
		},
		'rnbqk2r/p1pp1ppp/1p2pn2/8/1bPP4/2N1P3/PP2NPPP/R1BQKB1R b KQkq' => {
			eco => 'E44',
			# TRANSLATORS: E44: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 b6 5. Ne2
			variation => N__('Nimzo-Indian: Nimzowitsch, 5. Ne2'),
			moves => {
				'c8a6' => 1,
				'c8b7' => 1,
				'f6e4' => 1,
			},
		},
		'rn1qk2r/pbpp1ppp/1p2pn2/8/1bPP4/2N1P3/PP2NPPP/R1BQKB1R w KQkq' => {
			eco => 'E44',
			# TRANSLATORS: E44: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 b6 5. Ne2 Bb7
			variation => N__('Nimzo-Indian: Nimzowitsch, 5. Ne2 Bb7'),
			moves => {
			},
		},
		'rnbqk2r/p1pp1ppp/1p2p3/8/1bPPn3/2N1P3/PP2NPPP/R1BQKB1R w KQkq' => {
			eco => 'E44',
			# TRANSLATORS: E44: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 b6 5. Ne2 Ne4
			variation => N__('Nimzo-Indian: Nimzowitsch, 5. Ne2 Ne4'),
			moves => {
				'c1d2' => 1,
				'd1c2' => 1,
			},
		},
		'rnbqk2r/p1pp1ppp/1p2p3/8/1bPPn3/2N1P3/PP1BNPPP/R2QKB1R b KQkq' => {
			eco => 'E44',
			# TRANSLATORS: E44: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 b6 5. Ne2 Ne4 6. Bd2
			variation => N__('Nimzo-Indian: Nimzowitsch, 5. Ne2 Ne4 6. Bd2'),
			moves => {
			},
		},
		'rnbqk2r/p1pp1ppp/1p2p3/8/1bPPn3/2N1P3/PPQ1NPPP/R1B1KB1R b KQkq' => {
			eco => 'E44',
			# TRANSLATORS: E44: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 b6 5. Ne2 Ne4 6. Qc2
			variation => N__('Nimzo-Indian: Nimzowitsch, 5. Ne2 Ne4 6. Qc2'),
			moves => {
			},
		},
		'rn1qk2r/p1pp1ppp/bp2pn2/8/1bPP4/2N1P3/PP2NPPP/R1BQKB1R w KQkq' => {
			eco => 'E45',
			# TRANSLATORS: E45: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 b6 5. Ne2 Ba6
			variation => N__('Nimzo-Indian: Nimzowitsch, 5. Ne2 Ba6'),
			moves => {
				'a2a3' => 1,
				'e2g3' => 1,
			},
		},
		'rn1qk2r/p1pp1ppp/bp2pn2/8/1bPP4/P1N1P3/1P2NPPP/R1BQKB1R b KQkq' => {
			eco => 'E45',
			# TRANSLATORS: E45: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 b6 5. Ne2 Ba6 6. a3
			variation => N__('Nimzo-Indian: Nimzowitsch, 5. Ne2 Ba6 6. a3'),
			moves => {
				'b4c3' => 1,
				'b4e7' => 1,
			},
		},
		'rn1qk2r/p1pp1ppp/bp2pn2/8/2PP4/P1b1P3/1P2NPPP/R1BQKB1R w KQkq' => {
			eco => 'E45',
			# TRANSLATORS: E45: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 b6 5. Ne2 Ba6 6. a3 Bxc3+
			variation => N__('Nimzo-Indian: Nimzowitsch, 5. Ne2 Ba6 6. a3 Bxc3+'),
			moves => {
			},
		},
		'rn1qk2r/p1ppbppp/bp2pn2/8/2PP4/P1N1P3/1P2NPPP/R1BQKB1R w KQkq' => {
			eco => 'E45',
			# TRANSLATORS: E45: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 b6 5. Ne2 Ba6 6. a3 Be7
			variation => N__('Nimzo-Indian: Nimzowitsch, 5. Ne2 Ba6 6. a3 Be7'),
			moves => {
			},
		},
		'rn1qk2r/p1pp1ppp/bp2pn2/8/1bPP4/2N1P1N1/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'E45',
			# TRANSLATORS: E45: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 b6 5. Ne2 Ba6 6. Ng3
			variation => N__('Nimzo-Indian: Nimzowitsch, 5. Ne2 Ba6 6. Ng3'),
			moves => {
				'b4c3' => 1,
				'h7h5' => 1,
			},
		},
		'rn1qk2r/p1pp1ppp/bp2pn2/8/2PP4/2b1P1N1/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'E45',
			# TRANSLATORS: E45: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 b6 5. Ne2 Ba6 6. Ng3 Bxc3+
			variation => N__('Nimzo-Indian: Nimzowitsch, 5. Ne2 Ba6 6. Ng3 Bxc3+'),
			moves => {
			},
		},
		'rn1qk2r/p1pp1pp1/bp2pn2/7p/1bPP4/2N1P1N1/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'E45',
			# TRANSLATORS: E45: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 b6 5. Ne2 Ba6 6. Ng3 h5
			variation => N__('Nimzo-Indian: Nimzowitsch, 5. Ne2 Ba6 6. Ng3 h5'),
			moves => {
			},
		},
		'rnbq1rk1/pppp1ppp/4pn2/8/1bPP4/2N1P3/PP3PPP/R1BQKBNR w KQ' => {
			eco => 'E46',
			# TRANSLATORS: E46: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O
			variation => N__('Nimzo-Indian: 4. e3 O-O'),
			moves => {
				'f1d3' => 1,
				'g1e2' => 1,
				'g1f3' => 1,
			},
		},
		'rnbq1rk1/pppp1ppp/4pn2/8/1bPP4/2N1P3/PP2NPPP/R1BQKB1R b KQ' => {
			eco => 'E46',
			# TRANSLATORS: E46: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Ne2
			variation => N__('Nimzo-Indian: Reshevsky Variation'),
			moves => {
				'b7b6' => 1,
				'd7d5' => 1,
				'f8e8' => 1,
			},
		},
		'rnbq1rk1/p1pp1ppp/1p2pn2/8/1bPP4/2N1P3/PP2NPPP/R1BQKB1R w KQ' => {
			eco => 'E46',
			# TRANSLATORS: E46: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Ne2 b6
			variation => N__('Nimzo-Indian: Reshevsky Variation'),
			moves => {
			},
		},
		'rnbq1rk1/ppp2ppp/4pn2/3p4/1bPP4/2N1P3/PP2NPPP/R1BQKB1R w KQ' => {
			eco => 'E46',
			# TRANSLATORS: E46: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Ne2 d5
			variation => N__('Nimzo-Indian: Reshevsky Variation'),
			moves => {
				'a2a3' => 1,
			},
		},
		'rnbq1rk1/ppp2ppp/4pn2/3p4/1bPP4/P1N1P3/1P2NPPP/R1BQKB1R b KQ' => {
			eco => 'E46',
			# TRANSLATORS: E46: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Ne2 d5 6. a3
			variation => N__('Nimzo-Indian: Reshevsky Variation'),
			moves => {
				'b4d6' => 1,
				'b4e7' => 1,
			},
		},
		'rnbq1rk1/ppp2ppp/3bpn2/3p4/2PP4/P1N1P3/1P2NPPP/R1BQKB1R w KQ' => {
			eco => 'E46',
			# TRANSLATORS: E46: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Ne2 d5 6. a3 Bd6
			variation => N__('Nimzo-Indian: Reshevsky, Simagin Variation'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1bppp/4pn2/3p4/2PP4/P1N1P3/1P2NPPP/R1BQKB1R w KQ' => {
			eco => 'E46',
			# TRANSLATORS: E46: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Ne2 d5 6. a3 Be7
			variation => N__('Nimzo-Indian: Reshevsky, 6. a3 Be7'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rnbq1rk1/ppp1bppp/4pn2/3P4/3P4/P1N1P3/1P2NPPP/R1BQKB1R b KQ' => {
			eco => 'E46',
			# TRANSLATORS: E46: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Ne2 d5 6. a3 Be7 7. cxd5
			variation => N__('Nimzo-Indian: Reshevsky, 6. a3 Be7 7.cxd5'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rnbq1rk1/ppp1bppp/5n2/3p4/3P4/P1N1P3/1P2NPPP/R1BQKB1R w KQ' => {
			eco => 'E46',
			# TRANSLATORS: E46: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Ne2 d5 6. a3 Be7 7. cxd5 exd5
			variation => N__('Nimzo-Indian: Reshevsky, 6. a3 Be7 7.cxd5 exd5'),
			moves => {
			},
		},
		'rnbqr1k1/pppp1ppp/4pn2/8/1bPP4/2N1P3/PP2NPPP/R1BQKB1R w KQ' => {
			eco => 'E46',
			# TRANSLATORS: E46: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Ne2 Re8
			variation => N__('Nimzo-Indian: Reshevsky Variation'),
			moves => {
			},
		},
		'rnbq1rk1/pppp1ppp/4pn2/8/1bPP4/2NBP3/PP3PPP/R1BQK1NR b KQ' => {
			eco => 'E47',
			# TRANSLATORS: E47: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Bd3
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Bd3'),
			moves => {
				'b7b6' => 1,
				'c7c5' => 1,
				'd7d5' => 1,
				'd7d6' => 1,
			},
		},
		'rnbq1rk1/p1pp1ppp/1p2pn2/8/1bPP4/2NBP3/PP3PPP/R1BQK1NR w KQ' => {
			eco => 'E47',
			# TRANSLATORS: E47: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Bd3 b6
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Bd3 b6'),
			moves => {
			},
		},
		'rnbq1rk1/pp1p1ppp/4pn2/2p5/1bPP4/2NBP3/PP3PPP/R1BQK1NR w KQ' => {
			eco => 'E47',
			# TRANSLATORS: E47: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Bd3 c5
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Bd3 c5'),
			moves => {
				'g1e2' => 1,
			},
		},
		'rnbq1rk1/pp1p1ppp/4pn2/2p5/1bPP4/2NBP3/PP2NPPP/R1BQK2R b KQ' => {
			eco => 'E47',
			# TRANSLATORS: E47: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Bd3 c5 6. Ne2
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Bd3 c5 6. Ne2'),
			moves => {
				'c5d4' => 1,
			},
		},
		'rnbq1rk1/pp1p1ppp/4pn2/8/1bPp4/2NBP3/PP2NPPP/R1BQK2R w KQ' => {
			eco => 'E47',
			# TRANSLATORS: E47: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Bd3 c5 6. Ne2 cxd4
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Bd3 c5 6. Ne2 cxd4'),
			moves => {
			},
		},
		'rnbq1rk1/ppp2ppp/3ppn2/8/1bPP4/2NBP3/PP3PPP/R1BQK1NR w KQ' => {
			eco => 'E47',
			# TRANSLATORS: E47: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Bd3 d6
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Bd3 d6'),
			moves => {
			},
		},
		'rnbq1rk1/ppp2ppp/4pn2/3p4/1bPP4/2NBP3/PP3PPP/R1BQK1NR w KQ' => {
			eco => 'E48',
			# TRANSLATORS: E48: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Bd3 d5
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Bd3 d5'),
			moves => {
				'a2a3' => 1,
				'c4d5' => 1,
				'g1e2' => 1,
			},
		},
		'rnbq1rk1/ppp2ppp/4pn2/3p4/1bPP4/P1NBP3/1P3PPP/R1BQK1NR b KQ' => {
			eco => 'E48',
			# TRANSLATORS: E48: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Bd3 d5 6. a3
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Bd3 d5 6. a3'),
			moves => {
				'b4c3' => 1,
			},
		},
		'rnbq1rk1/ppp2ppp/4pn2/3p4/2PP4/P1bBP3/1P3PPP/R1BQK1NR w KQ' => {
			eco => 'E48',
			# TRANSLATORS: E48: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Bd3 d5 6. a3 Bxc3+
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Bd3 d5 6. a3'),
			moves => {
				'b2c3' => 1,
			},
		},
		'rnbq1rk1/ppp2ppp/4pn2/3P4/1b1P4/2NBP3/PP3PPP/R1BQK1NR b KQ' => {
			eco => 'E48',
			# TRANSLATORS: E48: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Bd3 d5 6. cxd5
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Bd3 d5 6.cxd5'),
			moves => {
			},
		},
		'rnbq1rk1/ppp2ppp/4pn2/3p4/1bPP4/2NBP3/PP2NPPP/R1BQK2R b KQ' => {
			eco => 'E48',
			# TRANSLATORS: E48: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Bd3 d5 6. Ne2
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Bd3 d5 6. Ne2'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbq1rk1/pp3ppp/4pn2/2pp4/1bPP4/2NBP3/PP2NPPP/R1BQK2R w KQ' => {
			eco => 'E48',
			# TRANSLATORS: E48: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Bd3 d5 6. Ne2 c5
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Bd3 d5 6. Ne2 c5'),
			moves => {
				'c4d5' => 1,
				'e1g1' => 1,
			},
		},
		'rnbq1rk1/pp3ppp/4pn2/2pP4/1b1P4/2NBP3/PP2NPPP/R1BQK2R b KQ' => {
			eco => 'E48',
			# TRANSLATORS: E48: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Bd3 d5 6. Ne2 c5 7. cxd5
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Bd3 d5 6. Ne2 c5 7.cxd5'),
			moves => {
				'c5d4' => 1,
			},
		},
		'rnbq1rk1/pp3ppp/4pn2/3P4/1b1p4/2NBP3/PP2NPPP/R1BQK2R w KQ' => {
			eco => 'E48',
			# TRANSLATORS: E48: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Bd3 d5 6. Ne2 c5 7. cxd5 cxd4
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Bd3 d5 6. Ne2 c5 7.cxd5'),
			moves => {
				'e3d4' => 1,
			},
		},
		'rnbq1rk1/pp3ppp/4pn2/3P4/1b1P4/2NB4/PP2NPPP/R1BQK2R b KQ' => {
			eco => 'E48',
			# TRANSLATORS: E48: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Bd3 d5 6. Ne2 c5 7. cxd5 cxd4 8. exd4
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Bd3 d5 6. Ne2 c5 7.cxd5 cxd4 8.exd4'),
			moves => {
				'f6d5' => 1,
			},
		},
		'rnbq1rk1/pp3ppp/4p3/3n4/1b1P4/2NB4/PP2NPPP/R1BQK2R w KQ' => {
			eco => 'E48',
			# TRANSLATORS: E48: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Bd3 d5 6. Ne2 c5 7. cxd5 cxd4 8. exd4 Nxd5
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Bd3 d5 6. Ne2 c5 7.cxd5 cxd4 8.exd4 Nxd5'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbq1rk1/pp3ppp/4p3/3n4/1b1P4/2NB4/PP2NPPP/R1BQ1RK1 b -' => {
			eco => 'E48',
			# TRANSLATORS: E48: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Bd3 d5 6. Ne2 c5 7. cxd5 cxd4 8. exd4 Nxd5 9. O-O
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Bd3 d5 6. Ne2 c5 7.cxd5 cxd4 8.exd4 Nxd5 9.O-O'),
			moves => {
			},
		},
		'rnbq1rk1/pp3ppp/4pn2/2pp4/1bPP4/2NBP3/PP2NPPP/R1BQ1RK1 b -' => {
			eco => 'E48',
			# TRANSLATORS: E48: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Bd3 d5 6. Ne2 c5 7. O-O
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Bd3 d5 6. Ne2 c5 7.O-O'),
			moves => {
				'c5d4' => 1,
			},
		},
		'rnbq1rk1/pp3ppp/4pn2/3p4/1bPp4/2NBP3/PP2NPPP/R1BQ1RK1 w -' => {
			eco => 'E48',
			# TRANSLATORS: E48: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Bd3 d5 6. Ne2 c5 7. O-O cxd4
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Bd3 d5 6. Ne2 c5 7.O-O'),
			moves => {
				'e3d4' => 1,
			},
		},
		'rnbq1rk1/pp3ppp/4pn2/3p4/1bPP4/2NB4/PP2NPPP/R1BQ1RK1 b -' => {
			eco => 'E48',
			# TRANSLATORS: E48: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Bd3 d5 6. Ne2 c5 7. O-O cxd4 8. exd4
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Bd3 d5 6. Ne2 c5 7.O-O cxd4 8.exd4'),
			moves => {
			},
		},
		'rnbq1rk1/ppp2ppp/4pn2/3p4/2PP4/P1PBP3/5PPP/R1BQK1NR b KQ' => {
			eco => 'E49',
			# TRANSLATORS: E49: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Bd3 d5 6. a3 Bxc3+ 7. bxc3
			variation => N__('Nimzo-Indian: Botvinnik System'),
			moves => {
				'c7c5' => 1,
				'd5c4' => 1,
			},
		},
		'rnbq1rk1/pp3ppp/4pn2/2pp4/2PP4/P1PBP3/5PPP/R1BQK1NR w KQ' => {
			eco => 'E49',
			# TRANSLATORS: E49: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Bd3 d5 6. a3 Bxc3+ 7. bxc3 c5
			variation => N__('Nimzo-Indian: Botvinnik, 7... c5'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rnbq1rk1/pp3ppp/4pn2/2pP4/3P4/P1PBP3/5PPP/R1BQK1NR b KQ' => {
			eco => 'E49',
			# TRANSLATORS: E49: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Bd3 d5 6. a3 Bxc3+ 7. bxc3 c5 8. cxd5
			variation => N__('Nimzo-Indian: Botvinnik, 7... c5 8.cxd5'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rnbq1rk1/pp3ppp/5n2/2pp4/3P4/P1PBP3/5PPP/R1BQK1NR w KQ' => {
			eco => 'E49',
			# TRANSLATORS: E49: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Bd3 d5 6. a3 Bxc3+ 7. bxc3 c5 8. cxd5 exd5
			variation => N__('Nimzo-Indian: Botvinnik, 7... c5 8.cxd5 exd5'),
			moves => {
				'g1e2' => 1,
			},
		},
		'rnbq1rk1/pp3ppp/5n2/2pp4/3P4/P1PBP3/4NPPP/R1BQK2R b KQ' => {
			eco => 'E49',
			# TRANSLATORS: E49: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Bd3 d5 6. a3 Bxc3+ 7. bxc3 c5 8. cxd5 exd5 9. Ne2
			variation => N__('Nimzo-Indian: Botvinnik, 7... c5 8.cxd5 exd5 9. Ne2'),
			moves => {
			},
		},
		'rnbq1rk1/ppp2ppp/4pn2/8/2pP4/P1PBP3/5PPP/R1BQK1NR w KQ' => {
			eco => 'E49',
			# TRANSLATORS: E49: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Bd3 d5 6. a3 Bxc3+ 7. bxc3 dxc4
			variation => N__('Nimzo-Indian: Botvinnik, 7...dxc4'),
			moves => {
				'd3c4' => 1,
			},
		},
		'rnbq1rk1/ppp2ppp/4pn2/8/2BP4/P1P1P3/5PPP/R1BQK1NR b KQ' => {
			eco => 'E49',
			# TRANSLATORS: E49: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Bd3 d5 6. a3 Bxc3+ 7. bxc3 dxc4 8. Bxc4
			variation => N__('Nimzo-Indian: Botvinnik, 7...dxc4'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbq1rk1/pp3ppp/4pn2/2p5/2BP4/P1P1P3/5PPP/R1BQK1NR w KQ' => {
			eco => 'E49',
			# TRANSLATORS: E49: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Bd3 d5 6. a3 Bxc3+ 7. bxc3 dxc4 8. Bxc4 c5
			variation => N__('Nimzo-Indian: Botvinnik, 7...dxc4 8.Bxc4 c5'),
			moves => {
				'g1e2' => 1,
			},
		},
		'rnbq1rk1/pp3ppp/4pn2/2p5/2BP4/P1P1P3/4NPPP/R1BQK2R b KQ' => {
			eco => 'E49',
			# TRANSLATORS: E49: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Bd3 d5 6. a3 Bxc3+ 7. bxc3 dxc4 8. Bxc4 c5 9. Ne2
			variation => N__('Nimzo-Indian: Botvinnik, 7...dxc4 8.Bxc4 c5 9. Ne2'),
			moves => {
			},
		},
		'rnbq1rk1/pppp1ppp/4pn2/8/1bPP4/2N1PN2/PP3PPP/R1BQKB1R b KQ' => {
			eco => 'E50',
			# TRANSLATORS: E50: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Nf3'),
			moves => {
				'b7b6' => 1,
				'c7c5' => 1,
				'd7d5' => 1,
				'f6e4' => 1,
			},
		},
		'rnbq1rk1/p1pp1ppp/1p2pn2/8/1bPP4/2N1PN2/PP3PPP/R1BQKB1R w KQ' => {
			eco => 'E50',
			# TRANSLATORS: E50: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 b6
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Nf3 b6'),
			moves => {
			},
		},
		'rnbq1rk1/pp1p1ppp/4pn2/2p5/1bPP4/2N1PN2/PP3PPP/R1BQKB1R w KQ' => {
			eco => 'E50',
			# TRANSLATORS: E50: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 c5
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Nf3 c5'),
			moves => {
				'f1d3' => 1,
				'f1e2' => 1,
			},
		},
		'rnbq1rk1/pp1p1ppp/4pn2/2p5/1bPP4/2NBPN2/PP3PPP/R1BQK2R b KQ' => {
			eco => 'E50',
			# TRANSLATORS: E50: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 c5 6. Bd3
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Nf3 c5 6. Bd3'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bq1rk1/pp1p1ppp/2n1pn2/2p5/1bPP4/2NBPN2/PP3PPP/R1BQK2R w KQ' => {
			eco => 'E50',
			# TRANSLATORS: E50: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 c5 6. Bd3 Nc6
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Nf3 c5 6. Bd3 Nc6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bq1rk1/pp1p1ppp/2n1pn2/2p5/1bPP4/2NBPN2/PP3PPP/R1BQ1RK1 b -' => {
			eco => 'E50',
			# TRANSLATORS: E50: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 c5 6. Bd3 Nc6 7. O-O
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Nf3 c5 6. Bd3 Nc6 7.O-O'),
			moves => {
			},
		},
		'rnbq1rk1/pp1p1ppp/4pn2/2p5/1bPP4/2N1PN2/PP2BPPP/R1BQK2R b KQ' => {
			eco => 'E50',
			# TRANSLATORS: E50: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 c5 6. Be2
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Nf3 c5 6. Be2'),
			moves => {
			},
		},
		'rnbq1rk1/pppp1ppp/4p3/8/1bPPn3/2N1PN2/PP3PPP/R1BQKB1R w KQ' => {
			eco => 'E50',
			# TRANSLATORS: E50: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 Ne4
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Nf3 Ne4'),
			moves => {
			},
		},
		'rnbq1rk1/ppp2ppp/4pn2/3p4/1bPP4/2N1PN2/PP3PPP/R1BQKB1R w KQ' => {
			eco => 'E51',
			# TRANSLATORS: E51: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Nf3 d5'),
			moves => {
				'a2a3' => 1,
				'f1d3' => 1,
				'f1e2' => 1,
			},
		},
		'rnbq1rk1/ppp2ppp/4pn2/3p4/1bPP4/P1N1PN2/1P3PPP/R1BQKB1R b KQ' => {
			eco => 'E51',
			# TRANSLATORS: E51: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. a3
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Nf3 d5 6. a3'),
			moves => {
			},
		},
		'rnbq1rk1/ppp2ppp/4pn2/3p4/1bPP4/2NBPN2/PP3PPP/R1BQK2R b KQ' => {
			eco => 'E51',
			# TRANSLATORS: E51: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Nf3 d5 6. Bd3'),
			moves => {
				'b7b6' => 1,
				'b8c6' => 1,
				'c7c5' => 1,
			},
		},
		'r1bq1rk1/ppp2ppp/2n1pn2/3p4/1bPP4/2NBPN2/PP3PPP/R1BQK2R w KQ' => {
			eco => 'E51',
			# TRANSLATORS: E51: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 Nc6
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Nf3 d5 6. Bd3 Nc6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bq1rk1/ppp2ppp/2n1pn2/3p4/1bPP4/2NBPN2/PP3PPP/R1BQ1RK1 b -' => {
			eco => 'E51',
			# TRANSLATORS: E51: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 Nc6 7. O-O
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Nf3 d5 6. Bd3 Nc6 7.O-O'),
			moves => {
				'a7a6' => 1,
				'd5c4' => 1,
			},
		},
		'r1bq1rk1/1pp2ppp/p1n1pn2/3p4/1bPP4/2NBPN2/PP3PPP/R1BQ1RK1 w -' => {
			eco => 'E51',
			# TRANSLATORS: E51: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 Nc6 7. O-O a6
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Nf3 d5 6. Bd3 Nc6 7.O-O a6'),
			moves => {
			},
		},
		'r1bq1rk1/ppp2ppp/2n1pn2/8/1bpP4/2NBPN2/PP3PPP/R1BQ1RK1 w -' => {
			eco => 'E51',
			# TRANSLATORS: E51: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 Nc6 7. O-O dxc4
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Nf3 d5 6. Bd3 Nc6 7.O-O dxc4'),
			moves => {
			},
		},
		'rnbq1rk1/ppp2ppp/4pn2/3p4/1bPP4/2N1PN2/PP2BPPP/R1BQK2R b KQ' => {
			eco => 'E51',
			# TRANSLATORS: E51: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Be2
			variation => N__('Nimzo-Indian: 4. e3 O-O 5. Nf3 d5 6. Be2'),
			moves => {
			},
		},
		'rnbq1rk1/p1p2ppp/1p2pn2/3p4/1bPP4/2NBPN2/PP3PPP/R1BQK2R w KQ' => {
			eco => 'E52',
			# TRANSLATORS: E52: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 b6
			variation => N__('Nimzo-Indian: Main Line, 6... b6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbq1rk1/p1p2ppp/1p2pn2/3p4/1bPP4/2NBPN2/PP3PPP/R1BQ1RK1 b -' => {
			eco => 'E52',
			# TRANSLATORS: E52: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 b6 7. O-O
			variation => N__('Nimzo-Indian: Main Line, 6... b6 7.O-O'),
			moves => {
				'c8b7' => 1,
			},
		},
		'rn1q1rk1/pbp2ppp/1p2pn2/3p4/1bPP4/2NBPN2/PP3PPP/R1BQ1RK1 w -' => {
			eco => 'E52',
			# TRANSLATORS: E52: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 b6 7. O-O Bb7
			variation => N__('Nimzo-Indian: Main Line, 6... b6 7.O-O Bb7'),
			moves => {
				'a2a3' => 1,
				'c4d5' => 1,
			},
		},
		'rn1q1rk1/pbp2ppp/1p2pn2/3p4/1bPP4/P1NBPN2/1P3PPP/R1BQ1RK1 b -' => {
			eco => 'E52',
			# TRANSLATORS: E52: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 b6 7. O-O Bb7 8. a3
			variation => N__('Nimzo-Indian: Main Line, 6... b6 7.O-O Bb7 8. a3'),
			moves => {
				'b4d6' => 1,
			},
		},
		'rn1q1rk1/pbp2ppp/1p1bpn2/3p4/2PP4/P1NBPN2/1P3PPP/R1BQ1RK1 w -' => {
			eco => 'E52',
			# TRANSLATORS: E52: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 b6 7. O-O Bb7 8. a3 Bd6
			variation => N__('Nimzo-Indian: Main Line, 6... b6 7.O-O Bb7 8. a3 Bd6'),
			moves => {
			},
		},
		'rn1q1rk1/pbp2ppp/1p2pn2/3P4/1b1P4/2NBPN2/PP3PPP/R1BQ1RK1 b -' => {
			eco => 'E52',
			# TRANSLATORS: E52: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 b6 7. O-O Bb7 8. cxd5
			variation => N__('Nimzo-Indian: Main Line, 6... b6 7.O-O Bb7 8.cxd5'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rn1q1rk1/pbp2ppp/1p3n2/3p4/1b1P4/2NBPN2/PP3PPP/R1BQ1RK1 w -' => {
			eco => 'E52',
			# TRANSLATORS: E52: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 b6 7. O-O Bb7 8. cxd5 exd5
			variation => N__('Nimzo-Indian: Main Line, 6... b6 7.O-O Bb7 8.cxd5 exd5'),
			moves => {
				'a2a3' => 1,
				'f3e5' => 1,
			},
		},
		'rn1q1rk1/pbp2ppp/1p3n2/3p4/1b1P4/P1NBPN2/1P3PPP/R1BQ1RK1 b -' => {
			eco => 'E52',
			# TRANSLATORS: E52: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 b6 7. O-O Bb7 8. cxd5 exd5 9. a3
			variation => N__('Nimzo-Indian: Main Line, 6... b6 7.O-O Bb7 8.cxd5 exd5 9. a3'),
			moves => {
				'b4d6' => 1,
			},
		},
		'rn1q1rk1/pbp2ppp/1p1b1n2/3p4/3P4/P1NBPN2/1P3PPP/R1BQ1RK1 w -' => {
			eco => 'E52',
			# TRANSLATORS: E52: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 b6 7. O-O Bb7 8. cxd5 exd5 9. a3 Bd6
			variation => N__('Nimzo-Indian: Main Line, 6... b6 7.O-O Bb7 8.cxd5 exd5 9. a3 Bd6'),
			moves => {
			},
		},
		'rn1q1rk1/pbp2ppp/1p3n2/3pN3/1b1P4/2NBP3/PP3PPP/R1BQ1RK1 b -' => {
			eco => 'E52',
			# TRANSLATORS: E52: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 b6 7. O-O Bb7 8. cxd5 exd5 9. Ne5
			variation => N__('Nimzo-Indian: Main Line, 6... b6 7.O-O Bb7 8.cxd5 exd5 9. Ne5'),
			moves => {
			},
		},
		'rnbq1rk1/pp3ppp/4pn2/2pp4/1bPP4/2NBPN2/PP3PPP/R1BQK2R w KQ' => {
			eco => 'E53',
			# TRANSLATORS: E53: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5
			variation => N__('Nimzo-Indian: Main Line, 6... c5'),
			moves => {
				'a2a3' => 1,
				'e1g1' => 1,
			},
		},
		'rnbq1rk1/pp3ppp/4pn2/2pp4/1bPP4/P1NBPN2/1P3PPP/R1BQK2R b KQ' => {
			eco => 'E53',
			# TRANSLATORS: E53: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. a3
			variation => N__('Nimzo-Indian: Main Line, 6... c5 7. a3'),
			moves => {
			},
		},
		'rnbq1rk1/pp3ppp/4pn2/2pp4/1bPP4/2NBPN2/PP3PPP/R1BQ1RK1 b -' => {
			eco => 'E53',
			# TRANSLATORS: E53: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O
			variation => N__('Nimzo-Indian: Main Line, 6... c5 7.O-O'),
			moves => {
				'b7b6' => 1,
				'b8c6' => 1,
				'b8d7' => 1,
				'c8d7' => 1,
				'd5c4' => 1,
			},
		},
		'rnbq1rk1/p4ppp/1p2pn2/2pp4/1bPP4/2NBPN2/PP3PPP/R1BQ1RK1 w -' => {
			eco => 'E53',
			# TRANSLATORS: E53: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O b6
			variation => N__('Nimzo-Indian: Main Line, Keres Variation'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rnbq1rk1/p4ppp/1p2pn2/2pP4/1b1P4/2NBPN2/PP3PPP/R1BQ1RK1 b -' => {
			eco => 'E53',
			# TRANSLATORS: E53: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O b6 8. cxd5
			variation => N__('Nimzo-Indian: Main Line, Keres Variation'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rnbq1rk1/p4ppp/1p3n2/2pp4/1b1P4/2NBPN2/PP3PPP/R1BQ1RK1 w -' => {
			eco => 'E53',
			# TRANSLATORS: E53: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O b6 8. cxd5 exd5
			variation => N__('Nimzo-Indian: Main Line, Keres, 8.cxd5 exd5'),
			moves => {
			},
		},
		'r1bq1rk1/pp1n1ppp/4pn2/2pp4/1bPP4/2NBPN2/PP3PPP/R1BQ1RK1 w -' => {
			eco => 'E53',
			# TRANSLATORS: E53: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nbd7
			variation => N__('Nimzo-Indian: Main Line, 7...Nbd7'),
			moves => {
			},
		},
		'rn1q1rk1/pp1b1ppp/4pn2/2pp4/1bPP4/2NBPN2/PP3PPP/R1BQ1RK1 w -' => {
			eco => 'E53',
			# TRANSLATORS: E53: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Bd7
			variation => N__('Nimzo-Indian: Main Line, 7... Bd7'),
			moves => {
			},
		},
		'rnbq1rk1/pp3ppp/4pn2/2p5/1bpP4/2NBPN2/PP3PPP/R1BQ1RK1 w -' => {
			eco => 'E54',
			# TRANSLATORS: E54: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O dxc4
			variation => N__('Nimzo-Indian: Main Line, 7...dxc4'),
			moves => {
				'd3c4' => 1,
			},
		},
		'rnbq1rk1/pp3ppp/4pn2/2p5/1bBP4/2N1PN2/PP3PPP/R1BQ1RK1 b -' => {
			eco => 'E54',
			# TRANSLATORS: E54: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O dxc4 8. Bxc4
			variation => N__('Nimzo-Indian: Main Line, 7...dxc4 8.Bxc4'),
			moves => {
				'b8c6' => 1,
				'b8d7' => 1,
				'c5d4' => 1,
				'd8e7' => 1,
			},
		},
		'r1bq1rk1/pp3ppp/2n1pn2/2p5/1bBP4/2N1PN2/PP3PPP/R1BQ1RK1 w -' => {
			eco => 'E54',
			# TRANSLATORS: E54: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O dxc4 8. Bxc4 Nc6
			variation => N__('Nimzo-Indian: Main Line, 7...dxc4 8.Bxc4 Nc6'),
			moves => {
			},
		},
		'rnbq1rk1/pp3ppp/4pn2/8/1bBp4/2N1PN2/PP3PPP/R1BQ1RK1 w -' => {
			eco => 'E54',
			# TRANSLATORS: E54: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O dxc4 8. Bxc4 cxd4
			variation => N__('Nimzo-Indian: Main Line, 7...dxc4 8.Bxc4 cxd4'),
			moves => {
				'e3d4' => 1,
			},
		},
		'rnbq1rk1/pp3ppp/4pn2/8/1bBP4/2N2N2/PP3PPP/R1BQ1RK1 b -' => {
			eco => 'E54',
			# TRANSLATORS: E54: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O dxc4 8. Bxc4 cxd4 9. exd4
			variation => N__('Nimzo-Indian: Main Line, 7...dxc4 8.Bxc4 cxd4 9.exd4'),
			moves => {
				'a7a6' => 1,
				'b7b6' => 1,
			},
		},
		'rnbq1rk1/1p3ppp/p3pn2/8/1bBP4/2N2N2/PP3PPP/R1BQ1RK1 w -' => {
			eco => 'E54',
			# TRANSLATORS: E54: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O dxc4 8. Bxc4 cxd4 9. exd4 a6
			variation => N__('Nimzo-Indian: Main Line, 7...dxc4 8.Bxc4 cxd4 9.exd4 a6'),
			moves => {
				'c1g5' => 1,
			},
		},
		'rnbq1rk1/1p3ppp/p3pn2/6B1/1bBP4/2N2N2/PP3PPP/R2Q1RK1 b -' => {
			eco => 'E54',
			# TRANSLATORS: E54: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O dxc4 8. Bxc4 cxd4 9. exd4 a6 10. Bg5
			variation => N__('Nimzo-Indian: Main Line, 7...dxc4 8.Bxc4 cxd4 9.exd4 a6 10. Bg5'),
			moves => {
			},
		},
		'rnbq1rk1/p4ppp/1p2pn2/8/1bBP4/2N2N2/PP3PPP/R1BQ1RK1 w -' => {
			eco => 'E54',
			# TRANSLATORS: E54: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O dxc4 8. Bxc4 cxd4 9. exd4 b6
			variation => N__('Nimzo-Indian: Main Line, Karpov Variation'),
			moves => {
				'c1g5' => 1,
			},
		},
		'rnbq1rk1/p4ppp/1p2pn2/6B1/1bBP4/2N2N2/PP3PPP/R2Q1RK1 b -' => {
			eco => 'E54',
			# TRANSLATORS: E54: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O dxc4 8. Bxc4 cxd4 9. exd4 b6 10. Bg5
			variation => N__('Nimzo-Indian: Main Line, Karpov, 10. Bg5'),
			moves => {
				'c8b7' => 1,
			},
		},
		'rn1q1rk1/pb3ppp/1p2pn2/6B1/1bBP4/2N2N2/PP3PPP/R2Q1RK1 w -' => {
			eco => 'E54',
			# TRANSLATORS: E54: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O dxc4 8. Bxc4 cxd4 9. exd4 b6 10. Bg5 Bb7
			variation => N__('Nimzo-Indian: Main Line, Karpov, 10. Bg5 Bb7'),
			moves => {
				'a1c1' => 1,
				'd1e2' => 1,
				'f1e1' => 1,
				'f3e5' => 1,
			},
		},
		'rn1q1rk1/pb3ppp/1p2pn2/6B1/1bBP4/2N2N2/PP3PPP/2RQ1RK1 b -' => {
			eco => 'E54',
			# TRANSLATORS: E54: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O dxc4 8. Bxc4 cxd4 9. exd4 b6 10. Bg5 Bb7 11. Rc1
			variation => N__('Nimzo-Indian: Main Line, Karpov, 10. Bg5 Bb7 11. Rc1'),
			moves => {
			},
		},
		'rn1q1rk1/pb3ppp/1p2pn2/6B1/1bBP4/2N2N2/PP2QPPP/R4RK1 b -' => {
			eco => 'E54',
			# TRANSLATORS: E54: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O dxc4 8. Bxc4 cxd4 9. exd4 b6 10. Bg5 Bb7 11. Qe2
			variation => N__('Nimzo-Indian: Main Line, Karpov, 10. Bg5 Bb7 11. Qe2'),
			moves => {
			},
		},
		'rn1q1rk1/pb3ppp/1p2pn2/6B1/1bBP4/2N2N2/PP3PPP/R2QR1K1 b -' => {
			eco => 'E54',
			# TRANSLATORS: E54: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O dxc4 8. Bxc4 cxd4 9. exd4 b6 10. Bg5 Bb7 11. Re1
			variation => N__('Nimzo-Indian: Main Line, Karpov, 10. Bg5 Bb7 11. Re1'),
			moves => {
			},
		},
		'rn1q1rk1/pb3ppp/1p2pn2/4N1B1/1bBP4/2N5/PP3PPP/R2Q1RK1 b -' => {
			eco => 'E54',
			# TRANSLATORS: E54: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O dxc4 8. Bxc4 cxd4 9. exd4 b6 10. Bg5 Bb7 11. Ne5
			variation => N__('Nimzo-Indian: Main Line, Karpov, 10. Bg5 Bb7 11. Ne5'),
			moves => {
			},
		},
		'rnb2rk1/pp2qppp/4pn2/2p5/1bBP4/2N1PN2/PP3PPP/R1BQ1RK1 w -' => {
			eco => 'E54',
			# TRANSLATORS: E54: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O dxc4 8. Bxc4 Qe7
			variation => N__('Nimzo-Indian: Main Line, Smyslov Variation'),
			moves => {
			},
		},
		'r1bq1rk1/pp1n1ppp/4pn2/2p5/1bBP4/2N1PN2/PP3PPP/R1BQ1RK1 w -' => {
			eco => 'E55',
			# TRANSLATORS: E55: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O dxc4 8. Bxc4 Nbd7
			variation => N__('Nimzo-Indian: Main Line, Bronstein Variation'),
			moves => {
				'a2a3' => 1,
				'c3e2' => 1,
				'd1e2' => 1,
			},
		},
		'r1bq1rk1/pp1n1ppp/4pn2/2p5/1bBP4/P1N1PN2/1P3PPP/R1BQ1RK1 b -' => {
			eco => 'E55',
			# TRANSLATORS: E55: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O dxc4 8. Bxc4 Nbd7 9. a3
			variation => N__('Nimzo-Indian: Main Line, Bronstein, 9. a3'),
			moves => {
				'c5d4' => 1,
			},
		},
		'r1bq1rk1/pp1n1ppp/4pn2/8/1bBp4/P1N1PN2/1P3PPP/R1BQ1RK1 w -' => {
			eco => 'E55',
			# TRANSLATORS: E55: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O dxc4 8. Bxc4 Nbd7 9. a3 cxd4
			variation => N__('Nimzo-Indian: Main Line, Bronstein, 9. a3'),
			moves => {
				'e3d4' => 1,
			},
		},
		'r1bq1rk1/pp1n1ppp/4pn2/8/1bBP4/P1N2N2/1P3PPP/R1BQ1RK1 b -' => {
			eco => 'E55',
			# TRANSLATORS: E55: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O dxc4 8. Bxc4 Nbd7 9. a3 cxd4 10. exd4
			variation => N__('Nimzo-Indian: Main Line, Bronstein, 9. a3 cd4 10.ed4'),
			moves => {
			},
		},
		'r1bq1rk1/pp1n1ppp/4pn2/2p5/1bBP4/4PN2/PP2NPPP/R1BQ1RK1 b -' => {
			eco => 'E55',
			# TRANSLATORS: E55: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O dxc4 8. Bxc4 Nbd7 9. Ne2
			variation => N__('Nimzo-Indian: Main Line, Bronstein, 9. Ne2'),
			moves => {
			},
		},
		'r1bq1rk1/pp1n1ppp/4pn2/2p5/1bBP4/2N1PN2/PP2QPPP/R1B2RK1 b -' => {
			eco => 'E55',
			# TRANSLATORS: E55: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O dxc4 8. Bxc4 Nbd7 9. Qe2
			variation => N__('Nimzo-Indian: Main Line, Bronstein, 9. Qe2'),
			moves => {
				'a7a6' => 1,
				'b7b6' => 1,
			},
		},
		'r1bq1rk1/1p1n1ppp/p3pn2/2p5/1bBP4/2N1PN2/PP2QPPP/R1B2RK1 w -' => {
			eco => 'E55',
			# TRANSLATORS: E55: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O dxc4 8. Bxc4 Nbd7 9. Qe2 a6
			variation => N__('Nimzo-Indian: Main Line, Bronstein, 9. Qe2 a6'),
			moves => {
			},
		},
		'r1bq1rk1/p2n1ppp/1p2pn2/2p5/1bBP4/2N1PN2/PP2QPPP/R1B2RK1 w -' => {
			eco => 'E55',
			# TRANSLATORS: E55: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O dxc4 8. Bxc4 Nbd7 9. Qe2 b6
			variation => N__('Nimzo-Indian: Main Line, Bronstein, 9. Qe2 b6'),
			moves => {
				'f1d1' => 1,
			},
		},
		'r1bq1rk1/p2n1ppp/1p2pn2/2p5/1bBP4/2N1PN2/PP2QPPP/R1BR2K1 b -' => {
			eco => 'E55',
			# TRANSLATORS: E55: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O dxc4 8. Bxc4 Nbd7 9. Qe2 b6 10. Rd1
			variation => N__('Nimzo-Indian: Main Line, Bronstein, 9. Qe2 b6 10. Rd1'),
			moves => {
			},
		},
		'r1bq1rk1/pp3ppp/2n1pn2/2pp4/1bPP4/2NBPN2/PP3PPP/R1BQ1RK1 w -' => {
			eco => 'E56',
			# TRANSLATORS: E56: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6
			variation => N__('Nimzo-Indian: Main Line, 7... Nc6'),
			moves => {
				'a2a3' => 1,
				'c4d5' => 1,
			},
		},
		'r1bq1rk1/pp3ppp/2n1pn2/2pp4/1bPP4/P1NBPN2/1P3PPP/R1BQ1RK1 b -' => {
			eco => 'E56',
			# TRANSLATORS: E56: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3
			variation => N__('Nimzo-Indian: Main Line, 7... Nc6 8. a3'),
			moves => {
				'b4a5' => 1,
				'b4c3' => 1,
				'c5d4' => 1,
				'd5c4' => 1,
			},
		},
		'r1bq1rk1/pp3ppp/2n1pn2/b1pp4/2PP4/P1NBPN2/1P3PPP/R1BQ1RK1 w -' => {
			eco => 'E56',
			# TRANSLATORS: E56: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 Ba5
			variation => N__('Nimzo-Indian: Main Line, 7... Nc6 8. a3 Ba5'),
			moves => {
				'c4d5' => 1,
			},
		},
		'r1bq1rk1/pp3ppp/2n1pn2/b1pP4/3P4/P1NBPN2/1P3PPP/R1BQ1RK1 b -' => {
			eco => 'E56',
			# TRANSLATORS: E56: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 Ba5 9. cxd5
			variation => N__('Nimzo-Indian: Main Line, 7... Nc6 8. a3 Ba5 9.cxd5'),
			moves => {
			},
		},
		'r1bq1rk1/pp3ppp/2n1pn2/3p4/1bPp4/P1NBPN2/1P3PPP/R1BQ1RK1 w -' => {
			eco => 'E56',
			# TRANSLATORS: E56: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 cxd4
			variation => N__('Nimzo-Indian: Main Line, 7... Nc6 8. a3 cxd4'),
			moves => {
				'e3d4' => 1,
			},
		},
		'r1bq1rk1/pp3ppp/2n1pn2/3p4/1bPP4/P1NB1N2/1P3PPP/R1BQ1RK1 b -' => {
			eco => 'E56',
			# TRANSLATORS: E56: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 cxd4 9. exd4
			variation => N__('Nimzo-Indian: Main Line, 7... Nc6 8. a3 cxd4 9.exd4'),
			moves => {
			},
		},
		'r1bq1rk1/pp3ppp/2n1pn2/2p5/1bpP4/P1NBPN2/1P3PPP/R1BQ1RK1 w -' => {
			eco => 'E56',
			# TRANSLATORS: E56: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 dxc4
			variation => N__('Nimzo-Indian: Main Line, 7... Nc6 8. a3 dxc4'),
			moves => {
				'd3c4' => 1,
			},
		},
		'r1bq1rk1/pp3ppp/2n1pn2/2p5/1bBP4/P1N1PN2/1P3PPP/R1BQ1RK1 b -' => {
			eco => 'E56',
			# TRANSLATORS: E56: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 dxc4 9. Bxc4
			variation => N__('Nimzo-Indian: Main Line, 7... Nc6 8. a3 dxc4 9.Bxc4'),
			moves => {
				'b4a5' => 1,
				'c5d4' => 1,
			},
		},
		'r1bq1rk1/pp3ppp/2n1pn2/b1p5/2BP4/P1N1PN2/1P3PPP/R1BQ1RK1 w -' => {
			eco => 'E56',
			# TRANSLATORS: E56: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 dxc4 9. Bxc4 Ba5
			variation => N__('Nimzo-Indian: Main Line, 7... Nc6 8. a3 dxc4 9.Bxc4 Ba5'),
			moves => {
			},
		},
		'r1bq1rk1/pp3ppp/2n1pn2/2pP4/1b1P4/2NBPN2/PP3PPP/R1BQ1RK1 b -' => {
			eco => 'E56',
			# TRANSLATORS: E56: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. cxd5
			variation => N__('Nimzo-Indian: Main Line, 7... Nc6 8.cxd5'),
			moves => {
			},
		},
		'r1bq1rk1/pp3ppp/2n1pn2/8/1bBp4/P1N1PN2/1P3PPP/R1BQ1RK1 w -' => {
			eco => 'E57',
			# TRANSLATORS: E57: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 dxc4 9. Bxc4 cxd4
			variation => N__('Nimzo-Indian: Main Line, 8...dxc4 9.Bxc4 cxd4'),
			moves => {
				'e3d4' => 1,
			},
		},
		'r1bq1rk1/pp3ppp/2n1pn2/8/1bBP4/P1N2N2/1P3PPP/R1BQ1RK1 b -' => {
			eco => 'E57',
			# TRANSLATORS: E57: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 dxc4 9. Bxc4 cxd4 10. exd4
			variation => N__('Nimzo-Indian: Main Line, 8...dxc4 9.Bxc4 cxd4 10.exd4'),
			moves => {
				'b4e7' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2n1pn2/8/2BP4/P1N2N2/1P3PPP/R1BQ1RK1 w -' => {
			eco => 'E57',
			# TRANSLATORS: E57: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 dxc4 9. Bxc4 cxd4 10. exd4 Be7
			variation => N__('Nimzo-Indian: Main Line, 8...dxc4 9.Bxc4 cxd4 10.exd4 Be7'),
			moves => {
				'c1e3' => 1,
				'c1f4' => 1,
				'c1g5' => 1,
				'd1d3' => 1,
				'f1e1' => 1,
			},
		},
		'r1bq1rk1/pp2bppp/2n1pn2/8/2BP4/P1N1BN2/1P3PPP/R2Q1RK1 b -' => {
			eco => 'E57',
			# TRANSLATORS: E57: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 dxc4 9. Bxc4 cxd4 10. exd4 Be7 11. Be3
			variation => N__('Nimzo-Indian: Main Line, 8...dxc4 9.Bxc4 cxd4 10.exd4 Be7 11. Be3'),
			moves => {
			},
		},
		'r1bq1rk1/pp2bppp/2n1pn2/8/2BP1B2/P1N2N2/1P3PPP/R2Q1RK1 b -' => {
			eco => 'E57',
			# TRANSLATORS: E57: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 dxc4 9. Bxc4 cxd4 10. exd4 Be7 11. Bf4
			variation => N__('Nimzo-Indian: Main Line, 8...dxc4 9.Bxc4 cxd4 10.exd4 Be7 11. Bf4'),
			moves => {
			},
		},
		'r1bq1rk1/pp2bppp/2n1pn2/6B1/2BP4/P1N2N2/1P3PPP/R2Q1RK1 b -' => {
			eco => 'E57',
			# TRANSLATORS: E57: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 dxc4 9. Bxc4 cxd4 10. exd4 Be7 11. Bg5
			variation => N__('Nimzo-Indian: Main Line, 8...dxc4 9.Bxc4 cxd4 10.exd4 Be7 11. Bg5'),
			moves => {
			},
		},
		'r1bq1rk1/pp2bppp/2n1pn2/8/2BP4/P1NQ1N2/1P3PPP/R1B2RK1 b -' => {
			eco => 'E57',
			# TRANSLATORS: E57: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 dxc4 9. Bxc4 cxd4 10. exd4 Be7 11. Qd3
			variation => N__('Nimzo-Indian: Main Line, 8...dxc4 9.Bxc4 cxd4 10.exd4 Be7 11. Qd3'),
			moves => {
			},
		},
		'r1bq1rk1/pp2bppp/2n1pn2/8/2BP4/P1N2N2/1P3PPP/R1BQR1K1 b -' => {
			eco => 'E57',
			# TRANSLATORS: E57: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 dxc4 9. Bxc4 cxd4 10. exd4 Be7 11. Re1
			variation => N__('Nimzo-Indian: Main Line, 8...dxc4 9.Bxc4 cxd4 10.exd4 Be7 11. Re1'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r1bq1rk1/1p2bppp/p1n1pn2/8/2BP4/P1N2N2/1P3PPP/R1BQR1K1 w -' => {
			eco => 'E57',
			# TRANSLATORS: E57: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 dxc4 9. Bxc4 cxd4 10. exd4 Be7 11. Re1 a6
			variation => N__('Nimzo-Indian: Main Line, 8...dxc4 9.Bxc4 cxd4 10.exd4 Be7 11. Re1 a6'),
			moves => {
			},
		},
		'r1bq1rk1/pp3ppp/2n1pn2/2pp4/2PP4/P1bBPN2/1P3PPP/R1BQ1RK1 w -' => {
			eco => 'E58',
			# TRANSLATORS: E58: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 Bxc3
			variation => N__('Nimzo-Indian: Main Line, 8...Bxc3'),
			moves => {
				'b2c3' => 1,
			},
		},
		'r1bq1rk1/pp3ppp/2n1pn2/2pp4/2PP4/P1PBPN2/5PPP/R1BQ1RK1 b -' => {
			eco => 'E58',
			# TRANSLATORS: E58: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 Bxc3 9. bxc3
			variation => N__('Nimzo-Indian: Main Line, 8...Bxc3'),
			moves => {
				'b7b6' => 1,
				'd5c4' => 1,
				'd8c7' => 1,
			},
		},
		'r1bq1rk1/p4ppp/1pn1pn2/2pp4/2PP4/P1PBPN2/5PPP/R1BQ1RK1 w -' => {
			eco => 'E58',
			# TRANSLATORS: E58: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 Bxc3 9. bxc3 b6
			variation => N__('Nimzo-Indian: Main Line, 9.bxc3 b6'),
			moves => {
			},
		},
		'r1b2rk1/ppq2ppp/2n1pn2/2pp4/2PP4/P1PBPN2/5PPP/R1BQ1RK1 w -' => {
			eco => 'E58',
			# TRANSLATORS: E58: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 Bxc3 9. bxc3 Qc7
			variation => N__('Nimzo-Indian: Main Line, 9.bxc3 Qc7'),
			moves => {
				'c1b2' => 1,
				'c4d5' => 1,
				'd1c2' => 1,
				'h2h3' => 1,
			},
		},
		'r1b2rk1/ppq2ppp/2n1pn2/2pp4/2PP4/P1PBPN2/1B3PPP/R2Q1RK1 b -' => {
			eco => 'E58',
			# TRANSLATORS: E58: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 Bxc3 9. bxc3 Qc7 10. Bb2
			variation => N__('Nimzo-Indian: Main Line, 9.bxc3 Qc7 10. Bb2'),
			moves => {
			},
		},
		'r1b2rk1/ppq2ppp/2n1pn2/2pP4/3P4/P1PBPN2/5PPP/R1BQ1RK1 b -' => {
			eco => 'E58',
			# TRANSLATORS: E58: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 Bxc3 9. bxc3 Qc7 10. cxd5
			variation => N__('Nimzo-Indian: Main Line, 9.bxc3 Qc7 10.cxd5'),
			moves => {
				'e6d5' => 1,
			},
		},
		'r1b2rk1/ppq2ppp/2n2n2/2pp4/3P4/P1PBPN2/5PPP/R1BQ1RK1 w -' => {
			eco => 'E58',
			# TRANSLATORS: E58: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 Bxc3 9. bxc3 Qc7 10. cxd5 exd5
			variation => N__('Nimzo-Indian: Main Line, 9.bxc3 Qc7 10.cxd5'),
			moves => {
				'a3a4' => 1,
				'f3h4' => 1,
			},
		},
		'r1b2rk1/ppq2ppp/2n2n2/2pp4/P2P4/2PBPN2/5PPP/R1BQ1RK1 b -' => {
			eco => 'E58',
			# TRANSLATORS: E58: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 Bxc3 9. bxc3 Qc7 10. cxd5 exd5 11. a4
			variation => N__('Nimzo-Indian: Main Line, 9.bxc3 Qc7 10.cxd5 exd5 11. a4'),
			moves => {
				'f8e8' => 1,
			},
		},
		'r1b1r1k1/ppq2ppp/2n2n2/2pp4/P2P4/2PBPN2/5PPP/R1BQ1RK1 w -' => {
			eco => 'E58',
			# TRANSLATORS: E58: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 Bxc3 9. bxc3 Qc7 10. cxd5 exd5 11. a4 Re8
			variation => N__('Nimzo-Indian: Main Line, 9.bxc3 Qc7 10.cxd5 exd5 11. a4 Re8'),
			moves => {
			},
		},
		'r1b2rk1/ppq2ppp/2n2n2/2pp4/3P3N/P1PBP3/5PPP/R1BQ1RK1 b -' => {
			eco => 'E58',
			# TRANSLATORS: E58: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 Bxc3 9. bxc3 Qc7 10. cxd5 exd5 11. Nh4
			variation => N__('Nimzo-Indian: Main Line, 9.bxc3 Qc7 10.cxd5 exd5 11. Nh4'),
			moves => {
			},
		},
		'r1b2rk1/ppq2ppp/2n1pn2/2pp4/2PP4/P1PBPN2/2Q2PPP/R1B2RK1 b -' => {
			eco => 'E58',
			# TRANSLATORS: E58: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 Bxc3 9. bxc3 Qc7 10. Qc2
			variation => N__('Nimzo-Indian: Main Line, 9.bxc3 Qc7 10. Qc2'),
			moves => {
			},
		},
		'r1b2rk1/ppq2ppp/2n1pn2/2pp4/2PP4/P1PBPN1P/5PP1/R1BQ1RK1 b -' => {
			eco => 'E58',
			# TRANSLATORS: E58: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 Bxc3 9. bxc3 Qc7 10. h3
			variation => N__('Nimzo-Indian: Main Line, 9.bxc3 Qc7 10. h3'),
			moves => {
			},
		},
		'r1bq1rk1/pp3ppp/2n1pn2/2p5/2pP4/P1PBPN2/5PPP/R1BQ1RK1 w -' => {
			eco => 'E59',
			# TRANSLATORS: E59: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 Bxc3 9. bxc3 dxc4
			variation => N__('Nimzo-Indian: Main Line, 9.bxc3 dxc4'),
			moves => {
				'd3c4' => 1,
			},
		},
		'r1bq1rk1/pp3ppp/2n1pn2/2p5/2BP4/P1P1PN2/5PPP/R1BQ1RK1 b -' => {
			eco => 'E59',
			# TRANSLATORS: E59: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 Bxc3 9. bxc3 dxc4 10. Bxc4
			variation => N__('Nimzo-Indian: Main Line, 9.bxc3 dxc4 10.Bxc4'),
			moves => {
				'd8c7' => 1,
			},
		},
		'r1b2rk1/ppq2ppp/2n1pn2/2p5/2BP4/P1P1PN2/5PPP/R1BQ1RK1 w -' => {
			eco => 'E59',
			# TRANSLATORS: E59: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 Bxc3 9. bxc3 dxc4 10. Bxc4 Qc7
			variation => N__('Nimzo-Indian: Main Line, 9.bxc3 dxc4 10.Bxc4 Qc7'),
			moves => {
				'a3a4' => 1,
				'c1b2' => 1,
				'c4a2' => 1,
				'c4b5' => 1,
				'c4d3' => 1,
				'c4e2' => 1,
				'd1c2' => 1,
				'd1e2' => 1,
			},
		},
		'r1b2rk1/ppq2ppp/2n1pn2/2p5/P1BP4/2P1PN2/5PPP/R1BQ1RK1 b -' => {
			eco => 'E59',
			# TRANSLATORS: E59: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 Bxc3 9. bxc3 dxc4 10. Bxc4 Qc7 11. a4
			variation => N__('Nimzo-Indian: Main Line, 9.bxc3 dxc4 10.Bxc4 Qc7 11. a4'),
			moves => {
			},
		},
		'r1b2rk1/ppq2ppp/2n1pn2/2p5/2BP4/P1P1PN2/1B3PPP/R2Q1RK1 b -' => {
			eco => 'E59',
			# TRANSLATORS: E59: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 Bxc3 9. bxc3 dxc4 10. Bxc4 Qc7 11. Bb2
			variation => N__('Nimzo-Indian: Main Line, 9.bxc3 dxc4 10.Bxc4 Qc7 11. Bb2'),
			moves => {
			},
		},
		'r1b2rk1/ppq2ppp/2n1pn2/2p5/3P4/P1P1PN2/B4PPP/R1BQ1RK1 b -' => {
			eco => 'E59',
			# TRANSLATORS: E59: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 Bxc3 9. bxc3 dxc4 10. Bxc4 Qc7 11. Ba2
			variation => N__('Nimzo-Indian: Main Line, 9.bxc3 dxc4 10.Bxc4 Qc7 11. Ba2'),
			moves => {
				'e6e5' => 1,
			},
		},
		'r1b2rk1/ppq2ppp/2n2n2/2p1p3/3P4/P1P1PN2/B4PPP/R1BQ1RK1 w -' => {
			eco => 'E59',
			# TRANSLATORS: E59: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 Bxc3 9. bxc3 dxc4 10. Bxc4 Qc7 11. Ba2 e5
			variation => N__('Nimzo-Indian: Main Line, 9.bxc3 dxc4 10.Bxc4 Qc7 11. Ba2 e5'),
			moves => {
			},
		},
		'r1b2rk1/ppq2ppp/2n1pn2/1Bp5/3P4/P1P1PN2/5PPP/R1BQ1RK1 b -' => {
			eco => 'E59',
			# TRANSLATORS: E59: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 Bxc3 9. bxc3 dxc4 10. Bxc4 Qc7 11. Bb5
			variation => N__('Nimzo-Indian: Main Line, 9.bxc3 dxc4 10.Bxc4 Qc7 11. Bb5'),
			moves => {
			},
		},
		'r1b2rk1/ppq2ppp/2n1pn2/2p5/3P4/P1PBPN2/5PPP/R1BQ1RK1 b -' => {
			eco => 'E59',
			# TRANSLATORS: E59: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 Bxc3 9. bxc3 dxc4 10. Bxc4 Qc7 11. Bd3
			variation => N__('Nimzo-Indian: Main Line, 9.bxc3 dxc4 10.Bxc4 Qc7 11. Bd3'),
			moves => {
				'e6e5' => 1,
			},
		},
		'r1b2rk1/ppq2ppp/2n2n2/2p1p3/3P4/P1PBPN2/5PPP/R1BQ1RK1 w -' => {
			eco => 'E59',
			# TRANSLATORS: E59: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 Bxc3 9. bxc3 dxc4 10. Bxc4 Qc7 11. Bd3 e5
			variation => N__('Nimzo-Indian: Main Line, 9.bxc3 dxc4 10.Bxc4 Qc7 11. Bd3'),
			moves => {
				'd1c2' => 1,
			},
		},
		'r1b2rk1/ppq2ppp/2n2n2/2p1p3/3P4/P1PBPN2/2Q2PPP/R1B2RK1 b -' => {
			eco => 'E59',
			# TRANSLATORS: E59: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 Bxc3 9. bxc3 dxc4 10. Bxc4 Qc7 11. Bd3 e5 12. Qc2
			variation => N__('Nimzo-Indian: Main Line, 9.bxc3 dxc4 10.Bxc4 Qc7 11. Bd3 e5 12. Qc2'),
			moves => {
				'f8e8' => 1,
			},
		},
		'r1b1r1k1/ppq2ppp/2n2n2/2p1p3/3P4/P1PBPN2/2Q2PPP/R1B2RK1 w -' => {
			eco => 'E59',
			# TRANSLATORS: E59: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 Bxc3 9. bxc3 dxc4 10. Bxc4 Qc7 11. Bd3 e5 12. Qc2 Re8
			variation => N__('Nimzo-Indian: Main Line, 9.bxc3 dxc4 10.Bxc4 Qc7 11. Bd3 e5 12. Qc2 Re8'),
			moves => {
				'd4e5' => 1,
			},
		},
		'r1b1r1k1/ppq2ppp/2n2n2/2p1P3/8/P1PBPN2/2Q2PPP/R1B2RK1 b -' => {
			eco => 'E59',
			# TRANSLATORS: E59: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 Bxc3 9. bxc3 dxc4 10. Bxc4 Qc7 11. Bd3 e5 12. Qc2 Re8 13. dxe5
			variation => N__('Nimzo-Indian: Main Line, 9.bxc3 dxc4 10.Bxc4 Qc7 11. Bd3 e5 12. Qc2 Re8 13.de5'),
			moves => {
			},
		},
		'r1b2rk1/ppq2ppp/2n1pn2/2p5/3P4/P1P1PN2/4BPPP/R1BQ1RK1 b -' => {
			eco => 'E59',
			# TRANSLATORS: E59: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 Bxc3 9. bxc3 dxc4 10. Bxc4 Qc7 11. Be2
			variation => N__('Nimzo-Indian: Main Line, 9.bxc3 dxc4 10.Bxc4 Qc7 11. Be2'),
			moves => {
			},
		},
		'r1b2rk1/ppq2ppp/2n1pn2/2p5/2BP4/P1P1PN2/2Q2PPP/R1B2RK1 b -' => {
			eco => 'E59',
			# TRANSLATORS: E59: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 Bxc3 9. bxc3 dxc4 10. Bxc4 Qc7 11. Qc2
			variation => N__('Nimzo-Indian: Main Line, 9.bxc3 dxc4 10.Bxc4 Qc7 11. Qc2'),
			moves => {
			},
		},
		'r1b2rk1/ppq2ppp/2n1pn2/2p5/2BP4/P1P1PN2/4QPPP/R1B2RK1 b -' => {
			eco => 'E59',
			# TRANSLATORS: E59: 1. d4 Nf6 2. c4 e6 3. Nc3 Bb4 4. e3 O-O 5. Nf3 d5 6. Bd3 c5 7. O-O Nc6 8. a3 Bxc3 9. bxc3 dxc4 10. Bxc4 Qc7 11. Qe2
			variation => N__('Nimzo-Indian: Main Line, 9.bxc3 dxc4 10.Bxc4 Qc7 11. Qe2'),
			moves => {
			},
		},
		'rnbqkb1r/pppppp1p/5np1/8/2PP4/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'E60a',
			# TRANSLATORS: E60a: 1. d4 Nf6 2. c4 g6
			variation => N__('King\'s Indian'),
			moves => {
				'b1c3' => 1,
				'c1g5' => 1,
				'd1c2' => 1,
				'd4d5' => 1,
				'f2f3' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqkb1r/pppppp1p/5np1/8/2PP4/8/PPQ1PPPP/RNB1KBNR b KQkq' => {
			eco => 'E60a',
			# TRANSLATORS: E60a: 1. d4 Nf6 2. c4 g6 3. Qc2
			variation => N__('King\'s Indian: Mengarini Attack'),
			moves => {
			},
		},
		'rnbqkb1r/pppppp1p/5np1/6B1/2PP4/8/PP2PPPP/RN1QKBNR b KQkq' => {
			eco => 'E60b',
			# TRANSLATORS: E60b: 1. d4 Nf6 2. c4 g6 3. Bg5
			variation => N__('King\'s Indian: 3. Bg5'),
			moves => {
			},
		},
		'rnbqkb1r/pppppp1p/5np1/3P4/2P5/8/PP2PPPP/RNBQKBNR b KQkq' => {
			eco => 'E60c',
			# TRANSLATORS: E60c: 1. d4 Nf6 2. c4 g6 3. d5
			variation => N__('King\'s Indian: 3. d5'),
			moves => {
				'b7b5' => 1,
			},
		},
		'rnbqkb1r/p1pppp1p/5np1/1p1P4/2P5/8/PP2PPPP/RNBQKBNR w KQkq' => {
			eco => 'E60c',
			# TRANSLATORS: E60c: 1. d4 Nf6 2. c4 g6 3. d5 b5
			variation => N__('King\'s Indian: 3. d5, Danube/Adorjan Gambit'),
			moves => {
			},
		},
		'rnbqkb1r/pppppp1p/5np1/8/2PP4/5P2/PP2P1PP/RNBQKBNR b KQkq' => {
			eco => 'E60d',
			# TRANSLATORS: E60d: 1. d4 Nf6 2. c4 g6 3. f3
			variation => N__('King\'s Indian: 3. f3'),
			moves => {
				'd7d5' => 1,
			},
		},
		'rnbqkb1r/pppppp1p/5np1/8/2PP4/6P1/PP2PP1P/RNBQKBNR b KQkq' => {
			eco => 'E60e',
			# TRANSLATORS: E60e: 1. d4 Nf6 2. c4 g6 3. g3
			variation => N__('King\'s Indian: 3. g3'),
			moves => {
				'd7d5' => 1,
				'f8g7' => 1,
			},
		},
		'rnbqk2r/ppppppbp/5np1/8/2PP4/6P1/PP2PP1P/RNBQKBNR w KQkq' => {
			eco => 'E60e',
			# TRANSLATORS: E60e: 1. d4 Nf6 2. c4 g6 3. g3 Bg7
			variation => N__('King\'s Indian: 3. g3'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqk2r/ppppppbp/5np1/8/2PP4/6P1/PP2PPBP/RNBQK1NR b KQkq' => {
			eco => 'E60e',
			# TRANSLATORS: E60e: 1. d4 Nf6 2. c4 g6 3. g3 Bg7 4. Bg2
			variation => N__('King\'s Indian: 3. g3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppppppbp/5np1/8/2PP4/6P1/PP2PPBP/RNBQK1NR w KQ' => {
			eco => 'E60e',
			# TRANSLATORS: E60e: 1. d4 Nf6 2. c4 g6 3. g3 Bg7 4. Bg2 O-O
			variation => N__('King\'s Indian: 3. g3'),
			moves => {
			},
		},
		'rnbqkb1r/pppppp1p/5np1/8/2PP4/5N2/PP2PPPP/RNBQKB1R b KQkq' => {
			eco => 'E60f',
			# TRANSLATORS: E60f: 1. d4 Nf6 2. c4 g6 3. Nf3
			variation => N__('King\'s Indian: 3. Nf3'),
			moves => {
				'd7d5' => 1,
				'd7d6' => 1,
				'f8g7' => 1,
			},
		},
		'rnbqkb1r/ppp1pp1p/3p1np1/8/2PP4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'E60f',
			# TRANSLATORS: E60f: 1. d4 Nf6 2. c4 g6 3. Nf3 d6
			variation => N__('King\'s Indian: 3. Nf3 d6'),
			moves => {
			},
		},
		'rnbqk2r/ppppppbp/5np1/8/2PP4/5N2/PP2PPPP/RNBQKB1R w KQkq' => {
			eco => 'E60g',
			# TRANSLATORS: E60g: 1. d4 Nf6 2. c4 g6 3. Nf3 Bg7
			variation => N__('King\'s Indian: 3. Nf3 Bg7'),
			moves => {
				'b2b3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqk2r/ppppppbp/5np1/8/2PP4/1P3N2/P3PPPP/RNBQKB1R b KQkq' => {
			eco => 'E60h',
			# TRANSLATORS: E60h: 1. d4 Nf6 2. c4 g6 3. Nf3 Bg7 4. b3
			variation => N__('King\'s Indian: b3 System'),
			moves => {
				'd7d6' => 1,
				'e8g8' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/2PP4/1P3N2/P3PPPP/RNBQKB1R w KQkq' => {
			eco => 'E60h',
			# TRANSLATORS: E60h: 1. d4 Nf6 2. c4 g6 3. Nf3 Bg7 4. b3 d6
			variation => N__('King\'s Indian: b3 System'),
			moves => {
				'c1b2' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/2PP4/1P3N2/PB2PPPP/RN1QKB1R b KQkq' => {
			eco => 'E60h',
			# TRANSLATORS: E60h: 1. d4 Nf6 2. c4 g6 3. Nf3 Bg7 4. b3 d6 5. Bb2
			variation => N__('King\'s Indian: b3 System'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PP4/1P3N2/PB2PPPP/RN1QKB1R w KQ' => {
			eco => 'E60h',
			# TRANSLATORS: E60h: 1. d4 Nf6 2. c4 g6 3. Nf3 Bg7 4. b3 d6 5. Bb2 O-O
			variation => N__('King\'s Indian: b3 System'),
			moves => {
				'e2e3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PP4/1P2PN2/PB3PPP/RN1QKB1R b KQ' => {
			eco => 'E60h',
			# TRANSLATORS: E60h: 1. d4 Nf6 2. c4 g6 3. Nf3 Bg7 4. b3 d6 5. Bb2 O-O 6. e3
			variation => N__('King\'s Indian: b3 System'),
			moves => {
			},
		},
		'rnbq1rk1/ppppppbp/5np1/8/2PP4/1P3N2/P3PPPP/RNBQKB1R w KQ' => {
			eco => 'E60h',
			# TRANSLATORS: E60h: 1. d4 Nf6 2. c4 g6 3. Nf3 Bg7 4. b3 O-O
			variation => N__('King\'s Indian: b3 System'),
			moves => {
				'c1b2' => 1,
			},
		},
		'rnbq1rk1/ppppppbp/5np1/8/2PP4/1P3N2/PB2PPPP/RN1QKB1R b KQ' => {
			eco => 'E60h',
			# TRANSLATORS: E60h: 1. d4 Nf6 2. c4 g6 3. Nf3 Bg7 4. b3 O-O 5. Bb2
			variation => N__('King\'s Indian: b3 System'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PP4/1P3NP1/PB2PP1P/RN1QKB1R b KQ' => {
			eco => 'E60i',
			# TRANSLATORS: E60i: 1. d4 Nf6 2. c4 g6 3. Nf3 Bg7 4. b3 d6 5. Bb2 O-O 6. g3
			variation => N__('King\'s Indian: b3+g3 System'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2p5/2PP4/1P3NP1/PB2PP1P/RN1QKB1R w KQ' => {
			eco => 'E60i',
			# TRANSLATORS: E60i: 1. d4 Nf6 2. c4 g6 3. Nf3 Bg7 4. b3 d6 5. Bb2 O-O 6. g3 c5
			variation => N__('King\'s Indian: b3+g3 System'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2p5/2PP4/1P3NP1/PB2PPBP/RN1QK2R b KQ' => {
			eco => 'E60i',
			# TRANSLATORS: E60i: 1. d4 Nf6 2. c4 g6 3. Nf3 Bg7 4. b3 d6 5. Bb2 O-O 6. g3 c5 7. Bg2
			variation => N__('King\'s Indian: b3+g3 System'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/2p5/2PP4/1P3NP1/PB2PPBP/RN1QK2R w KQ' => {
			eco => 'E60i',
			# TRANSLATORS: E60i: 1. d4 Nf6 2. c4 g6 3. Nf3 Bg7 4. b3 d6 5. Bb2 O-O 6. g3 c5 7. Bg2 Nc6
			variation => N__('King\'s Indian: b3+g3 System'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/2p5/2PP4/1P3NP1/PB2PPBP/RN1Q1RK1 b -' => {
			eco => 'E60i',
			# TRANSLATORS: E60i: 1. d4 Nf6 2. c4 g6 3. Nf3 Bg7 4. b3 d6 5. Bb2 O-O 6. g3 c5 7. Bg2 Nc6 8. O-O
			variation => N__('King\'s Indian: b3+g3 System'),
			moves => {
			},
		},
		'rnbqk2r/ppppppbp/5np1/8/2PP4/5NP1/PP2PP1P/RNBQKB1R b KQkq' => {
			eco => 'E60j',
			# TRANSLATORS: E60j: 1. d4 Nf6 2. c4 g6 3. Nf3 Bg7 4. g3
			variation => N__('King\'s Indian: Fianchetto'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppppppbp/5np1/8/2PP4/5NP1/PP2PP1P/RNBQKB1R w KQ' => {
			eco => 'E60j',
			# TRANSLATORS: E60j: 1. d4 Nf6 2. c4 g6 3. Nf3 Bg7 4. g3 O-O
			variation => N__('King\'s Indian: Fianchetto'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbq1rk1/ppppppbp/5np1/8/2PP4/5NP1/PP2PPBP/RNBQK2R b KQ' => {
			eco => 'E60k',
			# TRANSLATORS: E60k: 1. d4 Nf6 2. c4 g6 3. Nf3 Bg7 4. g3 O-O 5. Bg2
			variation => N__('King\'s Indian: Fianchetto without Nc3'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PP4/5NP1/PP2PPBP/RNBQK2R w KQ' => {
			eco => 'E60k',
			# TRANSLATORS: E60k: 1. d4 Nf6 2. c4 g6 3. Nf3 Bg7 4. g3 O-O 5. Bg2 d6
			variation => N__('King\'s Indian: Fianchetto without Nc3'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PP4/5NP1/PP2PPBP/RNBQ1RK1 b -' => {
			eco => 'E60k',
			# TRANSLATORS: E60k: 1. d4 Nf6 2. c4 g6 3. Nf3 Bg7 4. g3 O-O 5. Bg2 d6 6. O-O
			variation => N__('King\'s Indian: Fianchetto without Nc3'),
			moves => {
				'b8c6' => 1,
				'b8d7' => 1,
				'c7c5' => 1,
				'c7c6' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2p5/2PP4/5NP1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'E60l',
			# TRANSLATORS: E60l: 1. d4 Nf6 2. c4 g6 3. Nf3 Bg7 4. g3 O-O 5. Bg2 d6 6. O-O c5
			variation => N__('King\'s Indian: Fianchetto, Yugoslav without Nc3'),
			moves => {
				'd4c5' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2P5/2P5/5NP1/PP2PPBP/RNBQ1RK1 b -' => {
			eco => 'E60l',
			# TRANSLATORS: E60l: 1. d4 Nf6 2. c4 g6 3. Nf3 Bg7 4. g3 O-O 5. Bg2 d6 6. O-O c5 7. dxc5
			variation => N__('King\'s Indian: Fianchetto, Yugoslav without Nc3, 7.dxc5'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/2pp1np1/8/2PP4/5NP1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'E60m',
			# TRANSLATORS: E60m: 1. d4 Nf6 2. c4 g6 3. Nf3 Bg7 4. g3 O-O 5. Bg2 d6 6. O-O c6
			variation => N__('King\'s Indian: Fianchetto without Nc3, 6... c6'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1ppbp/2np1np1/8/2PP4/5NP1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'E60n',
			# TRANSLATORS: E60n: 1. d4 Nf6 2. c4 g6 3. Nf3 Bg7 4. g3 O-O 5. Bg2 d6 6. O-O Nc6
			variation => N__('King\'s Indian: Fianchetto without Nc3, 6... Nc6'),
			moves => {
			},
		},
		'r1bq1rk1/pppnppbp/3p1np1/8/2PP4/5NP1/PP2PPBP/RNBQ1RK1 w -' => {
			eco => 'E60o',
			# TRANSLATORS: E60o: 1. d4 Nf6 2. c4 g6 3. Nf3 Bg7 4. g3 O-O 5. Bg2 d6 6. O-O Nbd7
			variation => N__('King\'s Indian: Fianchetto without Nc3, 6...Nbd7'),
			moves => {
				'd1c2' => 1,
			},
		},
		'r1bq1rk1/pppnppbp/3p1np1/8/2PP4/5NP1/PPQ1PPBP/RNB2RK1 b -' => {
			eco => 'E60p',
			# TRANSLATORS: E60p: 1. d4 Nf6 2. c4 g6 3. Nf3 Bg7 4. g3 O-O 5. Bg2 d6 6. O-O Nbd7 7. Qc2
			variation => N__('King\'s Indian: Fianchetto without Nc3, 6...Nbd7 7. Qc2'),
			moves => {
				'e7e5' => 1,
			},
		},
		'r1bq1rk1/pppn1pbp/3p1np1/4p3/2PP4/5NP1/PPQ1PPBP/RNB2RK1 w -' => {
			eco => 'E60q',
			# TRANSLATORS: E60q: 1. d4 Nf6 2. c4 g6 3. Nf3 Bg7 4. g3 O-O 5. Bg2 d6 6. O-O Nbd7 7. Qc2 e5
			variation => N__('King\'s Indian: Fianchetto without Nc3, 6...Nbd7 7. Qc2 e5'),
			moves => {
				'f1d1' => 1,
			},
		},
		'r1bq1rk1/pppn1pbp/3p1np1/4p3/2PP4/5NP1/PPQ1PPBP/RNBR2K1 b -' => {
			eco => 'E60q',
			# TRANSLATORS: E60q: 1. d4 Nf6 2. c4 g6 3. Nf3 Bg7 4. g3 O-O 5. Bg2 d6 6. O-O Nbd7 7. Qc2 e5 8. Rd1
			variation => N__('King\'s Indian: Fianchetto without Nc3, 6...Nbd7 7. Qc2 e5'),
			moves => {
				'f8e8' => 1,
			},
		},
		'r1bqr1k1/pppn1pbp/3p1np1/4p3/2PP4/5NP1/PPQ1PPBP/RNBR2K1 w -' => {
			eco => 'E60r',
			# TRANSLATORS: E60r: 1. d4 Nf6 2. c4 g6 3. Nf3 Bg7 4. g3 O-O 5. Bg2 d6 6. O-O Nbd7 7. Qc2 e5 8. Rd1 Re8
			variation => N__('King\'s Indian: Fianchetto without Nc3, 6...Nbd7 7. Qc2 e5 8. Rd1 Re8'),
			moves => {
			},
		},
		'rnbqkb1r/pppppp1p/5np1/8/2PP4/2N5/PP2PPPP/R1BQKBNR b KQkq' => {
			eco => 'E61a',
			# TRANSLATORS: E61a: 1. d4 Nf6 2. c4 g6 3. Nc3
			variation => N__('King\'s Indian: 3. Nc3'),
			moves => {
				'c7c5' => 1,
				'c7c6' => 1,
				'd7d5' => 1,
				'd7d6' => 1,
				'f8g7' => 1,
			},
		},
		'rnbqkb1r/pp1ppp1p/5np1/2p5/2PP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'E61a',
			# TRANSLATORS: E61a: 1. d4 Nf6 2. c4 g6 3. Nc3 c5
			variation => N__('King\'s Indian: 3. Nc3 c5'),
			moves => {
			},
		},
		'rnbqkb1r/pp1ppp1p/2p2np1/8/2PP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'E61a',
			# TRANSLATORS: E61a: 1. d4 Nf6 2. c4 g6 3. Nc3 c6
			variation => N__('King\'s Indian: 3. Nc3 c6'),
			moves => {
			},
		},
		'rnbqkb1r/ppp1pp1p/3p1np1/8/2PP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'E61a',
			# TRANSLATORS: E61a: 1. d4 Nf6 2. c4 g6 3. Nc3 d6
			variation => N__('King\'s Indian: 3. Nc3 d6'),
			moves => {
			},
		},
		'rnbqk2r/ppppppbp/5np1/8/2PP4/2N5/PP2PPPP/R1BQKBNR w KQkq' => {
			eco => 'E61b',
			# TRANSLATORS: E61b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7
			variation => N__('King\'s Indian: 3. Nc3 Bg7'),
			moves => {
				'c1f4' => 1,
				'c1g5' => 1,
				'e2e4' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqk2r/ppppppbp/5np1/8/2PP1B2/2N5/PP2PPPP/R2QKBNR b KQkq' => {
			eco => 'E61b',
			# TRANSLATORS: E61b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Bf4
			variation => N__('King\'s Indian: 4. Bf4'),
			moves => {
			},
		},
		'rnbqk2r/ppppppbp/5np1/6B1/2PP4/2N5/PP2PPPP/R2QKBNR b KQkq' => {
			eco => 'E61c',
			# TRANSLATORS: E61c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Bg5
			variation => N__('King\'s Indian: 4. Bg5'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppppppbp/5np1/6B1/2PP4/2N5/PP2PPPP/R2QKBNR w KQ' => {
			eco => 'E61d',
			# TRANSLATORS: E61d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Bg5 O-O
			variation => N__('King\'s Indian: 4. Bg5 O-O'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbq1rk1/ppppppbp/5np1/6B1/2PP4/2N1P3/PP3PPP/R2QKBNR b KQ' => {
			eco => 'E61d',
			# TRANSLATORS: E61d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Bg5 O-O 5. e3
			variation => N__('King\'s Indian: 4. Bg5 O-O'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/6B1/2PP4/2N1P3/PP3PPP/R2QKBNR w KQ' => {
			eco => 'E61e',
			# TRANSLATORS: E61e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Bg5 O-O 5. e3 d6
			variation => N__('King\'s Indian: 4. Bg5 O-O 5. e3 d6'),
			moves => {
			},
		},
		'rnbqk2r/ppppppbp/5np1/8/2PP4/2N3P1/PP2PP1P/R1BQKBNR b KQkq' => {
			eco => 'E61f',
			# TRANSLATORS: E61f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. g3
			variation => N__('King\'s Indian: 4. g3'),
			moves => {
				'd7d6' => 1,
				'e8g8' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/2PP4/2N3P1/PP2PP1P/R1BQKBNR w KQkq' => {
			eco => 'E61f',
			# TRANSLATORS: E61f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. g3 d6
			variation => N__('King\'s Indian: 4. g3 d6'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/2PP4/2N3P1/PP2PPBP/R1BQK1NR b KQkq' => {
			eco => 'E61f',
			# TRANSLATORS: E61f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. g3 d6 5. Bg2
			variation => N__('King\'s Indian: 4. g3 d6 5. Bg2'),
			moves => {
			},
		},
		'rnbq1rk1/ppppppbp/5np1/8/2PP4/2N3P1/PP2PP1P/R1BQKBNR w KQ' => {
			eco => 'E61g',
			# TRANSLATORS: E61g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. g3 O-O
			variation => N__('King\'s Indian: 4. g3 O-O'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbq1rk1/ppppppbp/5np1/8/2PP4/2N3P1/PP2PPBP/R1BQK1NR b KQ' => {
			eco => 'E61g',
			# TRANSLATORS: E61g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. g3 O-O 5. Bg2
			variation => N__('King\'s Indian: 4. g3 O-O 5. Bg2'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PP4/2N3P1/PP2PPBP/R1BQK1NR w KQ' => {
			eco => 'E61g',
			# TRANSLATORS: E61g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. g3 O-O 5. Bg2 d6
			variation => N__('King\'s Indian: 4. g3 O-O 5. Bg2 d6'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PP4/2N1P1P1/PP3PBP/R1BQK1NR b KQ' => {
			eco => 'E61h',
			# TRANSLATORS: E61h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. g3 O-O 5. Bg2 d6 6. e3
			variation => N__('King\'s Indian: Fianchetto, Flohr Variation'),
			moves => {
			},
		},
		'rnbqk2r/ppppppbp/5np1/8/2PP4/2N2N2/PP2PPPP/R1BQKB1R b KQkq' => {
			eco => 'E61i',
			# TRANSLATORS: E61i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3
			variation => N__('King\'s Indian: 4. Nf3'),
			moves => {
				'd7d6' => 1,
				'e8g8' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/2PP4/2N2N2/PP2PPPP/R1BQKB1R w KQkq' => {
			eco => 'E61i',
			# TRANSLATORS: E61i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6
			variation => N__('King\'s Indian: 4. Nf3 d6'),
			moves => {
				'c1g5' => 1,
				'e2e3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/2PP4/2N1PN2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'E61i',
			# TRANSLATORS: E61i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. e3
			variation => N__('King\'s Indian: 4. Nf3 d6 5. e3'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/6B1/2PP4/2N2N2/PP2PPPP/R2QKB1R b KQkq' => {
			eco => 'E61j',
			# TRANSLATORS: E61j: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. Bg5
			variation => N__('King\'s Indian: Smyslov System'),
			moves => {
				'h7h6' => 1,
			},
		},
		'rnbqk2r/ppp1ppb1/3p1npp/6B1/2PP4/2N2N2/PP2PPPP/R2QKB1R w KQkq' => {
			eco => 'E61j',
			# TRANSLATORS: E61j: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. Bg5 h6
			variation => N__('King\'s Indian: Smyslov System'),
			moves => {
			},
		},
		'rnbq1rk1/ppppppbp/5np1/8/2PP4/2N2N2/PP2PPPP/R1BQKB1R w KQ' => {
			eco => 'E61k',
			# TRANSLATORS: E61k: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 O-O
			variation => N__('King\'s Indian: 4. Nf3 O-O'),
			moves => {
				'c1f4' => 1,
				'c1g5' => 1,
				'e2e3' => 1,
				'g2g3' => 1,
			},
		},
		'rnbq1rk1/ppppppbp/5np1/8/2PP4/2N2NP1/PP2PP1P/R1BQKB1R b KQ' => {
			eco => 'E61l',
			# TRANSLATORS: E61l: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 O-O 5. g3
			variation => N__('King\'s Indian: 4. Nf3 O-O 5. g3'),
			moves => {
			},
		},
		'rnbq1rk1/ppppppbp/5np1/8/2PP4/2N1PN2/PP3PPP/R1BQKB1R b KQ' => {
			eco => 'E61m',
			# TRANSLATORS: E61m: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 O-O 5. e3
			variation => N__('King\'s Indian: 4. Nf3 O-O 5. e3'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PP4/2N1PN2/PP3PPP/R1BQKB1R w KQ' => {
			eco => 'E61m',
			# TRANSLATORS: E61m: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 O-O 5. e3 d6
			variation => N__('King\'s Indian: 4. Nf3 O-O 5. e3 d6'),
			moves => {
				'f1e2' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PP4/2N1PN2/PP2BPPP/R1BQK2R b KQ' => {
			eco => 'E61n',
			# TRANSLATORS: E61n: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 O-O 5. e3 d6 6. Be2
			variation => N__('King\'s Indian: 4. Nf3 O-O 5. e3 d6 6. Be2'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2p5/2PP4/2N1PN2/PP2BPPP/R1BQK2R w KQ' => {
			eco => 'E61o',
			# TRANSLATORS: E61o: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 O-O 5. e3 d6 6. Be2 c5
			variation => N__('King\'s Indian: 4. Nf3 O-O 5. e3 d6 6. Be2 c5'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2p5/2PP4/2N1PN2/PP2BPPP/R1BQ1RK1 b -' => {
			eco => 'E61o',
			# TRANSLATORS: E61o: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 O-O 5. e3 d6 6. Be2 c5 7. O-O
			variation => N__('King\'s Indian: 4. Nf3 O-O 5. e3 d6 6. Be2 c5'),
			moves => {
			},
		},
		'rnbq1rk1/ppppppbp/5np1/8/2PP1B2/2N2N2/PP2PPPP/R2QKB1R b KQ' => {
			eco => 'E61p',
			# TRANSLATORS: E61p: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 O-O 5. Bf4
			variation => N__('King\'s Indian: 4. Nf3 O-O 5. Bf4'),
			moves => {
				'd7d6' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PP1B2/2N2N2/PP2PPPP/R2QKB1R w KQ' => {
			eco => 'E61q',
			# TRANSLATORS: E61q: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 O-O 5. Bf4 d6
			variation => N__('King\'s Indian: 4. Nf3 O-O 5. Bf4 d6'),
			moves => {
				'e2e3' => 1,
				'h2h3' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PP1B2/2N2N1P/PP2PPP1/R2QKB1R b KQ' => {
			eco => 'E61q',
			# TRANSLATORS: E61q: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 O-O 5. Bf4 d6 6. h3
			variation => N__('King\'s Indian: 4. Nf3 d6 5. Bf4 d6 6. h3'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PP1B2/2N1PN2/PP3PPP/R2QKB1R b KQ' => {
			eco => 'E61r',
			# TRANSLATORS: E61r: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 O-O 5. Bf4 d6 6. e3
			variation => N__('King\'s Indian: 4. Nf3 d6 5. Bf4 d6 6. e3'),
			moves => {
			},
		},
		'rnbq1rk1/ppppppbp/5np1/6B1/2PP4/2N2N2/PP2PPPP/R2QKB1R b KQ' => {
			eco => 'E61s',
			# TRANSLATORS: E61s: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 O-O 5. Bg5
			variation => N__('King\'s Indian: Smyslov System'),
			moves => {
				'c7c5' => 1,
				'd7d6' => 1,
			},
		},
		'rnbq1rk1/pp1pppbp/5np1/2p3B1/2PP4/2N2N2/PP2PPPP/R2QKB1R w KQ' => {
			eco => 'E61t',
			# TRANSLATORS: E61t: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 O-O 5. Bg5 c5
			variation => N__('King\'s Indian: Smyslov System, 5... c5'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbq1rk1/pp1pppbp/5np1/2p3B1/2PP4/2N1PN2/PP3PPP/R2QKB1R b KQ' => {
			eco => 'E61t',
			# TRANSLATORS: E61t: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 O-O 5. Bg5 c5 6. e3
			variation => N__('King\'s Indian: Smyslov System, 5... c5 6. e3'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/6B1/2PP4/2N2N2/PP2PPPP/R2QKB1R w KQ' => {
			eco => 'E61u',
			# TRANSLATORS: E61u: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 O-O 5. Bg5 d6
			variation => N__('King\'s Indian: Smyslov System, 5... d6'),
			moves => {
				'e2e3' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/6B1/2PP4/2N1PN2/PP3PPP/R2QKB1R b KQ' => {
			eco => 'E61v',
			# TRANSLATORS: E61v: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 O-O 5. Bg5 d6 6. e3
			variation => N__('King\'s Indian: Smyslov System, 6. e3'),
			moves => {
				'b8d7' => 1,
				'c7c5' => 1,
				'c7c6' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/2pp1np1/6B1/2PP4/2N1PN2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'E61w',
			# TRANSLATORS: E61w: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 O-O 5. Bg5 d6 6. e3 c6
			variation => N__('King\'s Indian: Smyslov System, 6. e3 c6'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2p3B1/2PP4/2N1PN2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'E61x',
			# TRANSLATORS: E61x: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 O-O 5. Bg5 d6 6. e3 c5
			variation => N__('King\'s Indian: Smyslov System, 6. e3 c6'),
			moves => {
			},
		},
		'r1bq1rk1/pppnppbp/3p1np1/6B1/2PP4/2N1PN2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'E61y',
			# TRANSLATORS: E61y: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 O-O 5. Bg5 d6 6. e3 Nbd7
			variation => N__('King\'s Indian: Smyslov System, 5...O-O 6. e3 Nbd7'),
			moves => {
				'f1e2' => 1,
			},
		},
		'r1bq1rk1/pppnppbp/3p1np1/6B1/2PP4/2N1PN2/PP2BPPP/R2QK2R b KQ' => {
			eco => 'E61y',
			# TRANSLATORS: E61y: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 O-O 5. Bg5 d6 6. e3 Nbd7 7. Be2
			variation => N__('King\'s Indian: Smyslov System, 5...O-O 6. e3 Nbd7 7. Be2'),
			moves => {
				'c7c6' => 1,
			},
		},
		'r1bq1rk1/pp1nppbp/2pp1np1/6B1/2PP4/2N1PN2/PP2BPPP/R2QK2R w KQ' => {
			eco => 'E61z',
			# TRANSLATORS: E61z: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 O-O 5. Bg5 d6 6. e3 Nbd7 7. Be2 c6
			variation => N__('King\'s Indian: Smyslov System, 5...O-O 6. e3 Nbd7 7. Be2 c6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bq1rk1/pp1nppbp/2pp1np1/6B1/2PP4/2N1PN2/PP2BPPP/R2Q1RK1 b -' => {
			eco => 'E61z',
			# TRANSLATORS: E61z: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 O-O 5. Bg5 d6 6. e3 Nbd7 7. Be2 c6 8. O-O
			variation => N__('King\'s Indian: Smyslov System, 5...O-O 6. e3 Nbd7 7. Be2 c6 8.O-O'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/2PP4/2N2NP1/PP2PP1P/R1BQKB1R b KQkq' => {
			eco => 'E62a',
			# TRANSLATORS: E62a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3
			variation => N__('King\'s Indian: Fianchetto Variation'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PP4/2N2NP1/PP2PP1P/R1BQKB1R w KQ' => {
			eco => 'E62a',
			# TRANSLATORS: E62a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O
			variation => N__('King\'s Indian: Fianchetto Variation'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PP4/2N2NP1/PP2PPBP/R1BQK2R b KQ' => {
			eco => 'E62b',
			# TRANSLATORS: E62b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2
			variation => N__('King\'s Indian: Fianchetto Variation'),
			moves => {
				'b8c6' => 1,
				'b8d7' => 1,
				'c7c5' => 1,
				'c7c6' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/2pp1np1/8/2PP4/2N2NP1/PP2PPBP/R1BQK2R w KQ' => {
			eco => 'E62c',
			# TRANSLATORS: E62c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c6
			variation => N__('King\'s Indian: Fianchetto, 6... c6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/2pp1np1/8/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'E62d',
			# TRANSLATORS: E62d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c6 7. O-O
			variation => N__('King\'s Indian: Fianchetto, 6... c6 7.O-O'),
			moves => {
				'a7a6' => 1,
				'c8f5' => 1,
				'd8a5' => 1,
			},
		},
		'rnbq1rk1/1p2ppbp/p1pp1np1/8/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'E62e',
			# TRANSLATORS: E62e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c6 7. O-O a6
			variation => N__('King\'s Indian: Fianchetto, 6... c6 7.O-O a6'),
			moves => {
			},
		},
		'rn1q1rk1/pp2ppbp/2pp1np1/5b2/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'E62f',
			# TRANSLATORS: E62f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c6 7. O-O Bf5
			variation => N__('King\'s Indian: Fianchetto, Larsen System'),
			moves => {
				'b2b3' => 1,
			},
		},
		'rn1q1rk1/pp2ppbp/2pp1np1/5b2/2PP4/1PN2NP1/P3PPBP/R1BQ1RK1 b -' => {
			eco => 'E62g',
			# TRANSLATORS: E62g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c6 7. O-O Bf5 8. b3
			variation => N__('King\'s Indian: Fianchetto, Larsen System, 8. b3'),
			moves => {
			},
		},
		'rnb2rk1/pp2ppbp/2pp1np1/q7/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'E62h',
			# TRANSLATORS: E62h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c6 7. O-O Qa5
			variation => N__('King\'s Indian: Fianchetto, Kavalek/Bronstein Variation'),
			moves => {
				'e2e4' => 1,
				'h2h3' => 1,
			},
		},
		'rnb2rk1/pp2ppbp/2pp1np1/q7/2PP4/2N2NPP/PP2PPB1/R1BQ1RK1 b -' => {
			eco => 'E62i',
			# TRANSLATORS: E62i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c6 7. O-O Qa5 8. h3
			variation => N__('King\'s Indian: Fianchetto, Kavalek/Bronstein, 8. h3'),
			moves => {
			},
		},
		'rnb2rk1/pp2ppbp/2pp1np1/q7/2PPP3/2N2NP1/PP3PBP/R1BQ1RK1 b -' => {
			eco => 'E62j',
			# TRANSLATORS: E62j: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c6 7. O-O Qa5 8. e4
			variation => N__('King\'s Indian: Fianchetto, Kavalek/Bronstein, 8. e4'),
			moves => {
				'c8g4' => 1,
			},
		},
		'rn3rk1/pp2ppbp/2pp1np1/q7/2PPP1b1/2N2NP1/PP3PBP/R1BQ1RK1 w -' => {
			eco => 'E62k',
			# TRANSLATORS: E62k: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c6 7. O-O Qa5 8. e4 Bg4
			variation => N__('King\'s Indian: Fianchetto, Kavalek/Bronstein, 8. e4 Bg4'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1ppbp/2np1np1/8/2PP4/2N2NP1/PP2PPBP/R1BQK2R w KQ' => {
			eco => 'E62l',
			# TRANSLATORS: E62l: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nc6
			variation => N__('King\'s Indian: Fianchetto, 6... Nc6'),
			moves => {
				'd4d5' => 1,
				'e1g1' => 1,
			},
		},
		'r1bq1rk1/ppp1ppbp/2np1np1/3P4/2P5/2N2NP1/PP2PPBP/R1BQK2R b KQ' => {
			eco => 'E62m',
			# TRANSLATORS: E62m: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nc6 7. d5
			variation => N__('King\'s Indian: Fianchetto, 6... Nc6 7. d5'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1ppbp/2np1np1/8/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'E62n',
			# TRANSLATORS: E62n: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nc6 7. O-O
			variation => N__('King\'s Indian: Fianchetto, 6... Nc6 7.O-O'),
			moves => {
				'a7a6' => 1,
				'a8b8' => 1,
				'c8f5' => 1,
				'c8g4' => 1,
				'e7e5' => 1,
			},
		},
		'1rbq1rk1/ppp1ppbp/2np1np1/8/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'E62o',
			# TRANSLATORS: E62o: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nc6 7. O-O Rb8
			variation => N__('King\'s Indian: Fianchetto, 6... Nc6 7.O-O Rb8'),
			moves => {
			},
		},
		'r2q1rk1/ppp1ppbp/2np1np1/5b2/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'E62p',
			# TRANSLATORS: E62p: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nc6 7. O-O Bf5
			variation => N__('King\'s Indian: Fianchetto, Spassky Variation'),
			moves => {
				'd4d5' => 1,
			},
		},
		'r2q1rk1/ppp1ppbp/2np1np1/3P1b2/2P5/2N2NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'E62q',
			# TRANSLATORS: E62q: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nc6 7. O-O Bf5 8. d5
			variation => N__('King\'s Indian: Fianchetto, Spassky, 8. d5'),
			moves => {
			},
		},
		'r2q1rk1/ppp1ppbp/2np1np1/8/2PP2b1/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'E62r',
			# TRANSLATORS: E62r: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nc6 7. O-O Bg4
			variation => N__('King\'s Indian: Fianchetto, Simagin Variation'),
			moves => {
				'd4d5' => 1,
			},
		},
		'r2q1rk1/ppp1ppbp/2np1np1/3P4/2P3b1/2N2NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'E62s',
			# TRANSLATORS: E62s: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nc6 7. O-O Bg4 8. d5
			variation => N__('King\'s Indian: Fianchetto, Simagin, 8. d5'),
			moves => {
			},
		},
		'r1bq1rk1/ppp2pbp/2np1np1/4p3/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'E62t',
			# TRANSLATORS: E62t: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nc6 7. O-O e5
			variation => N__('King\'s Indian: Fianchetto, Uhlmann/Szabo Variation'),
			moves => {
				'd4d5' => 1,
			},
		},
		'r1bq1rk1/ppp2pbp/2np1np1/3Pp3/2P5/2N2NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'E62t',
			# TRANSLATORS: E62t: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nc6 7. O-O e5 8. d5
			variation => N__('King\'s Indian: Fianchetto, Uhlmann/Szabo Variation'),
			moves => {
				'c6e7' => 1,
			},
		},
		'r1bq1rk1/ppp1npbp/3p1np1/3Pp3/2P5/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'E62u',
			# TRANSLATORS: E62u: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nc6 7. O-O e5 8. d5 Ne7
			variation => N__('King\'s Indian: Fianchetto, Uhlmann/Szabo Variation'),
			moves => {
				'e2e4' => 1,
			},
		},
		'r1bq1rk1/ppp1npbp/3p1np1/3Pp3/2P1P3/2N2NP1/PP3PBP/R1BQ1RK1 b -' => {
			eco => 'E62v',
			# TRANSLATORS: E62v: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nc6 7. O-O e5 8. d5 Ne7 9. e4
			variation => N__('King\'s Indian: Fianchetto, Uhlmann/Szabo, 9. e4'),
			moves => {
			},
		},
		'r1bq1rk1/1pp1ppbp/p1np1np1/8/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'E63a',
			# TRANSLATORS: E63a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nc6 7. O-O a6
			variation => N__('King\'s Indian: Fianchetto, Panno Variation'),
			moves => {
				'b2b3' => 1,
				'd4d5' => 1,
				'e2e4' => 1,
				'f1e1' => 1,
				'h2h3' => 1,
			},
		},
		'r1bq1rk1/1pp1ppbp/p1np1np1/8/2PP4/2N2NP1/PP2PPBP/R1BQR1K1 b -' => {
			eco => 'E63b',
			# TRANSLATORS: E63b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nc6 7. O-O a6 8. Re1
			variation => N__('King\'s Indian: Fianchetto, Panno, 8. Re1'),
			moves => {
			},
		},
		'r1bq1rk1/1pp1ppbp/p1np1np1/8/2PPP3/2N2NP1/PP3PBP/R1BQ1RK1 b -' => {
			eco => 'E63c',
			# TRANSLATORS: E63c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nc6 7. O-O a6 8. e4
			variation => N__('King\'s Indian: Fianchetto, Panno, 8. e4'),
			moves => {
			},
		},
		'r1bq1rk1/1pp1ppbp/p1np1np1/8/2PP4/1PN2NP1/P3PPBP/R1BQ1RK1 b -' => {
			eco => 'E63d',
			# TRANSLATORS: E63d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nc6 7. O-O a6 8. b3
			variation => N__('King\'s Indian: Fianchetto, Panno, 8. b3'),
			moves => {
				'a8b8' => 1,
			},
		},
		'1rbq1rk1/1pp1ppbp/p1np1np1/8/2PP4/1PN2NP1/P3PPBP/R1BQ1RK1 w -' => {
			eco => 'E63e',
			# TRANSLATORS: E63e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nc6 7. O-O a6 8. b3 Rb8
			variation => N__('King\'s Indian: Fianchetto, Panno, 8. b3 Rb8'),
			moves => {
				'c1b2' => 1,
				'c3d5' => 1,
			},
		},
		'1rbq1rk1/1pp1ppbp/p1np1np1/8/2PP4/1PN2NP1/PB2PPBP/R2Q1RK1 b -' => {
			eco => 'E63f',
			# TRANSLATORS: E63f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nc6 7. O-O a6 8. b3 Rb8 9. Bb2
			variation => N__('King\'s Indian: Fianchetto, Panno, 8. b3 Rb8 9. Bb2'),
			moves => {
			},
		},
		'1rbq1rk1/1pp1ppbp/p1np1np1/3N4/2PP4/1P3NP1/P3PPBP/R1BQ1RK1 b -' => {
			eco => 'E63g',
			# TRANSLATORS: E63g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nc6 7. O-O a6 8. b3 Rb8 9. Nd5
			variation => N__('King\'s Indian: Fianchetto, Panno, 8. b3 Rb8 9. Nd5'),
			moves => {
			},
		},
		'r1bq1rk1/1pp1ppbp/p1np1np1/8/2PP4/2N2NPP/PP2PPB1/R1BQ1RK1 b -' => {
			eco => 'E63h',
			# TRANSLATORS: E63h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nc6 7. O-O a6 8. h3
			variation => N__('King\'s Indian: Fianchetto, Panno, 8. h3'),
			moves => {
				'a8b8' => 1,
			},
		},
		'1rbq1rk1/1pp1ppbp/p1np1np1/8/2PP4/2N2NPP/PP2PPB1/R1BQ1RK1 w -' => {
			eco => 'E63i',
			# TRANSLATORS: E63i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nc6 7. O-O a6 8. h3 Rb8
			variation => N__('King\'s Indian: Fianchetto, Panno, 8. h3 Rb8'),
			moves => {
				'c1e3' => 1,
				'e2e4' => 1,
			},
		},
		'1rbq1rk1/1pp1ppbp/p1np1np1/8/2PP4/2N1BNPP/PP2PPB1/R2Q1RK1 b -' => {
			eco => 'E63j',
			# TRANSLATORS: E63j: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nc6 7. O-O a6 8. h3 Rb8 9. Be3
			variation => N__('King\'s Indian: Fianchetto, Panno, 8. h3 Rb8 9. Be3'),
			moves => {
			},
		},
		'1rbq1rk1/1pp1ppbp/p1np1np1/8/2PPP3/2N2NPP/PP3PB1/R1BQ1RK1 b -' => {
			eco => 'E63k',
			# TRANSLATORS: E63k: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nc6 7. O-O a6 8. h3 Rb8 9. e4
			variation => N__('King\'s Indian: Fianchetto, Panno, 8. h3 Rb8 9. e4'),
			moves => {
			},
		},
		'r1bq1rk1/1pp1ppbp/p1np1np1/3P4/2P5/2N2NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'E63l',
			# TRANSLATORS: E63l: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nc6 7. O-O a6 8. d5
			variation => N__('King\'s Indian: Fianchetto, Panno, 8. d5'),
			moves => {
				'c6a5' => 1,
			},
		},
		'r1bq1rk1/1pp1ppbp/p2p1np1/n2P4/2P5/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'E63m',
			# TRANSLATORS: E63m: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nc6 7. O-O a6 8. d5 Na5
			variation => N__('King\'s Indian: Fianchetto, Panno, 8. d5 Na5'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2p5/2PP4/2N2NP1/PP2PPBP/R1BQK2R w KQ' => {
			eco => 'E64a',
			# TRANSLATORS: E64a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c5
			variation => N__('King\'s Indian: Fianchetto, Yugoslav System'),
			moves => {
				'd4c5' => 1,
				'd4d5' => 1,
				'e1g1' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2P5/2P5/2N2NP1/PP2PPBP/R1BQK2R b KQ' => {
			eco => 'E64b',
			# TRANSLATORS: E64b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c5 7. dxc5
			variation => N__('King\'s Indian: Fianchetto, Yugoslav, Early Exchange'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2pP4/2P5/2N2NP1/PP2PPBP/R1BQK2R b KQ' => {
			eco => 'E64c',
			# TRANSLATORS: E64c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c5 7. d5
			variation => N__('King\'s Indian: Fianchetto, Yugoslav, 7. d5'),
			moves => {
				'b8a6' => 1,
				'e7e6' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3ppnp1/2pP4/2P5/2N2NP1/PP2PPBP/R1BQK2R w KQ' => {
			eco => 'E64d',
			# TRANSLATORS: E64d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c5 7. d5 e6
			variation => N__('King\'s Indian: Fianchetto, Yugoslav, 7. d5 e6'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/n2p1np1/2pP4/2P5/2N2NP1/PP2PPBP/R1BQK2R w KQ' => {
			eco => 'E64e',
			# TRANSLATORS: E64e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c5 7. d5 Na6
			variation => N__('King\'s Indian: Fianchetto, Yugoslav, 7. d5 Na6'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2p5/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'E65a',
			# TRANSLATORS: E65a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c5 7. O-O
			variation => N__('King\'s Indian: Fianchetto, Yugoslav, 7.O-O'),
			moves => {
				'b8c6' => 1,
				'b8d7' => 1,
				'c5d4' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/8/2Pp4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'E65b',
			# TRANSLATORS: E65b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c5 7. O-O cxd4
			variation => N__('King\'s Indian: Fianchetto, Yugoslav, 7.O-O cxd4'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nppbp/3p1np1/2p5/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'E65c',
			# TRANSLATORS: E65c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c5 7. O-O Nbd7
			variation => N__('King\'s Indian: Fianchetto, Yugoslav, 7.O-O Nbd7'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/2p5/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'E65d',
			# TRANSLATORS: E65d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c5 7. O-O Nc6
			variation => N__('King\'s Indian: Fianchetto, Yugoslav, 7.O-O Nc6'),
			moves => {
				'd4c5' => 1,
				'd4d5' => 1,
				'h2h3' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/2p5/2PP4/2N2NPP/PP2PPB1/R1BQ1RK1 b -' => {
			eco => 'E65e',
			# TRANSLATORS: E65e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c5 7. O-O Nc6 8. h3
			variation => N__('King\'s Indian: Fianchetto, Yugoslav, 7.O-O Nc6 8. h3'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/2P5/2P5/2N2NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'E65f',
			# TRANSLATORS: E65f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c5 7. O-O Nc6 8. dxc5
			variation => N__('King\'s Indian: Fianchetto, Yugoslav, Exchange'),
			moves => {
				'd6c5' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2n2np1/2p5/2P5/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'E65f',
			# TRANSLATORS: E65f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c5 7. O-O Nc6 8. dxc5 dxc5
			variation => N__('King\'s Indian: Fianchetto, Yugoslav, Exchange'),
			moves => {
				'c1e3' => 1,
				'c1f4' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2n2np1/2p5/2P5/2N1BNP1/PP2PPBP/R2Q1RK1 b -' => {
			eco => 'E65g',
			# TRANSLATORS: E65g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c5 7. O-O Nc6 8. dxc5 dxc5 9. Be3
			variation => N__('King\'s Indian: Fianchetto, Yugoslav, Exchange, 9. Be3'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/2n2np1/2p5/2P2B2/2N2NP1/PP2PPBP/R2Q1RK1 b -' => {
			eco => 'E65h',
			# TRANSLATORS: E65h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c5 7. O-O Nc6 8. dxc5 dxc5 9. Bf4
			variation => N__('King\'s Indian: Fianchetto, Yugoslav, Exchange, 9. Bf4'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/2pP4/2P5/2N2NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'E66a',
			# TRANSLATORS: E66a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c5 7. O-O Nc6 8. d5
			variation => N__('King\'s Indian: Fianchetto, Yugoslav Panno'),
			moves => {
				'c6a5' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/3p1np1/n1pP4/2P5/2N3P1/PP1NPPBP/R1BQ1RK1 b -' => {
			eco => 'E66b',
			# TRANSLATORS: E66b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c5 7. O-O Nc6 8. d5 Na5 9. Nd2
			variation => N__('King\'s Indian: Fianchetto, Yugoslav Panno'),
			moves => {
				'a7a6' => 1,
				'e7e5' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/3p1np1/n1pP4/2P5/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'E66c',
			# TRANSLATORS: E66c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c5 7. O-O Nc6 8. d5 Na5
			variation => N__('King\'s Indian: Fianchetto, Yugoslav Panno'),
			moves => {
				'f3d2' => 1,
			},
		},
		'r1bq1rk1/pp3pbp/3p1np1/n1pPp3/2P5/2N3P1/PP1NPPBP/R1BQ1RK1 w -' => {
			eco => 'E66d',
			# TRANSLATORS: E66d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c5 7. O-O Nc6 8. d5 Na5 9. Nd2 e5
			variation => N__('King\'s Indian: Fianchetto, Yugoslav Panno, 9... e5'),
			moves => {
			},
		},
		'r1bq1rk1/1p2ppbp/p2p1np1/n1pP4/2P5/2N3P1/PP1NPPBP/R1BQ1RK1 w -' => {
			eco => 'E66e',
			# TRANSLATORS: E66e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c5 7. O-O Nc6 8. d5 Na5 9. Nd2 a6
			variation => N__('King\'s Indian: Fianchetto, Yugoslav Panno, 9... a6'),
			moves => {
				'a1b1' => 1,
				'd1c2' => 1,
			},
		},
		'r1bq1rk1/1p2ppbp/p2p1np1/n1pP4/2P5/2N3P1/PP1NPPBP/1RBQ1RK1 b -' => {
			eco => 'E66f',
			# TRANSLATORS: E66f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c5 7. O-O Nc6 8. d5 Na5 9. Nd2 a6 10. Rb1
			variation => N__('King\'s Indian: Fianchetto, Yugoslav Panno, 9... a6 10. Rb1'),
			moves => {
				'a8b8' => 1,
			},
		},
		'1rbq1rk1/1p2ppbp/p2p1np1/n1pP4/2P5/2N3P1/PP1NPPBP/1RBQ1RK1 w -' => {
			eco => 'E66g',
			# TRANSLATORS: E66g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c5 7. O-O Nc6 8. d5 Na5 9. Nd2 a6 10. Rb1 Rb8
			variation => N__('King\'s Indian: Fianchetto, Yugoslav Panno, 9... a6 10. Rb1 Rb8'),
			moves => {
			},
		},
		'r1bq1rk1/1p2ppbp/p2p1np1/n1pP4/2P5/2N3P1/PPQNPPBP/R1B2RK1 b -' => {
			eco => 'E66h',
			# TRANSLATORS: E66h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c5 7. O-O Nc6 8. d5 Na5 9. Nd2 a6 10. Qc2
			variation => N__('King\'s Indian: Fianchetto, Yugoslav Panno, 9... a6 10. Qc2'),
			moves => {
				'a8b8' => 1,
			},
		},
		'1rbq1rk1/1p2ppbp/p2p1np1/n1pP4/2P5/2N3P1/PPQNPPBP/R1B2RK1 w -' => {
			eco => 'E66i',
			# TRANSLATORS: E66i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c5 7. O-O Nc6 8. d5 Na5 9. Nd2 a6 10. Qc2 Rb8
			variation => N__('King\'s Indian: Fianchetto, Yugoslav Panno, 9... a6 10. Qc2 Rb8'),
			moves => {
				'b2b3' => 1,
			},
		},
		'1rbq1rk1/1p2ppbp/p2p1np1/n1pP4/2P5/1PN3P1/P1QNPPBP/R1B2RK1 b -' => {
			eco => 'E66j',
			# TRANSLATORS: E66j: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c5 7. O-O Nc6 8. d5 Na5 9. Nd2 a6 10. Qc2 Rb8 11. b3
			variation => N__('King\'s Indian: Fianchetto, Yugoslav Panno, 9... a6 10. Qc2 Rb8 11. b3'),
			moves => {
				'b7b5' => 1,
			},
		},
		'1rbq1rk1/4ppbp/p2p1np1/nppP4/2P5/1PN3P1/P1QNPPBP/R1B2RK1 w -' => {
			eco => 'E66k',
			# TRANSLATORS: E66k: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c5 7. O-O Nc6 8. d5 Na5 9. Nd2 a6 10. Qc2 Rb8 11. b3 b5
			variation => N__('King\'s Indian: Fianchetto, Yugoslav Panno, Main Line'),
			moves => {
				'c1b2' => 1,
			},
		},
		'1rbq1rk1/4ppbp/p2p1np1/nppP4/2P5/1PN3P1/PBQNPPBP/R4RK1 b -' => {
			eco => 'E66l',
			# TRANSLATORS: E66l: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c5 7. O-O Nc6 8. d5 Na5 9. Nd2 a6 10. Qc2 Rb8 11. b3 b5 12. Bb2
			variation => N__('King\'s Indian: Fianchetto, Yugoslav Panno, Main Line, 12. Bb2'),
			moves => {
				'b5c4' => 1,
				'e7e5' => 1,
			},
		},
		'1rbq1rk1/5pbp/p2p1np1/nppPp3/2P5/1PN3P1/PBQNPPBP/R4RK1 w -' => {
			eco => 'E66m',
			# TRANSLATORS: E66m: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c5 7. O-O Nc6 8. d5 Na5 9. Nd2 a6 10. Qc2 Rb8 11. b3 b5 12. Bb2 e5
			variation => N__('King\'s Indian: Fianchetto, Yugoslav Panno, Main Line, 12. Bb2 e5'),
			moves => {
			},
		},
		'1rbq1rk1/4ppbp/p2p1np1/n1pP4/2p5/1PN3P1/PBQNPPBP/R4RK1 w -' => {
			eco => 'E66n',
			# TRANSLATORS: E66n: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 c5 7. O-O Nc6 8. d5 Na5 9. Nd2 a6 10. Qc2 Rb8 11. b3 b5 12. Bb2 bxc4
			variation => N__('King\'s Indian: Fianchetto, Yugoslav Panno, Main Line, 12. Bb2 bxc4'),
			moves => {
			},
		},
		'r1bq1rk1/pppnppbp/3p1np1/8/2PP4/2N2NP1/PP2PPBP/R1BQK2R w KQ' => {
			eco => 'E67a',
			# TRANSLATORS: E67a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7
			variation => N__('King\'s Indian: Fianchetto with 6... Nd7'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bq1rk1/pppnppbp/3p1np1/8/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'E67b',
			# TRANSLATORS: E67b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O
			variation => N__('King\'s Indian: Fianchetto with 6... Nd7 7.O-O'),
			moves => {
				'c7c6' => 1,
				'e7e5' => 1,
			},
		},
		'r1bq1rk1/pp1nppbp/2pp1np1/8/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'E67c',
			# TRANSLATORS: E67c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O c6
			variation => N__('King\'s Indian: Fianchetto with 6... Nd7 7.O-O c6'),
			moves => {
			},
		},
		'r1bq1rk1/pppn1pbp/3p1np1/4p3/2PP4/2N2NP1/PP2PPBP/R1BQ1RK1 w -' => {
			eco => 'E67d',
			# TRANSLATORS: E67d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5
			variation => N__('King\'s Indian: Fianchetto, Classical Variation'),
			moves => {
				'b2b3' => 1,
				'd1c2' => 1,
				'd4d5' => 1,
				'd4e5' => 1,
				'e2e4' => 1,
				'h2h3' => 1,
			},
		},
		'r1bq1rk1/pppn1pbp/3p1np1/3Pp3/2P5/2N2NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'E67e',
			# TRANSLATORS: E67e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. d5
			variation => N__('King\'s Indian: Fianchetto, Classical, 8. d5'),
			moves => {
			},
		},
		'r1bq1rk1/pppn1pbp/3p1np1/4P3/2P5/2N2NP1/PP2PPBP/R1BQ1RK1 b -' => {
			eco => 'E67f',
			# TRANSLATORS: E67f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. dxe5
			variation => N__('King\'s Indian: Fianchetto, Classical, 8.dxe5'),
			moves => {
			},
		},
		'r1bq1rk1/pppn1pbp/3p1np1/4p3/2PP4/1PN2NP1/P3PPBP/R1BQ1RK1 b -' => {
			eco => 'E67g',
			# TRANSLATORS: E67g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. b3
			variation => N__('King\'s Indian: Fianchetto, Classical, 8. b3'),
			moves => {
			},
		},
		'r1bq1rk1/pppn1pbp/3p1np1/4p3/2PP4/2N2NP1/PPQ1PPBP/R1B2RK1 b -' => {
			eco => 'E67h',
			# TRANSLATORS: E67h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. Qc2
			variation => N__('King\'s Indian: Fianchetto, Classical, 8. Qc2'),
			moves => {
				'c7c6' => 1,
			},
		},
		'r1bq1rk1/pp1n1pbp/2pp1np1/4p3/2PP4/2N2NP1/PPQ1PPBP/R1B2RK1 w -' => {
			eco => 'E67i',
			# TRANSLATORS: E67i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. Qc2 c6
			variation => N__('King\'s Indian: Fianchetto, Classical, 8. Qc2 c6'),
			moves => {
			},
		},
		'r1bq1rk1/pppn1pbp/3p1np1/4p3/2PP4/2N2NPP/PP2PPB1/R1BQ1RK1 b -' => {
			eco => 'E67j',
			# TRANSLATORS: E67j: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. h3
			variation => N__('King\'s Indian: Fianchetto, Classical, 8. h3'),
			moves => {
				'c7c6' => 1,
				'f8e8' => 1,
			},
		},
		'r1bqr1k1/pppn1pbp/3p1np1/4p3/2PP4/2N2NPP/PP2PPB1/R1BQ1RK1 w -' => {
			eco => 'E67k',
			# TRANSLATORS: E67k: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. h3 Re8
			variation => N__('King\'s Indian: Fianchetto, Classical, 8. h3 Re8'),
			moves => {
			},
		},
		'r1bq1rk1/pp1n1pbp/2pp1np1/4p3/2PP4/2N2NPP/PP2PPB1/R1BQ1RK1 w -' => {
			eco => 'E67l',
			# TRANSLATORS: E67l: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. h3 c6
			variation => N__('King\'s Indian: Fianchetto, Classical, 8. h3 c6'),
			moves => {
			},
		},
		'r1bq1rk1/pppn1pbp/3p1np1/4p3/2PPP3/2N2NP1/PP3PBP/R1BQ1RK1 b -' => {
			eco => 'E68a',
			# TRANSLATORS: E68a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4
			variation => N__('King\'s Indian: Fianchetto, Classical, 8. e4'),
			moves => {
				'a7a6' => 1,
				'c7c6' => 1,
				'e5d4' => 1,
				'f8e8' => 1,
			},
		},
		'r1bqr1k1/pppn1pbp/3p1np1/4p3/2PPP3/2N2NP1/PP3PBP/R1BQ1RK1 w -' => {
			eco => 'E68b',
			# TRANSLATORS: E68b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 Re8
			variation => N__('King\'s Indian: Fianchetto, Classical, 8. e4 Re8'),
			moves => {
			},
		},
		'r1bq1rk1/pppn1pbp/3p1np1/8/2PpP3/2N2NP1/PP3PBP/R1BQ1RK1 w -' => {
			eco => 'E68c',
			# TRANSLATORS: E68c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 exd4
			variation => N__('King\'s Indian: Fianchetto, Classical, 8. e4 exd4'),
			moves => {
				'f3d4' => 1,
			},
		},
		'r1bq1rk1/pppn1pbp/3p1np1/8/2PNP3/2N3P1/PP3PBP/R1BQ1RK1 b -' => {
			eco => 'E68c',
			# TRANSLATORS: E68c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 exd4 9. Nxd4
			variation => N__('King\'s Indian: Fianchetto, Classical, 8. e4 exd4'),
			moves => {
				'd7c5' => 1,
				'f8e8' => 1,
			},
		},
		'r1bq1rk1/ppp2pbp/3p1np1/2n5/2PNP3/2N3P1/PP3PBP/R1BQ1RK1 w -' => {
			eco => 'E68d',
			# TRANSLATORS: E68d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 exd4 9. Nxd4 Nc5
			variation => N__('King\'s Indian: Fianchetto, Classical, 8. e4 exd4 9.Nxd4 Nc5'),
			moves => {
			},
		},
		'r1bqr1k1/pppn1pbp/3p1np1/8/2PNP3/2N3P1/PP3PBP/R1BQ1RK1 w -' => {
			eco => 'E68e',
			# TRANSLATORS: E68e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 exd4 9. Nxd4 Re8
			variation => N__('King\'s Indian: Fianchetto, Classical, 8. e4 exd4 9.Nxd4 Re8'),
			moves => {
				'h2h3' => 1,
			},
		},
		'r1bqr1k1/pppn1pbp/3p1np1/8/2PNP3/2N3PP/PP3PB1/R1BQ1RK1 b -' => {
			eco => 'E68f',
			# TRANSLATORS: E68f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 exd4 9. Nxd4 Re8 10. h3
			variation => N__('King\'s Indian: Fianchetto, Classical, 8. e4 exd4 9.Nxd4 Re8 10. h3'),
			moves => {
				'd7c5' => 1,
			},
		},
		'r1bqr1k1/ppp2pbp/3p1np1/2n5/2PNP3/2N3PP/PP3PB1/R1BQ1RK1 w -' => {
			eco => 'E68g',
			# TRANSLATORS: E68g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 exd4 9. Nxd4 Re8 10. h3 Nc5
			variation => N__('King\'s Indian: Fianchetto, Classical, 8. e4 exd4 9.Nxd4 Re8 10. h3 Nc5'),
			moves => {
				'f1e1' => 1,
			},
		},
		'r1bqr1k1/ppp2pbp/3p1np1/2n5/2PNP3/2N3PP/PP3PB1/R1BQR1K1 b -' => {
			eco => 'E68g',
			# TRANSLATORS: E68g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 exd4 9. Nxd4 Re8 10. h3 Nc5 11. Re1
			variation => N__('King\'s Indian: Fianchetto, Classical, 8. e4 exd4 9.Nxd4 Re8 10. h3 Nc5'),
			moves => {
				'a7a5' => 1,
			},
		},
		'r1bqr1k1/1pp2pbp/3p1np1/p1n5/2PNP3/2N3PP/PP3PB1/R1BQR1K1 w -' => {
			eco => 'E68h',
			# TRANSLATORS: E68h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 exd4 9. Nxd4 Re8 10. h3 Nc5 11. Re1 a5
			variation => N__('King\'s Indian: Fianchetto, Classical, 8. e4 exd4 9.Nxd4 Re8 10. h3 Nc5 11. Re1 a5'),
			moves => {
			},
		},
		'r1bq1rk1/1ppn1pbp/p2p1np1/4p3/2PPP3/2N2NP1/PP3PBP/R1BQ1RK1 w -' => {
			eco => 'E68i',
			# TRANSLATORS: E68i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 a6
			variation => N__('King\'s Indian: Fianchetto, Classical, 8. e4 a6'),
			moves => {
			},
		},
		'r1bq1rk1/pp1n1pbp/2pp1np1/4p3/2PPP3/2N2NP1/PP3PBP/R1BQ1RK1 w -' => {
			eco => 'E68j',
			# TRANSLATORS: E68j: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6
			variation => N__('King\'s Indian: Fianchetto, Classical, 8. e4 c6'),
			moves => {
				'a1b1' => 1,
				'b2b3' => 1,
				'h2h3' => 1,
			},
		},
		'r1bq1rk1/pp1n1pbp/2pp1np1/4p3/2PPP3/2N2NP1/PP3PBP/1RBQ1RK1 b -' => {
			eco => 'E68k',
			# TRANSLATORS: E68k: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. Rb1
			variation => N__('King\'s Indian: Fianchetto, Classical, 8. e4 c6 9. Rb1'),
			moves => {
			},
		},
		'r1bq1rk1/pp1n1pbp/2pp1np1/4p3/2PPP3/1PN2NP1/P4PBP/R1BQ1RK1 b -' => {
			eco => 'E68l',
			# TRANSLATORS: E68l: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. b3
			variation => N__('King\'s Indian: Fianchetto, Classical, 8. e4 c6 9. b3'),
			moves => {
			},
		},
		'r1bq1rk1/pp1n1pbp/2pp1np1/4p3/2PPP3/2N2NPP/PP3PB1/R1BQ1RK1 b -' => {
			eco => 'E69a',
			# TRANSLATORS: E69a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. h3
			variation => N__('King\'s Indian: Fianchetto, Classical, 9. h3'),
			moves => {
				'a7a5' => 1,
				'a7a6' => 1,
				'd8a5' => 1,
				'd8b6' => 1,
				'd8e7' => 1,
				'e5d4' => 1,
				'f8e8' => 1,
			},
		},
		'r1b2rk1/pp1nqpbp/2pp1np1/4p3/2PPP3/2N2NPP/PP3PB1/R1BQ1RK1 w -' => {
			eco => 'E69b',
			# TRANSLATORS: E69b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. h3 Qe7
			variation => N__('King\'s Indian: Fianchetto, Classical, 9. h3 Qe7'),
			moves => {
			},
		},
		'r1bq1rk1/1p1n1pbp/p1pp1np1/4p3/2PPP3/2N2NPP/PP3PB1/R1BQ1RK1 w -' => {
			eco => 'E69c',
			# TRANSLATORS: E69c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. h3 a6
			variation => N__('King\'s Indian: Fianchetto, Classical, 9. h3 a6'),
			moves => {
			},
		},
		'r1bq1rk1/1p1n1pbp/2pp1np1/p3p3/2PPP3/2N2NPP/PP3PB1/R1BQ1RK1 w -' => {
			eco => 'E69d',
			# TRANSLATORS: E69d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. h3 a5
			variation => N__('King\'s Indian: Fianchetto, Classical, 9. h3 a5'),
			moves => {
			},
		},
		'r1bq1rk1/pp1n1pbp/2pp1np1/8/2PpP3/2N2NPP/PP3PB1/R1BQ1RK1 w -' => {
			eco => 'E69e',
			# TRANSLATORS: E69e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. h3 exd4
			variation => N__('King\'s Indian: Fianchetto, Classical, 9. h3 exd4'),
			moves => {
				'f3d4' => 1,
			},
		},
		'r1bq1rk1/pp1n1pbp/2pp1np1/8/2PNP3/2N3PP/PP3PB1/R1BQ1RK1 b -' => {
			eco => 'E69e',
			# TRANSLATORS: E69e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. h3 exd4 10. Nxd4
			variation => N__('King\'s Indian: Fianchetto, Classical, 9. h3 exd4'),
			moves => {
				'f8e8' => 1,
			},
		},
		'r1bqr1k1/pp1n1pbp/2pp1np1/8/2PNP3/2N3PP/PP3PB1/R1BQ1RK1 w -' => {
			eco => 'E69f',
			# TRANSLATORS: E69f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. h3 exd4 10. Nxd4 Re8
			variation => N__('King\'s Indian: Fianchetto, Classical, 9. h3 exd4 10.Nxd4 Re8'),
			moves => {
			},
		},
		'r1b2rk1/pp1n1pbp/2pp1np1/q3p3/2PPP3/2N2NPP/PP3PB1/R1BQ1RK1 w -' => {
			eco => 'E69g',
			# TRANSLATORS: E69g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. h3 Qa5
			variation => N__('King\'s Indian: Fianchetto, Classical, 9. h3 Qa5'),
			moves => {
				'f1e1' => 1,
			},
		},
		'r1b2rk1/pp1n1pbp/2pp1np1/q3p3/2PPP3/2N2NPP/PP3PB1/R1BQR1K1 b -' => {
			eco => 'E69h',
			# TRANSLATORS: E69h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. h3 Qa5 10. Re1
			variation => N__('King\'s Indian: Fianchetto, Classical, 9. h3 Qa5 10. Re1'),
			moves => {
				'e5d4' => 1,
			},
		},
		'r1b2rk1/pp1n1pbp/2pp1np1/q7/2PpP3/2N2NPP/PP3PB1/R1BQR1K1 w -' => {
			eco => 'E69h',
			# TRANSLATORS: E69h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. h3 Qa5 10. Re1 exd4
			variation => N__('King\'s Indian: Fianchetto, Classical, 9. h3 Qa5 10. Re1 exd4'),
			moves => {
				'f3d4' => 1,
			},
		},
		'r1b2rk1/pp1n1pbp/2pp1np1/q7/2PNP3/2N3PP/PP3PB1/R1BQR1K1 b -' => {
			eco => 'E69h',
			# TRANSLATORS: E69h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. h3 Qa5 10. Re1 exd4 11. Nxd4
			variation => N__('King\'s Indian: Fianchetto, Classical, 9. h3 Qa5 10. Re1 exd4'),
			moves => {
			},
		},
		'r1b2rk1/pp1n1pbp/1qpp1np1/4p3/2PPP3/2N2NPP/PP3PB1/R1BQ1RK1 w -' => {
			eco => 'E69i',
			# TRANSLATORS: E69i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. h3 Qb6
			variation => N__('King\'s Indian: Fianchetto, Classical, 9. h3 Qb6'),
			moves => {
				'c4c5' => 1,
				'd4d5' => 1,
				'f1e1' => 1,
			},
		},
		'r1b2rk1/pp1n1pbp/1qpp1np1/3Pp3/2P1P3/2N2NPP/PP3PB1/R1BQ1RK1 b -' => {
			eco => 'E69i',
			# TRANSLATORS: E69i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. h3 Qb6 10. d5
			variation => N__('King\'s Indian: Fianchetto, Classical, 9. h3 Qb6 10. d5'),
			moves => {
			},
		},
		'r1b2rk1/pp1n1pbp/1qpp1np1/2P1p3/3PP3/2N2NPP/PP3PB1/R1BQ1RK1 b -' => {
			eco => 'E69j',
			# TRANSLATORS: E69j: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. h3 Qb6 10. c5
			variation => N__('King\'s Indian: Fianchetto, Classical, 9. h3 Qb6 10. c5'),
			moves => {
			},
		},
		'r1b2rk1/pp1n1pbp/1qpp1np1/4p3/2PPP3/2N2NPP/PP3PB1/R1BQR1K1 b -' => {
			eco => 'E69k',
			# TRANSLATORS: E69k: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. h3 Qb6 10. Re1
			variation => N__('King\'s Indian: Fianchetto, Classical, 9. h3 Qb6 10. Re1'),
			moves => {
				'e5d4' => 1,
				'f8e8' => 1,
			},
		},
		'r1b1r1k1/pp1n1pbp/1qpp1np1/4p3/2PPP3/2N2NPP/PP3PB1/R1BQR1K1 w -' => {
			eco => 'E69l',
			# TRANSLATORS: E69l: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. h3 Qb6 10. Re1 Re8
			variation => N__('King\'s Indian: Fianchetto, Classical, 9. h3 Qb6 10. Re1 Re8'),
			moves => {
			},
		},
		'r1b2rk1/pp1n1pbp/1qpp1np1/8/2PpP3/2N2NPP/PP3PB1/R1BQR1K1 w -' => {
			eco => 'E69m',
			# TRANSLATORS: E69m: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. h3 Qb6 10. Re1 exd4
			variation => N__('King\'s Indian: Fianchetto, Classical, 9. h3 Qb6 10. Re1 exd4'),
			moves => {
				'f3d4' => 1,
			},
		},
		'r1b2rk1/pp1n1pbp/1qpp1np1/8/2PNP3/2N3PP/PP3PB1/R1BQR1K1 b -' => {
			eco => 'E69m',
			# TRANSLATORS: E69m: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. h3 Qb6 10. Re1 exd4 11. Nxd4
			variation => N__('King\'s Indian: Fianchetto, Classical, 9. h3 Qb6 10. Re1 exd4'),
			moves => {
				'f8e8' => 1,
			},
		},
		'r1b1r1k1/pp1n1pbp/1qpp1np1/8/2PNP3/2N3PP/PP3PB1/R1BQR1K1 w -' => {
			eco => 'E69n',
			# TRANSLATORS: E69n: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. h3 Qb6 10. Re1 exd4 11. Nxd4 Re8
			variation => N__('King\'s Indian: Fianchetto, Classical, 9. h3 Qb6 10. Re1 exd4 11.Nxd4 Re8'),
			moves => {
			},
		},
		'r1bqr1k1/pp1n1pbp/2pp1np1/4p3/2PPP3/2N2NPP/PP3PB1/R1BQ1RK1 w -' => {
			eco => 'E69o',
			# TRANSLATORS: E69o: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. h3 Re8
			variation => N__('King\'s Indian: Fianchetto, Classical, 9. h3 Re8'),
			moves => {
				'b2b3' => 1,
				'c1e3' => 1,
				'f1e1' => 1,
			},
		},
		'r1bqr1k1/pp1n1pbp/2pp1np1/4p3/2PPP3/1PN2NPP/P4PB1/R1BQ1RK1 b -' => {
			eco => 'E69p',
			# TRANSLATORS: E69p: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. h3 Re8 10. b3
			variation => N__('King\'s Indian: Fianchetto, Classical, 9. h3 Re8 10. b3'),
			moves => {
			},
		},
		'r1bqr1k1/pp1n1pbp/2pp1np1/4p3/2PPP3/2N1BNPP/PP3PB1/R2Q1RK1 b -' => {
			eco => 'E69q',
			# TRANSLATORS: E69q: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. h3 Re8 10. Be3
			variation => N__('King\'s Indian: Fianchetto, Classical, 9. h3 Re8 10. Be3'),
			moves => {
				'e5d4' => 1,
			},
		},
		'r1bqr1k1/pp1n1pbp/2pp1np1/8/2PpP3/2N1BNPP/PP3PB1/R2Q1RK1 w -' => {
			eco => 'E69r',
			# TRANSLATORS: E69r: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. h3 Re8 10. Be3 exd4
			variation => N__('King\'s Indian: Fianchetto, Classical, 9. h3 Re8 10. Be3 exd4'),
			moves => {
				'f3d4' => 1,
			},
		},
		'r1bqr1k1/pp1n1pbp/2pp1np1/8/2PNP3/2N1B1PP/PP3PB1/R2Q1RK1 b -' => {
			eco => 'E69r',
			# TRANSLATORS: E69r: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. h3 Re8 10. Be3 exd4 11. Nxd4
			variation => N__('King\'s Indian: Fianchetto, Classical, 9. h3 Re8 10. Be3 exd4 11.Nxd4'),
			moves => {
			},
		},
		'r1bqr1k1/pp1n1pbp/2pp1np1/4p3/2PPP3/2N2NPP/PP3PB1/R1BQR1K1 b -' => {
			eco => 'E69s',
			# TRANSLATORS: E69s: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. h3 Re8 10. Re1
			variation => N__('King\'s Indian: Fianchetto, Classical, 9. h3 Re8 10. Re1'),
			moves => {
				'a7a5' => 1,
				'd8c7' => 1,
				'e5d4' => 1,
			},
		},
		'r1b1r1k1/ppqn1pbp/2pp1np1/4p3/2PPP3/2N2NPP/PP3PB1/R1BQR1K1 w -' => {
			eco => 'E69t',
			# TRANSLATORS: E69t: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. h3 Re8 10. Re1 Qc7
			variation => N__('King\'s Indian: Fianchetto, Classical, 9. h3 Re8 10. Re1 Qc7'),
			moves => {
			},
		},
		'r1bqr1k1/1p1n1pbp/2pp1np1/p3p3/2PPP3/2N2NPP/PP3PB1/R1BQR1K1 w -' => {
			eco => 'E69u',
			# TRANSLATORS: E69u: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. h3 Re8 10. Re1 a5
			variation => N__('King\'s Indian: Fianchetto, Classical, 9. h3 Re8 10. Re1 a5'),
			moves => {
				'c1e3' => 1,
			},
		},
		'r1bqr1k1/1p1n1pbp/2pp1np1/p3p3/2PPP3/2N1BNPP/PP3PB1/R2QR1K1 b -' => {
			eco => 'E69u',
			# TRANSLATORS: E69u: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. h3 Re8 10. Re1 a5 11. Be3
			variation => N__('King\'s Indian: Fianchetto, Classical, 9. h3 Re8 10. Re1 a5 11. Be3'),
			moves => {
			},
		},
		'r1bqr1k1/pp1n1pbp/2pp1np1/8/2PpP3/2N2NPP/PP3PB1/R1BQR1K1 w -' => {
			eco => 'E69v',
			# TRANSLATORS: E69v: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. h3 Re8 10. Re1 exd4
			variation => N__('King\'s Indian: Fianchetto, Classical, 9. h3 Re8 10. Re1 exd4'),
			moves => {
				'f3d4' => 1,
			},
		},
		'r1bqr1k1/pp1n1pbp/2pp1np1/8/2PNP3/2N3PP/PP3PB1/R1BQR1K1 b -' => {
			eco => 'E69v',
			# TRANSLATORS: E69v: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. h3 Re8 10. Re1 exd4 11. Nxd4
			variation => N__('King\'s Indian: Fianchetto, Classical, 9. h3 Re8 10. Re1 exd4'),
			moves => {
				'a7a5' => 1,
				'd7c5' => 1,
			},
		},
		'r1bqr1k1/1p1n1pbp/2pp1np1/p7/2PNP3/2N3PP/PP3PB1/R1BQR1K1 w -' => {
			eco => 'E69w',
			# TRANSLATORS: E69w: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. h3 Re8 10. Re1 exd4 11. Nxd4 a5
			variation => N__('King\'s Indian: Fianchetto, Classical, 9. h3 Re8 10. Re1 exd4, 11... a5'),
			moves => {
			},
		},
		'r1bqr1k1/pp3pbp/2pp1np1/2n5/2PNP3/2N3PP/PP3PB1/R1BQR1K1 w -' => {
			eco => 'E69x',
			# TRANSLATORS: E69x: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. h3 Re8 10. Re1 exd4 11. Nxd4 Nc5
			variation => N__('King\'s Indian: Fianchetto, Classical, 9. h3 Re8 10. Re1 exd4, 11... Nc5'),
			moves => {
				'a1b1' => 1,
				'b2b3' => 1,
			},
		},
		'r1bqr1k1/pp3pbp/2pp1np1/2n5/2PNP3/2N3PP/PP3PB1/1RBQR1K1 b -' => {
			eco => 'E69y',
			# TRANSLATORS: E69y: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. h3 Re8 10. Re1 exd4 11. Nxd4 Nc5 12. Rb1
			variation => N__('King\'s Indian: Fianchetto, Classical, 9. h3 Re8 10. Re1 exd4, 11... Nc5 12. Rb1'),
			moves => {
			},
		},
		'r1bqr1k1/pp3pbp/2pp1np1/2n5/2PNP3/1PN3PP/P4PB1/R1BQR1K1 b -' => {
			eco => 'E69z',
			# TRANSLATORS: E69z: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. Nf3 d6 5. g3 O-O 6. Bg2 Nbd7 7. O-O e5 8. e4 c6 9. h3 Re8 10. Re1 exd4 11. Nxd4 Nc5 12. b3
			variation => N__('King\'s Indian: Fianchetto, Classical, 9. h3 Re8 10. Re1 exd4, 11... Nc5 12. b3'),
			moves => {
			},
		},
		'rnbqk2r/ppppppbp/5np1/8/2PPP3/2N5/PP3PPP/R1BQKBNR b KQkq' => {
			eco => 'E70a',
			# TRANSLATORS: E70a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4
			variation => N__('King\'s Indian: 4. e4'),
			moves => {
				'd7d6' => 1,
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppppppbp/5np1/8/2PPP3/2N5/PP3PPP/R1BQKBNR w KQ' => {
			eco => 'E70b',
			# TRANSLATORS: E70b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 O-O
			variation => N__('King\'s Indian: 4. e4 O-O'),
			moves => {
				'e4e5' => 1,
				'g1f3' => 1,
			},
		},
		'rnbq1rk1/ppppppbp/5np1/4P3/2PP4/2N5/PP3PPP/R1BQKBNR b KQ' => {
			eco => 'E70c',
			# TRANSLATORS: E70c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 O-O 5. e5
			variation => N__('King\'s Indian: 4. e4 O-O 5. e5'),
			moves => {
			},
		},
		'rnbq1rk1/ppppppbp/5np1/8/2PPP3/2N2N2/PP3PPP/R1BQKB1R b KQ' => {
			eco => 'E70d',
			# TRANSLATORS: E70d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 O-O 5. Nf3
			variation => N__('King\'s Indian: 4. e4 O-O 5. Nf3'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/2PPP3/2N5/PP3PPP/R1BQKBNR w KQkq' => {
			eco => 'E70e',
			# TRANSLATORS: E70e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6
			variation => N__('King\'s Indian: 4. e4 d6'),
			moves => {
				'c1g5' => 1,
				'f1d3' => 1,
				'f1e2' => 1,
				'f2f3' => 1,
				'f2f4' => 1,
				'g1e2' => 1,
				'g1f3' => 1,
				'g2g3' => 1,
				'h2h3' => 1,
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/2PPP3/2N5/PP2NPPP/R1BQKB1R b KQkq' => {
			eco => 'E70f',
			# TRANSLATORS: E70f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nge2
			variation => N__('King\'s Indian: Kramer'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PPP3/2N5/PP2NPPP/R1BQKB1R w KQ' => {
			eco => 'E70g',
			# TRANSLATORS: E70g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nge2 O-O
			variation => N__('King\'s Indian: Kramer, 5...O-O'),
			moves => {
				'e2g3' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PPP3/2N3N1/PP3PPP/R1BQKB1R b KQ' => {
			eco => 'E70h',
			# TRANSLATORS: E70h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nge2 O-O 6. Ng3
			variation => N__('King\'s Indian: Kramer, 5...O-O 6. Ng3'),
			moves => {
				'e7e5' => 1,
			},
		},
		'rnbq1rk1/ppp2pbp/3p1np1/4p3/2PPP3/2N3N1/PP3PPP/R1BQKB1R w KQ' => {
			eco => 'E70i',
			# TRANSLATORS: E70i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nge2 O-O 6. Ng3 e5
			variation => N__('King\'s Indian: Kramer, 5...O-O 6. Ng3 e5'),
			moves => {
				'd4d5' => 1,
			},
		},
		'rnbq1rk1/ppp2pbp/3p1np1/3Pp3/2P1P3/2N3N1/PP3PPP/R1BQKB1R b KQ' => {
			eco => 'E70i',
			# TRANSLATORS: E70i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nge2 O-O 6. Ng3 e5 7. d5
			variation => N__('King\'s Indian: Kramer, 5...O-O 6. Ng3 e5 7. d5'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/2PPP3/2NB4/PP3PPP/R1BQK1NR b KQkq' => {
			eco => 'E70j',
			# TRANSLATORS: E70j: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Bd3
			variation => N__('King\'s Indian: 4. e4 d6 5. Bd3'),
			moves => {
				'e7e5' => 1,
				'e8g8' => 1,
			},
		},
		'rnbqk2r/ppp2pbp/3p1np1/4p3/2PPP3/2NB4/PP3PPP/R1BQK1NR w KQkq' => {
			eco => 'E70k',
			# TRANSLATORS: E70k: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Bd3 e5
			variation => N__('King\'s Indian: 4. e4 d6 5. Bd3 e5'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PPP3/2NB4/PP3PPP/R1BQK1NR w KQ' => {
			eco => 'E70l',
			# TRANSLATORS: E70l: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Bd3 O-O
			variation => N__('King\'s Indian: 4. e4 d6 5. Bd3 O-O'),
			moves => {
				'g1e2' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PPP3/2NB4/PP2NPPP/R1BQK2R b KQ' => {
			eco => 'E70m',
			# TRANSLATORS: E70m: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Bd3 O-O 6. Nge2
			variation => N__('King\'s Indian: 4. e4 d6 5. Bd3 O-O 6.Nge2'),
			moves => {
				'b8c6' => 1,
				'c7c5' => 1,
				'e7e5' => 1,
			},
		},
		'r1bq1rk1/ppp1ppbp/2np1np1/8/2PPP3/2NB4/PP2NPPP/R1BQK2R w KQ' => {
			eco => 'E70n',
			# TRANSLATORS: E70n: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Bd3 O-O 6. Nge2 Nc6
			variation => N__('King\'s Indian: 4. e4 d6 5. Bd3 O-O 6.Nge2 Nc6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bq1rk1/ppp1ppbp/2np1np1/8/2PPP3/2NB4/PP2NPPP/R1BQ1RK1 b -' => {
			eco => 'E70n',
			# TRANSLATORS: E70n: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Bd3 O-O 6. Nge2 Nc6 7. O-O
			variation => N__('King\'s Indian: 4. e4 d6 5. Bd3 O-O 6.Nge2 Nc6 7.O-O'),
			moves => {
				'e7e5' => 1,
			},
		},
		'r1bq1rk1/ppp2pbp/2np1np1/4p3/2PPP3/2NB4/PP2NPPP/R1BQ1RK1 w -' => {
			eco => 'E70n',
			# TRANSLATORS: E70n: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Bd3 O-O 6. Nge2 Nc6 7. O-O e5
			variation => N__('King\'s Indian: 4. e4 d6 5. Bd3 O-O 6.Nge2 Nc6 7.O-O e5'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2p5/2PPP3/2NB4/PP2NPPP/R1BQK2R w KQ' => {
			eco => 'E70o',
			# TRANSLATORS: E70o: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Bd3 O-O 6. Nge2 c5
			variation => N__('King\'s Indian: 4. e4 d6 5. Bd3 O-O 6.Nge2 c5'),
			moves => {
				'd4d5' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2pP4/2P1P3/2NB4/PP2NPPP/R1BQK2R b KQ' => {
			eco => 'E70p',
			# TRANSLATORS: E70p: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Bd3 O-O 6. Nge2 c5 7. d5
			variation => N__('King\'s Indian: 4. e4 d6 5. Bd3 O-O 6.Nge2 c5 7. d5'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3ppnp1/2pP4/2P1P3/2NB4/PP2NPPP/R1BQK2R w KQ' => {
			eco => 'E70p',
			# TRANSLATORS: E70p: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Bd3 O-O 6. Nge2 c5 7. d5 e6
			variation => N__('King\'s Indian: 4. e4 d6 5. Bd3 O-O 6.Nge2 c5 7. d5 e6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3ppnp1/2pP4/2P1P3/2NB4/PP2NPPP/R1BQ1RK1 b -' => {
			eco => 'E70p',
			# TRANSLATORS: E70p: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Bd3 O-O 6. Nge2 c5 7. d5 e6 8. O-O
			variation => N__('King\'s Indian: 4. e4 d6 5. Bd3 O-O 6.Nge2 c5 7. d5 e6 8.O-O'),
			moves => {
			},
		},
		'rnbq1rk1/ppp2pbp/3p1np1/4p3/2PPP3/2NB4/PP2NPPP/R1BQK2R w KQ' => {
			eco => 'E70q',
			# TRANSLATORS: E70q: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Bd3 O-O 6. Nge2 e5
			variation => N__('King\'s Indian: 4. e4 d6 5. Bd3 O-O 6.Nge2 e5'),
			moves => {
				'd4d5' => 1,
			},
		},
		'rnbq1rk1/ppp2pbp/3p1np1/3Pp3/2P1P3/2NB4/PP2NPPP/R1BQK2R b KQ' => {
			eco => 'E70r',
			# TRANSLATORS: E70r: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Bd3 O-O 6. Nge2 e5 7. d5
			variation => N__('King\'s Indian: 4. e4 d6 5. Bd3 O-O 6.Nge2 e5 7. d5'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/6B1/2PPP3/2N5/PP3PPP/R2QKBNR b KQkq' => {
			eco => 'E70s',
			# TRANSLATORS: E70s: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Bg5
			variation => N__('King\'s Indian: Accelerated Averbakh System'),
			moves => {
				'e8g8' => 1,
				'h7h6' => 1,
			},
		},
		'rnbqk2r/ppp1ppb1/3p1npp/6B1/2PPP3/2N5/PP3PPP/R2QKBNR w KQkq' => {
			eco => 'E70t',
			# TRANSLATORS: E70t: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Bg5 h6
			variation => N__('King\'s Indian: Accelerated Averbakh, 5... h6'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/6B1/2PPP3/2N5/PP3PPP/R2QKBNR w KQ' => {
			eco => 'E70u',
			# TRANSLATORS: E70u: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Bg5 O-O
			variation => N__('King\'s Indian: Accelerated Averbakh, 5...O-O'),
			moves => {
				'd1d2' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/6B1/2PPP3/2N5/PP1Q1PPP/R3KBNR b KQ' => {
			eco => 'E70v',
			# TRANSLATORS: E70v: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Bg5 O-O 6. Qd2
			variation => N__('King\'s Indian: Accelerated Averbakh, 5...O-O 6. Qd2'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/2PPP3/2N4P/PP3PP1/R1BQKBNR b KQkq' => {
			eco => 'E71a',
			# TRANSLATORS: E71a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. h3
			variation => N__('King\'s Indian: Makagonov System'),
			moves => {
				'b8d7' => 1,
				'c7c5' => 1,
				'e8g8' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/3p1np1/2p5/2PPP3/2N4P/PP3PP1/R1BQKBNR w KQkq' => {
			eco => 'E71b',
			# TRANSLATORS: E71b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. h3 c5
			variation => N__('King\'s Indian: Makagonov, 5... c5'),
			moves => {
			},
		},
		'r1bqk2r/pppnppbp/3p1np1/8/2PPP3/2N4P/PP3PP1/R1BQKBNR w KQkq' => {
			eco => 'E71c',
			# TRANSLATORS: E71c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. h3 Nbd7
			variation => N__('King\'s Indian: Makagonov, 5...Nbd7'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PPP3/2N4P/PP3PP1/R1BQKBNR w KQ' => {
			eco => 'E71d',
			# TRANSLATORS: E71d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. h3 O-O
			variation => N__('King\'s Indian: Makagonov, 5...O-O'),
			moves => {
				'c1e3' => 1,
				'c1g5' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PPP3/2N1B2P/PP3PP1/R2QKBNR b KQ' => {
			eco => 'E71e',
			# TRANSLATORS: E71e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. h3 O-O 6. Be3
			variation => N__('King\'s Indian: Makagonov, 5...O-O 6. Be3'),
			moves => {
				'e7e5' => 1,
			},
		},
		'rnbq1rk1/ppp2pbp/3p1np1/4p3/2PPP3/2N1B2P/PP3PP1/R2QKBNR w KQ' => {
			eco => 'E71f',
			# TRANSLATORS: E71f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. h3 O-O 6. Be3 e5
			variation => N__('King\'s Indian: Makagonov, 5...O-O 6. Be3 e5'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/6B1/2PPP3/2N4P/PP3PP1/R2QKBNR b KQ' => {
			eco => 'E71g',
			# TRANSLATORS: E71g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. h3 O-O 6. Bg5
			variation => N__('King\'s Indian: Makagonov, 5...O-O 6. Bg5'),
			moves => {
				'b8a6' => 1,
				'b8d7' => 1,
				'c7c5' => 1,
				'c7c6' => 1,
				'h7h6' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/2pp1np1/6B1/2PPP3/2N4P/PP3PP1/R2QKBNR w KQ' => {
			eco => 'E71h',
			# TRANSLATORS: E71h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. h3 O-O 6. Bg5 c6
			variation => N__('King\'s Indian: Makagonov, 5...O-O 6. Bg5 c6'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppb1/3p1npp/6B1/2PPP3/2N4P/PP3PP1/R2QKBNR w KQ' => {
			eco => 'E71i',
			# TRANSLATORS: E71i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. h3 O-O 6. Bg5 h6
			variation => N__('King\'s Indian: Makagonov, 5...O-O 6. Bg5 h6'),
			moves => {
			},
		},
		'r1bq1rk1/pppnppbp/3p1np1/6B1/2PPP3/2N4P/PP3PP1/R2QKBNR w KQ' => {
			eco => 'E71j',
			# TRANSLATORS: E71j: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. h3 O-O 6. Bg5 Nbd7
			variation => N__('King\'s Indian: Makagonov, 5...O-O 6. Bg5 Nbd7'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1ppbp/n2p1np1/6B1/2PPP3/2N4P/PP3PP1/R2QKBNR w KQ' => {
			eco => 'E71k',
			# TRANSLATORS: E71k: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. h3 O-O 6. Bg5 Na6
			variation => N__('King\'s Indian: Makagonov, 5...O-O 6. Bg5 Na6'),
			moves => {
				'f1d3' => 1,
			},
		},
		'r1bq1rk1/ppp1ppbp/n2p1np1/6B1/2PPP3/2NB3P/PP3PP1/R2QK1NR b KQ' => {
			eco => 'E71l',
			# TRANSLATORS: E71l: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. h3 O-O 6. Bg5 Na6 7. Bd3
			variation => N__('King\'s Indian: Makagonov, 5...O-O 6. Bg5 Na6 7. Bd3'),
			moves => {
				'e7e5' => 1,
			},
		},
		'r1bq1rk1/ppp2pbp/n2p1np1/4p1B1/2PPP3/2NB3P/PP3PP1/R2QK1NR w KQ' => {
			eco => 'E71l',
			# TRANSLATORS: E71l: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. h3 O-O 6. Bg5 Na6 7. Bd3 e5
			variation => N__('King\'s Indian: Makagonov, 5...O-O 6. Bg5 Na6 7. Bd3 e5'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2p3B1/2PPP3/2N4P/PP3PP1/R2QKBNR w KQ' => {
			eco => 'E71m',
			# TRANSLATORS: E71m: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. h3 O-O 6. Bg5 c5
			variation => N__('King\'s Indian: Makagonov, 5...O-O 6. Bg5 c5'),
			moves => {
				'd4d5' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2pP2B1/2P1P3/2N4P/PP3PP1/R2QKBNR b KQ' => {
			eco => 'E71m',
			# TRANSLATORS: E71m: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. h3 O-O 6. Bg5 c5 7. d5
			variation => N__('King\'s Indian: Makagonov, 5...O-O 6. Bg5 c5 7. d5'),
			moves => {
				'b7b5' => 1,
				'e7e6' => 1,
			},
		},
		'rnbq1rk1/p3ppbp/3p1np1/1ppP2B1/2P1P3/2N4P/PP3PP1/R2QKBNR w KQ' => {
			eco => 'E71n',
			# TRANSLATORS: E71n: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. h3 O-O 6. Bg5 c5 7. d5 b5
			variation => N__('King\'s Indian: Makagonov, 5...O-O 6. Bg5 c5 7. d5 b5'),
			moves => {
			},
		},
		'rnbq1rk1/pp3pbp/3ppnp1/2pP2B1/2P1P3/2N4P/PP3PP1/R2QKBNR w KQ' => {
			eco => 'E71o',
			# TRANSLATORS: E71o: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. h3 O-O 6. Bg5 c5 7. d5 e6
			variation => N__('King\'s Indian: Makagonov, 5...O-O 6. Bg5 c5 7. d5 e6'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/2PPP3/2N3P1/PP3P1P/R1BQKBNR b KQkq' => {
			eco => 'E72',
			# TRANSLATORS: E72: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. g3
			variation => N__('King\'s Indian: 4. e4 d6 5. g3'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PPP3/2N3P1/PP3P1P/R1BQKBNR w KQ' => {
			eco => 'E72',
			# TRANSLATORS: E72: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. g3 O-O
			variation => N__('King\'s Indian: 4. e4 d6 5. g3 O-O'),
			moves => {
				'f1g2' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PPP3/2N3P1/PP3PBP/R1BQK1NR b KQ' => {
			eco => 'E72',
			# TRANSLATORS: E72: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. g3 O-O 6. Bg2
			variation => N__('King\'s Indian: 4. e4 d6 5. g3 O-O 6. Bg2'),
			moves => {
				'b8c6' => 1,
				'b8d7' => 1,
				'c7c5' => 1,
				'e7e5' => 1,
			},
		},
		'r1bq1rk1/ppp1ppbp/2np1np1/8/2PPP3/2N3P1/PP3PBP/R1BQK1NR w KQ' => {
			eco => 'E72',
			# TRANSLATORS: E72: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. g3 O-O 6. Bg2 Nc6
			variation => N__('King\'s Indian: 4. e4 d6 5. g3 O-O 6. Bg2 Nc6'),
			moves => {
			},
		},
		'r1bq1rk1/pppnppbp/3p1np1/8/2PPP3/2N3P1/PP3PBP/R1BQK1NR w KQ' => {
			eco => 'E72',
			# TRANSLATORS: E72: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. g3 O-O 6. Bg2 Nbd7
			variation => N__('King\'s Indian: 4. e4 d6 5. g3 O-O 6. Bg2 Nbd7'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2p5/2PPP3/2N3P1/PP3PBP/R1BQK1NR w KQ' => {
			eco => 'E72',
			# TRANSLATORS: E72: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. g3 O-O 6. Bg2 c5
			variation => N__('King\'s Indian: 4. e4 d6 5. g3 O-O 6. Bg2 c5'),
			moves => {
			},
		},
		'rnbq1rk1/ppp2pbp/3p1np1/4p3/2PPP3/2N3P1/PP3PBP/R1BQK1NR w KQ' => {
			eco => 'E72',
			# TRANSLATORS: E72: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. g3 O-O 6. Bg2 e5
			variation => N__('King\'s Indian: 4. e4 d6 5. g3 O-O 6. Bg2 e5'),
			moves => {
				'g1e2' => 1,
			},
		},
		'rnbq1rk1/ppp2pbp/3p1np1/4p3/2PPP3/2N3P1/PP2NPBP/R1BQK2R b KQ' => {
			eco => 'E72',
			# TRANSLATORS: E72: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. g3 O-O 6. Bg2 e5 7. Nge2
			variation => N__('King\'s Indian: Pomar System'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bq1rk1/ppp2pbp/2np1np1/4p3/2PPP3/2N3P1/PP2NPBP/R1BQK2R w KQ' => {
			eco => 'E72',
			# TRANSLATORS: E72: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. g3 O-O 6. Bg2 e5 7. Nge2 Nc6
			variation => N__('King\'s Indian: Pomar System'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/2PPP3/2N5/PP2BPPP/R1BQK1NR b KQkq' => {
			eco => 'E73a',
			# TRANSLATORS: E73a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2
			variation => N__('King\'s Indian: 5. Be2'),
			moves => {
				'b8d7' => 1,
				'c7c5' => 1,
				'e7e5' => 1,
				'e8g8' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/3p1np1/2p5/2PPP3/2N5/PP2BPPP/R1BQK1NR w KQkq' => {
			eco => 'E73b',
			# TRANSLATORS: E73b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 c5
			variation => N__('King\'s Indian: 5. Be2 c5'),
			moves => {
			},
		},
		'rnbqk2r/ppp2pbp/3p1np1/4p3/2PPP3/2N5/PP2BPPP/R1BQK1NR w KQkq' => {
			eco => 'E73c',
			# TRANSLATORS: E73c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 e5
			variation => N__('King\'s Indian: 5. Be2 e5'),
			moves => {
				'd4d5' => 1,
			},
		},
		'rnbqk2r/ppp2pbp/3p1np1/3Pp3/2P1P3/2N5/PP2BPPP/R1BQK1NR b KQkq' => {
			eco => 'E73d',
			# TRANSLATORS: E73d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 e5 6. d5
			variation => N__('King\'s Indian: 5. Be2 e5 6. d5'),
			moves => {
			},
		},
		'r1bqk2r/pppnppbp/3p1np1/8/2PPP3/2N5/PP2BPPP/R1BQK1NR w KQkq' => {
			eco => 'E73e',
			# TRANSLATORS: E73e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 Nbd7
			variation => N__('King\'s Indian: 5. Be2 Nbd7'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PPP3/2N5/PP2BPPP/R1BQK1NR w KQ' => {
			eco => 'E73f',
			# TRANSLATORS: E73f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O
			variation => N__('King\'s Indian: 5. Be2 O-O'),
			moves => {
				'c1e3' => 1,
				'c1g5' => 1,
				'g2g4' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PPP1P1/2N5/PP2BP1P/R1BQK1NR b KQ' => {
			eco => 'E73g',
			# TRANSLATORS: E73g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. g4
			variation => N__('King\'s Indian: 5. Be2 O-O 6. g4'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PPP3/2N1B3/PP2BPPP/R2QK1NR b KQ' => {
			eco => 'E73h',
			# TRANSLATORS: E73h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Be3
			variation => N__('King\'s Indian: Semi-Averbakh System'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/6B1/2PPP3/2N5/PP2BPPP/R2QK1NR b KQ' => {
			eco => 'E73i',
			# TRANSLATORS: E73i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5
			variation => N__('King\'s Indian: Averbakh'),
			moves => {
				'b8a6' => 1,
				'b8d7' => 1,
				'c7c5' => 1,
				'c7c6' => 1,
				'h7h6' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/2pp1np1/6B1/2PPP3/2N5/PP2BPPP/R2QK1NR w KQ' => {
			eco => 'E73j',
			# TRANSLATORS: E73j: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c6
			variation => N__('King\'s Indian: Averbakh, 6... c6'),
			moves => {
				'd1d2' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/2pp1np1/6B1/2PPP3/2N5/PP1QBPPP/R3K1NR b KQ' => {
			eco => 'E73k',
			# TRANSLATORS: E73k: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c6 7. Qd2
			variation => N__('King\'s Indian: Averbakh, 6... c6 7. Qd2'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r1bq1rk1/pp1nppbp/2pp1np1/6B1/2PPP3/2N5/PP1QBPPP/R3K1NR w KQ' => {
			eco => 'E73l',
			# TRANSLATORS: E73l: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c6 7. Qd2 Nbd7
			variation => N__('King\'s Indian: Averbakh, 6... c6 7. Qd2 Nbd7'),
			moves => {
			},
		},
		'r1bq1rk1/pppnppbp/3p1np1/6B1/2PPP3/2N5/PP2BPPP/R2QK1NR w KQ' => {
			eco => 'E73m',
			# TRANSLATORS: E73m: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 Nbd7
			variation => N__('King\'s Indian: Averbakh, 6...Nbd7'),
			moves => {
				'd1d2' => 1,
			},
		},
		'r1bq1rk1/pppnppbp/3p1np1/6B1/2PPP3/2N5/PP1QBPPP/R3K1NR b KQ' => {
			eco => 'E73n',
			# TRANSLATORS: E73n: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 Nbd7 7. Qd2
			variation => N__('King\'s Indian: Averbakh, 6...Nbd7 7. Qd2'),
			moves => {
				'e7e5' => 1,
			},
		},
		'r1bq1rk1/pppn1pbp/3p1np1/4p1B1/2PPP3/2N5/PP1QBPPP/R3K1NR w KQ' => {
			eco => 'E73o',
			# TRANSLATORS: E73o: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 Nbd7 7. Qd2 e5
			variation => N__('King\'s Indian: Averbakh, 6...Nbd7 7. Qd2 e5'),
			moves => {
				'd4d5' => 1,
			},
		},
		'r1bq1rk1/pppn1pbp/3p1np1/3Pp1B1/2P1P3/2N5/PP1QBPPP/R3K1NR b KQ' => {
			eco => 'E73o',
			# TRANSLATORS: E73o: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 Nbd7 7. Qd2 e5 8. d5
			variation => N__('King\'s Indian: Averbakh, 6...Nbd7 7. Qd2 e5 8. d5'),
			moves => {
				'd7c5' => 1,
			},
		},
		'r1bq1rk1/ppp2pbp/3p1np1/2nPp1B1/2P1P3/2N5/PP1QBPPP/R3K1NR w KQ' => {
			eco => 'E73o',
			# TRANSLATORS: E73o: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 Nbd7 7. Qd2 e5 8. d5 Nc5
			variation => N__('King\'s Indian: Averbakh, 6...Nbd7 7. Qd2 e5 8. d5 Nc5'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1ppbp/n2p1np1/6B1/2PPP3/2N5/PP2BPPP/R2QK1NR w KQ' => {
			eco => 'E73p',
			# TRANSLATORS: E73p: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 Na6
			variation => N__('King\'s Indian: Averbakh, 6... Na6'),
			moves => {
				'd1d2' => 1,
				'h2h4' => 1,
			},
		},
		'r1bq1rk1/ppp1ppbp/n2p1np1/6B1/2PPP2P/2N5/PP2BPP1/R2QK1NR b KQ' => {
			eco => 'E73q',
			# TRANSLATORS: E73q: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 Na6 7. h4
			variation => N__('King\'s Indian: Averbakh, 6... Na6 7. h4'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1ppbp/n2p1np1/6B1/2PPP3/2N5/PP1QBPPP/R3K1NR b KQ' => {
			eco => 'E73r',
			# TRANSLATORS: E73r: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 Na6 7. Qd2
			variation => N__('King\'s Indian: Averbakh, 6... Na6 7. Qd2'),
			moves => {
				'e7e5' => 1,
			},
		},
		'r1bq1rk1/ppp2pbp/n2p1np1/4p1B1/2PPP3/2N5/PP1QBPPP/R3K1NR w KQ' => {
			eco => 'E73s',
			# TRANSLATORS: E73s: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 Na6 7. Qd2 e5
			variation => N__('King\'s Indian: Averbakh, 6... Na6 7. Qd2 e5'),
			moves => {
				'd4d5' => 1,
			},
		},
		'r1bq1rk1/ppp2pbp/n2p1np1/3Pp1B1/2P1P3/2N5/PP1QBPPP/R3K1NR b KQ' => {
			eco => 'E73s',
			# TRANSLATORS: E73s: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 Na6 7. Qd2 e5 8. d5
			variation => N__('King\'s Indian: Averbakh, 6... Na6 7. Qd2 e5 8. d5'),
			moves => {
				'c7c6' => 1,
				'd8e8' => 1,
			},
		},
		'r1bq1rk1/pp3pbp/n1pp1np1/3Pp1B1/2P1P3/2N5/PP1QBPPP/R3K1NR w KQ' => {
			eco => 'E73t',
			# TRANSLATORS: E73t: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 Na6 7. Qd2 e5 8. d5 c6
			variation => N__('King\'s Indian: Averbakh, 6... Na6 7. Qd2 e5 8. d5 c6'),
			moves => {
			},
		},
		'r1b1qrk1/ppp2pbp/n2p1np1/3Pp1B1/2P1P3/2N5/PP1QBPPP/R3K1NR w KQ' => {
			eco => 'E73u',
			# TRANSLATORS: E73u: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 Na6 7. Qd2 e5 8. d5 Qe8
			variation => N__('King\'s Indian: Averbakh, 6... Na6 7. Qd2 e5 8. d5 Qe8'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppb1/3p1npp/6B1/2PPP3/2N5/PP2BPPP/R2QK1NR w KQ' => {
			eco => 'E73v',
			# TRANSLATORS: E73v: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 h6
			variation => N__('King\'s Indian: Averbakh, 6... h6'),
			moves => {
				'g5e3' => 1,
			},
		},
		'rnbq1rk1/ppp1ppb1/3p1npp/8/2PPP3/2N1B3/PP2BPPP/R2QK1NR b KQ' => {
			eco => 'E73w',
			# TRANSLATORS: E73w: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 h6 7. Be3
			variation => N__('King\'s Indian: Averbakh, 6... h6 7. Be3'),
			moves => {
				'c7c5' => 1,
				'e7e5' => 1,
			},
		},
		'rnbq1rk1/pp2ppb1/3p1npp/2p5/2PPP3/2N1B3/PP2BPPP/R2QK1NR w KQ' => {
			eco => 'E73x',
			# TRANSLATORS: E73x: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 h6 7. Be3 c5
			variation => N__('King\'s Indian: Averbakh, 6... h6 7. Be3 c5'),
			moves => {
			},
		},
		'rnbq1rk1/ppp2pb1/3p1npp/4p3/2PPP3/2N1B3/PP2BPPP/R2QK1NR w KQ' => {
			eco => 'E73y',
			# TRANSLATORS: E73y: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 h6 7. Be3 e5
			variation => N__('King\'s Indian: Averbakh, 6... h6 7. Be3 e5'),
			moves => {
				'd4d5' => 1,
			},
		},
		'rnbq1rk1/ppp2pb1/3p1npp/3Pp3/2P1P3/2N1B3/PP2BPPP/R2QK1NR b KQ' => {
			eco => 'E73y',
			# TRANSLATORS: E73y: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 h6 7. Be3 e5 8. d5
			variation => N__('King\'s Indian: Averbakh, 6... h6 7. Be3 e5 8. d5'),
			moves => {
				'b8d7' => 1,
				'c7c6' => 1,
			},
		},
		'rnbq1rk1/pp3pb1/2pp1npp/3Pp3/2P1P3/2N1B3/PP2BPPP/R2QK1NR w KQ' => {
			eco => 'E73y',
			# TRANSLATORS: E73y: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 h6 7. Be3 e5 8. d5 c6
			variation => N__('King\'s Indian: Averbakh, 6... h6 7. Be3 e5 8. d5 c6'),
			moves => {
			},
		},
		'r1bq1rk1/pppn1pb1/3p1npp/3Pp3/2P1P3/2N1B3/PP2BPPP/R2QK1NR w KQ' => {
			eco => 'E73z',
			# TRANSLATORS: E73z: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 h6 7. Be3 e5 8. d5 Nbd7
			variation => N__('King\'s Indian: Averbakh, 6... h6 7. Be3 e5 8. d5 Nbd7'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2p3B1/2PPP3/2N5/PP2BPPP/R2QK1NR w KQ' => {
			eco => 'E74a',
			# TRANSLATORS: E74a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5
			variation => N__('King\'s Indian: Averbakh, 6... c5'),
			moves => {
				'd4c5' => 1,
				'd4d5' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2P3B1/2P1P3/2N5/PP2BPPP/R2QK1NR b KQ' => {
			eco => 'E74b',
			# TRANSLATORS: E74b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. dxc5
			variation => N__('King\'s Indian: Averbakh, 6... c5 7.dxc5'),
			moves => {
				'd8a5' => 1,
			},
		},
		'rnb2rk1/pp2ppbp/3p1np1/q1P3B1/2P1P3/2N5/PP2BPPP/R2QK1NR w KQ' => {
			eco => 'E74b',
			# TRANSLATORS: E74b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. dxc5 Qa5
			variation => N__('King\'s Indian: Averbakh, 6... c5 7.dxc5 Qa5'),
			moves => {
				'g5d2' => 1,
			},
		},
		'rnb2rk1/pp2ppbp/3p1np1/q1P5/2P1P3/2N5/PP1BBPPP/R2QK1NR b KQ' => {
			eco => 'E74b',
			# TRANSLATORS: E74b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. dxc5 Qa5 8. Bd2
			variation => N__('King\'s Indian: Averbakh, 6... c5 7.dxc5 Qa5'),
			moves => {
				'a5c5' => 1,
			},
		},
		'rnb2rk1/pp2ppbp/3p1np1/2q5/2P1P3/2N5/PP1BBPPP/R2QK1NR w KQ' => {
			eco => 'E74b',
			# TRANSLATORS: E74b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. dxc5 Qa5 8. Bd2 Qxc5
			variation => N__('King\'s Indian: Averbakh, 6... c5 7.dxc5 Qa5'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnb2rk1/pp2ppbp/3p1np1/2q5/2P1P3/2N2N2/PP1BBPPP/R2QK2R b KQ' => {
			eco => 'E74b',
			# TRANSLATORS: E74b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. dxc5 Qa5 8. Bd2 Qxc5 9. Nf3
			variation => N__('King\'s Indian: Averbakh, 6... c5 7.dxc5 Qa5'),
			moves => {
				'c8g4' => 1,
			},
		},
		'rn3rk1/pp2ppbp/3p1np1/2q5/2P1P1b1/2N2N2/PP1BBPPP/R2QK2R w KQ' => {
			eco => 'E74c',
			# TRANSLATORS: E74c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. dxc5 Qa5 8. Bd2 Qxc5 9. Nf3 Bg4
			variation => N__('King\'s Indian: Averbakh, 6... c5 7.dxc5 Qa5 8. Bd2 Qxc5 9. Nf3 Bg4'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2pP2B1/2P1P3/2N5/PP2BPPP/R2QK1NR b KQ' => {
			eco => 'E74d',
			# TRANSLATORS: E74d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. d5
			variation => N__('King\'s Indian: Averbakh, 6... c5 7. d5'),
			moves => {
				'a7a6' => 1,
				'b7b5' => 1,
				'd8a5' => 1,
				'e7e6' => 1,
				'h7h6' => 1,
			},
		},
		'rnb2rk1/pp2ppbp/3p1np1/q1pP2B1/2P1P3/2N5/PP2BPPP/R2QK1NR w KQ' => {
			eco => 'E74e',
			# TRANSLATORS: E74e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. d5 Qa5
			variation => N__('King\'s Indian: Averbakh, 6... c5 7. d5 Qa5'),
			moves => {
			},
		},
		'rnbq1rk1/p3ppbp/3p1np1/1ppP2B1/2P1P3/2N5/PP2BPPP/R2QK1NR w KQ' => {
			eco => 'E74f',
			# TRANSLATORS: E74f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. d5 b5
			variation => N__('King\'s Indian: Averbakh, 6... c5 7. d5 b5'),
			moves => {
				'c4b5' => 1,
			},
		},
		'rnbq1rk1/p3ppbp/3p1np1/1PpP2B1/4P3/2N5/PP2BPPP/R2QK1NR b KQ' => {
			eco => 'E74f',
			# TRANSLATORS: E74f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. d5 b5 8. cxb5
			variation => N__('King\'s Indian: Averbakh, 6... c5 7. d5 b5'),
			moves => {
				'a7a6' => 1,
			},
		},
		'rnbq1rk1/4ppbp/p2p1np1/1PpP2B1/4P3/2N5/PP2BPPP/R2QK1NR w KQ' => {
			eco => 'E74f',
			# TRANSLATORS: E74f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. d5 b5 8. cxb5 a6
			variation => N__('King\'s Indian: Averbakh, 6... c5 7. d5 b5'),
			moves => {
				'a2a4' => 1,
			},
		},
		'rnbq1rk1/4ppbp/p2p1np1/1PpP2B1/P3P3/2N5/1P2BPPP/R2QK1NR b KQ' => {
			eco => 'E74f',
			# TRANSLATORS: E74f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. d5 b5 8. cxb5 a6 9. a4
			variation => N__('King\'s Indian: Averbakh, 6... c5 7. d5 b5 8.cxb5 a6 9. a4'),
			moves => {
			},
		},
		'rnbq1rk1/1p2ppbp/p2p1np1/2pP2B1/2P1P3/2N5/PP2BPPP/R2QK1NR w KQ' => {
			eco => 'E74g',
			# TRANSLATORS: E74g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. d5 a6
			variation => N__('King\'s Indian: Averbakh, 6... c5 7. d5 a6'),
			moves => {
				'a2a4' => 1,
				'd1d2' => 1,
			},
		},
		'rnbq1rk1/1p2ppbp/p2p1np1/2pP2B1/2P1P3/2N5/PP1QBPPP/R3K1NR b KQ' => {
			eco => 'E74g',
			# TRANSLATORS: E74g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. d5 a6 8. Qd2
			variation => N__('King\'s Indian: Averbakh, 6... c5 7. d5 a6 8. Qd2'),
			moves => {
			},
		},
		'rnbq1rk1/1p2ppbp/p2p1np1/2pP2B1/P1P1P3/2N5/1P2BPPP/R2QK1NR b KQ' => {
			eco => 'E74h',
			# TRANSLATORS: E74h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. d5 a6 8. a4
			variation => N__('King\'s Indian: Averbakh, 6... c5 7. d5 a6 8. a4'),
			moves => {
				'd8a5' => 1,
			},
		},
		'rnb2rk1/1p2ppbp/p2p1np1/q1pP2B1/P1P1P3/2N5/1P2BPPP/R2QK1NR w KQ' => {
			eco => 'E74i',
			# TRANSLATORS: E74i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. d5 a6 8. a4 Qa5
			variation => N__('King\'s Indian: Averbakh, 6... c5 7. d5 a6 8. a4 Qa5'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppb1/3p1npp/2pP2B1/2P1P3/2N5/PP2BPPP/R2QK1NR w KQ' => {
			eco => 'E74j',
			# TRANSLATORS: E74j: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. d5 h6
			variation => N__('King\'s Indian: Averbakh, 6... c5 7. d5 h6'),
			moves => {
				'g5e3' => 1,
				'g5f4' => 1,
				'g5h4' => 1,
			},
		},
		'rnbq1rk1/pp2ppb1/3p1npp/2pP4/2P1P2B/2N5/PP2BPPP/R2QK1NR b KQ' => {
			eco => 'E74j',
			# TRANSLATORS: E74j: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. d5 h6 8. Bh4
			variation => N__('King\'s Indian: Averbakh, 6... c5 7. d5 h6 8. Bh4'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppb1/3p1npp/2pP4/2P1P3/2N1B3/PP2BPPP/R2QK1NR b KQ' => {
			eco => 'E74k',
			# TRANSLATORS: E74k: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. d5 h6 8. Be3
			variation => N__('King\'s Indian: Averbakh, 6... c5 7. d5 h6 8. Be3'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rnbq1rk1/pp3pb1/3ppnpp/2pP4/2P1P3/2N1B3/PP2BPPP/R2QK1NR w KQ' => {
			eco => 'E74l',
			# TRANSLATORS: E74l: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. d5 h6 8. Be3 e6
			variation => N__('King\'s Indian: Averbakh, 6... c5 7. d5 h6 8. Be3 e6'),
			moves => {
				'd1d2' => 1,
			},
		},
		'rnbq1rk1/pp3pb1/3ppnpp/2pP4/2P1P3/2N1B3/PP1QBPPP/R3K1NR b KQ' => {
			eco => 'E74m',
			# TRANSLATORS: E74m: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. d5 h6 8. Be3 e6 9. Qd2
			variation => N__('King\'s Indian: Averbakh, 6... c5 7. d5 h6 8. Be3 e6 9. Qd2'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppb1/3p1npp/2pP4/2P1PB2/2N5/PP2BPPP/R2QK1NR b KQ' => {
			eco => 'E74n',
			# TRANSLATORS: E74n: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. d5 h6 8. Bf4
			variation => N__('King\'s Indian: Averbakh, 6... c5 7. d5 h6 8. Bf4'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rnbq1rk1/pp3pb1/3ppnpp/2pP4/2P1PB2/2N5/PP2BPPP/R2QK1NR w KQ' => {
			eco => 'E74o',
			# TRANSLATORS: E74o: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. d5 h6 8. Bf4 e6
			variation => N__('King\'s Indian: Averbakh, 6... c5 7. d5 h6 8. Bf4 e6'),
			moves => {
			},
		},
		'rnbq1rk1/pp3pbp/3ppnp1/2pP2B1/2P1P3/2N5/PP2BPPP/R2QK1NR w KQ' => {
			eco => 'E75a',
			# TRANSLATORS: E75a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. d5 e6
			variation => N__('King\'s Indian: Averbakh, 7. d5 e6'),
			moves => {
				'd1d2' => 1,
				'g1f3' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3ppnp1/2pP2B1/2P1P3/2N2N2/PP2BPPP/R2QK2R b KQ' => {
			eco => 'E75b',
			# TRANSLATORS: E75b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. d5 e6 8. Nf3
			variation => N__('King\'s Indian: Averbakh, 7. d5 e6 8. Nf3'),
			moves => {
				'e6d5' => 1,
				'h7h6' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2pp2B1/2P1P3/2N2N2/PP2BPPP/R2QK2R w KQ' => {
			eco => 'E75b',
			# TRANSLATORS: E75b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. d5 e6 8. Nf3 exd5
			variation => N__('King\'s Indian: Averbakh, 7. d5 e6 8. Nf3 exd5'),
			moves => {
				'e4d5' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2pP2B1/2P5/2N2N2/PP2BPPP/R2QK2R b KQ' => {
			eco => 'E75b',
			# TRANSLATORS: E75b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. d5 e6 8. Nf3 exd5 9. exd5
			variation => N__('King\'s Indian: Averbakh, 7. d5 e6 8. Nf3 exd5 9.exd5'),
			moves => {
			},
		},
		'rnbq1rk1/pp3pb1/3ppnpp/2pP2B1/2P1P3/2N2N2/PP2BPPP/R2QK2R w KQ' => {
			eco => 'E75c',
			# TRANSLATORS: E75c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. d5 e6 8. Nf3 h6
			variation => N__('King\'s Indian: Averbakh, 7. d5 e6 8. Nf3 h6'),
			moves => {
				'g5d2' => 1,
				'g5e3' => 1,
				'g5f4' => 1,
				'g5h4' => 1,
			},
		},
		'rnbq1rk1/pp3pb1/3ppnpp/2pP4/2P1P3/2N2N2/PP1BBPPP/R2QK2R b KQ' => {
			eco => 'E75c',
			# TRANSLATORS: E75c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. d5 e6 8. Nf3 h6 9. Bd2
			variation => N__('King\'s Indian: Averbakh, 7. d5 e6 8. Nf3 h6 9. Bd2'),
			moves => {
			},
		},
		'rnbq1rk1/pp3pb1/3ppnpp/2pP4/2P1P3/2N1BN2/PP2BPPP/R2QK2R b KQ' => {
			eco => 'E75c',
			# TRANSLATORS: E75c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. d5 e6 8. Nf3 h6 9. Be3
			variation => N__('King\'s Indian: Averbakh, 7. d5 e6 8. Nf3 h6 9. Be3'),
			moves => {
			},
		},
		'rnbq1rk1/pp3pb1/3ppnpp/2pP4/2P1PB2/2N2N2/PP2BPPP/R2QK2R b KQ' => {
			eco => 'E75c',
			# TRANSLATORS: E75c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. d5 e6 8. Nf3 h6 9. Bf4
			variation => N__('King\'s Indian: Averbakh, 7. d5 e6 8. Nf3 h6 9. Bf4'),
			moves => {
			},
		},
		'rnbq1rk1/pp3pb1/3ppnpp/2pP4/2P1P2B/2N2N2/PP2BPPP/R2QK2R b KQ' => {
			eco => 'E75d',
			# TRANSLATORS: E75d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. d5 e6 8. Nf3 h6 9. Bh4
			variation => N__('King\'s Indian: Averbakh, 7. d5 e6 8. Nf3 h6 9. Bh4'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rnbq1rk1/pp3pb1/3p1npp/2pp4/2P1P2B/2N2N2/PP2BPPP/R2QK2R w KQ' => {
			eco => 'E75d',
			# TRANSLATORS: E75d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. d5 e6 8. Nf3 h6 9. Bh4 exd5
			variation => N__('King\'s Indian: Averbakh, 7. d5 e6 8. Nf3 h6 9. Bh4'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rnbq1rk1/pp3pb1/3p1n1p/2pP2p1/4P2B/2N2N2/PP2BPPP/R2QK2R w KQ' => {
			eco => 'E75e',
			# TRANSLATORS: E75e: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. Bg5 h6 10. Bh4 g5
			variation => N__('King\'s Indian: Averbakh, 7. d5 e6 8. Nf3 h6 9. Bh4 exd5 10.cxd5'),
			moves => {
				'h4g3' => 1,
			},
		},
		'rnbq1rk1/pp3pb1/3p1n1p/2pP2p1/4P3/2N2NB1/PP2BPPP/R2QK2R b KQ' => {
			eco => 'E75e',
			# TRANSLATORS: E75e: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. Bg5 h6 10. Bh4 g5 11. Bg3
			variation => N__('King\'s Indian: Averbakh, 7. d5 e6 8. Nf3 h6 9. Bh4 exd5 10.cxd5'),
			moves => {
				'f6h5' => 1,
			},
		},
		'rnbq1rk1/pp3pb1/3p3p/2pP2pn/4P3/2N2NB1/PP2BPPP/R2QK2R w KQ' => {
			eco => 'E75e',
			# TRANSLATORS: E75e: 1. d4 Nf6 2. c4 c5 3. d5 e6 4. Nc3 exd5 5. cxd5 d6 6. e4 g6 7. Nf3 Bg7 8. Be2 O-O 9. Bg5 h6 10. Bh4 g5 11. Bg3 Nh5
			variation => N__('King\'s Indian: Averbakh, 7. d5 e6 8. Nf3 h6 9. Bh4 exd5 10.cxd5'),
			moves => {
				'f3d2' => 1,
			},
		},
		'rnbq1rk1/pp3pb1/3p1npp/2pP4/4P2B/2N2N2/PP2BPPP/R2QK2R b KQ' => {
			eco => 'E75e',
			# TRANSLATORS: E75e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. d5 e6 8. Nf3 h6 9. Bh4 exd5 10. cxd5
			variation => N__('King\'s Indian: Averbakh, 7. d5 e6 8. Nf3 h6 9. Bh4 exd5 10.cxd5'),
			moves => {
				'g6g5' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3ppnp1/2pP2B1/2P1P3/2N5/PP1QBPPP/R3K1NR b KQ' => {
			eco => 'E75f',
			# TRANSLATORS: E75f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. d5 e6 8. Qd2
			variation => N__('King\'s Indian: Averbakh, 7. d5 e6 8. Qd2'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2pp2B1/2P1P3/2N5/PP1QBPPP/R3K1NR w KQ' => {
			eco => 'E75g',
			# TRANSLATORS: E75g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. d5 e6 8. Qd2 exd5
			variation => N__('King\'s Indian: Averbakh, 7. d5 e6 8. Qd2 exd5'),
			moves => {
				'e4d5' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2pP2B1/2P5/2N5/PP1QBPPP/R3K1NR b KQ' => {
			eco => 'E75g',
			# TRANSLATORS: E75g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. d5 e6 8. Qd2 exd5 9. exd5
			variation => N__('King\'s Indian: Averbakh, 7. d5 e6 8. Qd2 exd5 9.exd5'),
			moves => {
				'a7a6' => 1,
				'f8e8' => 1,
			},
		},
		'rnbq1rk1/1p3pbp/p2p1np1/2pP2B1/2P5/2N5/PP1QBPPP/R3K1NR w KQ' => {
			eco => 'E75h',
			# TRANSLATORS: E75h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. d5 e6 8. Qd2 exd5 9. exd5 a6
			variation => N__('King\'s Indian: Averbakh, 7. d5 e6 8. Qd2 exd5 9.exd5 a6'),
			moves => {
			},
		},
		'rnbqr1k1/pp3pbp/3p1np1/2pP2B1/2P5/2N5/PP1QBPPP/R3K1NR w KQ' => {
			eco => 'E75i',
			# TRANSLATORS: E75i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. d5 e6 8. Qd2 exd5 9. exd5 Re8
			variation => N__('King\'s Indian: Averbakh, 7. d5 e6 8. Qd2 exd5 9.exd5 Re8'),
			moves => {
				'g1f3' => 1,
			},
		},
		'rnbqr1k1/pp3pbp/3p1np1/2pP2B1/2P5/2N2N2/PP1QBPPP/R3K2R b KQ' => {
			eco => 'E75i',
			# TRANSLATORS: E75i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. d5 e6 8. Qd2 exd5 9. exd5 Re8 10. Nf3
			variation => N__('King\'s Indian: Averbakh, 7. d5 e6 8. Qd2 exd5 9.exd5 Re8 10. Nf3'),
			moves => {
				'c8g4' => 1,
			},
		},
		'rn1qr1k1/pp3pbp/3p1np1/2pP2B1/2P3b1/2N2N2/PP1QBPPP/R3K2R w KQ' => {
			eco => 'E75j',
			# TRANSLATORS: E75j: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Be2 O-O 6. Bg5 c5 7. d5 e6 8. Qd2 exd5 9. exd5 Re8 10. Nf3 Bg4
			variation => N__('King\'s Indian: Averbakh, 7. d5 e6 8. Qd2 exd5 9.exd5 Re8 10. Nf3 Bg4'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/2PPPP2/2N5/PP4PP/R1BQKBNR b KQkq' => {
			eco => 'E76a',
			# TRANSLATORS: E76a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4
			variation => N__('King\'s Indian: Four Pawns Attack'),
			moves => {
				'c7c5' => 1,
				'e8g8' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/3p1np1/2p5/2PPPP2/2N5/PP4PP/R1BQKBNR w KQkq' => {
			eco => 'E76b',
			# TRANSLATORS: E76b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 c5
			variation => N__('King\'s Indian: Four Pawns Attack, 5... c5'),
			moves => {
				'd4c5' => 1,
				'd4d5' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/3p1np1/2P5/2P1PP2/2N5/PP4PP/R1BQKBNR b KQkq' => {
			eco => 'E76b',
			# TRANSLATORS: E76b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 c5 6. dxc5
			variation => N__('King\'s Indian: Four Pawns Attack, Exchange'),
			moves => {
			},
		},
		'rnbqk2r/pp2ppbp/3p1np1/2pP4/2P1PP2/2N5/PP4PP/R1BQKBNR b KQkq' => {
			eco => 'E76c',
			# TRANSLATORS: E76c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 c5 6. d5
			variation => N__('King\'s Indian: Four Pawns Attack, 5... c5 6. d5'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PPPP2/2N5/PP4PP/R1BQKBNR w KQ' => {
			eco => 'E76d',
			# TRANSLATORS: E76d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O
			variation => N__('King\'s Indian: Four Pawns Attack, 5...O-O'),
			moves => {
				'f1e2' => 1,
				'g1f3' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PPPP2/2N2N2/PP4PP/R1BQKB1R b KQ' => {
			eco => 'E76e',
			# TRANSLATORS: E76e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Nf3
			variation => N__('King\'s Indian: Four Pawns Attack, 5...O-O 6. Nf3'),
			moves => {
				'b8a6' => 1,
				'c7c5' => 1,
				'c8g4' => 1,
			},
		},
		'rn1q1rk1/ppp1ppbp/3p1np1/8/2PPPPb1/2N2N2/PP4PP/R1BQKB1R w KQ' => {
			eco => 'E76e',
			# TRANSLATORS: E76e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Nf3 Bg4
			variation => N__('King\'s Indian: Four Pawns Attack, 6. Nf3 Bg4'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1ppbp/n2p1np1/8/2PPPP2/2N2N2/PP4PP/R1BQKB1R w KQ' => {
			eco => 'E76f',
			# TRANSLATORS: E76f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Nf3 Na6
			variation => N__('King\'s Indian: Four Pawns Attack, 6. Nf3 Na6'),
			moves => {
				'e4e5' => 1,
				'f1d3' => 1,
				'f1e2' => 1,
			},
		},
		'r1bq1rk1/ppp1ppbp/n2p1np1/4P3/2PP1P2/2N2N2/PP4PP/R1BQKB1R b KQ' => {
			eco => 'E76g',
			# TRANSLATORS: E76g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Nf3 Na6 7. e5
			variation => N__('King\'s Indian: Four Pawns Attack, 6. Nf3 Na6 7. e5'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1ppbp/n2p1np1/8/2PPPP2/2N2N2/PP2B1PP/R1BQK2R b KQ' => {
			eco => 'E76h',
			# TRANSLATORS: E76h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Nf3 Na6 7. Be2
			variation => N__('King\'s Indian: Four Pawns Attack, 6. Nf3 Na6 7. Be2'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1ppbp/n2p1np1/8/2PPPP2/2NB1N2/PP4PP/R1BQK2R b KQ' => {
			eco => 'E76i',
			# TRANSLATORS: E76i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Nf3 Na6 7. Bd3
			variation => N__('King\'s Indian: Four Pawns Attack, 6. Nf3 Na6 7. Bd3'),
			moves => {
				'e7e5' => 1,
			},
		},
		'r1bq1rk1/ppp2pbp/n2p1np1/4p3/2PPPP2/2NB1N2/PP4PP/R1BQK2R w KQ' => {
			eco => 'E76j',
			# TRANSLATORS: E76j: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Nf3 Na6 7. Bd3 e5
			variation => N__('King\'s Indian: Four Pawns Attack, 6. Nf3 Na6 7. Bd3 e5'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2p5/2PPPP2/2N2N2/PP4PP/R1BQKB1R w KQ' => {
			eco => 'E76k',
			# TRANSLATORS: E76k: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Nf3 c5
			variation => N__('King\'s Indian: Four Pawns Attack, 6. Nf3 c5'),
			moves => {
				'd4c5' => 1,
				'd4d5' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2P5/2P1PP2/2N2N2/PP4PP/R1BQKB1R b KQ' => {
			eco => 'E76l',
			# TRANSLATORS: E76l: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Nf3 c5 7. dxc5
			variation => N__('King\'s Indian: Four Pawns Attack, 6. Nf3 c5 7.dxc5'),
			moves => {
				'd8a5' => 1,
			},
		},
		'rnb2rk1/pp2ppbp/3p1np1/q1P5/2P1PP2/2N2N2/PP4PP/R1BQKB1R w KQ' => {
			eco => 'E76l',
			# TRANSLATORS: E76l: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Nf3 c5 7. dxc5 Qa5
			variation => N__('King\'s Indian: Four Pawns Attack, 6. Nf3 c5 7.dxc5'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rnb2rk1/pp2ppbp/3p1np1/q1P5/2P1PP2/2NB1N2/PP4PP/R1BQK2R b KQ' => {
			eco => 'E76l',
			# TRANSLATORS: E76l: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Nf3 c5 7. dxc5 Qa5 8. Bd3
			variation => N__('King\'s Indian: Four Pawns Attack, 6. Nf3 c5 7.dxc5'),
			moves => {
				'a5c5' => 1,
			},
		},
		'rnb2rk1/pp2ppbp/3p1np1/2q5/2P1PP2/2NB1N2/PP4PP/R1BQK2R w KQ' => {
			eco => 'E76l',
			# TRANSLATORS: E76l: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Nf3 c5 7. dxc5 Qa5 8. Bd3 Qxc5
			variation => N__('King\'s Indian: Four Pawns Attack, 6. Nf3 c5 7.dxc5'),
			moves => {
				'd1e2' => 1,
			},
		},
		'rnb2rk1/pp2ppbp/3p1np1/2q5/2P1PP2/2NB1N2/PP2Q1PP/R1B1K2R b KQ' => {
			eco => 'E76l',
			# TRANSLATORS: E76l: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Nf3 c5 7. dxc5 Qa5 8. Bd3 Qxc5 9. Qe2
			variation => N__('King\'s Indian: Four Pawns Attack, 6. Nf3 c5 7.dxc5'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1b2rk1/pp2ppbp/2np1np1/2q5/2P1PP2/2NB1N2/PP2Q1PP/R1B1K2R w KQ' => {
			eco => 'E76m',
			# TRANSLATORS: E76m: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Nf3 c5 7. dxc5 Qa5 8. Bd3 Qxc5 9. Qe2 Nc6
			variation => N__('King\'s Indian: Four Pawns Attack, 6. Nf3 c5 7.dxc5 Qa5 8. Bd3 Qxc5 9. Qe2 Nc6'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2pP4/2P1PP2/2N2N2/PP4PP/R1BQKB1R b KQ' => {
			eco => 'E76n',
			# TRANSLATORS: E76n: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Nf3 c5 7. d5
			variation => N__('King\'s Indian: Four Pawns Attack, 6. Nf3 c5 7. d5'),
			moves => {
				'a7a6' => 1,
				'b7b5' => 1,
				'e7e6' => 1,
			},
		},
		'rnbq1rk1/1p2ppbp/p2p1np1/2pP4/2P1PP2/2N2N2/PP4PP/R1BQKB1R w KQ' => {
			eco => 'E76o',
			# TRANSLATORS: E76o: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Nf3 c5 7. d5 a6
			variation => N__('King\'s Indian: Four Pawns Attack, 6. Nf3 c5 7. d5 a6'),
			moves => {
			},
		},
		'rnbq1rk1/p3ppbp/3p1np1/1ppP4/2P1PP2/2N2N2/PP4PP/R1BQKB1R w KQ' => {
			eco => 'E76p',
			# TRANSLATORS: E76p: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Nf3 c5 7. d5 b5
			variation => N__('King\'s Indian: Four Pawns Attack, 6. Nf3 c5 7. d5 b5'),
			moves => {
				'c4b5' => 1,
			},
		},
		'rnbq1rk1/p3ppbp/3p1np1/1PpP4/4PP2/2N2N2/PP4PP/R1BQKB1R b KQ' => {
			eco => 'E76p',
			# TRANSLATORS: E76p: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Nf3 c5 7. d5 b5 8. cxb5
			variation => N__('King\'s Indian: Four Pawns Attack, 6. Nf3 c5 7. d5 b5'),
			moves => {
				'a7a6' => 1,
			},
		},
		'rnbq1rk1/4ppbp/p2p1np1/1PpP4/4PP2/2N2N2/PP4PP/R1BQKB1R w KQ' => {
			eco => 'E76p',
			# TRANSLATORS: E76p: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Nf3 c5 7. d5 b5 8. cxb5 a6
			variation => N__('King\'s Indian: Four Pawns Attack, 6. Nf3 c5 7. d5 b5'),
			moves => {
				'a2a4' => 1,
			},
		},
		'rnbq1rk1/4ppbp/p2p1np1/1PpP4/P3PP2/2N2N2/1P4PP/R1BQKB1R b KQ' => {
			eco => 'E76q',
			# TRANSLATORS: E76q: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Nf3 c5 7. d5 b5 8. cxb5 a6 9. a4
			variation => N__('King\'s Indian: Four Pawns Attack, 6. Nf3 c5 7. d5 b5 8.cxb5 a6 9. a4'),
			moves => {
			},
		},
		'rnbq1rk1/pp3pbp/3ppnp1/2pP4/2P1PP2/2N2N2/PP4PP/R1BQKB1R w KQ' => {
			eco => 'E76r',
			# TRANSLATORS: E76r: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Nf3 c5 7. d5 e6
			variation => N__('King\'s Indian: Four Pawns Attack, 6. Nf3 c5 7. d5 e6'),
			moves => {
				'd5e6' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3pPnp1/2p5/2P1PP2/2N2N2/PP4PP/R1BQKB1R b KQ' => {
			eco => 'E76r',
			# TRANSLATORS: E76r: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Nf3 c5 7. d5 e6 8. dxe6
			variation => N__('King\'s Indian: Four Pawns Attack, 6. Nf3 c5 7. d5 e6 8.dxe6'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PPPP2/2N5/PP2B1PP/R1BQK1NR b KQ' => {
			eco => 'E77',
			# TRANSLATORS: E77: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Be2
			variation => N__('King\'s Indian: Four Pawns Attack, 6. Be2'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2p5/2PPPP2/2N5/PP2B1PP/R1BQK1NR w KQ' => {
			eco => 'E77',
			# TRANSLATORS: E77: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Be2 c5
			variation => N__('King\'s Indian: Four Pawns Attack, 6. Be2 c5'),
			moves => {
				'd4d5' => 1,
				'g1f3' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2pP4/2P1PP2/2N5/PP2B1PP/R1BQK1NR b KQ' => {
			eco => 'E77',
			# TRANSLATORS: E77: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Be2 c5 7. d5
			variation => N__('King\'s Indian: Four Pawns Attack, 6. Be2 c5 7. d5'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3ppnp1/2pP4/2P1PP2/2N5/PP2B1PP/R1BQK1NR w KQ' => {
			eco => 'E77',
			# TRANSLATORS: E77: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Be2 c5 7. d5 e6
			variation => N__('King\'s Indian: Four Pawns Attack, 6. Be2 c5 7. d5'),
			moves => {
				'd5e6' => 1,
				'g1f3' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3pPnp1/2p5/2P1PP2/2N5/PP2B1PP/R1BQK1NR b KQ' => {
			eco => 'E77',
			# TRANSLATORS: E77: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Be2 c5 7. d5 e6 8. dxe6
			variation => N__('King\'s Indian: Four Pawns Attack, 6. Be2 c5 7. d5'),
			moves => {
				'f7e6' => 1,
			},
		},
		'rnbq1rk1/pp4bp/3ppnp1/2p5/2P1PP2/2N5/PP2B1PP/R1BQK1NR w KQ' => {
			eco => 'E77',
			# TRANSLATORS: E77: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Be2 c5 7. d5 e6 8. dxe6 fxe6
			variation => N__('King\'s Indian: Four Pawns Attack, 6. Be2 c5 7. d5'),
			moves => {
				'g2g4' => 1,
			},
		},
		'rnbq1rk1/pp4bp/3ppnp1/2p5/2P1PPP1/2N5/PP2B2P/R1BQK1NR b KQ' => {
			eco => 'E77',
			# TRANSLATORS: E77: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Be2 c5 7. d5 e6 8. dxe6 fxe6 9. g4
			variation => N__('King\'s Indian: Four Pawns Attack, 6. Be2 c5 7. d5'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bq1rk1/pp4bp/2nppnp1/2p5/2P1PPP1/2N5/PP2B2P/R1BQK1NR w KQ' => {
			eco => 'E77',
			# TRANSLATORS: E77: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Be2 c5 7. d5 e6 8. dxe6 fxe6 9. g4 Nc6
			variation => N__('King\'s Indian: Four Pawns Attack, 6. Be2 c5 7. d5'),
			moves => {
				'h2h4' => 1,
			},
		},
		'r1bq1rk1/pp4bp/2nppnp1/2p5/2P1PPPP/2N5/PP2B3/R1BQK1NR b KQ' => {
			eco => 'E77',
			# TRANSLATORS: E77: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Be2 c5 7. d5 e6 8. dxe6 fxe6 9. g4 Nc6 10. h4
			variation => N__('King\'s Indian: Four Pawns Attack, Six Pawns line'),
			moves => {
			},
		},
		'rnbq1rk1/pp3pbp/3ppnp1/2pP4/2P1PP2/2N2N2/PP2B1PP/R1BQK2R b KQ' => {
			eco => 'E77',
			# TRANSLATORS: E77: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Be2 c5 7. d5 e6 8. Nf3
			variation => N__('King\'s Indian: Four Pawns Attack, 6. Be2 c5 7. d5 e6 8. Nf3'),
			moves => {
				'e6d5' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2pp4/2P1PP2/2N2N2/PP2B1PP/R1BQK2R w KQ' => {
			eco => 'E77',
			# TRANSLATORS: E77: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Be2 c5 7. d5 e6 8. Nf3 exd5
			variation => N__('King\'s Indian: Four Pawns Attack, 6. Be2 c5 7. d5 e6 8. Nf3'),
			moves => {
				'e4d5' => 1,
				'e4e5' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2pP4/2P2P2/2N2N2/PP2B1PP/R1BQK2R b KQ' => {
			eco => 'E77',
			# TRANSLATORS: E77: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Be2 c5 7. d5 e6 8. Nf3 exd5 9. exd5
			variation => N__('King\'s Indian: Four Pawns Attack, 6. Be2 c5 7. d5 e6 8. Nf3 exd5 9.exd5'),
			moves => {
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2ppP3/2P2P2/2N2N2/PP2B1PP/R1BQK2R b KQ' => {
			eco => 'E77',
			# TRANSLATORS: E77: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Be2 c5 7. d5 e6 8. Nf3 exd5 9. e5
			variation => N__('King\'s Indian: Four Pawns Attack, Florentine Gambit'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2p5/2PPPP2/2N2N2/PP2B1PP/R1BQK2R b KQ' => {
			eco => 'E78',
			# TRANSLATORS: E78: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Be2 c5 7. Nf3
			variation => N__('King\'s Indian: Four Pawns Attack, 7. Nf3'),
			moves => {
				'c5d4' => 1,
				'c8g4' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/8/2PpPP2/2N2N2/PP2B1PP/R1BQK2R w KQ' => {
			eco => 'E78',
			# TRANSLATORS: E78: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Be2 c5 7. Nf3 cxd4
			variation => N__('King\'s Indian: Four Pawns Attack, 7. Nf3 cxd4'),
			moves => {
				'f3d4' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/8/2PNPP2/2N5/PP2B1PP/R1BQK2R b KQ' => {
			eco => 'E78',
			# TRANSLATORS: E78: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Be2 c5 7. Nf3 cxd4 8. Nxd4
			variation => N__('King\'s Indian: Four Pawns Attack, 7. Nf3 cxd4'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/8/2PNPP2/2N5/PP2B1PP/R1BQK2R w KQ' => {
			eco => 'E78',
			# TRANSLATORS: E78: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Be2 c5 7. Nf3 cxd4 8. Nxd4 Nc6
			variation => N__('King\'s Indian: Four Pawns Attack, 7. Nf3 cxd4'),
			moves => {
				'c1e3' => 1,
			},
		},
		'rn1q1rk1/pp2ppbp/3p1np1/2p5/2PPPPb1/2N2N2/PP2B1PP/R1BQK2R w KQ' => {
			eco => 'E78',
			# TRANSLATORS: E78: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Be2 c5 7. Nf3 Bg4
			variation => N__('King\'s Indian: Four Pawns Attack, 7. Nf3 Bg4'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/8/2PNPP2/2N1B3/PP2B1PP/R2QK2R b KQ' => {
			eco => 'E79a',
			# TRANSLATORS: E79a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Be2 c5 7. Nf3 cxd4 8. Nxd4 Nc6 9. Be3
			variation => N__('King\'s Indian: Four Pawns Attack, Main Line'),
			moves => {
				'c6d4' => 1,
				'c8d7' => 1,
				'c8g4' => 1,
				'f6g4' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/3p1np1/8/2PnPP2/2N1B3/PP2B1PP/R2QK2R w KQ' => {
			eco => 'E79b',
			# TRANSLATORS: E79b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Be2 c5 7. Nf3 cxd4 8. Nxd4 Nc6 9. Be3 Nxd4
			variation => N__('King\'s Indian: Four Pawns Attack, Main Line, 9...Nxd4'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/2np2p1/8/2PNPPn1/2N1B3/PP2B1PP/R2QK2R w KQ' => {
			eco => 'E79c',
			# TRANSLATORS: E79c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Be2 c5 7. Nf3 cxd4 8. Nxd4 Nc6 9. Be3 Ng4
			variation => N__('King\'s Indian: Four Pawns Attack, Main Line, 9... Ng4'),
			moves => {
			},
		},
		'r2q1rk1/pp2ppbp/2np1np1/8/2PNPPb1/2N1B3/PP2B1PP/R2QK2R w KQ' => {
			eco => 'E79d',
			# TRANSLATORS: E79d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Be2 c5 7. Nf3 cxd4 8. Nxd4 Nc6 9. Be3 Bg4
			variation => N__('King\'s Indian: Four Pawns Attack, Main Line, 9... Bg4'),
			moves => {
			},
		},
		'r2q1rk1/pp1bppbp/2np1np1/8/2PNPP2/2N1B3/PP2B1PP/R2QK2R w KQ' => {
			eco => 'E79e',
			# TRANSLATORS: E79e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Be2 c5 7. Nf3 cxd4 8. Nxd4 Nc6 9. Be3 Bd7
			variation => N__('King\'s Indian: Four Pawns Attack, Main Line, 9... Bd7'),
			moves => {
				'd1d2' => 1,
				'e1g1' => 1,
			},
		},
		'r2q1rk1/pp1bppbp/2np1np1/8/2PNPP2/2N1B3/PP1QB1PP/R3K2R b KQ' => {
			eco => 'E79e',
			# TRANSLATORS: E79e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Be2 c5 7. Nf3 cxd4 8. Nxd4 Nc6 9. Be3 Bd7 10. Qd2
			variation => N__('King\'s Indian: Four Pawns Attack, Main Line, 9... Bd7 10. Qd2'),
			moves => {
			},
		},
		'r2q1rk1/pp1bppbp/2np1np1/8/2PNPP2/2N1B3/PP2B1PP/R2Q1RK1 b -' => {
			eco => 'E79f',
			# TRANSLATORS: E79f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f4 O-O 6. Be2 c5 7. Nf3 cxd4 8. Nxd4 Nc6 9. Be3 Bd7 10. O-O
			variation => N__('King\'s Indian: Four Pawns Attack, Main Line, 9... Bd7 10.O-O'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/2PPP3/2N2P2/PP4PP/R1BQKBNR b KQkq' => {
			eco => 'E80a',
			# TRANSLATORS: E80a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3
			variation => N__('King\'s Indian: Sämisch Variation'),
			moves => {
				'a7a6' => 1,
				'b8a6' => 1,
				'b8c6' => 1,
				'b8d7' => 1,
				'c7c5' => 1,
				'c7c6' => 1,
				'e7e5' => 1,
				'e8g8' => 1,
			},
		},
		'r1bqk2r/ppp1ppbp/n2p1np1/8/2PPP3/2N2P2/PP4PP/R1BQKBNR w KQkq' => {
			eco => 'E80b',
			# TRANSLATORS: E80b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 Na6
			variation => N__('King\'s Indian: Sämisch, 5... Na6'),
			moves => {
			},
		},
		'r1bqk2r/ppp1ppbp/2np1np1/8/2PPP3/2N2P2/PP4PP/R1BQKBNR w KQkq' => {
			eco => 'E80c',
			# TRANSLATORS: E80c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 Nc6
			variation => N__('King\'s Indian: Sämisch, 5... Nc6'),
			moves => {
			},
		},
		'r1bqk2r/pppnppbp/3p1np1/8/2PPP3/2N2P2/PP4PP/R1BQKBNR w KQkq' => {
			eco => 'E80d',
			# TRANSLATORS: E80d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 Nbd7
			variation => N__('King\'s Indian: Sämisch, 5...Nbd7'),
			moves => {
			},
		},
		'rnbqk2r/ppp2pbp/3p1np1/4p3/2PPP3/2N2P2/PP4PP/R1BQKBNR w KQkq' => {
			eco => 'E80e',
			# TRANSLATORS: E80e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 e5
			variation => N__('King\'s Indian: Sämisch, 5... e5'),
			moves => {
				'd4d5' => 1,
				'g1e2' => 1,
			},
		},
		'rnbqk2r/ppp2pbp/3p1np1/4p3/2PPP3/2N2P2/PP2N1PP/R1BQKB1R b KQkq' => {
			eco => 'E80f',
			# TRANSLATORS: E80f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 e5 6. Nge2
			variation => N__('King\'s Indian: Sämisch, 5... e5 6.Nge2'),
			moves => {
			},
		},
		'rnbqk2r/ppp2pbp/3p1np1/3Pp3/2P1P3/2N2P2/PP4PP/R1BQKBNR b KQkq' => {
			eco => 'E80g',
			# TRANSLATORS: E80g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 e5 6. d5
			variation => N__('King\'s Indian: Sämisch, 5... e5 6. d5'),
			moves => {
			},
		},
		'rnbqk2r/pp2ppbp/3p1np1/2p5/2PPP3/2N2P2/PP4PP/R1BQKBNR w KQkq' => {
			eco => 'E80h',
			# TRANSLATORS: E80h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 c5
			variation => N__('King\'s Indian: Sämisch, 5... c5'),
			moves => {
				'd4c5' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/3p1np1/2P5/2P1P3/2N2P2/PP4PP/R1BQKBNR b KQkq' => {
			eco => 'E80h',
			# TRANSLATORS: E80h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 c5 6. dxc5
			variation => N__('King\'s Indian: Sämisch, 5... c5'),
			moves => {
				'd6c5' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/5np1/2p5/2P1P3/2N2P2/PP4PP/R1BQKBNR w KQkq' => {
			eco => 'E80h',
			# TRANSLATORS: E80h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 c5 6. dxc5 dxc5
			variation => N__('King\'s Indian: Sämisch, 5... c5'),
			moves => {
				'd1d8' => 1,
			},
		},
		'rnbQk2r/pp2ppbp/5np1/2p5/2P1P3/2N2P2/PP4PP/R1B1KBNR b KQkq' => {
			eco => 'E80h',
			# TRANSLATORS: E80h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 c5 6. dxc5 dxc5 7. Qxd8+
			variation => N__('King\'s Indian: Sämisch, 5... c5'),
			moves => {
				'e8d8' => 1,
			},
		},
		'rnbk3r/pp2ppbp/5np1/2p5/2P1P3/2N2P2/PP4PP/R1B1KBNR w KQ' => {
			eco => 'E80i',
			# TRANSLATORS: E80i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 c5 6. dxc5 dxc5 7. Qxd8+ Kxd8
			variation => N__('King\'s Indian: Sämisch, 5... c5 Queenswap'),
			moves => {
			},
		},
		'rnbqk2r/1pp1ppbp/p2p1np1/8/2PPP3/2N2P2/PP4PP/R1BQKBNR w KQkq' => {
			eco => 'E80j',
			# TRANSLATORS: E80j: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 a6
			variation => N__('King\'s Indian: Sämisch, 5... a6'),
			moves => {
				'c1e3' => 1,
			},
		},
		'rnbqk2r/1pp1ppbp/p2p1np1/8/2PPP3/2N1BP2/PP4PP/R2QKBNR b KQkq' => {
			eco => 'E80k',
			# TRANSLATORS: E80k: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 a6 6. Be3
			variation => N__('King\'s Indian: Sämisch, 5... a6 6. Be3'),
			moves => {
			},
		},
		'rnbqk2r/pp2ppbp/2pp1np1/8/2PPP3/2N2P2/PP4PP/R1BQKBNR w KQkq' => {
			eco => 'E80l',
			# TRANSLATORS: E80l: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 c6
			variation => N__('King\'s Indian: Sämisch, 5... c6'),
			moves => {
				'c1e3' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/2pp1np1/8/2PPP3/2N1BP2/PP4PP/R2QKBNR b KQkq' => {
			eco => 'E80m',
			# TRANSLATORS: E80m: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 c6 6. Be3
			variation => N__('King\'s Indian: Sämisch, 5... c6 6. Be3'),
			moves => {
				'a7a6' => 1,
			},
		},
		'rnbqk2r/1p2ppbp/p1pp1np1/8/2PPP3/2N1BP2/PP4PP/R2QKBNR w KQkq' => {
			eco => 'E80n',
			# TRANSLATORS: E80n: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 c6 6. Be3 a6
			variation => N__('King\'s Indian: Sämisch, 5... c6 6. Be3 a6'),
			moves => {
				'a2a4' => 1,
				'f1d3' => 1,
			},
		},
		'rnbqk2r/1p2ppbp/p1pp1np1/8/P1PPP3/2N1BP2/1P4PP/R2QKBNR b KQkq' => {
			eco => 'E80o',
			# TRANSLATORS: E80o: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 c6 6. Be3 a6 7. a4
			variation => N__('King\'s Indian: Sämisch, 5... c6 6. Be3 a6 7. a4'),
			moves => {
			},
		},
		'rnbqk2r/1p2ppbp/p1pp1np1/8/2PPP3/2NBBP2/PP4PP/R2QK1NR b KQkq' => {
			eco => 'E80p',
			# TRANSLATORS: E80p: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 c6 6. Be3 a6 7. Bd3
			variation => N__('King\'s Indian: Sämisch, 5... c6 6. Be3 a6 7. Bd3'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PPP3/2N2P2/PP4PP/R1BQKBNR w KQ' => {
			eco => 'E81a',
			# TRANSLATORS: E81a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O
			variation => N__('King\'s Indian: Sämisch, 5...O-O'),
			moves => {
				'c1e3' => 1,
				'c1g5' => 1,
				'g1e2' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PPP3/2N2P2/PP2N1PP/R1BQKB1R b KQ' => {
			eco => 'E81b',
			# TRANSLATORS: E81b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Nge2
			variation => N__('King\'s Indian: Sämisch, 5...O-O 6.Nge2'),
			moves => {
				'c7c5' => 1,
				'e7e5' => 1,
			},
		},
		'rnbq1rk1/ppp2pbp/3p1np1/4p3/2PPP3/2N2P2/PP2N1PP/R1BQKB1R w KQ' => {
			eco => 'E81c',
			# TRANSLATORS: E81c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Nge2 e5
			variation => N__('King\'s Indian: Sämisch, 5...O-O 6.Nge2 e5'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2p5/2PPP3/2N2P2/PP2N1PP/R1BQKB1R w KQ' => {
			eco => 'E81d',
			# TRANSLATORS: E81d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Nge2 c5
			variation => N__('King\'s Indian: Sämisch, 5...O-O 6.Nge2 c5'),
			moves => {
				'd4d5' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2pP4/2P1P3/2N2P2/PP2N1PP/R1BQKB1R b KQ' => {
			eco => 'E81d',
			# TRANSLATORS: E81d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Nge2 c5 7. d5
			variation => N__('King\'s Indian: Sämisch, 5...O-O 6.Nge2 c5 7. d5'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/6B1/2PPP3/2N2P2/PP4PP/R2QKBNR b KQ' => {
			eco => 'E81e',
			# TRANSLATORS: E81e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Bg5
			variation => N__('King\'s Indian: Sämisch, 5...O-O 6. Bg5'),
			moves => {
				'a7a6' => 1,
				'b8c6' => 1,
				'c7c5' => 1,
			},
		},
		'r1bq1rk1/ppp1ppbp/2np1np1/6B1/2PPP3/2N2P2/PP4PP/R2QKBNR w KQ' => {
			eco => 'E81f',
			# TRANSLATORS: E81f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Bg5 Nc6
			variation => N__('King\'s Indian: Sämisch, 5...O-O 6. Bg5 Nc6'),
			moves => {
			},
		},
		'rnbq1rk1/1pp1ppbp/p2p1np1/6B1/2PPP3/2N2P2/PP4PP/R2QKBNR w KQ' => {
			eco => 'E81g',
			# TRANSLATORS: E81g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Bg5 a6
			variation => N__('King\'s Indian: Sämisch, 5...O-O 6. Bg5 a6'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2p3B1/2PPP3/2N2P2/PP4PP/R2QKBNR w KQ' => {
			eco => 'E81h',
			# TRANSLATORS: E81h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Bg5 c5
			variation => N__('King\'s Indian: Sämisch, 5...O-O 6. Bg5 c5'),
			moves => {
				'd4d5' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2pP2B1/2P1P3/2N2P2/PP4PP/R2QKBNR b KQ' => {
			eco => 'E81h',
			# TRANSLATORS: E81h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Bg5 c5 7. d5
			variation => N__('King\'s Indian: Sämisch, 5...O-O 6. Bg5 c5 7. d5'),
			moves => {
				'a7a6' => 1,
				'e7e6' => 1,
				'h7h6' => 1,
			},
		},
		'rnbq1rk1/1p2ppbp/p2p1np1/2pP2B1/2P1P3/2N2P2/PP4PP/R2QKBNR w KQ' => {
			eco => 'E81h',
			# TRANSLATORS: E81h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Bg5 c5 7. d5 a6
			variation => N__('King\'s Indian: Sämisch, 5...O-O 6. Bg5 c5 7. d5 a6'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppb1/3p1npp/2pP2B1/2P1P3/2N2P2/PP4PP/R2QKBNR w KQ' => {
			eco => 'E81h',
			# TRANSLATORS: E81h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Bg5 c5 7. d5 h6
			variation => N__('King\'s Indian: Sämisch, 5...O-O 6. Bg5 c5 7. d5 h6'),
			moves => {
			},
		},
		'rnbq1rk1/pp3pbp/3ppnp1/2pP2B1/2P1P3/2N2P2/PP4PP/R2QKBNR w KQ' => {
			eco => 'E81i',
			# TRANSLATORS: E81i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Bg5 c5 7. d5 e6
			variation => N__('King\'s Indian: Sämisch, 5...O-O 6. Bg5 c5 7. d5 e6'),
			moves => {
				'd1d2' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3ppnp1/2pP2B1/2P1P3/2N2P2/PP1Q2PP/R3KBNR b KQ' => {
			eco => 'E81i',
			# TRANSLATORS: E81i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Bg5 c5 7. d5 e6 8. Qd2
			variation => N__('King\'s Indian: Sämisch, 5...O-O 6. Bg5 c5 7. d5 e6 8. Qd2'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PPP3/2N1BP2/PP4PP/R2QKBNR b KQ' => {
			eco => 'E81j',
			# TRANSLATORS: E81j: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3
			variation => N__('King\'s Indian: Sämisch, 5...O-O 6. Be3'),
			moves => {
				'a7a6' => 1,
				'b7b6' => 1,
				'b8c6' => 1,
				'b8d7' => 1,
				'c7c5' => 1,
				'c7c6' => 1,
				'e7e5' => 1,
			},
		},
		'rnbq1rk1/1pp1ppbp/p2p1np1/8/2PPP3/2N1BP2/PP4PP/R2QKBNR w KQ' => {
			eco => 'E81k',
			# TRANSLATORS: E81k: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 a6
			variation => N__('King\'s Indian: Sämisch, 5...O-O 6. Be3 a6'),
			moves => {
				'd1d2' => 1,
			},
		},
		'rnbq1rk1/1pp1ppbp/p2p1np1/8/2PPP3/2N1BP2/PP1Q2PP/R3KBNR b KQ' => {
			eco => 'E81k',
			# TRANSLATORS: E81k: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 a6 7. Qd2
			variation => N__('King\'s Indian: Sämisch, 5...O-O 6. Be3 a6 7. Qd2'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/2pp1np1/8/2PPP3/2N1BP2/PP4PP/R2QKBNR w KQ' => {
			eco => 'E81l',
			# TRANSLATORS: E81l: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 c6
			variation => N__('King\'s Indian: Sämisch, 5...O-O 6. Be3 c6'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/2pp1np1/8/2PPP3/2NBBP2/PP4PP/R2QK1NR b KQ' => {
			eco => 'E81l',
			# TRANSLATORS: E81l: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 c6 7. Bd3
			variation => N__('King\'s Indian: Sämisch, 5...O-O 6. Be3 c6'),
			moves => {
				'a7a6' => 1,
			},
		},
		'rnbq1rk1/1p2ppbp/p1pp1np1/8/2PPP3/2NBBP2/PP4PP/R2QK1NR w KQ' => {
			eco => 'E81l',
			# TRANSLATORS: E81l: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 c6 7. Bd3 a6
			variation => N__('King\'s Indian: Sämisch, Byrne Variation'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2p5/2PPP3/2N1BP2/PP4PP/R2QKBNR w KQ' => {
			eco => 'E81m',
			# TRANSLATORS: E81m: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 c5
			variation => N__('King\'s Indian: Sämisch, 5...O-O 6. Be3 c5'),
			moves => {
				'd4c5' => 1,
				'd4d5' => 1,
				'g1e2' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2pP4/2P1P3/2N1BP2/PP4PP/R2QKBNR b KQ' => {
			eco => 'E81m',
			# TRANSLATORS: E81m: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 c5 7. d5
			variation => N__('King\'s Indian: Sämisch, 5...O-O 6. Be3 c5 7. d5'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2P5/2P1P3/2N1BP2/PP4PP/R2QKBNR b KQ' => {
			eco => 'E81n',
			# TRANSLATORS: E81n: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 c5 7. dxc5
			variation => N__('King\'s Indian: Sämisch, 5...O-O 6. Be3 c5 7.dxc5'),
			moves => {
				'd6c5' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/5np1/2p5/2P1P3/2N1BP2/PP4PP/R2QKBNR w KQ' => {
			eco => 'E81n',
			# TRANSLATORS: E81n: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 c5 7. dxc5 dxc5
			variation => N__('King\'s Indian: Sämisch, 5...O-O 6. Be3 c5 7.dxc5'),
			moves => {
				'd1d8' => 1,
			},
		},
		'rnbQ1rk1/pp2ppbp/5np1/2p5/2P1P3/2N1BP2/PP4PP/R3KBNR b KQ' => {
			eco => 'E81n',
			# TRANSLATORS: E81n: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 c5 7. dxc5 dxc5 8. Qxd8
			variation => N__('King\'s Indian: Sämisch, 5...O-O 6. Be3 c5 Queenswap'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2p5/2PPP3/2N1BP2/PP2N1PP/R2QKB1R b KQ' => {
			eco => 'E81o',
			# TRANSLATORS: E81o: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 c5 7. Nge2
			variation => N__('King\'s Indian: Sämisch, 5...O-O 6. Be3 c5 7.Nge2'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/2p5/2PPP3/2N1BP2/PP2N1PP/R2QKB1R w KQ' => {
			eco => 'E81o',
			# TRANSLATORS: E81o: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 c5 7. Nge2 Nc6
			variation => N__('King\'s Indian: Sämisch, 5...O-O 6. Be3 c5 7.Nge2 Nc6'),
			moves => {
				'd4d5' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/2pP4/2P1P3/2N1BP2/PP2N1PP/R2QKB1R b KQ' => {
			eco => 'E81p',
			# TRANSLATORS: E81p: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 c5 7. Nge2 Nc6 8. d5
			variation => N__('King\'s Indian: Sämisch, 5...O-O 6. Be3 c5 7.Nge2 Nc6 8. d5'),
			moves => {
			},
		},
		'r1bq1rk1/pppnppbp/3p1np1/8/2PPP3/2N1BP2/PP4PP/R2QKBNR w KQ' => {
			eco => 'E81q',
			# TRANSLATORS: E81q: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nbd7
			variation => N__('King\'s Indian: Sämisch, 5...O-O 6. Be3 Nbd7'),
			moves => {
				'd1d2' => 1,
			},
		},
		'r1bq1rk1/pppnppbp/3p1np1/8/2PPP3/2N1BP2/PP1Q2PP/R3KBNR b KQ' => {
			eco => 'E81r',
			# TRANSLATORS: E81r: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nbd7 7. Qd2
			variation => N__('King\'s Indian: Sämisch, 5...O-O 6. Be3 Nbd7 7. Qd2'),
			moves => {
				'c7c5' => 1,
			},
		},
		'r1bq1rk1/pp1nppbp/3p1np1/2p5/2PPP3/2N1BP2/PP1Q2PP/R3KBNR w KQ' => {
			eco => 'E81s',
			# TRANSLATORS: E81s: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nbd7 7. Qd2 c5
			variation => N__('King\'s Indian: Sämisch, 5...O-O 6. Be3 Nbd7 7. Qd2 c5'),
			moves => {
				'd4d5' => 1,
				'g1e2' => 1,
			},
		},
		'r1bq1rk1/pp1nppbp/3p1np1/2pP4/2P1P3/2N1BP2/PP1Q2PP/R3KBNR b KQ' => {
			eco => 'E81s',
			# TRANSLATORS: E81s: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nbd7 7. Qd2 c5 8. d5
			variation => N__('King\'s Indian: Sämisch, 5...O-O 6. Be3 Nbd7 7. Qd2 c5 8. d5'),
			moves => {
			},
		},
		'r1bq1rk1/pp1nppbp/3p1np1/2p5/2PPP3/2N1BP2/PP1QN1PP/R3KB1R b KQ' => {
			eco => 'E81t',
			# TRANSLATORS: E81t: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nbd7 7. Qd2 c5 8. Nge2
			variation => N__('King\'s Indian: Sämisch, 5...O-O 6. Be3 Nbd7 7. Qd2 c5 8.Nge2'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r1bq1rk1/1p1nppbp/p2p1np1/2p5/2PPP3/2N1BP2/PP1QN1PP/R3KB1R w KQ' => {
			eco => 'E81t',
			# TRANSLATORS: E81t: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nbd7 7. Qd2 c5 8. Nge2 a6
			variation => N__('King\'s Indian: Sämisch, 5...O-O 6. Be3 Nbd7 7. Qd2 c5 8.Nge2 a6'),
			moves => {
			},
		},
		'rnbq1rk1/p1p1ppbp/1p1p1np1/8/2PPP3/2N1BP2/PP4PP/R2QKBNR w KQ' => {
			eco => 'E82a',
			# TRANSLATORS: E82a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 b6
			variation => N__('King\'s Indian: Sämisch, Fianchetto'),
			moves => {
				'd1d2' => 1,
				'f1d3' => 1,
			},
		},
		'rnbq1rk1/p1p1ppbp/1p1p1np1/8/2PPP3/2N1BP2/PP1Q2PP/R3KBNR b KQ' => {
			eco => 'E82b',
			# TRANSLATORS: E82b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 b6 7. Qd2
			variation => N__('King\'s Indian: Sämisch, Fianchetto, 7. Qd2'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbq1rk1/p3ppbp/1p1p1np1/2p5/2PPP3/2N1BP2/PP1Q2PP/R3KBNR w KQ' => {
			eco => 'E82b',
			# TRANSLATORS: E82b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 b6 7. Qd2 c5
			variation => N__('King\'s Indian: Sämisch, Fianchetto, 7. Qd2'),
			moves => {
				'd4d5' => 1,
			},
		},
		'rnbq1rk1/p3ppbp/1p1p1np1/2pP4/2P1P3/2N1BP2/PP1Q2PP/R3KBNR b KQ' => {
			eco => 'E82c',
			# TRANSLATORS: E82c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 b6 7. Qd2 c5 8. d5
			variation => N__('King\'s Indian: Sämisch, Fianchetto, 7. Qd2 c5 8. d5'),
			moves => {
			},
		},
		'rnbq1rk1/p1p1ppbp/1p1p1np1/8/2PPP3/2NBBP2/PP4PP/R2QK1NR b KQ' => {
			eco => 'E82d',
			# TRANSLATORS: E82d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 b6 7. Bd3
			variation => N__('King\'s Indian: Sämisch, Fianchetto, Bronstein Variation'),
			moves => {
				'a7a6' => 1,
				'c8b7' => 1,
				'f6d7' => 1,
			},
		},
		'rnbq1rk1/p1pnppbp/1p1p2p1/8/2PPP3/2NBBP2/PP4PP/R2QK1NR w KQ' => {
			eco => 'E82e',
			# TRANSLATORS: E82e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 b6 7. Bd3 Nfd7
			variation => N__('King\'s Indian: Sämisch, Fianchetto, 7. Bd3 Nfd7'),
			moves => {
			},
		},
		'rn1q1rk1/pbp1ppbp/1p1p1np1/8/2PPP3/2NBBP2/PP4PP/R2QK1NR w KQ' => {
			eco => 'E82f',
			# TRANSLATORS: E82f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 b6 7. Bd3 Bb7
			variation => N__('King\'s Indian: Sämisch, Fianchetto, 7. Bd3 Bb7'),
			moves => {
				'g1e2' => 1,
			},
		},
		'rn1q1rk1/pbp1ppbp/1p1p1np1/8/2PPP3/2NBBP2/PP2N1PP/R2QK2R b KQ' => {
			eco => 'E82g',
			# TRANSLATORS: E82g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 b6 7. Bd3 Bb7 8. Nge2
			variation => N__('King\'s Indian: Sämisch, Fianchetto, 7. Bd3 Bb7 8.Nge2'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rn1q1rk1/pb2ppbp/1p1p1np1/2p5/2PPP3/2NBBP2/PP2N1PP/R2QK2R w KQ' => {
			eco => 'E82g',
			# TRANSLATORS: E82g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 b6 7. Bd3 Bb7 8. Nge2 c5
			variation => N__('King\'s Indian: Sämisch, Fianchetto, 7. Bd3 Bb7 8.Nge2 c5'),
			moves => {
				'd4d5' => 1,
			},
		},
		'rn1q1rk1/pb2ppbp/1p1p1np1/2pP4/2P1P3/2NBBP2/PP2N1PP/R2QK2R b KQ' => {
			eco => 'E82g',
			# TRANSLATORS: E82g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 b6 7. Bd3 Bb7 8. Nge2 c5 9. d5
			variation => N__('King\'s Indian: Sämisch, Fianchetto, 7. Bd3 Bb7 8.Nge2 c5'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rn1q1rk1/pb3pbp/1p1ppnp1/2pP4/2P1P3/2NBBP2/PP2N1PP/R2QK2R w KQ' => {
			eco => 'E82g',
			# TRANSLATORS: E82g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 b6 7. Bd3 Bb7 8. Nge2 c5 9. d5 e6
			variation => N__('King\'s Indian: Sämisch, Fianchetto, 7. Bd3 Bb7 8.Nge2 c5 9. d5 e6'),
			moves => {
			},
		},
		'rnbq1rk1/2p1ppbp/pp1p1np1/8/2PPP3/2NBBP2/PP4PP/R2QK1NR w KQ' => {
			eco => 'E82h',
			# TRANSLATORS: E82h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 b6 7. Bd3 a6
			variation => N__('King\'s Indian: Sämisch, Fianchetto, 7. Bd3 a6'),
			moves => {
				'g1e2' => 1,
			},
		},
		'rnbq1rk1/2p1ppbp/pp1p1np1/8/2PPP3/2NBBP2/PP2N1PP/R2QK2R b KQ' => {
			eco => 'E82i',
			# TRANSLATORS: E82i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 b6 7. Bd3 a6 8. Nge2
			variation => N__('King\'s Indian: Sämisch, Fianchetto, 7. Bd3 a6 8.Nge2'),
			moves => {
				'c7c5' => 1,
			},
		},
		'rnbq1rk1/4ppbp/pp1p1np1/2p5/2PPP3/2NBBP2/PP2N1PP/R2QK2R w KQ' => {
			eco => 'E82i',
			# TRANSLATORS: E82i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 b6 7. Bd3 a6 8. Nge2 c5
			variation => N__('King\'s Indian: Sämisch, Fianchetto, 7. Bd3 a6 8.Nge2 c5'),
			moves => {
				'd4d5' => 1,
				'e4e5' => 1,
			},
		},
		'rnbq1rk1/4ppbp/pp1p1np1/2pP4/2P1P3/2NBBP2/PP2N1PP/R2QK2R b KQ' => {
			eco => 'E82j',
			# TRANSLATORS: E82j: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 b6 7. Bd3 a6 8. Nge2 c5 9. d5
			variation => N__('King\'s Indian: Sämisch, Fianchetto, 7. Bd3 a6 8.Nge2 c5 9. d5'),
			moves => {
			},
		},
		'rnbq1rk1/4ppbp/pp1p1np1/2p1P3/2PP4/2NBBP2/PP2N1PP/R2QK2R b KQ' => {
			eco => 'E82k',
			# TRANSLATORS: E82k: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 b6 7. Bd3 a6 8. Nge2 c5 9. e5
			variation => N__('King\'s Indian: Sämisch, Fianchetto, 7. Bd3 a6 8.Nge2 c5 9. e5'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1ppbp/2np1np1/8/2PPP3/2N1BP2/PP4PP/R2QKBNR w KQ' => {
			eco => 'E83a',
			# TRANSLATORS: E83a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nc6
			variation => N__('King\'s Indian: Sämisch, 6... Nc6'),
			moves => {
				'd1d2' => 1,
				'g1e2' => 1,
			},
		},
		'r1bq1rk1/ppp1ppbp/2np1np1/8/2PPP3/2N1BP2/PP1Q2PP/R3KBNR b KQ' => {
			eco => 'E83b',
			# TRANSLATORS: E83b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nc6 7. Qd2
			variation => N__('King\'s Indian: Sämisch, 6... Nc6 7. Qd2'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r1bq1rk1/1pp1ppbp/p1np1np1/8/2PPP3/2N1BP2/PP1Q2PP/R3KBNR w KQ' => {
			eco => 'E83c',
			# TRANSLATORS: E83c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nc6 7. Qd2 a6
			variation => N__('King\'s Indian: Sämisch, 6... Nc6 7. Qd2 a6'),
			moves => {
				'e1c1' => 1,
			},
		},
		'r1bq1rk1/1pp1ppbp/p1np1np1/8/2PPP3/2N1BP2/PP1Q2PP/2KR1BNR b -' => {
			eco => 'E83c',
			# TRANSLATORS: E83c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nc6 7. Qd2 a6 8. O-O-O
			variation => N__('King\'s Indian: Sämisch, 6... Nc6 7. Qd2 a6 8.O-O-O'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1ppbp/2np1np1/8/2PPP3/2N1BP2/PP2N1PP/R2QKB1R b KQ' => {
			eco => 'E83d',
			# TRANSLATORS: E83d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nc6 7. Nge2
			variation => N__('King\'s Indian: Sämisch, 6... Nc6 7.Nge2'),
			moves => {
				'a7a6' => 1,
				'a8b8' => 1,
			},
		},
		'1rbq1rk1/ppp1ppbp/2np1np1/8/2PPP3/2N1BP2/PP2N1PP/R2QKB1R w KQ' => {
			eco => 'E83e',
			# TRANSLATORS: E83e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nc6 7. Nge2 Rb8
			variation => N__('King\'s Indian: Sämisch, Ruban Variation'),
			moves => {
				'd1d2' => 1,
			},
		},
		'1rbq1rk1/ppp1ppbp/2np1np1/8/2PPP3/2N1BP2/PP1QN1PP/R3KB1R b KQ' => {
			eco => 'E83e',
			# TRANSLATORS: E83e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nc6 7. Nge2 Rb8 8. Qd2
			variation => N__('King\'s Indian: Sämisch, Ruban Variation'),
			moves => {
				'f8e8' => 1,
			},
		},
		'1rbqr1k1/ppp1ppbp/2np1np1/8/2PPP3/2N1BP2/PP1QN1PP/R3KB1R w KQ' => {
			eco => 'E83e',
			# TRANSLATORS: E83e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nc6 7. Nge2 Rb8 8. Qd2 Re8
			variation => N__('King\'s Indian: Sämisch, Ruban, 8. Qd2 Re8'),
			moves => {
			},
		},
		'r1bq1rk1/1pp1ppbp/p1np1np1/8/2PPP3/2N1BP2/PP2N1PP/R2QKB1R w KQ' => {
			eco => 'E83f',
			# TRANSLATORS: E83f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nc6 7. Nge2 a6
			variation => N__('King\'s Indian: Sämisch, Panno'),
			moves => {
				'a2a3' => 1,
				'd1d2' => 1,
				'e2c1' => 1,
			},
		},
		'r1bq1rk1/1pp1ppbp/p1np1np1/8/2PPP3/P1N1BP2/1P2N1PP/R2QKB1R b KQ' => {
			eco => 'E83g',
			# TRANSLATORS: E83g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nc6 7. Nge2 a6 8. a3
			variation => N__('King\'s Indian: Sämisch, Panno, 8. a3'),
			moves => {
			},
		},
		'r1bq1rk1/1pp1ppbp/p1np1np1/8/2PPP3/2N1BP2/PP4PP/R1NQKB1R b KQ' => {
			eco => 'E83h',
			# TRANSLATORS: E83h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nc6 7. Nge2 a6 8. Nc1
			variation => N__('King\'s Indian: Sämisch, Panno, 8. Nc1'),
			moves => {
			},
		},
		'r1bq1rk1/1pp1ppbp/p1np1np1/8/2PPP3/2N1BP2/PP1QN1PP/R3KB1R b KQ' => {
			eco => 'E83i',
			# TRANSLATORS: E83i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nc6 7. Nge2 a6 8. Qd2
			variation => N__('King\'s Indian: Sämisch, Panno, 8. Qd2'),
			moves => {
				'a8b8' => 1,
				'f8e8' => 1,
			},
		},
		'r1bqr1k1/1pp1ppbp/p1np1np1/8/2PPP3/2N1BP2/PP1QN1PP/R3KB1R w KQ' => {
			eco => 'E83j',
			# TRANSLATORS: E83j: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nc6 7. Nge2 a6 8. Qd2 Re8
			variation => N__('King\'s Indian: Sämisch, Panno, 8. Qd2 Re8'),
			moves => {
			},
		},
		'1rbq1rk1/1pp1ppbp/p1np1np1/8/2PPP3/2N1BP2/PP1QN1PP/R3KB1R w KQ' => {
			eco => 'E84a',
			# TRANSLATORS: E84a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nc6 7. Nge2 a6 8. Qd2 Rb8
			variation => N__('King\'s Indian: Sämisch, Panno Main Line'),
			moves => {
				'a1b1' => 1,
				'a2a3' => 1,
				'e1c1' => 1,
				'e2c1' => 1,
				'e3h6' => 1,
				'g2g4' => 1,
				'h2h4' => 1,
			},
		},
		'1rbq1rk1/1pp1ppbp/p1np1np1/8/2PPP3/P1N1BP2/1P1QN1PP/R3KB1R b KQ' => {
			eco => 'E84b',
			# TRANSLATORS: E84b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nc6 7. Nge2 a6 8. Qd2 Rb8 9. a3
			variation => N__('King\'s Indian: Sämisch, Panno Main Line, 9. a3'),
			moves => {
			},
		},
		'1rbq1rk1/1pp1ppbp/p1np1np1/8/2PPP3/2N1BP2/PP1QN1PP/2KR1B1R b -' => {
			eco => 'E84c',
			# TRANSLATORS: E84c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nc6 7. Nge2 a6 8. Qd2 Rb8 9. O-O-O
			variation => N__('King\'s Indian: Sämisch, Panno Main Line, 9.O-O-O'),
			moves => {
			},
		},
		'1rbq1rk1/1pp1ppbp/p1np1np1/8/2PPP1P1/2N1BP2/PP1QN2P/R3KB1R b KQ' => {
			eco => 'E84d',
			# TRANSLATORS: E84d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nc6 7. Nge2 a6 8. Qd2 Rb8 9. g4
			variation => N__('King\'s Indian: Sämisch, Panno Main Line, 9. g4'),
			moves => {
			},
		},
		'1rbq1rk1/1pp1ppbp/p1np1np1/8/2PPP3/2N1BP2/PP1QN1PP/1R2KB1R b K' => {
			eco => 'E84e',
			# TRANSLATORS: E84e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nc6 7. Nge2 a6 8. Qd2 Rb8 9. Rb1
			variation => N__('King\'s Indian: Sämisch, Panno Main Line, 9. Rb1'),
			moves => {
			},
		},
		'1rbq1rk1/1pp1ppbp/p1np1npB/8/2PPP3/2N2P2/PP1QN1PP/R3KB1R b KQ' => {
			eco => 'E84f',
			# TRANSLATORS: E84f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nc6 7. Nge2 a6 8. Qd2 Rb8 9. Bh6
			variation => N__('King\'s Indian: Sämisch, Panno Main Line, 9. Bh6'),
			moves => {
			},
		},
		'1rbq1rk1/1pp1ppbp/p1np1np1/8/2PPP3/2N1BP2/PP1Q2PP/R1N1KB1R b KQ' => {
			eco => 'E84g',
			# TRANSLATORS: E84g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nc6 7. Nge2 a6 8. Qd2 Rb8 9. Nc1
			variation => N__('King\'s Indian: Sämisch, Panno Main Line, 9. Nc1'),
			moves => {
				'e7e5' => 1,
			},
		},
		'1rbq1rk1/1pp2pbp/p1np1np1/4p3/2PPP3/2N1BP2/PP1Q2PP/R1N1KB1R w KQ' => {
			eco => 'E84g',
			# TRANSLATORS: E84g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nc6 7. Nge2 a6 8. Qd2 Rb8 9. Nc1 e5
			variation => N__('King\'s Indian: Sämisch, Panno Main Line, 9. Nc1 e5'),
			moves => {
				'c1b3' => 1,
				'd4d5' => 1,
			},
		},
		'1rbq1rk1/1pp2pbp/p1np1np1/4p3/2PPP3/1NN1BP2/PP1Q2PP/R3KB1R b KQ' => {
			eco => 'E84h',
			# TRANSLATORS: E84h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nc6 7. Nge2 a6 8. Qd2 Rb8 9. Nc1 e5 10. Nb3
			variation => N__('King\'s Indian: Sämisch, Panno Main Line, 9. Nc1 e5 10. Nb3'),
			moves => {
			},
		},
		'1rbq1rk1/1pp2pbp/p1np1np1/3Pp3/2P1P3/2N1BP2/PP1Q2PP/R1N1KB1R b KQ' => {
			eco => 'E84i',
			# TRANSLATORS: E84i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nc6 7. Nge2 a6 8. Qd2 Rb8 9. Nc1 e5 10. d5
			variation => N__('King\'s Indian: Sämisch, Panno Main Line, 9. Nc1 e5 10. d5'),
			moves => {
				'c6d4' => 1,
			},
		},
		'1rbq1rk1/1pp2pbp/p2p1np1/3Pp3/2PnP3/2N1BP2/PP1Q2PP/R1N1KB1R w KQ' => {
			eco => 'E84i',
			# TRANSLATORS: E84i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nc6 7. Nge2 a6 8. Qd2 Rb8 9. Nc1 e5 10. d5 Nd4
			variation => N__('King\'s Indian: Sämisch, Panno Main Line, 9. Nc1 e5 10. d5'),
			moves => {
				'c1b3' => 1,
			},
		},
		'1rbq1rk1/1pp2pbp/p2p1np1/3Pp3/2PnP3/1NN1BP2/PP1Q2PP/R3KB1R b KQ' => {
			eco => 'E84j',
			# TRANSLATORS: E84j: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nc6 7. Nge2 a6 8. Qd2 Rb8 9. Nc1 e5 10. d5 Nd4 11. Nb3
			variation => N__('King\'s Indian: Sämisch, Panno Main Line, 9. Nc1 e5 10. d5 Nd4 11. Nb3'),
			moves => {
			},
		},
		'1rbq1rk1/1pp1ppbp/p1np1np1/8/2PPP2P/2N1BP2/PP1QN1P1/R3KB1R b KQ' => {
			eco => 'E84k',
			# TRANSLATORS: E84k: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nc6 7. Nge2 a6 8. Qd2 Rb8 9. h4
			variation => N__('King\'s Indian: Sämisch, Panno Main Line, 9. h4'),
			moves => {
				'b7b5' => 1,
				'h7h5' => 1,
			},
		},
		'1rbq1rk1/2p1ppbp/p1np1np1/1p6/2PPP2P/2N1BP2/PP1QN1P1/R3KB1R w KQ' => {
			eco => 'E84l',
			# TRANSLATORS: E84l: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nc6 7. Nge2 a6 8. Qd2 Rb8 9. h4 b5
			variation => N__('King\'s Indian: Sämisch, Panno Main Line, 9. h4 b5'),
			moves => {
			},
		},
		'1rbq1rk1/1pp1ppb1/p1np1np1/7p/2PPP2P/2N1BP2/PP1QN1P1/R3KB1R w KQ' => {
			eco => 'E84m',
			# TRANSLATORS: E84m: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nc6 7. Nge2 a6 8. Qd2 Rb8 9. h4 h5
			variation => N__('King\'s Indian: Sämisch, Panno Main Line, 9. h4 h5'),
			moves => {
				'e1c1' => 1,
			},
		},
		'1rbq1rk1/1pp1ppb1/p1np1np1/7p/2PPP2P/2N1BP2/PP1QN1P1/2KR1B1R b -' => {
			eco => 'E84n',
			# TRANSLATORS: E84n: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nc6 7. Nge2 a6 8. Qd2 Rb8 9. h4 h5 10. O-O-O
			variation => N__('King\'s Indian: Sämisch, Panno Main Line, 9. h4 h5 10.O-O-O'),
			moves => {
				'b7b5' => 1,
			},
		},
		'1rbq1rk1/2p1ppb1/p1np1np1/1p5p/2PPP2P/2N1BP2/PP1QN1P1/2KR1B1R w -' => {
			eco => 'E84n',
			# TRANSLATORS: E84n: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nc6 7. Nge2 a6 8. Qd2 Rb8 9. h4 h5 10. O-O-O b5
			variation => N__('King\'s Indian: Sämisch, Panno Main Line, 9. h4 h5 10.O-O-O'),
			moves => {
				'e3h6' => 1,
			},
		},
		'1rbq1rk1/2p1ppb1/p1np1npB/1p5p/2PPP2P/2N2P2/PP1QN1P1/2KR1B1R b -' => {
			eco => 'E84o',
			# TRANSLATORS: E84o: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 Nc6 7. Nge2 a6 8. Qd2 Rb8 9. h4 h5 10. O-O-O b5 11. Bh6
			variation => N__('King\'s Indian: Sämisch, Panno Main Line, 9. h4 h5 10.O-O-O b5 11. Bh6'),
			moves => {
			},
		},
		'rnbq1rk1/ppp2pbp/3p1np1/4p3/2PPP3/2N1BP2/PP4PP/R2QKBNR w KQ' => {
			eco => 'E85a',
			# TRANSLATORS: E85a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5
			variation => N__('King\'s Indian: Sämisch, Orthodox Variation'),
			moves => {
				'd4d5' => 1,
				'd4e5' => 1,
				'g1e2' => 1,
			},
		},
		'rnbq1rk1/ppp2pbp/3p1np1/4P3/2P1P3/2N1BP2/PP4PP/R2QKBNR b KQ' => {
			eco => 'E85b',
			# TRANSLATORS: E85b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. dxe5
			variation => N__('King\'s Indian: Sämisch, Orthodox, 7.dxe5'),
			moves => {
				'd6e5' => 1,
			},
		},
		'rnbq1rk1/ppp2pbp/5np1/4p3/2P1P3/2N1BP2/PP4PP/R2QKBNR w KQ' => {
			eco => 'E85b',
			# TRANSLATORS: E85b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. dxe5 dxe5
			variation => N__('King\'s Indian: Sämisch, Orthodox, 7.dxe5'),
			moves => {
				'd1d8' => 1,
			},
		},
		'rnbQ1rk1/ppp2pbp/5np1/4p3/2P1P3/2N1BP2/PP4PP/R3KBNR b KQ' => {
			eco => 'E85c',
			# TRANSLATORS: E85c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. dxe5 dxe5 8. Qxd8
			variation => N__('King\'s Indian: Sämisch, Orthodox, Queenswap'),
			moves => {
			},
		},
		'rnbq1rk1/ppp2pbp/3p1np1/4p3/2PPP3/2N1BP2/PP2N1PP/R2QKB1R b KQ' => {
			eco => 'E85d',
			# TRANSLATORS: E85d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. Nge2
			variation => N__('King\'s Indian: Sämisch, Orthodox, 7.Nge2'),
			moves => {
				'b8c6' => 1,
				'b8d7' => 1,
				'c7c6' => 1,
				'e5d4' => 1,
			},
		},
		'rnbq1rk1/ppp2pbp/3p1np1/8/2PpP3/2N1BP2/PP2N1PP/R2QKB1R w KQ' => {
			eco => 'E85e',
			# TRANSLATORS: E85e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. Nge2 exd4
			variation => N__('King\'s Indian: Sämisch, Orthodox, 7.Nge2 exd4'),
			moves => {
			},
		},
		'r1bq1rk1/pppn1pbp/3p1np1/4p3/2PPP3/2N1BP2/PP2N1PP/R2QKB1R w KQ' => {
			eco => 'E85f',
			# TRANSLATORS: E85f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. Nge2 Nbd7
			variation => N__('King\'s Indian: Sämisch, Orthodox, 7.Nge2 Nbd7'),
			moves => {
			},
		},
		'r1bq1rk1/ppp2pbp/2np1np1/4p3/2PPP3/2N1BP2/PP2N1PP/R2QKB1R w KQ' => {
			eco => 'E85g',
			# TRANSLATORS: E85g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. Nge2 Nc6
			variation => N__('King\'s Indian: Sämisch, Orthodox, 7.Nge2 Nc6'),
			moves => {
				'd4d5' => 1,
			},
		},
		'r1bq1rk1/ppp2pbp/2np1np1/3Pp3/2P1P3/2N1BP2/PP2N1PP/R2QKB1R b KQ' => {
			eco => 'E85h',
			# TRANSLATORS: E85h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. Nge2 Nc6 8. d5
			variation => N__('King\'s Indian: Sämisch, Orthodox, 7.Nge2 Nc6 8. d5'),
			moves => {
				'c6e7' => 1,
			},
		},
		'r1bq1rk1/ppp1npbp/3p1np1/3Pp3/2P1P3/2N1BP2/PP2N1PP/R2QKB1R w KQ' => {
			eco => 'E85i',
			# TRANSLATORS: E85i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. Nge2 Nc6 8. d5 Ne7
			variation => N__('King\'s Indian: Sämisch, Orthodox, 7.Nge2 Nc6 8. d5 Ne7'),
			moves => {
				'd1d2' => 1,
			},
		},
		'r1bq1rk1/ppp1npbp/3p1np1/3Pp3/2P1P3/2N1BP2/PP1QN1PP/R3KB1R b KQ' => {
			eco => 'E85j',
			# TRANSLATORS: E85j: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. Nge2 Nc6 8. d5 Ne7 9. Qd2
			variation => N__('King\'s Indian: Sämisch, Orthodox, 7.Nge2 Nc6 8. d5 Ne7 9. Qd2'),
			moves => {
			},
		},
		'rnbq1rk1/pp3pbp/2pp1np1/4p3/2PPP3/2N1BP2/PP2N1PP/R2QKB1R w KQ' => {
			eco => 'E86a',
			# TRANSLATORS: E86a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. Nge2 c6
			variation => N__('King\'s Indian: Sämisch, Orthodox, 7.Nge2 c6'),
			moves => {
				'd1b3' => 1,
				'd1d2' => 1,
				'd4d5' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/2pp1np1/3Pp3/2P1P3/2N1BP2/PP2N1PP/R2QKB1R b KQ' => {
			eco => 'E86b',
			# TRANSLATORS: E86b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5 c6 8. Nge2
			variation => N__('King\'s Indian: Sämisch, Orthodox, 7.Nge2 c6 8. d5'),
			moves => {
				'c6d5' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/2pp1np1/4p3/2PPP3/1QN1BP2/PP2N1PP/R3KB1R b KQ' => {
			eco => 'E86c',
			# TRANSLATORS: E86c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. Nge2 c6 8. Qb3
			variation => N__('King\'s Indian: Sämisch, Orthodox, 7.Nge2 c6 8. Qb3'),
			moves => {
			},
		},
		'rnbq1rk1/pp3pbp/2pp1np1/4p3/2PPP3/2N1BP2/PP1QN1PP/R3KB1R b KQ' => {
			eco => 'E86d',
			# TRANSLATORS: E86d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. Nge2 c6 8. Qd2
			variation => N__('King\'s Indian: Sämisch, Orthodox, 7.Nge2 c6 8. Qd2'),
			moves => {
				'b8d7' => 1,
			},
		},
		'r1bq1rk1/pp1n1pbp/2pp1np1/4p3/2PPP3/2N1BP2/PP1QN1PP/R3KB1R w KQ' => {
			eco => 'E86e',
			# TRANSLATORS: E86e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. Nge2 c6 8. Qd2 Nbd7
			variation => N__('King\'s Indian: Sämisch, Orthodox, 7.Nge2 c6 8. Qd2 Nbd7'),
			moves => {
				'd4d5' => 1,
				'e1c1' => 1,
			},
		},
		'r1bq1rk1/pp1n1pbp/2pp1np1/3Pp3/2P1P3/2N1BP2/PP1QN1PP/R3KB1R b KQ' => {
			eco => 'E86f',
			# TRANSLATORS: E86f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. Nge2 c6 8. Qd2 Nbd7 9. d5
			variation => N__('King\'s Indian: Sämisch, Orthodox, 7.Nge2 c6 8. Qd2 Nbd7 9. d5'),
			moves => {
			},
		},
		'r1bq1rk1/pp1n1pbp/2pp1np1/4p3/2PPP3/2N1BP2/PP1QN1PP/2KR1B1R b -' => {
			eco => 'E86g',
			# TRANSLATORS: E86g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. Nge2 c6 8. Qd2 Nbd7 9. O-O-O
			variation => N__('King\'s Indian: Sämisch, Orthodox, 7.Nge2 c6 8. Qd2 Nbd7 9.O-O-O'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r1bq1rk1/1p1n1pbp/p1pp1np1/4p3/2PPP3/2N1BP2/PP1QN1PP/2KR1B1R w -' => {
			eco => 'E86h',
			# TRANSLATORS: E86h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. Nge2 c6 8. Qd2 Nbd7 9. O-O-O a6
			variation => N__('King\'s Indian: Sämisch, Orthodox, 7.Nge2 c6 8. Qd2 Nbd7 9.O-O-O a6'),
			moves => {
				'c1b1' => 1,
			},
		},
		'r1bq1rk1/1p1n1pbp/p1pp1np1/4p3/2PPP3/2N1BP2/PP1QN1PP/1K1R1B1R b -' => {
			eco => 'E86i',
			# TRANSLATORS: E86i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. Nge2 c6 8. Qd2 Nbd7 9. O-O-O a6 10. Kb1
			variation => N__('King\'s Indian: Sämisch, Orthodox, 7.Nge2 c6 8. Qd2 Nbd7 9.O-O-O a6 10. Kb1'),
			moves => {
			},
		},
		'rnbq1rk1/ppp2pbp/3p1np1/3Pp3/2P1P3/2N1BP2/PP4PP/R2QKBNR b KQ' => {
			eco => 'E87a',
			# TRANSLATORS: E87a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5
			variation => N__('King\'s Indian: Sämisch, Orthodox, 7. d5'),
			moves => {
				'a7a5' => 1,
				'b8d7' => 1,
				'c7c5' => 1,
				'c7c6' => 1,
				'f6h5' => 1,
			},
		},
		'rnbq1rk1/1pp2pbp/3p1np1/p2Pp3/2P1P3/2N1BP2/PP4PP/R2QKBNR w KQ' => {
			eco => 'E87b',
			# TRANSLATORS: E87b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5 a5
			variation => N__('King\'s Indian: Sämisch, Orthodox, 7. d5 a5'),
			moves => {
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2pPp3/2P1P3/2N1BP2/PP4PP/R2QKBNR w KQ' => {
			eco => 'E87c',
			# TRANSLATORS: E87c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5 c5
			variation => N__('King\'s Indian: Sämisch, Orthodox, 7. d5 c5'),
			moves => {
			},
		},
		'r1bq1rk1/pppn1pbp/3p1np1/3Pp3/2P1P3/2N1BP2/PP4PP/R2QKBNR w KQ' => {
			eco => 'E87d',
			# TRANSLATORS: E87d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5 Nbd7
			variation => N__('King\'s Indian: Sämisch, Orthodox, 7. d5 Nbd7'),
			moves => {
			},
		},
		'rnbq1rk1/ppp2pbp/3p2p1/3Pp2n/2P1P3/2N1BP2/PP4PP/R2QKBNR w KQ' => {
			eco => 'E87e',
			# TRANSLATORS: E87e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5 Nh5
			variation => N__('King\'s Indian: Sämisch, Orthodox, 7. d5 Nh5'),
			moves => {
				'd1d2' => 1,
			},
		},
		'rnbq1rk1/ppp2pbp/3p2p1/3Pp2n/2P1P3/2N1BP2/PP1Q2PP/R3KBNR b KQ' => {
			eco => 'E87f',
			# TRANSLATORS: E87f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5 Nh5 8. Qd2
			variation => N__('King\'s Indian: Sämisch, Orthodox, 7. d5 Nh5 8. Qd2'),
			moves => {
				'd8h4' => 1,
				'f7f5' => 1,
			},
		},
		'rnb2rk1/ppp2pbp/3p2p1/3Pp2n/2P1P2q/2N1BP2/PP1Q2PP/R3KBNR w KQ' => {
			eco => 'E87g',
			# TRANSLATORS: E87g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5 Nh5 8. Qd2 Qh4+
			variation => N__('King\'s Indian: Sämisch, Orthodox, Bronstein Variation'),
			moves => {
				'e3f2' => 1,
				'g2g3' => 1,
			},
		},
		'rnb2rk1/ppp2pbp/3p2p1/3Pp2n/2P1P2q/2N1BPP1/PP1Q3P/R3KBNR b KQ' => {
			eco => 'E87h',
			# TRANSLATORS: E87h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5 Nh5 8. Qd2 Qh4+ 9. g3
			variation => N__('King\'s Indian: Sämisch, Orthodox, Bronstein, 9. g3'),
			moves => {
			},
		},
		'rnb2rk1/ppp2pbp/3p2p1/3Pp2n/2P1P2q/2N2P2/PP1Q1BPP/R3KBNR b KQ' => {
			eco => 'E87i',
			# TRANSLATORS: E87i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5 Nh5 8. Qd2 Qh4+ 9. Bf2
			variation => N__('King\'s Indian: Sämisch, Orthodox, Bronstein, 9. Bf2'),
			moves => {
			},
		},
		'rnbq1rk1/ppp3bp/3p2p1/3Ppp1n/2P1P3/2N1BP2/PP1Q2PP/R3KBNR w KQ' => {
			eco => 'E87j',
			# TRANSLATORS: E87j: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5 Nh5 8. Qd2 f5
			variation => N__('King\'s Indian: Sämisch, Orthodox, 7. d5 Nh5 8. Qd2 f5'),
			moves => {
				'e1c1' => 1,
			},
		},
		'rnbq1rk1/ppp3bp/3p2p1/3Ppp1n/2P1P3/2N1BP2/PP1Q2PP/2KR1BNR b -' => {
			eco => 'E87k',
			# TRANSLATORS: E87k: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5 Nh5 8. Qd2 f5 9. O-O-O
			variation => N__('King\'s Indian: Sämisch, Orthodox, 7. d5 Nh5 8. Qd2 f5 9.O-O-O'),
			moves => {
				'b8d7' => 1,
				'f5f4' => 1,
			},
		},
		'rnbq1rk1/ppp3bp/3p2p1/3Pp2n/2P1Pp2/2N1BP2/PP1Q2PP/2KR1BNR w -' => {
			eco => 'E87l',
			# TRANSLATORS: E87l: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5 Nh5 8. Qd2 f5 9. O-O-O f4
			variation => N__('King\'s Indian: Sämisch, Orthodox, 7. d5 Nh5 8. Qd2 f5 9.O-O-O f4'),
			moves => {
			},
		},
		'r1bq1rk1/pppn2bp/3p2p1/3Ppp1n/2P1P3/2N1BP2/PP1Q2PP/2KR1BNR w -' => {
			eco => 'E87m',
			# TRANSLATORS: E87m: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5 Nh5 8. Qd2 f5 9. O-O-O Nd7
			variation => N__('King\'s Indian: Sämisch, Orthodox, 7. d5 Nh5 8. Qd2 f5 9.O-O-O Nd7'),
			moves => {
				'f1d3' => 1,
			},
		},
		'r1bq1rk1/pppn2bp/3p2p1/3Ppp1n/2P1P3/2NBBP2/PP1Q2PP/2KR2NR b -' => {
			eco => 'E87n',
			# TRANSLATORS: E87n: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5 Nh5 8. Qd2 f5 9. O-O-O Nd7 10. Bd3
			variation => N__('King\'s Indian: Sämisch, Orthodox, 7. d5 Nh5 8. Qd2 f5 9.O-O-O Nd7 10. Bd3'),
			moves => {
			},
		},
		'rnbq1rk1/pp3pbp/2pp1np1/3Pp3/2P1P3/2N1BP2/PP4PP/R2QKBNR w KQ' => {
			eco => 'E88a',
			# TRANSLATORS: E88a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5 c6
			variation => N__('King\'s Indian: Sämisch, Orthodox, 7. d5 c6'),
			moves => {
				'd1d2' => 1,
				'f1d3' => 1,
				'g1e2' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/2pp1np1/3Pp3/2P1P3/2N1BP2/PP1Q2PP/R3KBNR b KQ' => {
			eco => 'E88b',
			# TRANSLATORS: E88b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5 c6 8. Qd2
			variation => N__('King\'s Indian: Sämisch, Orthodox, 7. d5 c6 8. Qd2'),
			moves => {
				'c6d5' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/3pp3/2P1P3/2N1BP2/PP1Q2PP/R3KBNR w KQ' => {
			eco => 'E88c',
			# TRANSLATORS: E88c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5 c6 8. Qd2 cxd5
			variation => N__('King\'s Indian: Sämisch, Orthodox, 7. d5 c6 8. Qd2 cxd5'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/3Pp3/4P3/2N1BP2/PP1Q2PP/R3KBNR b KQ' => {
			eco => 'E88c',
			# TRANSLATORS: E88c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5 c6 8. Qd2 cxd5 9. cxd5
			variation => N__('King\'s Indian: Sämisch, Orthodox, 7. d5 c6 8. Qd2 cxd5'),
			moves => {
				'a7a6' => 1,
			},
		},
		'rnbq1rk1/1p3pbp/p2p1np1/3Pp3/4P3/2N1BP2/PP1Q2PP/R3KBNR w KQ' => {
			eco => 'E88d',
			# TRANSLATORS: E88d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5 c6 8. Qd2 cxd5 9. cxd5 a6
			variation => N__('King\'s Indian: Sämisch, Orthodox, 7. d5 c6 8. Qd2 cxd5 9.cxd5 a6'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rnbq1rk1/1p3pbp/p2p1np1/3Pp3/4P3/2NBBP2/PP1Q2PP/R3K1NR b KQ' => {
			eco => 'E88e',
			# TRANSLATORS: E88e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5 c6 8. Qd2 cxd5 9. cxd5 a6 10. Bd3
			variation => N__('King\'s Indian: Sämisch, Orthodox, 7. d5 c6 8. Qd2 cxd5 9.cxd5 a6 10. Bd3'),
			moves => {
			},
		},
		'rnbq1rk1/pp3pbp/2pp1np1/3Pp3/2P1P3/2NBBP2/PP4PP/R2QK1NR b KQ' => {
			eco => 'E88f',
			# TRANSLATORS: E88f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5 c6 8. Bd3
			variation => N__('King\'s Indian: Sämisch, Orthodox, Polugayevsky'),
			moves => {
				'b7b5' => 1,
				'c6d5' => 1,
			},
		},
		'rnbq1rk1/p4pbp/2pp1np1/1p1Pp3/2P1P3/2NBBP2/PP4PP/R2QK1NR w KQ' => {
			eco => 'E88g',
			# TRANSLATORS: E88g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5 c6 8. Bd3 b5
			variation => N__('King\'s Indian: Sämisch, Orthodox, Polugayevsky, 8... b5'),
			moves => {
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/3pp3/2P1P3/2NBBP2/PP4PP/R2QK1NR w KQ' => {
			eco => 'E88h',
			# TRANSLATORS: E88h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5 c6 8. Bd3 cxd5
			variation => N__('King\'s Indian: Sämisch, Orthodox, Polugayevsky, 8...cxd5'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/3Pp3/4P3/2NBBP2/PP4PP/R2QK1NR b KQ' => {
			eco => 'E88h',
			# TRANSLATORS: E88h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5 c6 8. Bd3 cxd5 9. cxd5
			variation => N__('King\'s Indian: Sämisch, Orthodox, Polugayevsky, 8...cxd5'),
			moves => {
				'f6h5' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3p2p1/3Pp2n/4P3/2NBBP2/PP4PP/R2QK1NR w KQ' => {
			eco => 'E88i',
			# TRANSLATORS: E88i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5 c6 8. Bd3 cxd5 9. cxd5 Nh5
			variation => N__('King\'s Indian: Sämisch, Orthodox, Polugayevsky, 8...cxd5 9.cxd5 Nh5'),
			moves => {
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/3pp3/2P1P3/2N1BP2/PP2N1PP/R2QKB1R w KQ' => {
			eco => 'E89a',
			# TRANSLATORS: E89a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5 c6 8. Nge2 cxd5
			variation => N__('King\'s Indian: Sämisch, Orthodox Main Line'),
			moves => {
				'c4d5' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/3Pp3/4P3/2N1BP2/PP2N1PP/R2QKB1R b KQ' => {
			eco => 'E89a',
			# TRANSLATORS: E89a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5 c6 8. Nge2 cxd5 9. cxd5
			variation => N__('King\'s Indian: Sämisch, Orthodox Main Line'),
			moves => {
				'a7a6' => 1,
				'b8d7' => 1,
				'c8d7' => 1,
			},
		},
		'rnbq1rk1/1p3pbp/p2p1np1/3Pp3/4P3/2N1BP2/PP2N1PP/R2QKB1R w KQ' => {
			eco => 'E89b',
			# TRANSLATORS: E89b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5 c6 8. Nge2 cxd5 9. cxd5 a6
			variation => N__('King\'s Indian: Sämisch, Orthodox Main Line, 9... a6'),
			moves => {
			},
		},
		'rn1q1rk1/pp1b1pbp/3p1np1/3Pp3/4P3/2N1BP2/PP2N1PP/R2QKB1R w KQ' => {
			eco => 'E89c',
			# TRANSLATORS: E89c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5 c6 8. Nge2 cxd5 9. cxd5 Bd7
			variation => N__('King\'s Indian: Sämisch, Orthodox Main Line, 9... Bd7'),
			moves => {
			},
		},
		'r1bq1rk1/pp1n1pbp/3p1np1/3Pp3/4P3/2N1BP2/PP2N1PP/R2QKB1R w KQ' => {
			eco => 'E89d',
			# TRANSLATORS: E89d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5 c6 8. Nge2 cxd5 9. cxd5 Nbd7
			variation => N__('King\'s Indian: Sämisch, Orthodox Main Line, 9...Nbd7'),
			moves => {
				'd1d2' => 1,
			},
		},
		'r1bq1rk1/pp1n1pbp/3p1np1/3Pp3/4P3/2N1BP2/PP1QN1PP/R3KB1R b KQ' => {
			eco => 'E89e',
			# TRANSLATORS: E89e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5 c6 8. Nge2 cxd5 9. cxd5 Nbd7 10. Qd2
			variation => N__('King\'s Indian: Sämisch, Orthodox Main Line, 10. Qd2'),
			moves => {
				'a7a6' => 1,
			},
		},
		'r1bq1rk1/1p1n1pbp/p2p1np1/3Pp3/4P3/2N1BP2/PP1QN1PP/R3KB1R w KQ' => {
			eco => 'E89f',
			# TRANSLATORS: E89f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5 c6 8. Nge2 cxd5 9. cxd5 Nbd7 10. Qd2 a6
			variation => N__('King\'s Indian: Sämisch, Orthodox Main Line, 10. Qd2 a6'),
			moves => {
				'g2g4' => 1,
			},
		},
		'r1bq1rk1/1p1n1pbp/p2p1np1/3Pp3/4P1P1/2N1BP2/PP1QN2P/R3KB1R b KQ' => {
			eco => 'E89g',
			# TRANSLATORS: E89g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5 c6 8. Nge2 cxd5 9. cxd5 Nbd7 10. Qd2 a6 11. g4
			variation => N__('King\'s Indian: Sämisch, Orthodox Main Line, 10. Qd2 a6 11. g4'),
			moves => {
				'h7h5' => 1,
			},
		},
		'r1bq1rk1/1p1n1pb1/p2p1np1/3Pp2p/4P1P1/2N1BP2/PP1QN2P/R3KB1R w KQ' => {
			eco => 'E89h',
			# TRANSLATORS: E89h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5 c6 8. Nge2 cxd5 9. cxd5 Nbd7 10. Qd2 a6 11. g4 h5
			variation => N__('King\'s Indian: Sämisch, Orthodox Main Line, 10. Qd2 a6 11. g4 h5'),
			moves => {
				'h2h3' => 1,
			},
		},
		'r1bq1rk1/1p1n1pb1/p2p1np1/3Pp2p/4P1P1/2N1BP1P/PP1QN3/R3KB1R b KQ' => {
			eco => 'E89i',
			# TRANSLATORS: E89i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. f3 O-O 6. Be3 e5 7. d5 c6 8. Nge2 cxd5 9. cxd5 Nbd7 10. Qd2 a6 11. g4 h5 12. h3
			variation => N__('King\'s Indian: Sämisch, Orthodox Main Line, 10. Qd2 a6 11. g4 h5 12. h3'),
			moves => {
			},
		},
		'rnbqk2r/ppp1ppbp/3p1np1/8/2PPP3/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'E90a',
			# TRANSLATORS: E90a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3
			variation => N__('King\'s Indian: 5. Nf3'),
			moves => {
				'b8d7' => 1,
				'c7c5' => 1,
				'c8g4' => 1,
				'e8g8' => 1,
			},
		},
		'r1bqk2r/pppnppbp/3p1np1/8/2PPP3/2N2N2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'E90a',
			# TRANSLATORS: E90a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 Nbd7
			variation => N__('King\'s Indian: 5. Nf3 Nbd7'),
			moves => {
				'f1e2' => 1,
			},
		},
		'r1bqk2r/pppnppbp/3p1np1/8/2PPP3/2N2N2/PP2BPPP/R1BQK2R b KQkq' => {
			eco => 'E90a',
			# TRANSLATORS: E90a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 Nbd7 6. Be2
			variation => N__('King\'s Indian: 5. Nf3 Nbd7 6. Be2'),
			moves => {
				'e7e5' => 1,
			},
		},
		'r1bqk2r/pppn1pbp/3p1np1/4p3/2PPP3/2N2N2/PP2BPPP/R1BQK2R w KQkq' => {
			eco => 'E90a',
			# TRANSLATORS: E90a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 Nbd7 6. Be2 e5
			variation => N__('King\'s Indian: 5. Nf3 Nbd7 6. Be2 e5'),
			moves => {
			},
		},
		'rn1qk2r/ppp1ppbp/3p1np1/8/2PPP1b1/2N2N2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'E90b',
			# TRANSLATORS: E90b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 Bg4
			variation => N__('King\'s Indian: 5. Nf3 Bg4'),
			moves => {
			},
		},
		'rnbqk2r/pp2ppbp/3p1np1/2p5/2PPP3/2N2N2/PP3PPP/R1BQKB1R w KQkq' => {
			eco => 'E90c',
			# TRANSLATORS: E90c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 c5
			variation => N__('King\'s Indian: 5. Nf3 c5'),
			moves => {
				'd4d5' => 1,
			},
		},
		'rnbqk2r/pp2ppbp/3p1np1/2pP4/2P1P3/2N2N2/PP3PPP/R1BQKB1R b KQkq' => {
			eco => 'E90c',
			# TRANSLATORS: E90c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 c5 6. d5
			variation => N__('King\'s Indian: 5. Nf3 c5'),
			moves => {
				'e8g8' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2pP4/2P1P3/2N2N2/PP3PPP/R1BQKB1R w KQ' => {
			eco => 'E90d',
			# TRANSLATORS: E90d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 c5 6. d5 O-O
			variation => N__('King\'s Indian: 5. Nf3 c5 6. d5 O-O'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PPP3/2N2N2/PP3PPP/R1BQKB1R w KQ' => {
			eco => 'E90e',
			# TRANSLATORS: E90e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O
			variation => N__('King\'s Indian: 5. Nf3 O-O'),
			moves => {
				'c1e3' => 1,
				'c1g5' => 1,
				'f1d3' => 1,
				'f1e2' => 1,
				'h2h3' => 1,
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PPP3/2NB1N2/PP3PPP/R1BQK2R b KQ' => {
			eco => 'E90f',
			# TRANSLATORS: E90f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Bd3
			variation => N__('King\'s Indian: 5. Nf3 O-O 6. Bd3'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/6B1/2PPP3/2N2N2/PP3PPP/R2QKB1R b KQ' => {
			eco => 'E90g',
			# TRANSLATORS: E90g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Bg5
			variation => N__('King\'s Indian: Zinnowitz Variation'),
			moves => {
				'h7h6' => 1,
			},
		},
		'rnbq1rk1/ppp1ppb1/3p1npp/6B1/2PPP3/2N2N2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'E90g',
			# TRANSLATORS: E90g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Bg5 h6
			variation => N__('King\'s Indian: Zinnowitz, 6... h6'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PPP3/2N1BN2/PP3PPP/R2QKB1R b KQ' => {
			eco => 'E90h',
			# TRANSLATORS: E90h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be3
			variation => N__('King\'s Indian: Larsen Variation'),
			moves => {
				'c7c5' => 1,
				'e7e5' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2p5/2PPP3/2N1BN2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'E90h',
			# TRANSLATORS: E90h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be3 c5
			variation => N__('King\'s Indian: Larsen, 6... c5'),
			moves => {
			},
		},
		'rnbq1rk1/ppp2pbp/3p1np1/4p3/2PPP3/2N1BN2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'E90i',
			# TRANSLATORS: E90i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be3 e5
			variation => N__('King\'s Indian: Larsen, 6... e5'),
			moves => {
				'd4e5' => 1,
			},
		},
		'rnbq1rk1/ppp2pbp/3p1np1/4P3/2P1P3/2N1BN2/PP3PPP/R2QKB1R b KQ' => {
			eco => 'E90i',
			# TRANSLATORS: E90i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be3 e5 7. dxe5
			variation => N__('King\'s Indian: Larsen, 6... e5'),
			moves => {
				'd6e5' => 1,
			},
		},
		'rnbq1rk1/ppp2pbp/5np1/4p3/2P1P3/2N1BN2/PP3PPP/R2QKB1R w KQ' => {
			eco => 'E90i',
			# TRANSLATORS: E90i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be3 e5 7. dxe5 dxe5
			variation => N__('King\'s Indian: Larsen, 6... e5'),
			moves => {
				'd1d8' => 1,
			},
		},
		'rnbQ1rk1/ppp2pbp/5np1/4p3/2P1P3/2N1BN2/PP3PPP/R3KB1R b KQ' => {
			eco => 'E90j',
			# TRANSLATORS: E90j: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be3 e5 7. dxe5 dxe5 8. Qxd8
			variation => N__('King\'s Indian: Larsen, 6... e5, Queenswap'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PPP3/2N2N1P/PP3PP1/R1BQKB1R b KQ' => {
			eco => 'E90k',
			# TRANSLATORS: E90k: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. h3
			variation => N__('King\'s Indian: 5. Nf3 O-O 6. h3'),
			moves => {
				'b8a6' => 1,
				'b8d7' => 1,
				'c7c5' => 1,
				'e7e5' => 1,
			},
		},
		'r1bq1rk1/pppnppbp/3p1np1/8/2PPP3/2N2N1P/PP3PP1/R1BQKB1R w KQ' => {
			eco => 'E90l',
			# TRANSLATORS: E90l: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. h3 Nbd7
			variation => N__('King\'s Indian: 5. Nf3 O-O 6. h3 Nbd7'),
			moves => {
				'c1g5' => 1,
			},
		},
		'r1bq1rk1/pppnppbp/3p1np1/6B1/2PPP3/2N2N1P/PP3PP1/R2QKB1R b KQ' => {
			eco => 'E90l',
			# TRANSLATORS: E90l: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. h3 Nbd7 7. Bg5
			variation => N__('King\'s Indian: 5. Nf3 O-O 6. h3 Nbd7 7. Bg5'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1ppbp/n2p1np1/8/2PPP3/2N2N1P/PP3PP1/R1BQKB1R w KQ' => {
			eco => 'E90m',
			# TRANSLATORS: E90m: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. h3 Na6
			variation => N__('King\'s Indian: 5. Nf3 O-O 6. h3 Na6'),
			moves => {
				'c1g5' => 1,
			},
		},
		'r1bq1rk1/ppp1ppbp/n2p1np1/6B1/2PPP3/2N2N1P/PP3PP1/R2QKB1R b KQ' => {
			eco => 'E90m',
			# TRANSLATORS: E90m: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. h3 Na6 7. Bg5
			variation => N__('King\'s Indian: 5. Nf3 O-O 6. h3 Na6 7. Bg5'),
			moves => {
			},
		},
		'rnbq1rk1/ppp2pbp/3p1np1/4p3/2PPP3/2N2N1P/PP3PP1/R1BQKB1R w KQ' => {
			eco => 'E90n',
			# TRANSLATORS: E90n: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. h3 e5
			variation => N__('King\'s Indian: 5. Nf3 O-O 6. h3 e5'),
			moves => {
				'c1e3' => 1,
				'd4d5' => 1,
				'd4e5' => 1,
			},
		},
		'rnbq1rk1/ppp2pbp/3p1np1/4p3/2PPP3/2N1BN1P/PP3PP1/R2QKB1R b KQ' => {
			eco => 'E90n',
			# TRANSLATORS: E90n: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. h3 e5 7. Be3
			variation => N__('King\'s Indian: 5. Nf3 O-O 6. h3 e5 7. Be3'),
			moves => {
			},
		},
		'rnbq1rk1/ppp2pbp/3p1np1/4P3/2P1P3/2N2N1P/PP3PP1/R1BQKB1R b KQ' => {
			eco => 'E90n',
			# TRANSLATORS: E90n: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. h3 e5 7. dxe5
			variation => N__('King\'s Indian: 5. Nf3 O-O 6. h3 e5'),
			moves => {
				'd6e5' => 1,
			},
		},
		'rnbq1rk1/ppp2pbp/5np1/4p3/2P1P3/2N2N1P/PP3PP1/R1BQKB1R w KQ' => {
			eco => 'E90n',
			# TRANSLATORS: E90n: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. h3 e5 7. dxe5 dxe5
			variation => N__('King\'s Indian: 5. Nf3 O-O 6. h3 e5'),
			moves => {
				'd1d8' => 1,
			},
		},
		'rnbQ1rk1/ppp2pbp/5np1/4p3/2P1P3/2N2N1P/PP3PP1/R1B1KB1R b KQ' => {
			eco => 'E90o',
			# TRANSLATORS: E90o: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. h3 e5 7. dxe5 dxe5 8. Qxd8
			variation => N__('King\'s Indian: 5. Nf3 O-O 6. h3 e5 Queenswap'),
			moves => {
			},
		},
		'rnbq1rk1/ppp2pbp/3p1np1/3Pp3/2P1P3/2N2N1P/PP3PP1/R1BQKB1R b KQ' => {
			eco => 'E90p',
			# TRANSLATORS: E90p: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. h3 e5 7. d5
			variation => N__('King\'s Indian: 5. Nf3 O-O 6. h3 e5 7. d5'),
			moves => {
				'a7a5' => 1,
				'b8a6' => 1,
				'b8d7' => 1,
			},
		},
		'rnbq1rk1/1pp2pbp/3p1np1/p2Pp3/2P1P3/2N2N1P/PP3PP1/R1BQKB1R w KQ' => {
			eco => 'E90q',
			# TRANSLATORS: E90q: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. h3 e5 7. d5 a5
			variation => N__('King\'s Indian: 5. Nf3 O-O 6. h3 e5 7. d5 a5'),
			moves => {
			},
		},
		'r1bq1rk1/pppn1pbp/3p1np1/3Pp3/2P1P3/2N2N1P/PP3PP1/R1BQKB1R w KQ' => {
			eco => 'E90r',
			# TRANSLATORS: E90r: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. h3 e5 7. d5 Nbd7
			variation => N__('King\'s Indian: 5. Nf3 O-O 6. h3 e5 7. d5 Nbd7'),
			moves => {
				'c1e3' => 1,
				'c1g5' => 1,
			},
		},
		'r1bq1rk1/pppn1pbp/3p1np1/3Pp3/2P1P3/2N1BN1P/PP3PP1/R2QKB1R b KQ' => {
			eco => 'E90r',
			# TRANSLATORS: E90r: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. h3 e5 7. d5 Nbd7 8. Be3
			variation => N__('King\'s Indian: 5. Nf3 O-O 6. h3 e5 7. d5 Nbd7 8. Be3'),
			moves => {
			},
		},
		'r1bq1rk1/pppn1pbp/3p1np1/3Pp1B1/2P1P3/2N2N1P/PP3PP1/R2QKB1R b KQ' => {
			eco => 'E90r',
			# TRANSLATORS: E90r: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. h3 e5 7. d5 Nbd7 8. Bg5
			variation => N__('King\'s Indian: 5. Nf3 O-O 6. h3 e5 7. d5 Nbd7 8. Bg5'),
			moves => {
			},
		},
		'r1bq1rk1/ppp2pbp/n2p1np1/3Pp3/2P1P3/2N2N1P/PP3PP1/R1BQKB1R w KQ' => {
			eco => 'E90s',
			# TRANSLATORS: E90s: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. h3 e5 7. d5 Na6
			variation => N__('King\'s Indian: 5. Nf3 O-O 6. h3 e5 7. d5 Na6'),
			moves => {
				'c1e3' => 1,
				'c1g5' => 1,
			},
		},
		'r1bq1rk1/ppp2pbp/n2p1np1/3Pp3/2P1P3/2N1BN1P/PP3PP1/R2QKB1R b KQ' => {
			eco => 'E90s',
			# TRANSLATORS: E90s: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. h3 e5 7. d5 Na6 8. Be3
			variation => N__('King\'s Indian: 5. Nf3 O-O 6. h3 e5 7. d5 Na6 8. Be3'),
			moves => {
			},
		},
		'r1bq1rk1/ppp2pbp/n2p1np1/3Pp1B1/2P1P3/2N2N1P/PP3PP1/R2QKB1R b KQ' => {
			eco => 'E90s',
			# TRANSLATORS: E90s: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. h3 e5 7. d5 Na6 8. Bg5
			variation => N__('King\'s Indian: 5. Nf3 O-O 6. h3 e5 7. d5 Na6 8. Bg5'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2p5/2PPP3/2N2N1P/PP3PP1/R1BQKB1R w KQ' => {
			eco => 'E90t',
			# TRANSLATORS: E90t: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. h3 c5
			variation => N__('King\'s Indian: 5. Nf3 O-O 6. h3 c5'),
			moves => {
				'c1e3' => 1,
				'd4d5' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2p5/2PPP3/2N1BN1P/PP3PP1/R2QKB1R b KQ' => {
			eco => 'E90t',
			# TRANSLATORS: E90t: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. h3 c5 7. Be3
			variation => N__('King\'s Indian: 5. Nf3 O-O 6. h3 c5 7. Be3'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2pP4/2P1P3/2N2N1P/PP3PP1/R1BQKB1R b KQ' => {
			eco => 'E90u',
			# TRANSLATORS: E90u: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. h3 c5 7. d5
			variation => N__('King\'s Indian: 5. Nf3 O-O 6. h3 c5 7. d5'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3ppnp1/2pP4/2P1P3/2N2N1P/PP3PP1/R1BQKB1R w KQ' => {
			eco => 'E90v',
			# TRANSLATORS: E90v: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. h3 c5 7. d5 e6
			variation => N__('King\'s Indian: 5. Nf3 O-O 6. h3 c5 7. d5 e6'),
			moves => {
				'f1d3' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3ppnp1/2pP4/2P1P3/2NB1N1P/PP3PP1/R1BQK2R b KQ' => {
			eco => 'E90v',
			# TRANSLATORS: E90v: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. h3 c5 7. d5 e6 8. Bd3
			variation => N__('King\'s Indian: 5. Nf3 O-O 6. h3 c5 7. d5 e6 8. Bd3'),
			moves => {
				'b8a6' => 1,
				'e6d5' => 1,
			},
		},
		'r1bq1rk1/pp3pbp/n2ppnp1/2pP4/2P1P3/2NB1N1P/PP3PP1/R1BQK2R w KQ' => {
			eco => 'E90w',
			# TRANSLATORS: E90w: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. h3 c5 7. d5 e6 8. Bd3 Na6
			variation => N__('King\'s Indian: 5. Nf3 O-O 6. h3 c5 7. d5 e6 8. Bd3 Na6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1bq1rk1/pp3pbp/n2ppnp1/2pP4/2P1P3/2NB1N1P/PP3PP1/R1BQ1RK1 b -' => {
			eco => 'E90w',
			# TRANSLATORS: E90w: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. h3 c5 7. d5 e6 8. Bd3 Na6 9. O-O
			variation => N__('King\'s Indian: 5. Nf3 O-O 6. h3 c5 7. d5 e6 8. Bd3 Na6 9.O-O'),
			moves => {
				'a6c7' => 1,
			},
		},
		'r1bq1rk1/ppn2pbp/3ppnp1/2pP4/2P1P3/2NB1N1P/PP3PP1/R1BQ1RK1 w -' => {
			eco => 'E90w',
			# TRANSLATORS: E90w: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. h3 c5 7. d5 e6 8. Bd3 Na6 9. O-O Nc7
			variation => N__('King\'s Indian: 5. Nf3 O-O 6. h3 c5 7. d5 e6 8. Bd3 Na6 9.O-O Nc7'),
			moves => {
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2pp4/2P1P3/2NB1N1P/PP3PP1/R1BQK2R w KQ' => {
			eco => 'E90x',
			# TRANSLATORS: E90x: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. h3 c5 7. d5 e6 8. Bd3 exd5
			variation => N__('King\'s Indian: 5. Nf3 O-O 6. h3 c5 7. d5 e6 8. Bd3 exd5'),
			moves => {
				'e4d5' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2pP4/2P5/2NB1N1P/PP3PP1/R1BQK2R b KQ' => {
			eco => 'E90x',
			# TRANSLATORS: E90x: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. h3 c5 7. d5 e6 8. Bd3 exd5 9. exd5
			variation => N__('King\'s Indian: 5. Nf3 O-O 6. h3 c5 7. d5 e6 8. Bd3 exd5 9.exd5'),
			moves => {
				'f8e8' => 1,
			},
		},
		'rnbqr1k1/pp3pbp/3p1np1/2pP4/2P5/2NB1N1P/PP3PP1/R1BQK2R w KQ' => {
			eco => 'E90y',
			# TRANSLATORS: E90y: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. h3 c5 7. d5 e6 8. Bd3 exd5 9. exd5 Re8+
			variation => N__('King\'s Indian: 5. Nf3 O-O 6. h3 c5 7. d5 e6 8. Bd3 exd5 9.exd5 Re8'),
			moves => {
			},
		},
		'rnbq1rk1/ppp1ppbp/3p1np1/8/2PPP3/2N2N2/PP2BPPP/R1BQK2R b KQ' => {
			eco => 'E91a',
			# TRANSLATORS: E91a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2
			variation => N__('King\'s Indian: 6. Be2'),
			moves => {
				'a7a5' => 1,
				'a7a6' => 1,
				'b8a6' => 1,
				'b8c6' => 1,
				'b8d7' => 1,
				'c7c5' => 1,
				'c7c6' => 1,
				'c8g4' => 1,
				'e7e5' => 1,
			},
		},
		'rnbq1rk1/1pp1ppbp/3p1np1/p7/2PPP3/2N2N2/PP2BPPP/R1BQK2R w KQ' => {
			eco => 'E91b',
			# TRANSLATORS: E91b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 a5
			variation => N__('King\'s Indian: 6. Be2 a5'),
			moves => {
			},
		},
		'rnbq1rk1/1pp1ppbp/p2p1np1/8/2PPP3/2N2N2/PP2BPPP/R1BQK2R w KQ' => {
			eco => 'E91c',
			# TRANSLATORS: E91c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 a6
			variation => N__('King\'s Indian: 6. Be2 a6'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/2pp1np1/8/2PPP3/2N2N2/PP2BPPP/R1BQK2R w KQ' => {
			eco => 'E91d',
			# TRANSLATORS: E91d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 c6
			variation => N__('King\'s Indian: 6. Be2 c6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/2pp1np1/8/2PPP3/2N2N2/PP2BPPP/R1BQ1RK1 b -' => {
			eco => 'E91e',
			# TRANSLATORS: E91e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 c6 7. O-O
			variation => N__('King\'s Indian: 6. Be2 c6 7.O-O'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2p5/2PPP3/2N2N2/PP2BPPP/R1BQK2R w KQ' => {
			eco => 'E91f',
			# TRANSLATORS: E91f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 c5
			variation => N__('King\'s Indian: 6. Be2 c5'),
			moves => {
				'd4d5' => 1,
				'e1g1' => 1,
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2pP4/2P1P3/2N2N2/PP2BPPP/R1BQK2R b KQ' => {
			eco => 'E91g',
			# TRANSLATORS: E91g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 c5 7. d5
			variation => N__('King\'s Indian: 6. Be2 c5 7. d5'),
			moves => {
				'e7e6' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3ppnp1/2pP4/2P1P3/2N2N2/PP2BPPP/R1BQK2R w KQ' => {
			eco => 'E91h',
			# TRANSLATORS: E91h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 c5 7. d5 e6
			variation => N__('King\'s Indian: 6. Be2 c5 7. d5 e6'),
			moves => {
				'e1g1' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3ppnp1/2pP4/2P1P3/2N2N2/PP2BPPP/R1BQ1RK1 b -' => {
			eco => 'E91h',
			# TRANSLATORS: E91h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 c5 7. d5 e6 8. O-O
			variation => N__('King\'s Indian: 6. Be2 c5 7. d5 e6 8.O-O'),
			moves => {
				'f8e8' => 1,
			},
		},
		'rnbqr1k1/pp3pbp/3ppnp1/2pP4/2P1P3/2N2N2/PP2BPPP/R1BQ1RK1 w -' => {
			eco => 'E91i',
			# TRANSLATORS: E91i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 c5 7. d5 e6 8. O-O Re8
			variation => N__('King\'s Indian: 6. Be2 c5 7. d5 e6 8.O-O Re8'),
			moves => {
				'f3d2' => 1,
			},
		},
		'rnbqr1k1/pp3pbp/3ppnp1/2pP4/2P1P3/2N5/PP1NBPPP/R1BQ1RK1 b -' => {
			eco => 'E91i',
			# TRANSLATORS: E91i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 c5 7. d5 e6 8. O-O Re8 9. Nd2
			variation => N__('King\'s Indian: 6. Be2 c5 7. d5 e6 8.O-O Re8 9. Nd2'),
			moves => {
			},
		},
		'rnbq1rk1/pp2ppbp/3p1np1/2p5/2PPP3/2N2N2/PP2BPPP/R1BQ1RK1 b -' => {
			eco => 'E91j',
			# TRANSLATORS: E91j: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 c5 7. O-O
			variation => N__('King\'s Indian: 6. Be2 c5 7.O-O'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/2np1np1/2p5/2PPP3/2N2N2/PP2BPPP/R1BQ1RK1 w -' => {
			eco => 'E91k',
			# TRANSLATORS: E91k: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 c5 7. O-O Nc6
			variation => N__('King\'s Indian: 6. Be2 c5 7.O-O Nc6'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1ppbp/n2p1np1/8/2PPP3/2N2N2/PP2BPPP/R1BQK2R w KQ' => {
			eco => 'E91l',
			# TRANSLATORS: E91l: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 Na6
			variation => N__('King\'s Indian: Kazakh Variation'),
			moves => {
				'c1g5' => 1,
				'e1g1' => 1,
			},
		},
		'r1bq1rk1/ppp1ppbp/n2p1np1/6B1/2PPP3/2N2N2/PP2BPPP/R2QK2R b KQ' => {
			eco => 'E91l',
			# TRANSLATORS: E91l: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 Na6 7. Bg5
			variation => N__('King\'s Indian: Kazakh Variation, 7. Bg5'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1ppbp/n2p1np1/8/2PPP3/2N2N2/PP2BPPP/R1BQ1RK1 b -' => {
			eco => 'E91m',
			# TRANSLATORS: E91m: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 Na6 7. O-O
			variation => N__('King\'s Indian: Kazakh Variation, 7.O-O'),
			moves => {
				'c7c5' => 1,
				'c7c6' => 1,
			},
		},
		'r1bq1rk1/pp2ppbp/n2p1np1/2p5/2PPP3/2N2N2/PP2BPPP/R1BQ1RK1 w -' => {
			eco => 'E91m',
			# TRANSLATORS: E91m: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 Na6 7. O-O c5
			variation => N__('King\'s Indian: Kazakh Variation, 7.O-O c5'),
			moves => {
			},
		},
		'r1bq1rk1/pp2ppbp/n1pp1np1/8/2PPP3/2N2N2/PP2BPPP/R1BQ1RK1 w -' => {
			eco => 'E91n',
			# TRANSLATORS: E91n: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 Na6 7. O-O c6
			variation => N__('King\'s Indian: Kazakh Variation, 7.O-O c6'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1ppbp/2np1np1/8/2PPP3/2N2N2/PP2BPPP/R1BQK2R w KQ' => {
			eco => 'E91o',
			# TRANSLATORS: E91o: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 Nc6
			variation => N__('King\'s Indian: 6. Be2 Nc6'),
			moves => {
				'd4d5' => 1,
			},
		},
		'r1bq1rk1/ppp1ppbp/2np1np1/3P4/2P1P3/2N2N2/PP2BPPP/R1BQK2R b KQ' => {
			eco => 'E91p',
			# TRANSLATORS: E91p: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 Nc6 7. d5
			variation => N__('King\'s Indian: 6. Be2 Nc6 7. d5'),
			moves => {
			},
		},
		'r1bq1rk1/pppnppbp/3p1np1/8/2PPP3/2N2N2/PP2BPPP/R1BQK2R w KQ' => {
			eco => 'E91q',
			# TRANSLATORS: E91q: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 Nbd7
			variation => N__('King\'s Indian: 6. Be2 Nbd7'),
			moves => {
				'c1g5' => 1,
				'e1g1' => 1,
				'e4e5' => 1,
			},
		},
		'r1bq1rk1/pppnppbp/3p1np1/6B1/2PPP3/2N2N2/PP2BPPP/R2QK2R b KQ' => {
			eco => 'E91q',
			# TRANSLATORS: E91q: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 Nbd7 7. Bg5
			variation => N__('King\'s Indian: 6. Be2 Nbd7 7. Bg5'),
			moves => {
			},
		},
		'r1bq1rk1/pppnppbp/3p1np1/4P3/2PP4/2N2N2/PP2BPPP/R1BQK2R b KQ' => {
			eco => 'E91r',
			# TRANSLATORS: E91r: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 Nbd7 7. e5
			variation => N__('King\'s Indian: 6. Be2 Nbd7 7. e5'),
			moves => {
			},
		},
		'r1bq1rk1/pppnppbp/3p1np1/8/2PPP3/2N2N2/PP2BPPP/R1BQ1RK1 b -' => {
			eco => 'E91s',
			# TRANSLATORS: E91s: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 Nbd7 7. O-O
			variation => N__('King\'s Indian: 6. Be2 Nbd7 7.O-O'),
			moves => {
				'c7c6' => 1,
			},
		},
		'r1bq1rk1/pp1nppbp/2pp1np1/8/2PPP3/2N2N2/PP2BPPP/R1BQ1RK1 w -' => {
			eco => 'E91t',
			# TRANSLATORS: E91t: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 Nbd7 7. O-O c6
			variation => N__('King\'s Indian: 6. Be2 Nbd7 7.O-O c6'),
			moves => {
			},
		},
		'rn1q1rk1/ppp1ppbp/3p1np1/8/2PPP1b1/2N2N2/PP2BPPP/R1BQK2R w KQ' => {
			eco => 'E91u',
			# TRANSLATORS: E91u: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 Bg4
			variation => N__('King\'s Indian: 6. Be2 Bg4'),
			moves => {
				'c1e3' => 1,
			},
		},
		'rn1q1rk1/ppp1ppbp/3p1np1/8/2PPP1b1/2N1BN2/PP2BPPP/R2QK2R b KQ' => {
			eco => 'E91v',
			# TRANSLATORS: E91v: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 Bg4 7. Be3
			variation => N__('King\'s Indian: 6. Be2 Bg4 7. Be3'),
			moves => {
				'f6d7' => 1,
			},
		},
		'rn1q1rk1/pppnppbp/3p2p1/8/2PPP1b1/2N1BN2/PP2BPPP/R2QK2R w KQ' => {
			eco => 'E91w',
			# TRANSLATORS: E91w: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 Bg4 7. Be3 Nfd7
			variation => N__('King\'s Indian: 6. Be2 Bg4 7. Be3 Nfd7'),
			moves => {
				'a1c1' => 1,
				'f3g1' => 1,
			},
		},
		'rn1q1rk1/pppnppbp/3p2p1/8/2PPP1b1/2N1BN2/PP2BPPP/2RQK2R b K' => {
			eco => 'E91x',
			# TRANSLATORS: E91x: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 Bg4 7. Be3 Nfd7 8. Rc1
			variation => N__('King\'s Indian: 6. Be2 Bg4 7. Be3 Nfd7 8. Rc1'),
			moves => {
			},
		},
		'rn1q1rk1/pppnppbp/3p2p1/8/2PPP1b1/2N1B3/PP2BPPP/R2QK1NR b KQ' => {
			eco => 'E91y',
			# TRANSLATORS: E91y: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 Bg4 7. Be3 Nfd7 8. Ng1
			variation => N__('King\'s Indian: 6. Be2 Bg4 7. Be3 Nfd7 8. Ng1'),
			moves => {
			},
		},
		'rnbq1rk1/ppp2pbp/3p1np1/4p3/2PPP3/2N2N2/PP2BPPP/R1BQK2R w KQ' => {
			eco => 'E92a',
			# TRANSLATORS: E92a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5
			variation => N__('King\'s Indian: 6. Be2 e5'),
			moves => {
				'c1e3' => 1,
				'd4d5' => 1,
				'd4e5' => 1,
				'e1g1' => 1,
			},
		},
		'rnbq1rk1/ppp2pbp/3p1np1/4P3/2P1P3/2N2N2/PP2BPPP/R1BQK2R b KQ' => {
			eco => 'E92b',
			# TRANSLATORS: E92b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. dxe5
			variation => N__('King\'s Indian: 6. Be2 e5 Queenswap'),
			moves => {
				'd6e5' => 1,
			},
		},
		'rnbq1rk1/ppp2pbp/5np1/4p3/2P1P3/2N2N2/PP2BPPP/R1BQK2R w KQ' => {
			eco => 'E92b',
			# TRANSLATORS: E92b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. dxe5 dxe5
			variation => N__('King\'s Indian: 6. Be2 e5 Queenswap'),
			moves => {
				'd1d8' => 1,
			},
		},
		'rnbQ1rk1/ppp2pbp/5np1/4p3/2P1P3/2N2N2/PP2BPPP/R1B1K2R b KQ' => {
			eco => 'E92b',
			# TRANSLATORS: E92b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. dxe5 dxe5 8. Qxd8
			variation => N__('King\'s Indian: 6. Be2 e5 Queenswap'),
			moves => {
				'f8d8' => 1,
			},
		},
		'rnbr2k1/ppp2pbp/5np1/4p3/2P1P3/2N2N2/PP2BPPP/R1B1K2R w KQ' => {
			eco => 'E92b',
			# TRANSLATORS: E92b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. dxe5 dxe5 8. Qxd8 Rxd8
			variation => N__('King\'s Indian: 6. Be2 e5 Queenswap'),
			moves => {
				'c1g5' => 1,
			},
		},
		'rnbr2k1/ppp2pbp/5np1/4p1B1/2P1P3/2N2N2/PP2BPPP/R3K2R b KQ' => {
			eco => 'E92c',
			# TRANSLATORS: E92c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. dxe5 dxe5 8. Qxd8 Rxd8 9. Bg5
			variation => N__('King\'s Indian: 6. Be2 e5 Queenswap, 9. Bg5'),
			moves => {
				'c7c6' => 1,
				'd8e8' => 1,
			},
		},
		'rnbr2k1/pp3pbp/2p2np1/4p1B1/2P1P3/2N2N2/PP2BPPP/R3K2R w KQ' => {
			eco => 'E92d',
			# TRANSLATORS: E92d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. dxe5 dxe5 8. Qxd8 Rxd8 9. Bg5 c6
			variation => N__('King\'s Indian: 6. Be2 e5 Queenswap, 9. Bg5 c6'),
			moves => {
			},
		},
		'rnb1r1k1/ppp2pbp/5np1/4p1B1/2P1P3/2N2N2/PP2BPPP/R3K2R w KQ' => {
			eco => 'E92e',
			# TRANSLATORS: E92e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. dxe5 dxe5 8. Qxd8 Rxd8 9. Bg5 Re8
			variation => N__('King\'s Indian: 6. Be2 e5 Queenswap, 9. Bg5 Re8'),
			moves => {
				'c3d5' => 1,
			},
		},
		'rnb1r1k1/ppp2pbp/5np1/3Np1B1/2P1P3/5N2/PP2BPPP/R3K2R b KQ' => {
			eco => 'E92f',
			# TRANSLATORS: E92f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. dxe5 dxe5 8. Qxd8 Rxd8 9. Bg5 Re8 10. Nd5
			variation => N__('King\'s Indian: 6. Be2 e5 Queenswap, 9. Bg5 Re8 10. Nd5'),
			moves => {
			},
		},
		'rnbq1rk1/ppp2pbp/3p1np1/4p3/2PPP3/2N1BN2/PP2BPPP/R2QK2R b KQ' => {
			eco => 'E92g',
			# TRANSLATORS: E92g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. Be3
			variation => N__('King\'s Indian: Gligoric-Taimanov System'),
			moves => {
				'c7c6' => 1,
				'd8e7' => 1,
				'e5d4' => 1,
				'f6g4' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/2pp1np1/4p3/2PPP3/2N1BN2/PP2BPPP/R2QK2R w KQ' => {
			eco => 'E92h',
			# TRANSLATORS: E92h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. Be3 c6
			variation => N__('King\'s Indian: Gligoric-Taimanov, 7... c6'),
			moves => {
			},
		},
		'rnbq1rk1/ppp2pbp/3p1np1/8/2PpP3/2N1BN2/PP2BPPP/R2QK2R w KQ' => {
			eco => 'E92i',
			# TRANSLATORS: E92i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. Be3 exd4
			variation => N__('King\'s Indian: Gligoric-Taimanov, 7...exd4'),
			moves => {
			},
		},
		'rnb2rk1/ppp1qpbp/3p1np1/4p3/2PPP3/2N1BN2/PP2BPPP/R2QK2R w KQ' => {
			eco => 'E92j',
			# TRANSLATORS: E92j: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. Be3 Qe7
			variation => N__('King\'s Indian: Gligoric-Taimanov, 7... Qe7'),
			moves => {
			},
		},
		'rnbq1rk1/ppp2pbp/3p2p1/4p3/2PPP1n1/2N1BN2/PP2BPPP/R2QK2R w KQ' => {
			eco => 'E92k',
			# TRANSLATORS: E92k: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. Be3 Ng4
			variation => N__('King\'s Indian: Gligoric-Taimanov, 7... Ng4'),
			moves => {
				'e3g5' => 1,
			},
		},
		'rnbq1rk1/ppp2pbp/3p2p1/4p1B1/2PPP1n1/2N2N2/PP2BPPP/R2QK2R b KQ' => {
			eco => 'E92k',
			# TRANSLATORS: E92k: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. Be3 Ng4 8. Bg5
			variation => N__('King\'s Indian: Gligoric-Taimanov, 7... Ng4'),
			moves => {
				'f7f6' => 1,
			},
		},
		'rnbq1rk1/ppp3bp/3p1pp1/4p1B1/2PPP1n1/2N2N2/PP2BPPP/R2QK2R w KQ' => {
			eco => 'E92k',
			# TRANSLATORS: E92k: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. Be3 Ng4 8. Bg5 f6
			variation => N__('King\'s Indian: Gligoric-Taimanov, 7... Ng4'),
			moves => {
				'g5c1' => 1,
				'g5h4' => 1,
			},
		},
		'rnbq1rk1/ppp3bp/3p1pp1/4p3/2PPP1n1/2N2N2/PP2BPPP/R1BQK2R b KQ' => {
			eco => 'E92k',
			# TRANSLATORS: E92k: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. Be3 Ng4 8. Bg5 f6 9. Bc1
			variation => N__('King\'s Indian: Gligoric-Taimanov, 7... Ng4 8. Bg5 f6 9. Bc1'),
			moves => {
			},
		},
		'rnbq1rk1/ppp3bp/3p1pp1/4p3/2PPP1nB/2N2N2/PP2BPPP/R2QK2R b KQ' => {
			eco => 'E92l',
			# TRANSLATORS: E92l: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. Be3 Ng4 8. Bg5 f6 9. Bh4
			variation => N__('King\'s Indian: Gligoric-Taimanov, 7... Ng4 8. Bg5 f6 9. Bh4'),
			moves => {
				'b8c6' => 1,
			},
		},
		'r1bq1rk1/ppp3bp/2np1pp1/4p3/2PPP1nB/2N2N2/PP2BPPP/R2QK2R w KQ' => {
			eco => 'E92m',
			# TRANSLATORS: E92m: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. Be3 Ng4 8. Bg5 f6 9. Bh4 Nc6
			variation => N__('King\'s Indian: Gligoric-Taimanov, Main Line'),
			moves => {
			},
		},
		'rnbq1rk1/ppp2pbp/3p1np1/3Pp3/2P1P3/2N2N2/PP2BPPP/R1BQK2R b KQ' => {
			eco => 'E92n',
			# TRANSLATORS: E92n: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. d5
			variation => N__('King\'s Indian: Petrosian System'),
			moves => {
				'a7a5' => 1,
				'b8d7' => 1,
				'c7c5' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2pPp3/2P1P3/2N2N2/PP2BPPP/R1BQK2R w KQ' => {
			eco => 'E92o',
			# TRANSLATORS: E92o: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. d5 c5
			variation => N__('King\'s Indian: Petrosian, 7... c5'),
			moves => {
				'c1g5' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/3p1np1/2pPp1B1/2P1P3/2N2N2/PP2BPPP/R2QK2R b KQ' => {
			eco => 'E92p',
			# TRANSLATORS: E92p: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. d5 c5 8. Bg5
			variation => N__('King\'s Indian: Petrosian, 7... c5 8. Bg5'),
			moves => {
			},
		},
		'rnbq1rk1/1pp2pbp/3p1np1/p2Pp3/2P1P3/2N2N2/PP2BPPP/R1BQK2R w KQ' => {
			eco => 'E92q',
			# TRANSLATORS: E92q: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. d5 a5
			variation => N__('King\'s Indian: Petrosian, Stein Variation'),
			moves => {
				'c1g5' => 1,
				'h2h3' => 1,
			},
		},
		'rnbq1rk1/1pp2pbp/3p1np1/p2Pp3/2P1P3/2N2N1P/PP2BPP1/R1BQK2R b KQ' => {
			eco => 'E92r',
			# TRANSLATORS: E92r: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. d5 a5 8. h3
			variation => N__('King\'s Indian: Petrosian, Stein, 8. h3'),
			moves => {
			},
		},
		'rnbq1rk1/1pp2pbp/3p1np1/p2Pp1B1/2P1P3/2N2N2/PP2BPPP/R2QK2R b KQ' => {
			eco => 'E92s',
			# TRANSLATORS: E92s: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. d5 a5 8. Bg5
			variation => N__('King\'s Indian: Petrosian, Stein, 8. Bg5'),
			moves => {
				'h7h6' => 1,
			},
		},
		'rnbq1rk1/1pp2pb1/3p1npp/p2Pp1B1/2P1P3/2N2N2/PP2BPPP/R2QK2R w KQ' => {
			eco => 'E92s',
			# TRANSLATORS: E92s: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. d5 a5 8. Bg5 h6
			variation => N__('King\'s Indian: Petrosian, Stein, 8. Bg5 h6'),
			moves => {
				'g5h4' => 1,
			},
		},
		'rnbq1rk1/1pp2pb1/3p1npp/p2Pp3/2P1P2B/2N2N2/PP2BPPP/R2QK2R b KQ' => {
			eco => 'E92s',
			# TRANSLATORS: E92s: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. d5 a5 8. Bg5 h6 9. Bh4
			variation => N__('King\'s Indian: Petrosian, Stein, 8. Bg5 h6'),
			moves => {
				'b8a6' => 1,
			},
		},
		'r1bq1rk1/1pp2pb1/n2p1npp/p2Pp3/2P1P2B/2N2N2/PP2BPPP/R2QK2R w KQ' => {
			eco => 'E92t',
			# TRANSLATORS: E92t: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. d5 a5 8. Bg5 h6 9. Bh4 Na6
			variation => N__('King\'s Indian: Petrosian, Stein, 8. Bg5 h6 9. Bh4 Na6'),
			moves => {
				'f3d2' => 1,
			},
		},
		'r1bq1rk1/1pp2pb1/n2p1npp/p2Pp3/2P1P2B/2N5/PP1NBPPP/R2QK2R b KQ' => {
			eco => 'E92u',
			# TRANSLATORS: E92u: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. d5 a5 8. Bg5 h6 9. Bh4 Na6 10. Nd2
			variation => N__('King\'s Indian: Petrosian, Stein, Main Line'),
			moves => {
				'd8e8' => 1,
			},
		},
		'r1b1qrk1/1pp2pb1/n2p1npp/p2Pp3/2P1P2B/2N5/PP1NBPPP/R2QK2R w KQ' => {
			eco => 'E92v',
			# TRANSLATORS: E92v: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. d5 a5 8. Bg5 h6 9. Bh4 Na6 10. Nd2 Qe8
			variation => N__('King\'s Indian: Petrosian, Stein, Main Line, 10... Qe8'),
			moves => {
				'e1g1' => 1,
			},
		},
		'r1b1qrk1/1pp2pb1/n2p1npp/p2Pp3/2P1P2B/2N5/PP1NBPPP/R2Q1RK1 b -' => {
			eco => 'E92w',
			# TRANSLATORS: E92w: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. d5 a5 8. Bg5 h6 9. Bh4 Na6 10. Nd2 Qe8 11. O-O
			variation => N__('King\'s Indian: Petrosian, Stein, Main Line, 10... Qe8 11.O-O'),
			moves => {
				'c8d7' => 1,
				'f6h7' => 1,
			},
		},
		'r3qrk1/1ppb1pb1/n2p1npp/p2Pp3/2P1P2B/2N5/PP1NBPPP/R2Q1RK1 w -' => {
			eco => 'E92w',
			# TRANSLATORS: E92w: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. d5 a5 8. Bg5 h6 9. Bh4 Na6 10. Nd2 Qe8 11. O-O Bd7
			variation => N__('King\'s Indian: Petrosian, Stein, Main Line, 10... Qe8 11.O-O Bd7'),
			moves => {
			},
		},
		'r1b1qrk1/1pp2pbn/n2p2pp/p2Pp3/2P1P2B/2N5/PP1NBPPP/R2Q1RK1 w -' => {
			eco => 'E92x',
			# TRANSLATORS: E92x: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. d5 a5 8. Bg5 h6 9. Bh4 Na6 10. Nd2 Qe8 11. O-O Nh7
			variation => N__('King\'s Indian: Petrosian, Stein, Main Line, 10... Qe8 11.O-O Nh7'),
			moves => {
			},
		},
		'r1bq1rk1/pppn1pbp/3p1np1/3Pp3/2P1P3/2N2N2/PP2BPPP/R1BQK2R w KQ' => {
			eco => 'E93',
			# TRANSLATORS: E93: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. d5 Nbd7
			variation => N__('King\'s Indian: Petrosian, Main Line'),
			moves => {
				'c1e3' => 1,
				'c1g5' => 1,
				'd1c2' => 1,
			},
		},
		'r1bq1rk1/pppn1pbp/3p1np1/3Pp3/2P1P3/2N1BN2/PP2BPPP/R2QK2R b KQ' => {
			eco => 'E93',
			# TRANSLATORS: E93: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. d5 Nbd7 8. Be3
			variation => N__('King\'s Indian: Petrosian, Main Line, 8. Be3'),
			moves => {
				'f6g4' => 1,
			},
		},
		'r1bq1rk1/pppn1pbp/3p2p1/3Pp3/2P1P1n1/2N1BN2/PP2BPPP/R2QK2R w KQ' => {
			eco => 'E93',
			# TRANSLATORS: E93: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. d5 Nbd7 8. Be3 Ng4
			variation => N__('King\'s Indian: Petrosian, Main Line, 8. Be3 Ng4'),
			moves => {
			},
		},
		'r1bq1rk1/pppn1pbp/3p1np1/3Pp1B1/2P1P3/2N2N2/PP2BPPP/R2QK2R b KQ' => {
			eco => 'E93',
			# TRANSLATORS: E93: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. d5 Nbd7 8. Bg5
			variation => N__('King\'s Indian: Petrosian, Main Line, 8. Bg5'),
			moves => {
				'h7h6' => 1,
			},
		},
		'r1bq1rk1/pppn1pb1/3p1npp/3Pp1B1/2P1P3/2N2N2/PP2BPPP/R2QK2R w KQ' => {
			eco => 'E93',
			# TRANSLATORS: E93: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. d5 Nbd7 8. Bg5 h6
			variation => N__('King\'s Indian: Petrosian, Main Line, 8. Bg5 h6'),
			moves => {
				'g5h4' => 1,
			},
		},
		'r1bq1rk1/pppn1pb1/3p1npp/3Pp3/2P1P2B/2N2N2/PP2BPPP/R2QK2R b KQ' => {
			eco => 'E93',
			# TRANSLATORS: E93: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. d5 Nbd7 8. Bg5 h6 9. Bh4
			variation => N__('King\'s Indian: Petrosian, Main Line, 8. Bg5 h6 9. Bh4'),
			moves => {
				'a7a5' => 1,
				'a7a6' => 1,
				'g6g5' => 1,
			},
		},
		'r1bq1rk1/1ppn1pb1/3p1npp/p2Pp3/2P1P2B/2N2N2/PP2BPPP/R2QK2R w KQ' => {
			eco => 'E93',
			# TRANSLATORS: E93: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. d5 Nbd7 8. Bg5 h6 9. Bh4 a5
			variation => N__('King\'s Indian: Petrosian, Main Line, 8. Bg5 h6 9. Bh4 a5'),
			moves => {
			},
		},
		'r1bq1rk1/1ppn1pb1/p2p1npp/3Pp3/2P1P2B/2N2N2/PP2BPPP/R2QK2R w KQ' => {
			eco => 'E93',
			# TRANSLATORS: E93: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. d5 Nbd7 8. Bg5 h6 9. Bh4 a6
			variation => N__('King\'s Indian: Petrosian, Main Line, 8. Bg5 h6 9. Bh4 a6'),
			moves => {
			},
		},
		'r1bq1rk1/pppn1pb1/3p1n1p/3Pp1p1/2P1P2B/2N2N2/PP2BPPP/R2QK2R w KQ' => {
			eco => 'E93',
			# TRANSLATORS: E93: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. d5 Nbd7 8. Bg5 h6 9. Bh4 g5
			variation => N__('King\'s Indian: Petrosian, Main Line, 8. Bg5 h6 9. Bh4 g5'),
			moves => {
				'h4g3' => 1,
			},
		},
		'r1bq1rk1/pppn1pb1/3p1n1p/3Pp1p1/2P1P3/2N2NB1/PP2BPPP/R2QK2R b KQ' => {
			eco => 'E93',
			# TRANSLATORS: E93: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. d5 Nbd7 8. Bg5 h6 9. Bh4 g5 10. Bg3
			variation => N__('King\'s Indian: Petrosian, Main Line, 8. Bg5 h6 9. Bh4 g5'),
			moves => {
				'f6h5' => 1,
			},
		},
		'r1bq1rk1/pppn1pb1/3p3p/3Pp1pn/2P1P3/2N2NB1/PP2BPPP/R2QK2R w KQ' => {
			eco => 'E93',
			# TRANSLATORS: E93: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. d5 Nbd7 8. Bg5 h6 9. Bh4 g5 10. Bg3 Nh5
			variation => N__('King\'s Indian: Petrosian, Main Line, 8. Bg5 h6 9. Bh4 g5'),
			moves => {
				'h2h4' => 1,
			},
		},
		'r1bq1rk1/pppn1pb1/3p3p/3Pp1pn/2P1P2P/2N2NB1/PP2BPP1/R2QK2R b KQ' => {
			eco => 'E93',
			# TRANSLATORS: E93: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. d5 Nbd7 8. Bg5 h6 9. Bh4 g5 10. Bg3 Nh5 11. h4
			variation => N__('King\'s Indian: Petrosian, Keres Variation'),
			moves => {
			},
		},
		'r1bq1rk1/pppn1pbp/3p1np1/3Pp3/2P1P3/2N2N2/PPQ1BPPP/R1B1K2R b KQ' => {
			eco => 'E93',
			# TRANSLATORS: E93: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. d5 Nbd7 8. Qc2
			variation => N__('King\'s Indian: Petrosian, Main Line, 8. Qc2'),
			moves => {
			},
		},
		'rnbq1rk1/ppp2pbp/3p1np1/4p3/2PPP3/2N2N2/PP2BPPP/R1BQ1RK1 b -' => {
			eco => 'E94a',
			# TRANSLATORS: E94a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O
			variation => N__('King\'s Indian: 7.O-O'),
			moves => {
				'b8a6' => 1,
				'b8c6' => 1,
				'b8d7' => 1,
				'c7c6' => 1,
				'e5d4' => 1,
			},
		},
		'rnbq1rk1/ppp2pbp/3p1np1/8/2PpP3/2N2N2/PP2BPPP/R1BQ1RK1 w -' => {
			eco => 'E94b',
			# TRANSLATORS: E94b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O exd4
			variation => N__('King\'s Indian: 7.O-O exd4'),
			moves => {
				'f3d4' => 1,
			},
		},
		'rnbq1rk1/ppp2pbp/3p1np1/8/2PNP3/2N5/PP2BPPP/R1BQ1RK1 b -' => {
			eco => 'E94b',
			# TRANSLATORS: E94b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O exd4 8. Nxd4
			variation => N__('King\'s Indian: 7.O-O exd4'),
			moves => {
				'f8e8' => 1,
			},
		},
		'rnbqr1k1/ppp2pbp/3p1np1/8/2PNP3/2N5/PP2BPPP/R1BQ1RK1 w -' => {
			eco => 'E94b',
			# TRANSLATORS: E94b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O exd4 8. Nxd4 Re8
			variation => N__('King\'s Indian: 7.O-O exd4'),
			moves => {
				'f2f3' => 1,
			},
		},
		'rnbqr1k1/ppp2pbp/3p1np1/8/2PNP3/2N2P2/PP2B1PP/R1BQ1RK1 b -' => {
			eco => 'E94c',
			# TRANSLATORS: E94c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O exd4 8. Nxd4 Re8 9. f3
			variation => N__('King\'s Indian: 7.O-O exd4 8.Nxd4 Re8 9. f3'),
			moves => {
				'b8c6' => 1,
				'c7c6' => 1,
			},
		},
		'rnbqr1k1/pp3pbp/2pp1np1/8/2PNP3/2N2P2/PP2B1PP/R1BQ1RK1 w -' => {
			eco => 'E94c',
			# TRANSLATORS: E94c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O exd4 8. Nxd4 Re8 9. f3 c6
			variation => N__('King\'s Indian: 7.O-O exd4 8.Nxd4 Re8 9. f3 c6'),
			moves => {
				'g1h1' => 1,
			},
		},
		'rnbqr1k1/pp3pbp/2pp1np1/8/2PNP3/2N2P2/PP2B1PP/R1BQ1R1K b -' => {
			eco => 'E94c',
			# TRANSLATORS: E94c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O exd4 8. Nxd4 Re8 9. f3 c6 10. Kh1
			variation => N__('King\'s Indian: 7.O-O exd4 8.Nxd4 Re8 9. f3 c6 10. Kh1'),
			moves => {
			},
		},
		'r1bqr1k1/ppp2pbp/2np1np1/8/2PNP3/2N2P2/PP2B1PP/R1BQ1RK1 w -' => {
			eco => 'E94d',
			# TRANSLATORS: E94d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O exd4 8. Nxd4 Re8 9. f3 Nc6
			variation => N__('King\'s Indian: 7.O-O exd4 8.Nxd4 Re8 9. f3 Nc6'),
			moves => {
				'c1e3' => 1,
			},
		},
		'r1bqr1k1/ppp2pbp/2np1np1/8/2PNP3/2N1BP2/PP2B1PP/R2Q1RK1 b -' => {
			eco => 'E94d',
			# TRANSLATORS: E94d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O exd4 8. Nxd4 Re8 9. f3 Nc6 10. Be3
			variation => N__('King\'s Indian: 7.O-O exd4 8.Nxd4 Re8 9. f3 Nc6 10. Be3'),
			moves => {
				'f6h5' => 1,
			},
		},
		'r1bqr1k1/ppp2pbp/2np2p1/7n/2PNP3/2N1BP2/PP2B1PP/R2Q1RK1 w -' => {
			eco => 'E94d',
			# TRANSLATORS: E94d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O exd4 8. Nxd4 Re8 9. f3 Nc6 10. Be3 Nh5
			variation => N__('King\'s Indian: 7.O-O exd4 8.Nxd4 Re8 9. f3 Nc6 10. Be3'),
			moves => {
				'd1d2' => 1,
			},
		},
		'r1bqr1k1/ppp2pbp/2np2p1/7n/2PNP3/2N1BP2/PP1QB1PP/R4RK1 b -' => {
			eco => 'E94e',
			# TRANSLATORS: E94e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O exd4 8. Nxd4 Re8 9. f3 Nc6 10. Be3 Nh5 11. Qd2
			variation => N__('King\'s Indian: 7.O-O exd4 8.Nxd4 Re8 9. f3 Nc6 10. Be3 Nh5 11. Qd2'),
			moves => {
			},
		},
		'rnbq1rk1/pp3pbp/2pp1np1/4p3/2PPP3/2N2N2/PP2BPPP/R1BQ1RK1 w -' => {
			eco => 'E94f',
			# TRANSLATORS: E94f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O c6
			variation => N__('King\'s Indian: Donner Variation'),
			moves => {
				'c1e3' => 1,
				'd4d5' => 1,
			},
		},
		'rnbq1rk1/pp3pbp/2pp1np1/3Pp3/2P1P3/2N2N2/PP2BPPP/R1BQ1RK1 b -' => {
			eco => 'E94g',
			# TRANSLATORS: E94g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O c6 8. d5
			variation => N__('King\'s Indian: Donner, 8. d5'),
			moves => {
			},
		},
		'rnbq1rk1/pp3pbp/2pp1np1/4p3/2PPP3/2N1BN2/PP2BPPP/R2Q1RK1 b -' => {
			eco => 'E94h',
			# TRANSLATORS: E94h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O c6 8. Be3
			variation => N__('King\'s Indian: Donner, 8. Be3'),
			moves => {
			},
		},
		'r1bq1rk1/ppp2pbp/n2p1np1/4p3/2PPP3/2N2N2/PP2BPPP/R1BQ1RK1 w -' => {
			eco => 'E94i',
			# TRANSLATORS: E94i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Na6
			variation => N__('King\'s Indian: Glek Variation'),
			moves => {
				'c1e3' => 1,
				'f1e1' => 1,
			},
		},
		'r1bq1rk1/ppp2pbp/n2p1np1/4p3/2PPP3/2N2N2/PP2BPPP/R1BQR1K1 b -' => {
			eco => 'E94j',
			# TRANSLATORS: E94j: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Na6 8. Re1
			variation => N__('King\'s Indian: Glek, 8. Re1'),
			moves => {
				'c7c6' => 1,
			},
		},
		'r1bq1rk1/pp3pbp/n1pp1np1/4p3/2PPP3/2N2N2/PP2BPPP/R1BQR1K1 w -' => {
			eco => 'E94k',
			# TRANSLATORS: E94k: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Na6 8. Re1 c6
			variation => N__('King\'s Indian: Glek, 8. Re1 c6'),
			moves => {
				'e2f1' => 1,
			},
		},
		'r1bq1rk1/pp3pbp/n1pp1np1/4p3/2PPP3/2N2N2/PP3PPP/R1BQRBK1 b -' => {
			eco => 'E94k',
			# TRANSLATORS: E94k: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Na6 8. Re1 c6 9. Bf1
			variation => N__('King\'s Indian: Glek, 8. Re1 c6 9. Bf1'),
			moves => {
			},
		},
		'r1bq1rk1/ppp2pbp/n2p1np1/4p3/2PPP3/2N1BN2/PP2BPPP/R2Q1RK1 b -' => {
			eco => 'E94l',
			# TRANSLATORS: E94l: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Na6 8. Be3
			variation => N__('King\'s Indian: Glek, 8. Be3'),
			moves => {
				'f6g4' => 1,
			},
		},
		'r1bq1rk1/ppp2pbp/n2p2p1/4p3/2PPP1n1/2N1BN2/PP2BPPP/R2Q1RK1 w -' => {
			eco => 'E94m',
			# TRANSLATORS: E94m: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Na6 8. Be3 Ng4
			variation => N__('King\'s Indian: Glek, 8. Be3 Ng4'),
			moves => {
				'e3g5' => 1,
			},
		},
		'r1bq1rk1/ppp2pbp/n2p2p1/4p1B1/2PPP1n1/2N2N2/PP2BPPP/R2Q1RK1 b -' => {
			eco => 'E94m',
			# TRANSLATORS: E94m: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Na6 8. Be3 Ng4 9. Bg5
			variation => N__('King\'s Indian: Glek, 8. Be3 Ng4'),
			moves => {
				'd8e8' => 1,
			},
		},
		'r1b1qrk1/ppp2pbp/n2p2p1/4p1B1/2PPP1n1/2N2N2/PP2BPPP/R2Q1RK1 w -' => {
			eco => 'E94n',
			# TRANSLATORS: E94n: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Na6 8. Be3 Ng4 9. Bg5 Qe8
			variation => N__('King\'s Indian: Glek, 8. Be3 Ng4 9. Ng5 Qe8'),
			moves => {
				'd4e5' => 1,
			},
		},
		'r1b1qrk1/ppp2pbp/n2p2p1/4P1B1/2P1P1n1/2N2N2/PP2BPPP/R2Q1RK1 b -' => {
			eco => 'E94n',
			# TRANSLATORS: E94n: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Na6 8. Be3 Ng4 9. Bg5 Qe8 10. dxe5
			variation => N__('King\'s Indian: Glek, 8. Be3 Ng4 9. Ng5 Qe8'),
			moves => {
				'd6e5' => 1,
			},
		},
		'r1b1qrk1/ppp2pbp/n5p1/4p1B1/2P1P1n1/2N2N2/PP2BPPP/R2Q1RK1 w -' => {
			eco => 'E94o',
			# TRANSLATORS: E94o: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Na6 8. Be3 Ng4 9. Bg5 Qe8 10. dxe5 dxe5
			variation => N__('King\'s Indian: Glek, Main Line'),
			moves => {
				'h2h3' => 1,
			},
		},
		'r1b1qrk1/ppp2pbp/n5p1/4p1B1/2P1P1n1/2N2N1P/PP2BPP1/R2Q1RK1 b -' => {
			eco => 'E94o',
			# TRANSLATORS: E94o: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Na6 8. Be3 Ng4 9. Bg5 Qe8 10. dxe5 dxe5 11. h3
			variation => N__('King\'s Indian: Glek, Main Line, 11. h3'),
			moves => {
				'h7h6' => 1,
			},
		},
		'r1b1qrk1/ppp2pb1/n5pp/4p1B1/2P1P1n1/2N2N1P/PP2BPP1/R2Q1RK1 w -' => {
			eco => 'E94o',
			# TRANSLATORS: E94o: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Na6 8. Be3 Ng4 9. Bg5 Qe8 10. dxe5 dxe5 11. h3 h6
			variation => N__('King\'s Indian: Glek, Main Line, 11. h3 h6'),
			moves => {
			},
		},
		'r1bq1rk1/pppn1pbp/3p1np1/4p3/2PPP3/2N2N2/PP2BPPP/R1BQ1RK1 w -' => {
			eco => 'E94p',
			# TRANSLATORS: E94p: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7
			variation => N__('King\'s Indian: 7.O-O Nbd7'),
			moves => {
				'c1e3' => 1,
				'd1c2' => 1,
				'd4d5' => 1,
				'f1e1' => 1,
			},
		},
		'r1bq1rk1/pppn1pbp/3p1np1/3Pp3/2P1P3/2N2N2/PP2BPPP/R1BQ1RK1 b -' => {
			eco => 'E94q',
			# TRANSLATORS: E94q: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. d5
			variation => N__('King\'s Indian: 7.O-O Nbd7 8. d5'),
			moves => {
				'd7c5' => 1,
			},
		},
		'r1bq1rk1/ppp2pbp/3p1np1/2nPp3/2P1P3/2N2N2/PP2BPPP/R1BQ1RK1 w -' => {
			eco => 'E94q',
			# TRANSLATORS: E94q: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. d5 Nc5
			variation => N__('King\'s Indian: 7.O-O Nbd7 8. d5 Nc5'),
			moves => {
				'd1c2' => 1,
			},
		},
		'r1bq1rk1/ppp2pbp/3p1np1/2nPp3/2P1P3/2N2N2/PPQ1BPPP/R1B2RK1 b -' => {
			eco => 'E94r',
			# TRANSLATORS: E94r: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. d5 Nc5 9. Qc2
			variation => N__('King\'s Indian: 7.O-O Nbd7 8. d5 Nc5 9. Qc2'),
			moves => {
				'a7a5' => 1,
			},
		},
		'r1bq1rk1/1pp2pbp/3p1np1/p1nPp3/2P1P3/2N2N2/PPQ1BPPP/R1B2RK1 w -' => {
			eco => 'E94r',
			# TRANSLATORS: E94r: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. d5 Nc5 9. Qc2 a5
			variation => N__('King\'s Indian: 7.O-O Nbd7 8. d5 Nc5 9. Qc2 a5'),
			moves => {
			},
		},
		'r1bq1rk1/pppn1pbp/3p1np1/4p3/2PPP3/2N2N2/PPQ1BPPP/R1B2RK1 b -' => {
			eco => 'E94s',
			# TRANSLATORS: E94s: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. Qc2
			variation => N__('King\'s Indian: 7.O-O Nbd7 8. Qc2'),
			moves => {
				'c7c6' => 1,
				'f8e8' => 1,
			},
		},
		'r1bqr1k1/pppn1pbp/3p1np1/4p3/2PPP3/2N2N2/PPQ1BPPP/R1B2RK1 w -' => {
			eco => 'E94s',
			# TRANSLATORS: E94s: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. Qc2 Re8
			variation => N__('King\'s Indian: 7.O-O Nbd7 8. Qc2 Re8'),
			moves => {
			},
		},
		'r1bq1rk1/pp1n1pbp/2pp1np1/4p3/2PPP3/2N2N2/PPQ1BPPP/R1B2RK1 w -' => {
			eco => 'E94t',
			# TRANSLATORS: E94t: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. Qc2 c6
			variation => N__('King\'s Indian: 7.O-O Nbd7 8. Qc2 c6'),
			moves => {
			},
		},
		'r1bq1rk1/pppn1pbp/3p1np1/4p3/2PPP3/2N1BN2/PP2BPPP/R2Q1RK1 b -' => {
			eco => 'E94u',
			# TRANSLATORS: E94u: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. Be3
			variation => N__('King\'s Indian: 7.O-O Nbd7 8. Be3'),
			moves => {
				'c7c6' => 1,
				'f6g4' => 1,
				'f8e8' => 1,
			},
		},
		'r1bq1rk1/pppn1pbp/3p2p1/4p3/2PPP1n1/2N1BN2/PP2BPPP/R2Q1RK1 w -' => {
			eco => 'E94v',
			# TRANSLATORS: E94v: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. Be3 Ng4
			variation => N__('King\'s Indian: 7.O-O Nbd7 8. Be3 Ng4'),
			moves => {
			},
		},
		'r1bqr1k1/pppn1pbp/3p1np1/4p3/2PPP3/2N1BN2/PP2BPPP/R2Q1RK1 w -' => {
			eco => 'E94w',
			# TRANSLATORS: E94w: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. Be3 Re8
			variation => N__('King\'s Indian: 7.O-O Nbd7 8. Be3 Re8'),
			moves => {
			},
		},
		'r1bq1rk1/pp1n1pbp/2pp1np1/4p3/2PPP3/2N1BN2/PP2BPPP/R2Q1RK1 w -' => {
			eco => 'E94x',
			# TRANSLATORS: E94x: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. Be3 c6
			variation => N__('King\'s Indian: 7.O-O Nbd7 8. Be3 c6'),
			moves => {
				'd4d5' => 1,
			},
		},
		'r1bq1rk1/pp1n1pbp/2pp1np1/3Pp3/2P1P3/2N1BN2/PP2BPPP/R2Q1RK1 b -' => {
			eco => 'E94y',
			# TRANSLATORS: E94y: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. Be3 c6 9. d5
			variation => N__('King\'s Indian: 7.O-O Nbd7 8. Be3 c6 9. d5'),
			moves => {
				'c6c5' => 1,
			},
		},
		'r1bq1rk1/pp1n1pbp/3p1np1/2pPp3/2P1P3/2N1BN2/PP2BPPP/R2Q1RK1 w -' => {
			eco => 'E94y',
			# TRANSLATORS: E94y: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. Be3 c6 9. d5 c5
			variation => N__('King\'s Indian: 7.O-O Nbd7 8. Be3 c6 9. d5 c5'),
			moves => {
			},
		},
		'r1bq1rk1/pppn1pbp/3p1np1/4p3/2PPP3/2N2N2/PP2BPPP/R1BQR1K1 b -' => {
			eco => 'E95a',
			# TRANSLATORS: E95a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. Re1
			variation => N__('King\'s Indian: 7.O-O Nbd7 8. Re1'),
			moves => {
				'a7a5' => 1,
				'c7c6' => 1,
				'e5d4' => 1,
				'f8e8' => 1,
				'h7h6' => 1,
			},
		},
		'r1bq1rk1/1ppn1pbp/3p1np1/p3p3/2PPP3/2N2N2/PP2BPPP/R1BQR1K1 w -' => {
			eco => 'E95b',
			# TRANSLATORS: E95b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. Re1 a5
			variation => N__('King\'s Indian: 7.O-O Nbd7 8. Re1 a5'),
			moves => {
			},
		},
		'r1bq1rk1/pppn1pb1/3p1npp/4p3/2PPP3/2N2N2/PP2BPPP/R1BQR1K1 w -' => {
			eco => 'E95c',
			# TRANSLATORS: E95c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. Re1 h6
			variation => N__('King\'s Indian: 7.O-O Nbd7 8. Re1 h6'),
			moves => {
			},
		},
		'r1bqr1k1/pppn1pbp/3p1np1/4p3/2PPP3/2N2N2/PP2BPPP/R1BQR1K1 w -' => {
			eco => 'E95d',
			# TRANSLATORS: E95d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. Re1 Re8
			variation => N__('King\'s Indian: 7.O-O Nbd7 8. Re1 Re8'),
			moves => {
				'e2f1' => 1,
			},
		},
		'r1bqr1k1/pppn1pbp/3p1np1/4p3/2PPP3/2N2N2/PP3PPP/R1BQRBK1 b -' => {
			eco => 'E95e',
			# TRANSLATORS: E95e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. Re1 Re8 9. Bf1
			variation => N__('King\'s Indian: 7.O-O Nbd7 8. Re1 Re8 9. Bf1'),
			moves => {
			},
		},
		'r1bq1rk1/pppn1pbp/3p1np1/8/2PpP3/2N2N2/PP2BPPP/R1BQR1K1 w -' => {
			eco => 'E95f',
			# TRANSLATORS: E95f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. Re1 exd4
			variation => N__('King\'s Indian: 7.O-O Nbd7 8. Re1 exd4'),
			moves => {
				'f3d4' => 1,
			},
		},
		'r1bq1rk1/pppn1pbp/3p1np1/8/2PNP3/2N5/PP2BPPP/R1BQR1K1 b -' => {
			eco => 'E95f',
			# TRANSLATORS: E95f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. Re1 exd4 9. Nxd4
			variation => N__('King\'s Indian: 7.O-O Nbd7 8. Re1 exd4'),
			moves => {
				'd7c5' => 1,
			},
		},
		'r1bq1rk1/ppp2pbp/3p1np1/2n5/2PNP3/2N5/PP2BPPP/R1BQR1K1 w -' => {
			eco => 'E95g',
			# TRANSLATORS: E95g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. Re1 exd4 9. Nxd4 Nc5
			variation => N__('King\'s Indian: 7.O-O Nbd7 8. Re1 exd4 9.Nxd4 Nc5'),
			moves => {
			},
		},
		'r1bq1rk1/pp1n1pbp/2pp1np1/4p3/2PPP3/2N2N2/PP2BPPP/R1BQR1K1 w -' => {
			eco => 'E95h',
			# TRANSLATORS: E95h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. Re1 c6
			variation => N__('King\'s Indian: 7.O-O Nbd7 8. Re1 c6'),
			moves => {
				'a1b1' => 1,
				'e2f1' => 1,
			},
		},
		'r1bq1rk1/pp1n1pbp/2pp1np1/4p3/2PPP3/2N2N2/PP2BPPP/1RBQR1K1 b -' => {
			eco => 'E95i',
			# TRANSLATORS: E95i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. Re1 c6 9. Rb1
			variation => N__('King\'s Indian: 7.O-O Nbd7 8. Re1 c6 9. Rb1'),
			moves => {
			},
		},
		'r1bq1rk1/pp1n1pbp/2pp1np1/4p3/2PPP3/2N2N2/PP3PPP/R1BQRBK1 b -' => {
			eco => 'E95j',
			# TRANSLATORS: E95j: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. Re1 c6 9. Bf1
			variation => N__('King\'s Indian: 7.O-O Nbd7 8. Re1 c6 9. Bf1'),
			moves => {
				'a7a5' => 1,
				'e5d4' => 1,
				'f8e8' => 1,
			},
		},
		'r1bqr1k1/pp1n1pbp/2pp1np1/4p3/2PPP3/2N2N2/PP3PPP/R1BQRBK1 w -' => {
			eco => 'E95k',
			# TRANSLATORS: E95k: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. Re1 c6 9. Bf1 Re8
			variation => N__('King\'s Indian: 7.O-O Nbd7 8. Re1 c6 9. Bf1 Re8'),
			moves => {
			},
		},
		'r1bq1rk1/pp1n1pbp/2pp1np1/8/2PpP3/2N2N2/PP3PPP/R1BQRBK1 w -' => {
			eco => 'E95l',
			# TRANSLATORS: E95l: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. Re1 c6 9. Bf1 exd4
			variation => N__('King\'s Indian: 7.O-O Nbd7 8. Re1 c6 9. Bf1 exd4'),
			moves => {
				'f3d4' => 1,
			},
		},
		'r1bq1rk1/pp1n1pbp/2pp1np1/8/2PNP3/2N5/PP3PPP/R1BQRBK1 b -' => {
			eco => 'E95l',
			# TRANSLATORS: E95l: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. Re1 c6 9. Bf1 exd4 10. Nxd4
			variation => N__('King\'s Indian: 7.O-O Nbd7 8. Re1 c6 9. Bf1 exd4'),
			moves => {
				'f6g4' => 1,
				'f8e8' => 1,
			},
		},
		'r1bq1rk1/pp1n1pbp/2pp2p1/8/2PNP1n1/2N5/PP3PPP/R1BQRBK1 w -' => {
			eco => 'E95m',
			# TRANSLATORS: E95m: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. Re1 c6 9. Bf1 exd4 10. Nxd4 Ng4
			variation => N__('King\'s Indian: 7.O-O Nbd7 8. Re1 c6 9. Bf1 exd4 10.Nxd4 Ng4'),
			moves => {
			},
		},
		'r1bqr1k1/pp1n1pbp/2pp1np1/8/2PNP3/2N5/PP3PPP/R1BQRBK1 w -' => {
			eco => 'E95n',
			# TRANSLATORS: E95n: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. Re1 c6 9. Bf1 exd4 10. Nxd4 Re8
			variation => N__('King\'s Indian: 7.O-O Nbd7 8. Re1 c6 9. Bf1 exd4 10.Nxd4 Re8'),
			moves => {
			},
		},
		'r1bq1rk1/1p1n1pbp/2pp1np1/p3p3/2PPP3/2N2N2/PP3PPP/R1BQRBK1 w -' => {
			eco => 'E96',
			# TRANSLATORS: E96: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. Re1 c6 9. Bf1 a5
			variation => N__('King\'s Indian: 7.O-O Nbd7, Old Main Line'),
			moves => {
				'a1b1' => 1,
				'd4e5' => 1,
				'h2h3' => 1,
			},
		},
		'r1bq1rk1/1p1n1pbp/2pp1np1/p3p3/2PPP3/2N2N2/PP3PPP/1RBQRBK1 b -' => {
			eco => 'E96',
			# TRANSLATORS: E96: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. Re1 c6 9. Bf1 a5 10. Rb1
			variation => N__('King\'s Indian: 7.O-O Nbd7, Old Main Line, 10. Rb1'),
			moves => {
				'f8e8' => 1,
			},
		},
		'r1bqr1k1/1p1n1pbp/2pp1np1/p3p3/2PPP3/2N2N2/PP3PPP/1RBQRBK1 w -' => {
			eco => 'E96',
			# TRANSLATORS: E96: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. Re1 c6 9. Bf1 a5 10. Rb1 Re8
			variation => N__('King\'s Indian: 7.O-O Nbd7, Old Main Line, 10. Rb1 Re8'),
			moves => {
				'd4d5' => 1,
			},
		},
		'r1bqr1k1/1p1n1pbp/2pp1np1/p2Pp3/2P1P3/2N2N2/PP3PPP/1RBQRBK1 b -' => {
			eco => 'E96',
			# TRANSLATORS: E96: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. Re1 c6 9. Bf1 a5 10. Rb1 Re8 11. d5
			variation => N__('King\'s Indian: 7.O-O Nbd7, Old Main Line, 10. Rb1 Re8 11. d5'),
			moves => {
				'd7c5' => 1,
			},
		},
		'r1bqr1k1/1p3pbp/2pp1np1/p1nPp3/2P1P3/2N2N2/PP3PPP/1RBQRBK1 w -' => {
			eco => 'E96',
			# TRANSLATORS: E96: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. Re1 c6 9. Bf1 a5 10. Rb1 Re8 11. d5 Nc5
			variation => N__('King\'s Indian: 7.O-O Nbd7, Old Main Line, 10. Rb1 Re8 11. d5'),
			moves => {
				'b2b3' => 1,
			},
		},
		'r1bqr1k1/1p3pbp/2pp1np1/p1nPp3/2P1P3/1PN2N2/P4PPP/1RBQRBK1 b -' => {
			eco => 'E96',
			# TRANSLATORS: E96: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. Re1 c6 9. Bf1 a5 10. Rb1 Re8 11. d5 Nc5 12. b3
			variation => N__('King\'s Indian: 7.O-O Nbd7, Old Main Line, 10. Rb1 Re8 11. d5 Nc5 12. b3'),
			moves => {
			},
		},
		'r1bq1rk1/1p1n1pbp/2pp1np1/p3P3/2P1P3/2N2N2/PP3PPP/R1BQRBK1 b -' => {
			eco => 'E96',
			# TRANSLATORS: E96: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. Re1 c6 9. Bf1 a5 10. dxe5
			variation => N__('King\'s Indian: 7.O-O Nbd7, Old Main Line, 10.dxe5'),
			moves => {
				'd6e5' => 1,
			},
		},
		'r1bq1rk1/1p1n1pbp/2p2np1/p3p3/2P1P3/2N2N2/PP3PPP/R1BQRBK1 w -' => {
			eco => 'E96',
			# TRANSLATORS: E96: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. Re1 c6 9. Bf1 a5 10. dxe5 dxe5
			variation => N__('King\'s Indian: 7.O-O Nbd7, Old Main Line, 10.dxe5'),
			moves => {
			},
		},
		'r1bq1rk1/1p1n1pbp/2pp1np1/p3p3/2PPP3/2N2N1P/PP3PP1/R1BQRBK1 b -' => {
			eco => 'E96',
			# TRANSLATORS: E96: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nbd7 8. Re1 c6 9. Bf1 a5 10. h3
			variation => N__('King\'s Indian: 7.O-O Nbd7, Old Main Line, 10. h3'),
			moves => {
			},
		},
		'r1bq1rk1/ppp2pbp/2np1np1/4p3/2PPP3/2N2N2/PP2BPPP/R1BQ1RK1 w -' => {
			eco => 'E97a',
			# TRANSLATORS: E97a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6
			variation => N__('King\'s Indian: Mar del Plata'),
			moves => {
				'c1e3' => 1,
				'd4d5' => 1,
				'd4e5' => 1,
			},
		},
		'r1bq1rk1/ppp2pbp/2np1np1/4P3/2P1P3/2N2N2/PP2BPPP/R1BQ1RK1 b -' => {
			eco => 'E97b',
			# TRANSLATORS: E97b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. dxe5
			variation => N__('King\'s Indian: Mar del Plata, 8.dxe5'),
			moves => {
			},
		},
		'r1bq1rk1/ppp2pbp/2np1np1/4p3/2PPP3/2N1BN2/PP2BPPP/R2Q1RK1 b -' => {
			eco => 'E97c',
			# TRANSLATORS: E97c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. Be3
			variation => N__('King\'s Indian: Mar del Plata, 8. Be3'),
			moves => {
				'f6g4' => 1,
			},
		},
		'r1bq1rk1/ppp2pbp/2np2p1/4p3/2PPP1n1/2N1BN2/PP2BPPP/R2Q1RK1 w -' => {
			eco => 'E97c',
			# TRANSLATORS: E97c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. Be3 Ng4
			variation => N__('King\'s Indian: Mar del Plata, 8. Be3 Ng4'),
			moves => {
				'e3g5' => 1,
			},
		},
		'r1bq1rk1/ppp2pbp/2np2p1/4p1B1/2PPP1n1/2N2N2/PP2BPPP/R2Q1RK1 b -' => {
			eco => 'E97c',
			# TRANSLATORS: E97c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. Be3 Ng4 9. Bg5
			variation => N__('King\'s Indian: Mar del Plata, 8. Be3 Ng4'),
			moves => {
				'f7f6' => 1,
			},
		},
		'r1bq1rk1/ppp3bp/2np1pp1/4p1B1/2PPP1n1/2N2N2/PP2BPPP/R2Q1RK1 w -' => {
			eco => 'E97c',
			# TRANSLATORS: E97c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. Be3 Ng4 9. Bg5 f6
			variation => N__('King\'s Indian: Mar del Plata, 8. Be3 Ng4'),
			moves => {
				'g5c1' => 1,
			},
		},
		'r1bq1rk1/ppp3bp/2np1pp1/4p3/2PPP1n1/2N2N2/PP2BPPP/R1BQ1RK1 b -' => {
			eco => 'E97c',
			# TRANSLATORS: E97c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. Be3 Ng4 9. Bg5 f6 10. Bc1
			variation => N__('King\'s Indian: Mar del Plata, 8. Be3 Ng4'),
			moves => {
			},
		},
		'r1bq1rk1/ppp2pbp/2np1np1/3Pp3/2P1P3/2N2N2/PP2BPPP/R1BQ1RK1 b -' => {
			eco => 'E97d',
			# TRANSLATORS: E97d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5
			variation => N__('King\'s Indian: Mar del Plata, 8. d5'),
			moves => {
				'c6e7' => 1,
			},
		},
		'r1bq1rk1/ppp1npbp/3p1np1/3Pp3/2P1P3/2N2N2/PP2BPPP/R1BQ1RK1 w -' => {
			eco => 'E97d',
			# TRANSLATORS: E97d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7
			variation => N__('King\'s Indian: Mar del Plata, 8. d5 Ne7'),
			moves => {
				'b2b4' => 1,
				'c1d2' => 1,
				'c1g5' => 1,
				'f3d2' => 1,
				'f3e1' => 1,
			},
		},
		'r1bq1rk1/ppp1npbp/3p1np1/3Pp1B1/2P1P3/2N2N2/PP2BPPP/R2Q1RK1 b -' => {
			eco => 'E97d',
			# TRANSLATORS: E97d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Bg5
			variation => N__('King\'s Indian: Mar del Plata, Odessa Variation'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1npbp/3p1np1/3Pp3/2P1P3/2N2N2/PP1BBPPP/R2Q1RK1 b -' => {
			eco => 'E97e',
			# TRANSLATORS: E97e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Bd2
			variation => N__('King\'s Indian: Mar del Plata, 9. Bd2'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1npbp/3p1np1/3Pp3/1PP1P3/2N2N2/P3BPPP/R1BQ1RK1 b -' => {
			eco => 'E97f',
			# TRANSLATORS: E97f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. b4
			variation => N__('King\'s Indian: Mar del Plata, Bayonet Attack'),
			moves => {
				'a7a5' => 1,
				'f6e8' => 1,
				'f6h5' => 1,
				'g8h8' => 1,
			},
		},
		'r1bq1r1k/ppp1npbp/3p1np1/3Pp3/1PP1P3/2N2N2/P3BPPP/R1BQ1RK1 w -' => {
			eco => 'E97g',
			# TRANSLATORS: E97g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. b4 Kh8
			variation => N__('King\'s Indian: Mar del Plata, Bayonet Attack, 9... Kh8'),
			moves => {
			},
		},
		'r1bqnrk1/ppp1npbp/3p2p1/3Pp3/1PP1P3/2N2N2/P3BPPP/R1BQ1RK1 w -' => {
			eco => 'E97h',
			# TRANSLATORS: E97h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. b4 Ne8
			variation => N__('King\'s Indian: Mar del Plata, Bayonet Attack, 9... Ne8'),
			moves => {
				'c4c5' => 1,
			},
		},
		'r1bqnrk1/ppp1npbp/3p2p1/2PPp3/1P2P3/2N2N2/P3BPPP/R1BQ1RK1 b -' => {
			eco => 'E97h',
			# TRANSLATORS: E97h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. b4 Ne8 10. c5
			variation => N__('King\'s Indian: Mar del Plata, Bayonet Attack, 9... Ne8 10. c5'),
			moves => {
			},
		},
		'r1bq1rk1/1pp1npbp/3p1np1/p2Pp3/1PP1P3/2N2N2/P3BPPP/R1BQ1RK1 w -' => {
			eco => 'E97i',
			# TRANSLATORS: E97i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. b4 a5
			variation => N__('King\'s Indian: Mar del Plata, Bayonet Attack, 9... a5'),
			moves => {
				'b4a5' => 1,
				'c1a3' => 1,
			},
		},
		'r1bq1rk1/1pp1npbp/3p1np1/P2Pp3/2P1P3/2N2N2/P3BPPP/R1BQ1RK1 b -' => {
			eco => 'E97i',
			# TRANSLATORS: E97i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. b4 a5 10. bxa5
			variation => N__('King\'s Indian: Mar del Plata, Bayonet Attack, 9... a5 10.bxa5'),
			moves => {
			},
		},
		'r1bq1rk1/1pp1npbp/3p1np1/p2Pp3/1PP1P3/B1N2N2/P3BPPP/R2Q1RK1 b -' => {
			eco => 'E97j',
			# TRANSLATORS: E97j: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. b4 a5 10. Ba3
			variation => N__('King\'s Indian: Mar del Plata, Bayonet Attack, 9... a5 10. Ba3'),
			moves => {
				'a5b4' => 1,
			},
		},
		'r1bq1rk1/1pp1npbp/3p1np1/3Pp3/1pP1P3/B1N2N2/P3BPPP/R2Q1RK1 w -' => {
			eco => 'E97k',
			# TRANSLATORS: E97k: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. b4 a5 10. Ba3 axb4
			variation => N__('King\'s Indian: Mar del Plata, Bayonet Attack, 9... a5 10. Ba3 axb4'),
			moves => {
				'a3b4' => 1,
			},
		},
		'r1bq1rk1/1pp1npbp/3p1np1/3Pp3/1BP1P3/2N2N2/P3BPPP/R2Q1RK1 b -' => {
			eco => 'E97k',
			# TRANSLATORS: E97k: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. b4 a5 10. Ba3 axb4 11. Bxb4
			variation => N__('King\'s Indian: Mar del Plata, Bayonet Attack, 9... a5 10. Ba3 axb4'),
			moves => {
				'f6d7' => 1,
			},
		},
		'r1bq1rk1/1ppnnpbp/3p2p1/3Pp3/1BP1P3/2N2N2/P3BPPP/R2Q1RK1 w -' => {
			eco => 'E97k',
			# TRANSLATORS: E97k: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. b4 a5 10. Ba3 axb4 11. Bxb4 Nd7
			variation => N__('King\'s Indian: Mar del Plata, Bayonet Attack, 9... a5 10. Ba3 axb4 11.Bxb4 Nd7'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1npbp/3p2p1/3Pp2n/1PP1P3/2N2N2/P3BPPP/R1BQ1RK1 w -' => {
			eco => 'E97l',
			# TRANSLATORS: E97l: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. b4 Nh5
			variation => N__('King\'s Indian: Mar del Plata, Bayonet Attack, 9... Nh5'),
			moves => {
				'c4c5' => 1,
				'f1e1' => 1,
				'g2g3' => 1,
			},
		},
		'r1bq1rk1/ppp1npbp/3p2p1/2PPp2n/1P2P3/2N2N2/P3BPPP/R1BQ1RK1 b -' => {
			eco => 'E97m',
			# TRANSLATORS: E97m: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. b4 Nh5 10. c5
			variation => N__('King\'s Indian: Mar del Plata, Bayonet Attack, 9... Nh5 10. c5'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1npbp/3p2p1/3Pp2n/1PP1P3/2N2NP1/P3BP1P/R1BQ1RK1 b -' => {
			eco => 'E97n',
			# TRANSLATORS: E97n: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. b4 Nh5 10. g3
			variation => N__('King\'s Indian: Mar del Plata, Bayonet Attack, 9... Nh5 10. g3'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1npbp/3p2p1/3Pp2n/1PP1P3/2N2N2/P3BPPP/R1BQR1K1 b -' => {
			eco => 'E97o',
			# TRANSLATORS: E97o: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. b4 Nh5 10. Re1
			variation => N__('King\'s Indian: Mar del Plata, Bayonet Attack, 9... Nh5 10. Re1'),
			moves => {
				'a7a5' => 1,
				'f7f5' => 1,
				'h5f4' => 1,
			},
		},
		'r1bq1rk1/1pp1npbp/3p2p1/p2Pp2n/1PP1P3/2N2N2/P3BPPP/R1BQR1K1 w -' => {
			eco => 'E97p',
			# TRANSLATORS: E97p: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. b4 Nh5 10. Re1 a5
			variation => N__('King\'s Indian: Mar del Plata, Bayonet, 9... Nh5 10. Re1 a5'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1npbp/3p2p1/3Pp3/1PP1Pn2/2N2N2/P3BPPP/R1BQR1K1 w -' => {
			eco => 'E97q',
			# TRANSLATORS: E97q: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. b4 Nh5 10. Re1 Nf4
			variation => N__('King\'s Indian: Mar del Plata, Bayonet, 9... Nh5 10. Re1 Nf4'),
			moves => {
				'e2f1' => 1,
			},
		},
		'r1bq1rk1/ppp1npbp/3p2p1/3Pp3/1PP1Pn2/2N2N2/P4PPP/R1BQRBK1 b -' => {
			eco => 'E97q',
			# TRANSLATORS: E97q: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. b4 Nh5 10. Re1 Nf4 11. Bf1
			variation => N__('King\'s Indian: Mar del Plata, Bayonet, 9... Nh5 10. Re1 Nf4'),
			moves => {
				'a7a5' => 1,
			},
		},
		'r1bq1rk1/1pp1npbp/3p2p1/p2Pp3/1PP1Pn2/2N2N2/P4PPP/R1BQRBK1 w -' => {
			eco => 'E97q',
			# TRANSLATORS: E97q: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. b4 Nh5 10. Re1 Nf4 11. Bf1 a5
			variation => N__('King\'s Indian: Mar del Plata, Bayonet, 9... Nh5 10. Re1 Nf4 11. Bf1 a5'),
			moves => {
				'b4a5' => 1,
			},
		},
		'r1bq1rk1/1pp1npbp/3p2p1/P2Pp3/2P1Pn2/2N2N2/P4PPP/R1BQRBK1 b -' => {
			eco => 'E97q',
			# TRANSLATORS: E97q: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. b4 Nh5 10. Re1 Nf4 11. Bf1 a5 12. bxa5
			variation => N__('King\'s Indian: Mar del Plata, Bayonet, 9... Nh5 10. Re1 Nf4 11. Bf1 a5 12.bxa5'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1n1bp/3p2p1/3Ppp1n/1PP1P3/2N2N2/P3BPPP/R1BQR1K1 w -' => {
			eco => 'E97r',
			# TRANSLATORS: E97r: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. b4 Nh5 10. Re1 f5
			variation => N__('King\'s Indian: Mar del Plata, Bayonet, 9... Nh5 10. Re1 f5'),
			moves => {
				'f3g5' => 1,
			},
		},
		'r1bq1rk1/ppp1n1bp/3p2p1/3PppNn/1PP1P3/2N5/P3BPPP/R1BQR1K1 b -' => {
			eco => 'E97r',
			# TRANSLATORS: E97r: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. b4 Nh5 10. Re1 f5 11. Ng5
			variation => N__('King\'s Indian: Mar del Plata, Bayonet, 9... Nh5 10. Re1 f5'),
			moves => {
				'h5f6' => 1,
			},
		},
		'r1bq1rk1/ppp1n1bp/3p1np1/3PppN1/1PP1P3/2N5/P3BPPP/R1BQR1K1 w -' => {
			eco => 'E97s',
			# TRANSLATORS: E97s: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. b4 Nh5 10. Re1 f5 11. Ng5 Nf6
			variation => N__('King\'s Indian: Mar del Plata, Bayonet, 9... Nh5 10. Re1 f5 11. Ng5 Nf6'),
			moves => {
				'e2f3' => 1,
			},
		},
		'r1bq1rk1/ppp1n1bp/3p1np1/3PppN1/1PP1P3/2N2B2/P4PPP/R1BQR1K1 b -' => {
			eco => 'E97s',
			# TRANSLATORS: E97s: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. b4 Nh5 10. Re1 f5 11. Ng5 Nf6 12. Bf3
			variation => N__('King\'s Indian: Mar del Plata, Bayonet, 9... Nh5 10. Re1 f5 11. Ng5 Nf6 12. Bf3'),
			moves => {
				'c7c6' => 1,
			},
		},
		'r1bq1rk1/pp2n1bp/2pp1np1/3PppN1/1PP1P3/2N2B2/P4PPP/R1BQR1K1 w -' => {
			eco => 'E97s',
			# TRANSLATORS: E97s: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. b4 Nh5 10. Re1 f5 11. Ng5 Nf6 12. Bf3 c6
			variation => N__('King\'s Indian: Mar del Plata, Bayonet, 9... Nh5 10. Re1 f5 11. Ng5 Nf6 12. Bf3 c6'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1npbp/3p1np1/3Pp3/2P1P3/2N5/PP1NBPPP/R1BQ1RK1 b -' => {
			eco => 'E97t',
			# TRANSLATORS: E97t: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Nd2
			variation => N__('King\'s Indian: Mar del Plata, 9. Nd2'),
			moves => {
				'a7a5' => 1,
				'c7c5' => 1,
				'f6d7' => 1,
				'f6e8' => 1,
			},
		},
		'r1bqnrk1/ppp1npbp/3p2p1/3Pp3/2P1P3/2N5/PP1NBPPP/R1BQ1RK1 w -' => {
			eco => 'E97u',
			# TRANSLATORS: E97u: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Nd2 Ne8
			variation => N__('King\'s Indian: Mar del Plata, 9. Nd2 Ne8'),
			moves => {
				'b2b4' => 1,
			},
		},
		'r1bqnrk1/ppp1npbp/3p2p1/3Pp3/1PP1P3/2N5/P2NBPPP/R1BQ1RK1 b -' => {
			eco => 'E97u',
			# TRANSLATORS: E97u: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Nd2 Ne8 10. b4
			variation => N__('King\'s Indian: Mar del Plata, 9. Nd2 Ne8 10. b4'),
			moves => {
			},
		},
		'r1bq1rk1/pppnnpbp/3p2p1/3Pp3/2P1P3/2N5/PP1NBPPP/R1BQ1RK1 w -' => {
			eco => 'E97v',
			# TRANSLATORS: E97v: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Nd2 Nd7
			variation => N__('King\'s Indian: Mar del Plata, 9. Nd2 Nd7'),
			moves => {
				'b2b4' => 1,
			},
		},
		'r1bq1rk1/pppnnpbp/3p2p1/3Pp3/1PP1P3/2N5/P2NBPPP/R1BQ1RK1 b -' => {
			eco => 'E97v',
			# TRANSLATORS: E97v: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Nd2 Nd7 10. b4
			variation => N__('King\'s Indian: Mar del Plata, 9. Nd2 Nd7 10. b4'),
			moves => {
			},
		},
		'r1bq1rk1/pp2npbp/3p1np1/2pPp3/2P1P3/2N5/PP1NBPPP/R1BQ1RK1 w -' => {
			eco => 'E97w',
			# TRANSLATORS: E97w: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Nd2 c5
			variation => N__('King\'s Indian: Mar del Plata, 9. Nd2 c5'),
			moves => {
			},
		},
		'r1bq1rk1/1pp1npbp/3p1np1/p2Pp3/2P1P3/2N5/PP1NBPPP/R1BQ1RK1 w -' => {
			eco => 'E97x',
			# TRANSLATORS: E97x: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Nd2 a5
			variation => N__('King\'s Indian: Mar del Plata, 9. Nd2 a5'),
			moves => {
				'a1b1' => 1,
				'a2a3' => 1,
			},
		},
		'r1bq1rk1/1pp1npbp/3p1np1/p2Pp3/2P1P3/2N5/PP1NBPPP/1RBQ1RK1 b -' => {
			eco => 'E97x',
			# TRANSLATORS: E97x: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Nd2 a5 10. Rb1
			variation => N__('King\'s Indian: Mar del Plata, 9. Nd2 a5 10. Rb1'),
			moves => {
			},
		},
		'r1bq1rk1/1pp1npbp/3p1np1/p2Pp3/2P1P3/P1N5/1P1NBPPP/R1BQ1RK1 b -' => {
			eco => 'E97y',
			# TRANSLATORS: E97y: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Nd2 a5 10. a3
			variation => N__('King\'s Indian: Mar del Plata, 9. Nd2 a5 10. a3'),
			moves => {
				'c8d7' => 1,
				'f6d7' => 1,
			},
		},
		'r2q1rk1/1ppbnpbp/3p1np1/p2Pp3/2P1P3/P1N5/1P1NBPPP/R1BQ1RK1 w -' => {
			eco => 'E97y',
			# TRANSLATORS: E97y: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Nd2 a5 10. a3 Bd7
			variation => N__('King\'s Indian: Mar del Plata, 9. Nd2 a5 10. a3 Bd7'),
			moves => {
			},
		},
		'r1bq1rk1/1ppnnpbp/3p2p1/p2Pp3/2P1P3/P1N5/1P1NBPPP/R1BQ1RK1 w -' => {
			eco => 'E97z',
			# TRANSLATORS: E97z: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Nd2 a5 10. a3 Nd7
			variation => N__('King\'s Indian: Mar del Plata, 9. Nd2 a5 10. a3 Nd7'),
			moves => {
				'a1b1' => 1,
			},
		},
		'r1bq1rk1/1ppnnpbp/3p2p1/p2Pp3/2P1P3/P1N5/1P1NBPPP/1RBQ1RK1 b -' => {
			eco => 'E97z',
			# TRANSLATORS: E97z: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Nd2 a5 10. a3 Nd7 11. Rb1
			variation => N__('King\'s Indian: Mar del Plata, 9. Nd2 a5 10. a3 Nd7 11. Rb1'),
			moves => {
				'f7f5' => 1,
			},
		},
		'r1bq1rk1/1ppnn1bp/3p2p1/p2Ppp2/2P1P3/P1N5/1P1NBPPP/1RBQ1RK1 w -' => {
			eco => 'E97z',
			# TRANSLATORS: E97z: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Nd2 a5 10. a3 Nd7 11. Rb1 f5
			variation => N__('King\'s Indian: Mar del Plata, 9. Nd2 a5 10. a3 Nd7 11. Rb1'),
			moves => {
				'b2b4' => 1,
			},
		},
		'r1bq1rk1/1ppnn1bp/3p2p1/p2Ppp2/1PP1P3/P1N5/3NBPPP/1RBQ1RK1 b -' => {
			eco => 'E97z',
			# TRANSLATORS: E97z: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Nd2 a5 10. a3 Nd7 11. Rb1 f5 12. b4
			variation => N__('King\'s Indian: Mar del Plata, 9. Nd2 a5 10. a3 Nd7 11. Rb1 f5 12. b4'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1npbp/3p1np1/3Pp3/2P1P3/2N5/PP2BPPP/R1BQNRK1 b -' => {
			eco => 'E98a',
			# TRANSLATORS: E98a: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1
			variation => N__('King\'s Indian: Mar del Plata, 9. Ne1'),
			moves => {
				'c7c5' => 1,
				'f6d7' => 1,
				'f6e8' => 1,
			},
		},
		'r1bq1rk1/pp2npbp/3p1np1/2pPp3/2P1P3/2N5/PP2BPPP/R1BQNRK1 w -' => {
			eco => 'E98b',
			# TRANSLATORS: E98b: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 c5
			variation => N__('King\'s Indian: Mar del Plata, 9. Ne1 c5'),
			moves => {
			},
		},
		'r1bqnrk1/ppp1npbp/3p2p1/3Pp3/2P1P3/2N5/PP2BPPP/R1BQNRK1 w -' => {
			eco => 'E98c',
			# TRANSLATORS: E98c: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 Ne8
			variation => N__('King\'s Indian: Mar del Plata, 9. Ne1 Ne8'),
			moves => {
				'c1e3' => 1,
				'e1d3' => 1,
			},
		},
		'r1bqnrk1/ppp1npbp/3p2p1/3Pp3/2P1P3/2NN4/PP2BPPP/R1BQ1RK1 b -' => {
			eco => 'E98d',
			# TRANSLATORS: E98d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 Ne8 10. Nd3
			variation => N__('King\'s Indian: Mar del Plata, 9. Ne1 Ne8 10. Nd3'),
			moves => {
				'f7f5' => 1,
			},
		},
		'r1bqnrk1/ppp1n1bp/3p2p1/3Ppp2/2P1P3/2NN4/PP2BPPP/R1BQ1RK1 w -' => {
			eco => 'E98d',
			# TRANSLATORS: E98d: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 Ne8 10. Nd3 f5
			variation => N__('King\'s Indian: Mar del Plata, 9. Ne1 Ne8 10. Nd3 f5'),
			moves => {
			},
		},
		'r1bqnrk1/ppp1npbp/3p2p1/3Pp3/2P1P3/2N1B3/PP2BPPP/R2QNRK1 b -' => {
			eco => 'E98e',
			# TRANSLATORS: E98e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 Ne8 10. Be3
			variation => N__('King\'s Indian: Mar del Plata, 9. Ne1 Ne8 10. Be3'),
			moves => {
				'f7f5' => 1,
			},
		},
		'r1bqnrk1/ppp1n1bp/3p2p1/3Ppp2/2P1P3/2N1B3/PP2BPPP/R2QNRK1 w -' => {
			eco => 'E98e',
			# TRANSLATORS: E98e: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 Ne8 10. Be3 f5
			variation => N__('King\'s Indian: Mar del Plata, 9. Ne1 Ne8 10. Be3'),
			moves => {
				'f2f3' => 1,
			},
		},
		'r1bqnrk1/ppp1n1bp/3p2p1/3Ppp2/2P1P3/2N1BP2/PP2B1PP/R2QNRK1 b -' => {
			eco => 'E98f',
			# TRANSLATORS: E98f: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 Ne8 10. Be3 f5 11. f3
			variation => N__('King\'s Indian: Mar del Plata, 9. Ne1 Ne8 10. Be3 f5 11. f3'),
			moves => {
				'f5f4' => 1,
			},
		},
		'r1bqnrk1/ppp1n1bp/3p2p1/3Pp3/2P1Pp2/2N1BP2/PP2B1PP/R2QNRK1 w -' => {
			eco => 'E98g',
			# TRANSLATORS: E98g: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 Ne8 10. Be3 f5 11. f3 f4
			variation => N__('King\'s Indian: Mar del Plata, 9. Ne1 Ne8 10. Be3 f5 11. f3 f4'),
			moves => {
			},
		},
		'r1bq1rk1/pppnnpbp/3p2p1/3Pp3/2P1P3/2N5/PP2BPPP/R1BQNRK1 w -' => {
			eco => 'E98h',
			# TRANSLATORS: E98h: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 Nd7
			variation => N__('King\'s Indian: Mar del Plata, 9. Ne1 Nd7'),
			moves => {
				'c1e3' => 1,
				'e1d3' => 1,
				'f2f3' => 1,
				'g1h1' => 1,
			},
		},
		'r1bq1rk1/pppnnpbp/3p2p1/3Pp3/2P1P3/2N5/PP2BPPP/R1BQNR1K b -' => {
			eco => 'E98i',
			# TRANSLATORS: E98i: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 Nd7 10. Kh1
			variation => N__('King\'s Indian: Mar del Plata, 9. Ne1 Nd7 10. Kh1'),
			moves => {
			},
		},
		'r1bq1rk1/pppnnpbp/3p2p1/3Pp3/2P1P3/2N1B3/PP2BPPP/R2QNRK1 b -' => {
			eco => 'E98j',
			# TRANSLATORS: E98j: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 Nd7 10. Be3
			variation => N__('King\'s Indian: Mar del Plata, 9. Ne1 Nd7 10. Be3'),
			moves => {
				'f7f5' => 1,
			},
		},
		'r1bq1rk1/pppnn1bp/3p2p1/3Ppp2/2P1P3/2N1B3/PP2BPPP/R2QNRK1 w -' => {
			eco => 'E98k',
			# TRANSLATORS: E98k: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 Nd7 10. Be3 f5
			variation => N__('King\'s Indian: Mar del Plata, 9. Ne1 Nd7 10. Be3 f5'),
			moves => {
			},
		},
		'r1bq1rk1/pppnnpbp/3p2p1/3Pp3/2P1P3/2NN4/PP2BPPP/R1BQ1RK1 b -' => {
			eco => 'E98l',
			# TRANSLATORS: E98l: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 Nd7 10. Nd3
			variation => N__('King\'s Indian: Mar del Plata, 9. Ne1 Nd7 10. Nd3'),
			moves => {
				'f7f5' => 1,
			},
		},
		'r1bq1rk1/pppnn1bp/3p2p1/3Ppp2/2P1P3/2NN4/PP2BPPP/R1BQ1RK1 w -' => {
			eco => 'E98m',
			# TRANSLATORS: E98m: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 Nd7 10. Nd3 f5
			variation => N__('King\'s Indian: Mar del Plata, 9. Ne1 Nd7 10. Nd3 f5'),
			moves => {
				'c1d2' => 1,
			},
		},
		'r1bq1rk1/pppnn1bp/3p2p1/3Ppp2/2P1P3/2NN4/PP1BBPPP/R2Q1RK1 b -' => {
			eco => 'E98n',
			# TRANSLATORS: E98n: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 Nd7 10. Nd3 f5 11. Bd2
			variation => N__('King\'s Indian: Mar del Plata, 9. Ne1 Nd7 10. Nd3 f5 11. Bd2'),
			moves => {
				'c7c5' => 1,
				'd7f6' => 1,
				'g8h8' => 1,
			},
		},
		'r1bq1rk1/pp1nn1bp/3p2p1/2pPpp2/2P1P3/2NN4/PP1BBPPP/R2Q1RK1 w -' => {
			eco => 'E98o',
			# TRANSLATORS: E98o: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 Nd7 10. Nd3 f5 11. Bd2 c5
			variation => N__('King\'s Indian: Mar del Plata, Fischer Variation'),
			moves => {
			},
		},
		'r1bq1r1k/pppnn1bp/3p2p1/3Ppp2/2P1P3/2NN4/PP1BBPPP/R2Q1RK1 w -' => {
			eco => 'E98p',
			# TRANSLATORS: E98p: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 Nd7 10. Nd3 f5 11. Bd2 Kh8
			variation => N__('King\'s Indian: Mar del Plata, 9. Ne1 Nd7 10. Nd3 f5 11. Bd2 Kh8'),
			moves => {
			},
		},
		'r1bq1rk1/ppp1n1bp/3p1np1/3Ppp2/2P1P3/2NN4/PP1BBPPP/R2Q1RK1 w -' => {
			eco => 'E98q',
			# TRANSLATORS: E98q: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 Nd7 10. Nd3 f5 11. Bd2 Nf6
			variation => N__('King\'s Indian: Mar del Plata, 9. Ne1 Nd7 10. Nd3 f5 11. Bd2 Nf6'),
			moves => {
			},
		},
		'r1bq1rk1/pppnnpbp/3p2p1/3Pp3/2P1P3/2N2P2/PP2B1PP/R1BQNRK1 b -' => {
			eco => 'E98r',
			# TRANSLATORS: E98r: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 Nd7 10. f3
			variation => N__('King\'s Indian: Mar del Plata, 9. Ne1 Nd7 10. f3'),
			moves => {
				'f7f5' => 1,
			},
		},
		'r1bq1rk1/pppnn1bp/3p2p1/3Ppp2/2P1P3/2N2P2/PP2B1PP/R1BQNRK1 w -' => {
			eco => 'E99',
			# TRANSLATORS: E99: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 Nd7 10. f3 f5
			variation => N__('King\'s Indian: Mar del Plata, 10. f3 f5'),
			moves => {
				'c1e3' => 1,
				'e1d3' => 1,
				'g2g4' => 1,
			},
		},
		'r1bq1rk1/pppnn1bp/3p2p1/3Ppp2/2P1P3/2N1BP2/PP2B1PP/R2QNRK1 b -' => {
			eco => 'E99',
			# TRANSLATORS: E99: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 Nd7 10. f3 f5 11. Be3
			variation => N__('King\'s Indian: Mar del Plata, 10. f3 f5 11. Be3'),
			moves => {
				'f5f4' => 1,
			},
		},
		'r1bq1rk1/pppnn1bp/3p2p1/3Pp3/2P1Pp2/2N1BP2/PP2B1PP/R2QNRK1 w -' => {
			eco => 'E99',
			# TRANSLATORS: E99: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 Nd7 10. f3 f5 11. Be3 f4
			variation => N__('King\'s Indian: Mar del Plata, 10. f3 f5 11. Be3 f4'),
			moves => {
				'e3f2' => 1,
			},
		},
		'r1bq1rk1/pppnn1bp/3p2p1/3Pp3/2P1Pp2/2N2P2/PP2BBPP/R2QNRK1 b -' => {
			eco => 'E99',
			# TRANSLATORS: E99: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 Nd7 10. f3 f5 11. Be3 f4 12. Bf2
			variation => N__('King\'s Indian: Mar del Plata, 10. f3 f5 11. Be3 f4'),
			moves => {
				'g6g5' => 1,
			},
		},
		'r1bq1rk1/pppnn1bp/3p4/3Pp1p1/2P1Pp2/2N2P2/PP2BBPP/R2QNRK1 w -' => {
			eco => 'E99',
			# TRANSLATORS: E99: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 Nd7 10. f3 f5 11. Be3 f4 12. Bf2 g5
			variation => N__('King\'s Indian: Mar del Plata, 10. f3 f5 11. Be3 f4 12. Bf2 g5'),
			moves => {
				'a2a4' => 1,
			},
		},
		'r1bq1rk1/pppnn1bp/3p4/3Pp1p1/P1P1Pp2/2N2P2/1P2BBPP/R2QNRK1 b -' => {
			eco => 'E99',
			# TRANSLATORS: E99: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 Nd7 10. f3 f5 11. Be3 f4 12. Bf2 g5 13. a4
			variation => N__('King\'s Indian: Mar del Plata, 10. f3 f5 11. Be3 f4 12. Bf2 g5 13. a4'),
			moves => {
				'e7g6' => 1,
			},
		},
		'r1bq1rk1/pppn2bp/3p2n1/3Pp1p1/P1P1Pp2/2N2P2/1P2BBPP/R2QNRK1 w -' => {
			eco => 'E99',
			# TRANSLATORS: E99: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 Nd7 10. f3 f5 11. Be3 f4 12. Bf2 g5 13. a4 Ng6
			variation => N__('King\'s Indian: Mar del Plata, 10. f3 f5 11. Be3 f4 12. Bf2 g5 13. a4 Ng6'),
			moves => {
			},
		},
		'r1bq1rk1/pppnn1bp/3p2p1/3Ppp2/2P1P3/2NN1P2/PP2B1PP/R1BQ1RK1 b -' => {
			eco => 'E99',
			# TRANSLATORS: E99: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 Nd7 10. f3 f5 11. Nd3
			variation => N__('King\'s Indian: Mar del Plata, 10. f3 f5 11. Nd3'),
			moves => {
				'd7f6' => 1,
				'f5f4' => 1,
			},
		},
		'r1bq1rk1/ppp1n1bp/3p1np1/3Ppp2/2P1P3/2NN1P2/PP2B1PP/R1BQ1RK1 w -' => {
			eco => 'E99',
			# TRANSLATORS: E99: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 Nd7 10. f3 f5 11. Nd3 Nf6
			variation => N__('King\'s Indian: Mar del Plata, 10. f3 f5 11. Nd3 Nf6'),
			moves => {
				'c1d2' => 1,
			},
		},
		'r1bq1rk1/ppp1n1bp/3p1np1/3Ppp2/2P1P3/2NN1P2/PP1BB1PP/R2Q1RK1 b -' => {
			eco => 'E99',
			# TRANSLATORS: E99: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 Nd7 10. f3 f5 11. Nd3 Nf6 12. Bd2
			variation => N__('King\'s Indian: Mar del Plata, 10. f3 f5 11. Nd3 Nf6 12. Bd2'),
			moves => {
				'f5f4' => 1,
			},
		},
		'r1bq1rk1/ppp1n1bp/3p1np1/3Pp3/2P1Pp2/2NN1P2/PP1BB1PP/R2Q1RK1 w -' => {
			eco => 'E99',
			# TRANSLATORS: E99: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 Nd7 10. f3 f5 11. Nd3 Nf6 12. Bd2 f4
			variation => N__('King\'s Indian: Mar del Plata, 10. f3 f5 11. Nd3 Nf6 12. Bd2 f4'),
			moves => {
				'c4c5' => 1,
			},
		},
		'r1bq1rk1/ppp1n1bp/3p1np1/2PPp3/4Pp2/2NN1P2/PP1BB1PP/R2Q1RK1 b -' => {
			eco => 'E99',
			# TRANSLATORS: E99: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 Nd7 10. f3 f5 11. Nd3 Nf6 12. Bd2 f4 13. c5
			variation => N__('King\'s Indian: Mar del Plata, 10. f3 f5 11. Nd3 Nf6 12. Bd2 f4 13. c5'),
			moves => {
			},
		},
		'r1bq1rk1/pppnn1bp/3p2p1/3Pp3/2P1Pp2/2NN1P2/PP2B1PP/R1BQ1RK1 w -' => {
			eco => 'E99',
			# TRANSLATORS: E99: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 Nd7 10. f3 f5 11. Nd3 f4
			variation => N__('King\'s Indian: Mar del Plata, 10. f3 f5 11. Nd3 f4'),
			moves => {
			},
		},
		'r1bq1rk1/pppnn1bp/3p2p1/3Ppp2/2P1P1P1/2N2P2/PP2B2P/R1BQNRK1 b -' => {
			eco => 'E99',
			# TRANSLATORS: E99: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 Nd7 10. f3 f5 11. g4
			variation => N__('King\'s Indian: Mar del Plata, Benko Attack'),
			moves => {
				'd7f6' => 1,
				'g8h8' => 1,
			},
		},
		'r1bq1rk1/ppp1n1bp/3p1np1/3Ppp2/2P1P1P1/2N2P2/PP2B2P/R1BQNRK1 w -' => {
			eco => 'E99',
			# TRANSLATORS: E99: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 Nd7 10. f3 f5 11. g4 Nf6
			variation => N__('King\'s Indian: Mar del Plata, Benko Attack, 11... Nf6'),
			moves => {
				'e1d3' => 1,
			},
		},
		'r1bq1rk1/ppp1n1bp/3p1np1/3Ppp2/2P1P1P1/2NN1P2/PP2B2P/R1BQ1RK1 b -' => {
			eco => 'E99',
			# TRANSLATORS: E99: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 Nd7 10. f3 f5 11. g4 Nf6 12. Nd3
			variation => N__('King\'s Indian: Mar del Plata, Benko Attack, 11... Nf6 12. Nd3'),
			moves => {
			},
		},
		'r1bq1r1k/pppnn1bp/3p2p1/3Ppp2/2P1P1P1/2N2P2/PP2B2P/R1BQNRK1 w -' => {
			eco => 'E99',
			# TRANSLATORS: E99: 1. d4 Nf6 2. c4 g6 3. Nc3 Bg7 4. e4 d6 5. Nf3 O-O 6. Be2 e5 7. O-O Nc6 8. d5 Ne7 9. Ne1 Nd7 10. f3 f5 11. g4 Kh8
			variation => N__('King\'s Indian: Mar del Plata, Benko Attack, 11... Kh8'),
			moves => {
			},
		},
	};
}

1;

=head1 NAME

Chess::Opening::ECO - ECO data

=head1 SYNOPSIS

	use Chess::Opening::ECO;

	$positions = Chess::Opening::ECO->positions;

=head1 DESCRIPTION

This module is a mere container for the ECO (Encyclopedia of Chess Openings)
data.  You should rather use one the high-level interface
L<Chess::Opening::Book::ECO> for accessing or browsing the data contained here.

=head1 METHODS

=over 4

=item B<positions>

This is the only method in this module.  You can call it as a class method
or simply as C<Chess::Opening::ECO::Data>.  It returns a reference to a hash
of opening positions.  The keys of this hash are the positions in
Forsyth-Edwards Notation (FEN).  The values have four items:

=over 8

=item B<eco>

The ECO code of the position.  Note that these codes contain the so-called
"Scid Extensions to ECO", see L<http://scidvspc.sourceforge.net/doc/ECO.htm>.
If you are only interested in the pure ECO code, strip off everything after
the third character.

=item B<variation>

The name of the variation (like "Sicilian", "El Greco", and so on).  Note that
this is always the English name of the variation.  Use L<Chess::Opening::ECO>
if you want to have them translated into the user's language.

=item B<parent>

The parent position as FEN or C<undef> for the starting position.

=item B<moves>

A reference to a possibly empty array of moves that lead from this position
to other opening positions.

=back

=back

=head1 COPYRIGHT

Copyright (C) 2019 Guido Flohr <guido.flohr@cantanea.com>,
all rights reserved.

=head1 SEE ALSO

L<Chess::Opening::Book::ECO>, L<Chess::Opening::Book::Entry>, perl(1)
